(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    497356,      13612]*)
(*NotebookOutlinePosition[    516877,      14028]*)
(*  CellTagsIndexPosition[    516461,      14016]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
  "Control Chart for Variables 1.0\n",
  StyleBox["by Guillermo Sanchez, guillerm@gugu.usal.es",
    FontSize->18,
    FontWeight->"Plain"],
  " "
}], "Title"],

Cell["Introduction (Loading the package)", "Section",
  CellTags->"Introduction (Loading the package)"],

Cell[TextData[{
  StyleBox["Control chart",
    FontWeight->"Bold"],
  " is a statistic tool to distinguish when a process is ",
  StyleBox["out of control",
    FontWeight->"Bold"],
  ".   A control chart requires data obtained by sampling a specific quality \
characteristic of the process at approximately regular intervals. The \
intervals may be defined in terms of time (for example hourly) or quantity \
(every lot). Every sampling is usually is named  \"subgroup\", each subgroup \
consists of the same measure units and the same subgroup size.  One o more \
parameters are derived from each subgroup such as: the subgroup average,  ",
  Cell[BoxData[
      \(TraditionalForm\`X\&_\)]],
  ", subgroup standards deviation, ",
  StyleBox["s",
    FontSlant->"Italic"],
  ", etc.   \nShewhart control chart, and others, contains a center line (CL) \
 that represents the average value of the quality characteristics, and two \
other horizontal lines, called the upper control limit (UCL) and the lower \
control limit (LCL). The Shewhart Control Charts (ex.: XbarS) only use the \
information of the process contained in the last subgroup. To detect \
systematic manner it is necessary introduce additional criteria. This makes \
the  Shewhart CC relatively insensitive to small shifts in the process. Two \
alternative kind of control charts may be used to detect small shifts: Cusum \
and EWMA. \nWhen the quality characteristic is measured using a scale is said \
that it is a ",
  StyleBox["variable",
    FontWeight->"Bold"],
  ". The result of measurements can be represented by a list of data ."
}], "Text",
  CellTags->"Introduction (Loading the package)"],

Cell["Download the package", "Subsection",
  CellTags->"Introduction (Loading the package)"],

Cell["\<\
This package can be used to make the most known variable control charts: \
Xbar-S, Individuals, Cusum and EWMA for individual values, T2 Multivariable. \
The package is downloaded as usual: \
\>", "Text",
  CellTags->"Introduction (Loading the package)"],

Cell[BoxData[
    \(Needs["\<QualityControl`VariableChart`\>"]\)], "Input",
  CellLabel->"In[1]:=",
  CellTags->"Introduction (Loading the package)"],

Cell[TextData[{
  "(It dawnload also the packages: ",
  StyleBox["MultiDescriptiveStatistics ",
    FontFamily->"Courier New"],
  StyleBox["and",
    FontFamily->"Times New Roman"],
  StyleBox[" MultipleListPlot",
    FontFamily->"Courier New"],
  StyleBox[")",
    FontFamily->"Times New Roman"]
}], "Text",
  CellTags->"Introduction (Loading the package)"],

Cell["Mean and standard deviation chart", "Section",
  PageWidth->PaperWidth,
  PageBreakBelow->False,
  CellTags->"Mean and standard deviation chart"],

Cell["Introduction", "Subsection",
  PageBreakBelow->False,
  CellTags->"Mean and standard deviation chart"],

Cell[TextData[{
  "This kind of control chart , also known as ",
  Cell[BoxData[
      \(TraditionalForm\`X\&_\)]],
  ",",
  StyleBox["s",
    FontSlant->"Italic"],
  " charts or Xbar-S Chart, calculate the average, ",
  Cell[BoxData[
      \(TraditionalForm\`X\&_\_k\)]],
  ",  and standard deviation, ",
  Cell[BoxData[
      \(TraditionalForm\`s\_k\)]],
  " for each subgroup ",
  StyleBox["k",
    FontSlant->"Italic"],
  " . "
}], "Text",
  PageBreakBelow->False,
  CellTags->"Mean and standard deviation chart"],

Cell[TextData[{
  "The limits (UCL and LCL)  and center line (CL) are estimated depending of \
the situation",
  StyleBox[
  ": If standards values are unknown and must be estimated or if standards \
values are given.  ",
    FontFamily->"Times New Roman"],
  "Table 1 gives the formulae for both situation."
}], "Text",
  PageBreakBelow->False,
  CellTags->"Mean and standard deviation chart"],

Cell[TextData[{
  "Table 1.- Formulae for ",
  Cell[BoxData[
      \(TraditionalForm\`X\&_\)]],
  ",",
  StyleBox["s",
    FontSlant->"Italic"],
  StyleBox[" ",
    FontSlant->"Italic"],
  "charts"
}], "Text",
  PageBreakBelow->False,
  TextAlignment->Center,
  TextJustification->0,
  CellTags->"Mean and standard deviation chart"],

Cell[TextData[Cell[BoxData[GridBox[{
        {
          StyleBox[\(\(Stad\)\(.\)\),
            FontWeight->"Bold"], 
          StyleBox[
            SuperscriptBox["CL", 
              StyleBox["1",
                FontWeight->"Plain"]],
            FontWeight->"Bold"], 
          RowBox[{
            StyleBox[\(LC  L\  &\),
              FontWeight->"Bold"], 
            StyleBox[" ",
              FontWeight->"Bold"], 
            SuperscriptBox[
              StyleBox["UCL",
                FontWeight->"Bold"], "1"]}], 
          SuperscriptBox[
            StyleBox["CL",
              FontWeight->"Bold"], "2"], 
          RowBox[{
            StyleBox[" ",
              FontWeight->"Bold"], 
            RowBox[{
              StyleBox[\(LCL\  &\),
                FontWeight->"Bold"], 
              StyleBox[" ",
                FontWeight->"Bold"], 
              SuperscriptBox[
                StyleBox["UCL",
                  FontWeight->"Bold"], "2"]}]}]},
        {
          StyleBox[\(X\&-\),
            FontSlant->"Italic"], 
          StyleBox[\(\(\ \)\(\(X\&_\)\&_\)\),
            FontSlant->"Italic"], 
          RowBox[{\(\(X\&_\)\&_\), "\[PlusMinus]", 
            RowBox[{
              SubscriptBox[
                StyleBox["A",
                  FontSlant->"Italic"], "3"], 
              StyleBox[
                OverscriptBox[
                  StyleBox["s",
                    FontSlant->"Italic"], "_"],
                FontSlant->"Italic"]}]}], 
          RowBox[{
            SubscriptBox[
              StyleBox["X",
                FontSlant->"Italic"], "0"], "or", " ", "\[Mu]"}], 
          RowBox[{
            SubscriptBox[
              StyleBox["X",
                FontSlant->"Italic"], "0"], "\[PlusMinus]", 
            RowBox[{
              StyleBox["A",
                FontSlant->"Italic"], 
              StyleBox[" ",
                FontSlant->"Italic"], \(\[Sigma]\_0\)}]}]},
        {
          StyleBox["s",
            FontSlant->"Italic"], 
          RowBox[{" ", 
            StyleBox[\(s\&_\),
              FontSlant->"Italic"]}], 
          RowBox[{
            RowBox[{
              SubscriptBox[
                StyleBox["B",
                  FontSlant->"Italic"], "3"], 
              StyleBox[\(s\&_\),
                FontSlant->"Italic"]}], 
            StyleBox[",",
              FontSlant->"Italic"], 
            RowBox[{
              SubscriptBox[
                StyleBox["B",
                  FontSlant->"Italic"], "4"], 
              StyleBox[\(s\&_\),
                FontSlant->"Italic"]}]}], 
          RowBox[{
            SubscriptBox[
              StyleBox["s",
                FontSlant->"Italic"], "0"], "or", " ", 
            StyleBox[\(c\_4\),
              FontSlant->"Italic"], 
            StyleBox[" ",
              FontSlant->"Italic"], \(\[Sigma]\_0\)}], 
          RowBox[{
            RowBox[{
              SubscriptBox[
                StyleBox["B",
                  FontSlant->"Italic"], "5"], \(\[Sigma]\_0\)}], ",", 
            RowBox[{
              SubscriptBox[
                StyleBox["B",
                  FontSlant->"Italic"], "6"], \(\[Sigma]\_0\)}]}]}
        },
      GridFrame->True,
      RowLines->True,
      ColumnLines->True]]]], "Text",
  PageWidth->PaperWidth,
  PageBreakBelow->False,
  TextAlignment->Center,
  TextJustification->0,
  CellTags->"Mean and standard deviation chart"],

Cell[TextData[{
  StyleBox["(1) No standards values given.",
    FontSize->10],
  Cell[BoxData[
      RowBox[{" ", 
        OverscriptBox[
          OverscriptBox[
            StyleBox["X",
              FontSlant->"Italic"], "_"], "_"]}]],
    FontSize->10],
  StyleBox[",  and ",
    FontSize->10],
  Cell[BoxData[
      StyleBox[
        OverscriptBox[
          StyleBox["s",
            FontSlant->"Italic"], "_"],
        FontSlant->"Italic"]],
    FontSize->10],
  StyleBox[" must be calculated, where",
    FontSize->10],
  Cell[BoxData[
      RowBox[{" ", 
        OverscriptBox[
          OverscriptBox[
            StyleBox["X",
              FontSlant->"Italic"], "_"], "_"]}]],
    FontSize->10],
  StyleBox[" and ",
    FontSize->10],
  Cell[BoxData[
      StyleBox[
        OverscriptBox[
          StyleBox["s",
            FontSlant->"Italic"], "_"],
        FontSlant->"Italic"]],
    FontSize->10],
  StyleBox[" are the average of {",
    FontSize->10],
  Cell[BoxData[
      \(TraditionalForm\`X\&_\_k\)],
    FontSize->10],
  StyleBox["} and {",
    FontSize->10],
  Cell[BoxData[
      \(TraditionalForm\`s\_k\)],
    FontSize->10],
  StyleBox["}, respectively.",
    FontSize->10],
  Cell[BoxData[
      FormBox[
        OverscriptBox[
          FormBox[\(X\&_\),
            "TraditionalForm"], "_"], TraditionalForm]]],
  StyleBox["  is often called great mean.",
    FontSize->10],
  "\n",
  StyleBox["(2) ",
    FontSize->10],
  Cell[BoxData[
      SubscriptBox[
        StyleBox["X",
          FontSlant->"Italic"], "0"]],
    FontSize->10],
  StyleBox[",  \[Mu],  ",
    FontSize->10],
  Cell[BoxData[
      \(\[Sigma]\_0\)],
    FontSize->10],
  StyleBox[", and ",
    FontSize->10],
  Cell[BoxData[
      RowBox[{
        SubscriptBox[
          StyleBox["s",
            FontSlant->"Italic"], "0"], " "}]],
    FontSize->10],
  StyleBox["are given standard values.",
    FontSize->10]
}], "Text",
  PageWidth->PaperWidth,
  PageBreakBelow->False,
  TextAlignment->Left,
  TextJustification->0,
  CellTags->"Mean and standard deviation chart"],

Cell[TextData[{
  Cell[BoxData[
      StyleBox["A",
        FontSlant->"Italic"]]],
  ", ",
  Cell[BoxData[
      SubscriptBox[
        StyleBox["A",
          FontSlant->"Italic"], "3"]]],
  ", ",
  Cell[BoxData[
      SubscriptBox[
        StyleBox["B",
          FontSlant->"Italic"], "3"]]],
  " ,",
  Cell[BoxData[
      SubscriptBox[
        StyleBox["B",
          FontSlant->"Italic"], "4"]]],
  ", ",
  Cell[BoxData[
      SubscriptBox[
        StyleBox["B",
          FontSlant->"Italic"], "5"]]],
  ", ",
  Cell[BoxData[
      SubscriptBox[
        StyleBox["B",
          FontSlant->"Italic"], "6"]]],
  ", ",
  Cell[BoxData[
      SubscriptBox[
        StyleBox["D",
          FontSlant->"Italic"], "1"]]],
  ", ",
  Cell[BoxData[
      SubscriptBox[
        StyleBox["D",
          FontSlant->"Italic"], "2"]]],
  " and ",
  Cell[BoxData[
      StyleBox[\(c\_4\),
        FontSlant->"Italic"]]],
  " are tabulated in many statistics books and standards (ex.: ISO \
8258:1991(E)). We can also expressed analytically:"
}], "Text",
  PageBreakBelow->False,
  CellTags->"Mean and standard deviation chart"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`c\_\(\(4\)\(\ \)\)\)]],
  "= ",
  Cell[BoxData[
      \(TraditionalForm\`\@\(2\/\(m - 1\)\)\)]],
  Cell[BoxData[
      \(TraditionalForm
      \`\(\[CapitalGamma](m/2)\)\/\[CapitalGamma][\((m - 1)\)/2]\)]],
  StyleBox["A",
    FontSlant->"Italic"],
  " = 3/",
  Cell[BoxData[
      \(TraditionalForm\`\@m\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`A\_3\)]],
  " = 3/(",
  Cell[BoxData[
      \(TraditionalForm\`\(c\_\(\(4\)\(\ \)\)\) \@m\)]],
  "), "
}], "Text",
  PageBreakBelow->False,
  CellTags->"Mean and standard deviation chart"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`B\_3\)]],
  " =   1 - ",
  Cell[BoxData[
      \(TraditionalForm\`3\/c\_4\)]],
  Cell[BoxData[
      \(TraditionalForm\`\@\(1 - c\_4\%2\)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`B\_4\)]],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \) \)\)]],
  " 1 + ",
  Cell[BoxData[
      \(TraditionalForm\`3\/c\_4\)]],
  Cell[BoxData[
      \(TraditionalForm\`\@\(1 - c\_4\%2\)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`B\_5\)]],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`c\_4\)]],
  "- 3",
  Cell[BoxData[
      \(TraditionalForm\`\@\(1 - c\_4\%2\)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`B\_6\)]],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`c\_4\)]],
  "+ 3",
  Cell[BoxData[
      \(TraditionalForm\`\@\(1 - c\_4\%2\)\)]]
}], "Text",
  PageBreakBelow->False,
  CellTags->"Mean and standard deviation chart"],

Cell[TextData[{
  "The package  gives a general report, a short report, and plot the control \
chart using the values from ",
  StyleBox["data",
    FontSlant->"Italic"],
  ". "
}], "Text",
  CellTags->"Mean and standard deviation chart"],

Cell[TextData[{
  StyleBox["data",
    FontSlant->"Italic"],
  " = {{",
  Cell[BoxData[
      \(TraditionalForm\`X\_11\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`X\_12\)]],
  ", ..., ",
  Cell[BoxData[
      \(TraditionalForm\`X\_\(1  m\)\)]],
  "}, {",
  Cell[BoxData[
      \(TraditionalForm\`X\_21\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`X\_22\)]],
  ", ..., ",
  Cell[BoxData[
      \(TraditionalForm\`X\_\(2  m\)\)]],
  "}, ..., {",
  Cell[BoxData[
      FormBox[
        SubscriptBox["X", 
          StyleBox[
            RowBox[{
              StyleBox["k",
                FontSlant->"Italic"], "1"}]]], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["X", 
          StyleBox[
            RowBox[{
              StyleBox["k",
                FontSlant->"Italic"], "2"}]]], TraditionalForm]]],
  ", ..., ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["X", 
          StyleBox["ki",
            FontSlant->"Italic"]], TraditionalForm]]],
  ", ...,",
  Cell[BoxData[
      FormBox[
        StyleBox[\(X\_km\),
          FontSlant->"Italic"], TraditionalForm]]],
  "}, ...}, where ",
  StyleBox["k",
    FontSlant->"Italic"],
  " is the subgroup, and ",
  StyleBox["i",
    FontSlant->"Italic"],
  " the observation in each subgroup. It is assumed that the size of \
subgroups is the same and  ",
  StyleBox["m",
    FontSlant->"Italic"],
  ">1."
}], "Text",
  CellTags->"Mean and standard deviation chart"],

Cell["X bar S chart for no standard values given (Initial Study)", 
  "Subsection",
  CellTags->"Mean and standard deviation chart"],

Cell[TextData[{
  "Mean and deviation of process are calculated using ",
  StyleBox["data",
    FontSlant->"Italic"],
  " values"
}], "Text",
  CellTags->"Mean and standard deviation chart"],

Cell[TextData[{
  "XbarSReportSh[",
  StyleBox["data",
    FontSlant->"Italic"],
  "] \t\tgive CL, LCL, UCL for X and for s\n\nXbarSReport[",
  StyleBox["data",
    FontSlant->"Italic"],
  "] \t\tgive ",
  Cell[BoxData[
      FormBox[
        FormBox[\(X\&_\_k\),
          "TraditionalForm"], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`s\_k\)]],
  " CL, LCL, UCL for X and for s\n\nXbarSChart[",
  StyleBox["data",
    FontSlant->"Italic"],
  "] \t\tplots the Control Chart"
}], "DefinitionBox",
  CellTags->"Mean and standard deviation chart"],

Cell["X bar S chart for standard values given ", "Subsection",
  CellTags->"Mean and standard deviation chart"],

Cell[TextData[{
  "Mean, ",
  StyleBox["mu",
    FontSlant->"Italic"],
  ",  and deviation, ",
  StyleBox["sig",
    FontSlant->"Italic"],
  ",  of process are supposed that are known."
}], "Text",
  CellTags->"Mean and standard deviation chart"],

Cell[TextData[{
  "XbarSReportShSG[",
  StyleBox["data",
    FontSlant->"Italic"],
  ", ",
  StyleBox["mu, sig",
    FontSlant->"Italic"],
  "] \tgives CL, LCL, UCL for X and for s\n\nXbarSReportSG[",
  StyleBox["data",
    FontSlant->"Italic"],
  ", ",
  StyleBox["mu, sig",
    FontSlant->"Italic"],
  "] \tgives ",
  Cell[BoxData[
      FormBox[
        FormBox[\(X\&_\_k\),
          "TraditionalForm"], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`s\_k\)]],
  " CL, LCL, UCL for X and for s\n\nXbarSChartSG[",
  StyleBox["data",
    FontSlant->"Italic"],
  ", ",
  StyleBox["mu, sig",
    FontSlant->"Italic"],
  "] \t\tplots the Control Charts for X and s"
}], "DefinitionBox",
  CellTags->"Mean and standard deviation chart"],

Cell["Examples ", "Subsection",
  PageBreakBelow->False,
  CellTags->"Mean and standard deviation chart"],

Cell[BoxData[
    \(\(data1\  = 
        {{5.65, 5.71, 4.76, 4.64, 5.92}, {4.43, 7.03, 4.34, 3.77, 4.03}, 
          {5.54, 4.1, 7.75, 4.18, 4.79}, {5.26, 5.45, 3.09, 5.37, 5.16}, 
          {5.41, 4.06, 5.53, 6.09, 5.64}, {4.44, 4.81, 4.11, 4.56, 6.14}, 
          {3.09, 5.66, 4.06, 4.78, 4.72}, {4.05, 4.89, 6.85, 6.96, 4.16}, 
          {3.71, 4.63, 6.83, 5.32, 4.46}, {3.68, 3.7, 5.75, 6.66, 5.51}, 
          {7.21, 5.38, 4.29, 3.93, 4.04}, {5.42, 5.16, 4.67, 4.41, 3.55}, 
          {4.21, 3.58, 4.43, 4.17, 5.46}, {4.83, 3.40, 6.4, 4.0, 4.02}, 
          {5.57, 5.12, 5.05, 4.68, 3.61}, {2.5, 3.87, 4.68, 6.19, 5.19}, 
          {4.64, 5.41, 4.48, 6.45, 3.99}, {5.47, 6.14, 5.24, 4.37, 5.74}, 
          {3.89, 4.65, 6.03, 5.39, 3.84}, {5.35, 5.85, 6.52, 6.53, 5.41}};
      \)\)], "Input",
  CellLabel->"In[2]:=",
  PageBreakBelow->False,
  CellTags->"Mean and standard deviation chart"],

Cell["No standard values given", "Subsubsection",
  CellTags->"Mean and standard deviation chart"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?XbarSReport\)\)], "Input",
  CellLabel->"In[3]:=",
  CellTags->"Mean and standard deviation chart"],

Cell["\<\
XbarSReport[list] give the full report for a
   XbarS chart, no standard given.\
\>", "Print",
  CellLabel->"From In[3]:=",
  CellTags->"Mean and standard deviation chart"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(XbarSReport[data1]\)], "Input",
  CellLabel->"In[4]:=",
  CellTags->"Mean and standard deviation chart"],

Cell[OutputFormData["\<\
{{\"Subgroup\", \"Xmean\", \"S\"}, 
 {1, 5.336, 0.5907029710438235}, 
 {2, 4.720000000000001, 
  1.3174976280813564}, {3, 5.272, 
  1.5008897361232105}, 
 {4, 4.8660000000000005, 
  0.9988643551553936}, {5, 5.346, 
  0.7634985265211717}, 
 {6, 4.811999999999999, 
  0.7839451511426037}, {7, 4.462, 
  0.9548403007833302}, {8, 5.382, 
  1.4278200166687676}, 
 {9, 4.99, 1.1772213045982476}, 
 {10, 5.06, 1.322176236361855}, 
 {11, 4.97, 1.3779150917237244}, 
 {12, 4.642, 0.7281277360463616}, 
 {13, 4.37, 0.6858206762704081}, 
 {14, 4.53, 1.1624112869376313}, 
 {15, 4.806, 0.7396147645903238}, 
 {16, 4.486000000000001, 
  1.3928854942169513}, {17, 4.994, 
  0.9605363085276891}, {18, 5.392, 
  0.6622461777919143}, {19, 4.76, 
  0.9519978991573459}, {20, 5.932, 
  0.5747347214150195}, {\"CL\", 4.9564, 
  1.0036873191578564}, 
 {\"LCL\", 3.5238377990509964, 0}, 
 {\"UCL\", 6.388962200949004, 
  2.0967006704920057}}\
\>", "\<\
Subgroup   Xmean     S

1          5.336     0.590703

2          4.72      1.3175

3          5.272     1.50089

4          4.866     0.998864

5          5.346     0.763499

6          4.812     0.783945

7          4.462     0.95484

8          5.382     1.42782

9          4.99      1.17722

10         5.06      1.32218

11         4.97      1.37792

12         4.642     0.728128

13         4.37      0.685821

14         4.53      1.16241

15         4.806     0.739615

16         4.486     1.39289

17         4.994     0.960536

18         5.392     0.662246

19         4.76      0.951998

20         5.932     0.574735

CL         4.9564    1.00369

LCL        3.52384   0

UCL        6.38896   2.0967\
\>"], "Output",
  CellLabel->"Out[4]//TableForm=",
  CellTags->"Mean and standard deviation chart"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?XbarSReportSh\)\)], "Input",
  CellLabel->"In[5]:=",
  CellTags->"Mean and standard deviation chart"],

Cell["\<\
XbarSReportSh[list] give the short report
   for a XbarS chart, no standard given.\
\>", "Print",
  CellLabel->"From In[5]:=",
  CellTags->"Mean and standard deviation chart"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(XbarSReportSh[data1]\)], "Input",
  CellLabel->"In[6]:=",
  CellTags->"Mean and standard deviation chart"],

Cell[OutputFormData["\<\
{{\"\", \"X\", \"S\"}, {\"CL\", 4.9564, 
  1.0036873191578564}, 
 {\"LCL\", 3.5238377990509964, 0}, 
 {\"UCL\", 6.388962200949004, 
  2.0967006704920057}}\
\>", "\<\
      X         S

CL    4.9564    1.00369

LCL   3.52384   0

UCL   6.38896   2.0967\
\>"], "Output",
  CellLabel->"Out[6]//TableForm=",
  CellTags->"Mean and standard deviation chart"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(\[IndentingNewLine]\)\(?XbarSChart\)\)\)], "Input",
  CellLabel->"In[7]:=",
  CellTags->"Mean and standard deviation chart"],

Cell["\<\
XbarSChart[list] plot the XbarChart of the
   entries in list ,no standard given.\
\>", "Print",
  CellLabel->"From In[7]:=",
  CellTags->"Mean and standard deviation chart"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(XbarSChart[data1]\)], "Input",
  CellLabel->"In[8]:=",
  CellTags->"Mean and standard deviation chart"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.047619 -0.454656 0.154078 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -6 -9 ]
[.5 -0.0125 6 0 ]
[.7381 -0.0125 -6 -9 ]
[.7381 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -26 -21.5625 ]
[.5 -0.0125 26 -9 ]
[-0.0125 .00758 -6 -4.5 ]
[-0.0125 .00758 0 4.5 ]
[-0.0125 .16166 -6 -4.5 ]
[-0.0125 .16166 0 4.5 ]
[-0.0125 .31573 -6 -4.5 ]
[-0.0125 .31573 0 4.5 ]
[-0.0125 .46981 -6 -4.5 ]
[-0.0125 .46981 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -18.5625 -5 ]
[-0.01875 .30902 -6 5 ]
[.5 .63053 -101 0 ]
[.5 .63053 101 25.75 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .30902 m
1 .30902 L
s
0 .08829 m
1 .08829 L
s
0 .52974 m
1 .52974 L
s
0 g
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(10)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(15)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(20)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -87 -25.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(subgroup) show
111.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .00758 m
.00625 .00758 L
s
[(3)] -0.0125 .00758 1 0 Mshowa
0 .16166 m
.00625 .16166 L
s
[(4)] -0.0125 .16166 1 0 Mshowa
0 .31573 m
.00625 .31573 L
s
[(5)] -0.0125 .31573 1 0 Mshowa
0 .46981 m
.00625 .46981 L
s
[(6)] -0.0125 .46981 1 0 Mshowa
.125 Mabswid
0 .03839 m
.00375 .03839 L
s
0 .06921 m
.00375 .06921 L
s
0 .10003 m
.00375 .10003 L
s
0 .13084 m
.00375 .13084 L
s
0 .19247 m
.00375 .19247 L
s
0 .22329 m
.00375 .22329 L
s
0 .2541 m
.00375 .2541 L
s
0 .28492 m
.00375 .28492 L
s
0 .34655 m
.00375 .34655 L
s
0 .37737 m
.00375 .37737 L
s
0 .40818 m
.00375 .40818 L
s
0 .439 m
.00375 .439 L
s
0 .50063 m
.00375 .50063 L
s
0 .53144 m
.00375 .53144 L
s
0 .56226 m
.00375 .56226 L
s
0 .59308 m
.00375 .59308 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -78.2813 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
66 10.2813 translate
90 rotate
-66 -10.2813 translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(X) show
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 7.375 moveto
(\\217) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -162 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 33.75 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(X) show
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 7.375 moveto
(\\217) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(values) show
117.000 12.813 moveto
(for) show
141.000 12.813 moveto
(XbarS) show
177.000 12.813 moveto
(Control) show
225.000 12.813 moveto
(chart) show
255.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
63.000 26.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Initial) show
111.000 26.000 moveto
(Study) show
141.000 26.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.07143 .36751 m
.11905 .27259 L
.16667 .35764 L
.21429 .29509 L
.2619 .36905 L
.30952 .28677 L
.35714 .23284 L
.40476 .37459 L
.45238 .31419 L
.5 .32498 L
.54762 .31111 L
.59524 .26057 L
.64286 .21867 L
.69048 .24332 L
.7381 .28584 L
.78571 .23654 L
.83333 .31481 L
.88095 .37613 L
.92857 .27876 L
.97619 .45934 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[8]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012Q000`40O003h00Oogoo/Goo003oOona
Ool00?mook5oo`00h7oo10007goo0`00ZWoo003TOol00`00Oomoo`0MOol00`00Oomoo`2YOol00>Ao
o`03001oogoo01eoo`03001oogoo0:Uoo`00aGoo1@001Goo0`0000Aoo`00001oo`800004Ool00000
0004Ool300000goo001oo`03Ool50005Ool40005Ool300000goo00000002Ool00`00Ool00002002W
Ool00<Eoo`03001oogoo009oo`05001oogooOol00003Ool20003Ool20003Ool01000Oomoo`000goo
0P001Goo00<007ooOol01Goo00<007ooOol00Woo00D007ooOomoo`0000=oo`8000=oo`8000=oo`03
001oogoo0:Aoo`00bWoo00D007ooOomoo`0000Aoo`05001oogooOol00004Ool01000Oomoo`0017oo
00<007ooOol00goo00<007ooOol01Goo00<007ooOol00Woo00D007ooOomoo`0000Aoo`05001oogoo
Ool00004Ool00`00Oomoo`2TOol00<Ioo`@000Aoo`03001oogoo009oo`05001oogooOol00004Ool0
1000Oomoo`0017oo00<007ooOol00goo00<007ooOol01Goo00<007ooOol00Woo00D007ooOomoo`00
00Aoo`05001oogooOol00004Ool00`00Oomoo`2TOol00<Eoo`03001oogoo009oo`05001oogooOol0
0004Ool01000Oomoogoo0P000goo00@007ooOol000=oo`8000Eoo`8000Ioo`03001oogoo009oo`05
001oogooOol00004Ool01000Oomoogoo0P000goo00<007ooOol0Y7oo0036Ool50002Ool20003Ool2
0003Ool00`00Ool000020004Ool300000goo00000003Ool2000017oo0000000017oo10000goo0P00
0goo0P000Woo0P0000Aoo`0000000:Moo`00egoo00<007ooOol0eWoo003GOol00`00Oomoo`3FOol0
0=Ioo`800=Qoo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol005Aoo`@004Ao
o`@003moo`L000=oo`@003Yoo`L000=oo`@003Yoo`H000Aoo`@003=oo`00Dgoo00<007ooOol00Woo
00<007ooOol0@7oo00<007ooOol00Woo00<007ooOol0?goo00<007ooOol00goo00<007ooOol00Woo
00<007ooOol0>Woo00<007ooOol00goo00<007ooOol00Woo00<007ooOol0=goo00<007ooOol00Woo
00D007ooOomoo`0000Aoo`03001oogoo031oo`00Dgoo00<007ooOol00Woo00<007ooOol0AGoo00<0
07ooOol0?goo00<007ooOol00goo00<007ooOol00Woo00<007ooOol0>Woo00<007ooOol027oo00<0
07ooOol0>7oo00<007ooOol01Goo00<007ooOol00Woo00<007ooOol0<7oo001COol00`00Oomoo`02
Ool00`00Oomoo`15Ool00`00Oomoo`0oOol00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`0j
Ool00`00Oomoo`08Ool00`00Oomoo`0iOol00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`0`
Ool005=oo`03001oogoo009oo`03001oogoo04Eoo`03001oogoo03moo`03001oogoo00=oo`03001o
ogoo009oo`03001oogoo03Yoo`03001oogoo00Qoo`03001oogoo03Yoo`03001oogoo00=oo`03001o
ogoo009oo`03001oogoo031oo`00Dgoo00<007ooOol00Woo00<007ooOol0@Goo1000@Woo00<007oo
Ool00goo00<007ooOol00Woo00<007ooOol0>Woo00<007ooOol017oo1000?Woo00<007ooOol00Woo
00<007ooOol00Woo00<007ooOol0<7oo001COol00`00Oomoo`02Ool00`00Oomoo`11Ool00`00Oomo
o`13Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`0jOol00`00Oomoo`04Ool00`00Oomo
o`0kOol00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol0<7oo001COol00`00Oomoo`02
Ool00`00Oomoo`11Ool00`00Oomoo`11Ool30005Ool00`00Oomoo`02Ool00`00Oomoo`0hOol30006
Ool00`00Oomoo`0kOol00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol0<7oo001DOol4
0014Ool50011Ool00`00Oomoo`04Ool4000mOol00`00Oomoo`04Ool5000jOol40005Ool4000cOol0
0?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol004Eoo`@00?moofQo
o`00A7oo00<007ooOol00Woo00<007ooOol00gooo`00<@00<Goo0019Ool00`00Oomoo`03Ool00`00
Oomoo`05Ool00`00Oomoo`0;Ool00`00Oomoo`0;Ool00`00Oomoo`0<Ool00`00Oomoo`0;Ool00`00
Oomoo`0<Ool00`00Oomoo`0;Ool00`00Oomoo`0<Ool00`00Oomoo`0;Ool00`00Oomoo`0;Ool00`00
Oomoo`0<Ool00`00Oomoo`0;Ool00`00Oomoo`0<Ool00`00Oomoo`0;Ool00`00Oomoo`0<Ool00`00
Oomoo`0;Ool00`00Oomoo`0;Ool00`00Oomoo`0<Ool00`00Oomoo`0;Ool00`00Oomoo`0<Ool00`00
Oomoo`0;Ool00`00Oomoo`0fOol004Uoo`03001oogoo00=oo`<000Eoo`03001oogoo04Eoo`03001o
ogoo04Eoo`03001oogoo04Eoo`03001oogoo04Eoo`03001oogoo03Ioo`00Agoo0P001Woo00<007oo
Ool0ogooGgoo0019Ool00`00Oomoo`03Ool00`00Oomoo`3oOomOOol004Uoo`03001oogoo00=oo`03
001oogoo0?mooemoo`00A7oo00<007ooOol00Woo00<007ooOol00goo00<007ooOol0ogooGgoo0015
Ool40006Ool00`00Oomoo`3oOomOOol004moo`03001oogoo0?mooemoo`00Cgoo00<007ooOol0ogoo
Ggoo001?Ool00`00Oomoo`3oOomOOol004moo`800?moof1oo`00Cgoo00<007ooOol0ogooGgoo001?
Ool00`00Oomoo`3oOomOOol004moo`03001oogoo0?mooemoo`00Cgoo00<007ooOol0ogooGgoo001?
Ool00`00Oomoo`3oOomOOol004moo`03001oogoo0?mooemoo`00Cgoo00<007ooOol0ogooGgoo001?
Ool00`00Oomoo`3oOomOOol004moo`03001oogoo0?mooemoo`00Cgoo0P00ogooH7oo001?Ool00`00
Oomoo`3oOomOOol004moo`03001oogoo0?mooemoo`00Cgoo00<007ooOol0ogooGgoo001?Ool00`00
Oomoo`3oOomOOol004moo`03001oogoo0?mooemoo`00Cgoo00<0000?00l0o`0?;P0?<Goo001?Ool0
0`00Oomoo`3oOomOOol004moo`03001oogoo0?mooemoo`00Cgoo0P00ogooH7oo001?Ool00`00Oomo
o`3oOomOOol004moo`03001oogoo0?mooemoo`00Cgoo00<007ooOol0ogooGgoo001?Ool00`00Oomo
o`3oOomOOol004moo`03001oogoo0?mooemoo`00Cgoo00<007ooOol0ogooGgoo001?Ool00`00Oomo
o`3oOomOOol004moo`03001oogoo0?mooemoo`00Cgoo0P00ogooH7oo001?Ool00`00Oomoo`3oOomO
Ool004moo`03001oogoo0?mooemoo`00Cgoo00<007ooOol0ogooGgoo001?Ool00`00Oomoo`3oOomO
Ool004moo`03001oogoo0?mooemoo`00AWoo10001Goo00<007ooOol0ogooGgoo0018Ool00`00Oomo
o`04Ool00`00Oomoo`3oOomOOol004Qoo`03001oogoo00Aoo`03001oogoo0?mooemoo`00A7oo1P00
1Goo00<007ooOol0ogooGgoo0015Ool01000Oomoo`001Woo0`00ogooGgoo0015Ool01000Oomoo`00
1Woo00<007ooOol0ogooGgoo0016Ool00`00Ool00006Ool00`00Oomoo`3oOomOOol004Ioo`03001o
o`0000Ioo`03001oogoo0?mooemoo`00Agoo0P001Woo00<007ooOol0ogooGgoo001?Ool00`00Oomo
o`3oOomOOol004moo`03001oogoo0?mooemoo`00Cgoo00<007ooOol0ogooGgoo001?Ool00`00Oomo
o`3oOomOOol004moo`800?moof1oo`00Cgoo00<007ooOol0ogooGgoo001?Ool00`00Oomoo`3oOomO
Ool004moo`03001oogoo0?mooemoo`00Cgoo00<007ooOol0ogooGgoo001?Ool00`00Oomoo`3oOomO
Ool004moo`03001oogoo0?mooemoo`00Cgoo00<007ooOol0ogooGgoo001?Ool00`00Oomoo`30Ool0
0`00Oomoo`2KOol004moo`800<1oo`04001oo`00002KOol004moo`03001oogoo0;ioo`03001oogoo
009oo`8009Uoo`00Cgoo00<007ooOol0_Goo00<007ooOol01Goo0P00Ugoo001?Ool00`00Oomoo`1Z
Ool00`00Oomoo`1?Ool00`00Oomoo`08Ool2002EOol004moo`03001oogoo06Uoo`80051oo`03001o
ogoo00]oo`80021oo`03001oogoo071oo`00Cgoo00<007ooOol0J7oo00@007ooOol004ioo`03001o
ogoo00ioo`8001eoo`03001oo`00075oo`00Cgoo00<007ooOol0Igoo00D007ooOomoo`0004aoo`80
01=oo`8001Yoo`04001oogoo001aOol004moo`03001oogoo06Ioo`03001oogoo009oo`03001oogoo
04Uoo`03001oogoo01Eoo`03001oogoo01Ioo`03001oogoo009oo`03001oogoo06ioo`00Cgoo00<0
07ooOol0IWoo00<007ooOol00goo00<007ooOol0Agoo00<007ooOol05goo00<007ooOol057oo00<0
07ooOol017oo00<007ooOol0KGoo001?Ool00`00Oomoo`1UOol00`00Oomoo`04Ool00`00Oomoo`16
Ool00`00Oomoo`0IOol00`00Oomoo`0BOol00`00Oomoo`05Ool00`00Oomoo`1]Ool004moo`8006Eo
o`03001oogoo00Eoo`03001oogoo04Eoo`03001oogoo01]oo`80015oo`03001oogoo00Moo`03001o
ogoo06aoo`00Cgoo00<007ooOol0Hgoo00<007ooOol01goo00<007ooOol0@goo00<007ooOol07Woo
00<007ooOol03Goo00<007ooOol027oo00<007ooOol0K7oo001?Ool00`00Oomoo`1ROol00`00Oomo
o`08Ool00`00Oomoo`12Ool00`00Oomoo`0POol00`00Oomoo`0<Ool00`00Oomoo`09Ool00`00Oomo
o`1[Ool004moo`03001oogoo065oo`03001oogoo00Uoo`03001oogoo045oo`03001oogoo029oo`03
001oogoo00Yoo`03001oogoo00]oo`03001oogoo06Yoo`00Cgoo00<007ooOol0H7oo00<007ooOol0
2goo00<007ooOol0?goo00<007ooOol097oo00<007ooOol027oo00<007ooOol037oo00<007ooOol0
JWoo001?Ool00`00Oomoo`0QOol00`00Oomoo`0kOol00`00Oomoo`0<Ool00`00Oomoo`0nOol00`00
Oomoo`0VOol00`00Oomoo`06Ool00`00Oomoo`0>Ool00`00Oomoo`1YOol004moo`03001oogoo025o
o`8003aoo`03001oogoo00aoo`03001oogoo03eoo`03001oogoo02Qoo`8000Eoo`03001oogoo011o
o`03001oogoo06Qoo`00Cgoo00<007ooOol087oo00<007oo0000>goo00<007ooOol03Woo00<007oo
Ool0>goo00<007ooOol0:goo00D007ooOomoo`0001=oo`03001oogoo025oo`03001oogoo04Aoo`00
Cgoo00<007ooOol087oo00@007ooOol003Uoo`03001oogoo00moo`03001oogoo03Yoo`03001oogoo
02eoo`03001oo`0001Eoo`03001oogoo021oo`03001oogoo04Aoo`00Cgoo0P0087oo00D007ooOomo
o`0003Qoo`03001oogoo011oo`03001oogoo03Uoo`03001oogoo02moo`03001oogoo01Aoo`03001o
ogoo01moo`03001oo`0004Eoo`00Cgoo00<007ooOol07goo00<007ooOol00Woo00<007ooOol0=7oo
00<007ooOol04Woo00<007ooOol0=goo00<007ooOol0B7oo00<007ooOol07Woo00<007oo0000AGoo
001?Ool00`00Oomoo`0NOol00`00Oomoo`03Ool00`00Oomoo`0cOol00`00Oomoo`0COol00`00Oomo
o`0fOol00`00Oomoo`1:Ool00`00Oomoo`0LOol01000Oomoo`00AGoo001?Ool00`00Oomoo`0NOol0
0`00Oomoo`04Ool00`00Oomoo`0FOol00`00Oomoo`0IOol00`00Oomoo`0COol00`00Oomoo`0eOol0
0`00Oomoo`1;Ool00`00Oomoo`0LOol01000Oomoo`00AGoo001?Ool00`00Oomoo`0MOol00`00Oomo
o`06Ool00`00Oomoo`0DOol00`00Ool0000IOol00`00Oomoo`0EOol00`00Oomoo`0cOol00`00Oomo
o`1=Ool00`00Oomoo`0JOol00`00Oomoo`02Ool00`00Oomoo`12Ool003=oo`03001oogoo00Aoo`03
001oogoo019oo`03001oogoo01eoo`03001oogoo00Ioo`03001oogoo01Aoo`03001oo`0001Uoo`03
001oogoo01Eoo`03001oogoo039oo`03001oogoo04moo`03001oogoo01Uoo`03001oogoo009oo`03
001oogoo049oo`00<Goo00@007oo000000Aoo`8000Yoo`@000Ioo`03001oogoo01aoo`03001oogoo
00Qoo`03001oogoo019oo`05001oogooOol0000GOol00`00Oomoo`0FOol00`00Oomoo`0aOol00`00
Oomoo`1@Ool00`00Oomoo`0HOol00`00Oomoo`03Ool00`00Oomoo`12Ool0035oo`05001oo`00Ool0
0002Ool00`00Ool00009Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`0000l03`0L00l00`0000l0
3`0800l00`0000l03`0A00l00`0000l03`0300l00`0000l03`0D00l00`0000l03`0F00l00`0000l0
3`0`00l00`0000l03`1B00l00`0000l03`0G00l00`0000l03`0300l00`0000l03`0A00laOol0035o
o`03001oogoo009oo`80015oo`03001oogoo00=oo`03001oogoo01]oo`03001oogoo00Yoo`03001o
ogoo00moo`03001oogoo00Aoo`03001oogoo01=oo`03001oogoo01Qoo`03001oogoo02eoo`8005Eo
o`03001oogoo01Ioo`03001oogoo00Eoo`03001oogoo045oo`00<Goo00D007oo001oo`00009oo`03
001oo`0000ioo`03001oogoo00=oo`<001]oo`03001oogoo00Yoo`03001oogoo00moo`03001oogoo
00Eoo`03001oogoo019oo`03001oogoo01Qoo`03001oogoo015oo`<001Eoo`@005Qoo`03001oogoo
01Eoo`03001oogoo00Eoo`03001oogoo045oo`00<Goo00@007oo000000Aoo`8000ioo`03001oogoo
00=oo`03001oogoo01Yoo`03001oogoo00aoo`03001oogoo00eoo`03001oogoo00Moo`03001oogoo
011oo`03001oogoo01Uoo`03001oogoo011oo`04001oogooOol5000=Ool3001MOol00`00Oomoo`0C
Ool00`00Oomoo`06Ool00`00Oomoo`11Ool003=oo`03001oogoo00Aoo`03001oogoo00Qoo`@000Io
o`03001oogoo01Yoo`03001oogoo00eoo`03001oogoo00]oo`03001oogoo00Qoo`03001oogoo00mo
o`03001oogoo01]oo`03001oogoo00ioo`03001oogoo00Moo`D000Aoo`@0061oo`03001oogoo01=o
o`03001oogoo00Ioo`03001oogoo045oo`00AGoo00<007ooOol01goo00<007ooOol06Goo00<007oo
Ool03Woo00<007ooOol02Woo00<007ooOol02Woo00<007ooOol03Woo00<007ooOol06goo00<007oo
Ool03Woo00<007ooOol037oo1000IGoo00<007ooOol04Goo00<007ooOol027oo00<007ooOol0@7oo
0015Ool00`00Oomoo`07Ool00`00Oomoo`0IOol00`00Oomoo`0?Ool00`00Oomoo`09Ool00`00Oomo
o`0;Ool00`00Oomoo`0<Ool00`00Oomoo`0LOol00`00Oomoo`0=Ool00`00Oomoo`1gOol00`00Oomo
o`0@Ool00`00Oomoo`08Ool00`00Oomoo`10Ool004Eoo`D000Eoo`03001oogoo01Qoo`03001oogoo
011oo`03001oogoo00Qoo`03001oogoo00aoo`03001oogoo00aoo`03001oogoo01eoo`03001oogoo
00]oo`03001oogoo07Uoo`03001oogoo00ioo`03001oogoo00Uoo`03001oogoo041oo`00Cgoo00<0
07ooOol067oo00<007ooOol04Goo00<007ooOol01Woo00<007ooOol03Woo00<007ooOol02Woo00<0
07ooOol07Woo00<007ooOol02Woo00<007ooOol0NWoo00<007ooOol03Woo00<007ooOol02Goo00<0
07ooOol0@7oo001?Ool00`00Oomoo`0GOol00`00Oomoo`0COol00`00Oomoo`04Ool00`00Oomoo`0?
Ool00`00Oomoo`0:Ool00`00Oomoo`0NOol00`00Oomoo`0:Ool00`00Oomoo`1kOol00`00Oomoo`0<
Ool00`00Oomoo`0;Ool00`00Oomoo`0oOol004moo`03001oogoo01Moo`03001oogoo01=oo`03001o
ogoo00Aoo`03001oogoo011oo`03001oogoo00Qoo`03001oogoo021oo`03001oogoo00Qoo`03001o
ogoo07eoo`03001oogoo00]oo`03001oogoo00]oo`03001oogoo03moo`00Cgoo00<007ooOol05Woo
00<007ooOol05Goo00<007ooOol00Woo00<007ooOol04Woo00<007ooOol01Woo00<007ooOol08Goo
00<007ooOol01goo00<007ooOol0Ogoo00<007ooOol02Goo00<007ooOol037oo00<007ooOol0?goo
001?Ool2000GOol00`00Oomoo`0EOol01@00Oomoogoo00005Goo00<007ooOol01Woo00<007ooOol0
8Goo00<007ooOol01Woo00<007ooOol0P7oo00<007ooOol02Goo00<007ooOol037oo00<007ooOol0
?goo001?Ool00`00Oomoo`0EOol00`00Oomoo`0GOol00`00Ool0000GOol00`00Oomoo`04Ool00`00
Oomoo`0SOol00`00Oomoo`04Ool00`00Oomoo`22Ool00`00Oomoo`07Ool00`00Oomoo`0>Ool00`00
Oomoo`0nOol004moo`03001oogoo01Eoo`03001oogoo01Moo`03001oo`0001Qoo`03001oogoo00=o
o`03001oogoo02=oo`03001oogoo00Aoo`03001oogoo08=oo`03001oogoo00Ioo`03001oogoo00io
o`03001oogoo03ioo`00Cgoo00<007ooOol057oo00<007ooOol06Goo00<007ooOol05goo00<007oo
Ool00Woo00<007ooOol097oo00<007ooOol00goo00<007ooOol0QGoo00<007ooOol017oo00<007oo
Ool03goo00<007ooOol0?Woo001?Ool00`00Oomoo`0DOol00`00Oomoo`0dOol01@00Oomoogoo0000
9goo00D007ooOomoo`0008Qoo`03001oogoo00Aoo`03001oogoo00moo`03001oogoo03ioo`00Cgoo
00<007ooOol04goo00<007ooOol0=Woo00<007oo0000:7oo00@007ooOol008Yoo`03001oogoo009o
o`03001oogoo015oo`03001oogoo03eoo`00Cgoo00<007ooOol04goo00<007ooOol0=Woo00<007oo
0000:7oo00@007ooOol008]oo`05001oogooOol0000COol00`00Oomoo`0mOol004moo`03001oogoo
04eoo`03001oogoo02Qoo`8008eoo`03001oo`0001Aoo`03001oogoo03eoo`00Cgoo00<007ooOol0
N7oo00<007ooOol0S7oo00<007oo000057oo00<007ooOol0?Goo001?Ool2003oOol:Ool00`00Oomo
o`0DOol00`00Oomoo`0lOol004moo`03001oogoo0?moob1oo`03001oogoo03aoo`00Cgoo00<007oo
Ool0ogoo87oo00<007ooOol0?7oo001?Ool00`00Oomoo`3oOolPOol00`00Oomoo`0lOol004moo`03
001oogoo0?moob5oo`03001oogoo03]oo`00Cgoo00<007ooOol0ogoo8Goo00<007ooOol0>goo001?
Ool00`00Oomoo`3oOolQOol00`00Oomoo`0kOol004moo`03001oogoo0?moob5oo`03001oogoo03]o
o`00Cgoo00<007ooOol0ogoo8Woo00<007ooOol0>Woo001?Ool2003oOolSOol00`00Oomoo`0jOol0
04moo`03001oogoo0?moob9oo`03001oogoo03Yoo`00Cgoo00<007ooOol0ogoo8Woo00<007ooOol0
>Woo001?Ool00`00Oomoo`3oOolSOol00`00Oomoo`0iOol004moo`03001oogoo0?moob=oo`03001o
ogoo03Uoo`00Cgoo00<007ooOol0ogoo8goo00<007ooOol0>Goo001?Ool00`00Oomoo`3oOolSOol0
0`00Oomoo`0iOol004moo`03001oogoo0?moobAoo`03001oogoo03Qoo`00Cgoo00<007ooOol0ogoo
97oo00<007ooOol0>7oo001?Ool00`00Oomoo`3oOolTOol00`00Oomoo`0hOol004moo`800?moobEo
o`03001oogoo03Qoo`00Cgoo00<007ooOol0ogoo9Goo00<007ooOol0=goo001?Ool00`00Oomoo`3o
OolUOol00`00Oomoo`0gOol004moo`03001oogoo0?moobEoo`03001oogoo03Moo`00Cgoo00<007oo
Ool0ogoo9Goo00<007ooOol0=goo001?Ool00`00Oomoo`3oOolVOol00`00Oomoo`0fOol004Ioo`@0
00Eoo`03001oogoo0?moobIoo`03001oogoo03Ioo`00AGoo00<007ooOol00Woo00<007ooOol00Woo
00<007ooOol0ogooGgoo0015Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`3oOomOOol0
04Eoo`8000=oo`03001oogoo009oo`<00?mooemoo`00AGoo00<007oo00000P001Goo00<007ooOol0
ogooGgoo0015Ool00`00Oomoo`07Ool00`00Oomoo`3oOomOOol004Ioo`03001oogoo00Ioo`03001o
ogoo0?mooemoo`00Agoo00<007ooOol01Goo00<007ooOol0ogooGgoo0018Ool30004Ool00`00Oomo
o`3oOomOOol004moo`03001oogoo0?mooemoo`00Cgoo00<007ooOol0ogooGgoo001?Ool00`00Oomo
o`3oOomOOol004moo`800?moof1oo`00Cgoo00<007ooOol0ogooGgoo001?Ool00`00Oomoo`3oOomO
Ool004moo`03001oogoo0?mooemoo`00Cgoo00<007ooOol0ogooGgoo001?Ool00`00Oomoo`3oOomO
Ool004moo`03001oogoo0?mooemoo`00Cgoo00<007ooOol0ogooGgoo001?Ool00`00Oomoo`3oOomO
Ool004moo`0300003`0?0?l03bh03c5oo`00Cgoo0P00ogooH7oo001?Ool00`00Oomoo`3oOomOOol0
04moo`03001oogoo0?mooemoo`00Cgoo00<007ooOol0ogooGgoo001?Ool00`00Oomoo`3oOomOOol0
04moo`03001oogoo0?mooemoo`00Cgoo00<007ooOol0ogooGgoo001?Ool00`00Oomoo`3oOomOOol0
04moo`03001oogoo0?mooemoo`00Cgoo0P00ogooH7oo001?Ool00`00Oomoo`3oOomOOol004moo`03
001oogoo0?mooemoo`00Cgoo00<007ooOol0ogooGgoo001?Ool00`00Oomoo`3oOomOOol004moo`03
001oogoo0?mooemoo`00Cgoo00<007ooOol0ogooGgoo001?Ool00`00Oomoo`3oOomOOol004moo`03
001oogoo0?mooemoo`00Cgoo00<007ooOol0ogooGgoo001?Ool2003oOomPOol004moo`03001oogoo
0?mooemoo`00Cgoo00<007ooOol0ogooGgoo001?Ool00`00Oomoo`3oOomOOol004moo`03001oogoo
0?mooemoo`00Cgoo00<007ooOol0ogooGgoo001?Ool00`00Oomoo`3oOomOOol004moo`03001oogoo
0?mooemoo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00`7oo
0`00kGoo0032Ool00`00Oomoo`3[Ool00<9oo`03001oogoo0>]oo`00Dgoo1`000Woo0`000Woo0`00
00=oo`0000001@001Goo10000Woo1`0017oo1@000Woo1`0037oo00<007oo00000P001Woo100017oo
0`0000=oo`0000000Woo0`0000=oo`0000001Goo0P00k7oo001FOol00`00Oomoo`04Ool00`00Oomo
o`02Ool00`00Oomoo`03Ool00`00Oomoo`05Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomo
o`04Ool01@00Oomoogoo00001Woo00<007ooOol03Goo0P000goo00<007ooOol00Woo00<007ooOol0
0Woo00@007ooOol000=oo`80009oo`04001oogooOol20006Ool2003/Ool005Ioo`03001oogoo00Ao
o`03001oogoo009oo`03001oogoo00=oo`03001oogoo00Eoo`03001oogoo00Moo`03001oogoo00Ao
o`05001oogooOol00006Ool00`00Oomoo`0=Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomo
o`05Ool00`00Oomoo`02Ool01000Oomoo`0017oo00<007ooOol00goo00@007ooOol00>]oo`00EWoo
00<007ooOol017oo00<007ooOol00Woo00<007ooOol00goo00<007ooOol01Goo00<007ooOol01goo
00<007ooOol01Goo10001Woo00<007ooOol04Woo00<007ooOol00Woo00<007ooOol01Goo00<007oo
Ool00Woo00@007ooOol000Aoo`03001oogoo00=oo`04001oogoo003[Ool005Ioo`03001oogoo00Ao
o`8000=oo`03001oogoo00=oo`03001oogoo00Eoo`03001oogoo00Moo`03001oogoo00Aoo`05001o
ogooOol00006Ool00`00Oomoo`0>Ool40005Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomo
o`000goo0P0017oo00<007ooOol00Woo00<007ooOol0j7oo001FOol00`00Oomoo`03Ool2000017oo
0000000017oo0`001Goo1`000goo0`001goo0`001goo00<007ooOol03Goo00<007ooOol00Woo00<0
07ooOol01`000Woo0P000goo0P000goo0`0000=oo`00Ool00Woo0`000Woo0`00jGoo001FOol00`00
Oomoo`0GOol00`00Oomoo`0IOol00`00Oomoo`0=Ool01000Oomoogoo0P0017oo00<007ooOol04Woo
00<007ooOol0lWoo001COol7000FOol00`00Oomoo`0IOol00`00Oomoo`0>Ool300000goo001oo`03
Ool00`00Oomoo`0BOol00`00Oomoo`3bOol006Qoo`03001oogoo00moo`03001oogoo00eoo`<002eo
o`800?Aoo`00J7oo00<007ooOol03goo00<007ooOol0ogoo=7oo003oOonaOol00?mook5oo`00ogoo
/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogooMGoo00<007ooOol0
>Goo003oOomeOol2000jOol005=oo`<00004Ool00000000>Ool20006Ool50002Ool70004Ool30000
0goo00000003Ool40004Ool5000>Ool50004Ool40004Ool5000<Ool3000017oo000000000Woo0P00
00Aoo`00000000Eoo`D000=oo`D000Aoo`03001oo`00008000ioo`@000Eoo`@000=oo`<0009oo`<0
00Aoo`@000=oo`D000Eoo`@000=oo`L000eoo`@000=oo`<0009oo`<000=oo`D000=oo`D000Ioo`@0
00Aoo`03001oogoo03Qoo`00E7oo00D007ooOomoo`0000moo`8000Eoo`05001oogooOol00006Ool0
0`00Oomoo`04Ool01000Oomoogoo0P000goo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001o
ogoo00aoo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo009oo`03001oogoo00ioo`05001o
ogooOol00004Ool20003Ool01@00Oomoogoo00000goo00<007ooOol00goo00<007ooOol01Goo0P00
0goo00<007ooOol02Woo00<007ooOol00Woo00D007ooOomoo`0000Aoo`05001oogooOol00004Ool0
0`00Oomoo`02Ool00`00Oomoo`02Ool01@00Oomoogoo00001goo00<007ooOol00Woo00<007ooOol0
0goo00<007ooOol03Goo00<007ooOol00Woo00D007ooOomoo`0000Aoo`05001oogooOol00003Ool0
0`00Oomoo`03Ool00`00Oomoo`06Ool00`00Oomoo`02Ool01000Oomoogoo0P00>Goo001EOol00`00
Ool0000?Ool01000Oomoo`0017oo00D007ooOomoo`0000Ioo`03001oogoo00Aoo`03001oogoo009o
o`05001oogooOol0000=Ool00`00Oomoo`0<Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomo
o`02Ool00`00Oomoo`0?Ool00`00Ool00005Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00<0
07ooOol00goo00<007ooOol01Goo00<007ooOol00Woo00<007ooOol02Goo00<007ooOol01goo00<0
07ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo00Eo
o`03001oogoo009oo`03001oogoo00=oo`03001oogoo00aoo`03001oogoo00Moo`03001oogoo009o
o`05001oogooOol00003Ool00`00Oomoo`03Ool00`00Oomoo`06Ool00`00Oomoo`11Ool005Ioo`03
001oogoo00ioo`04001oogoo0005Ool40006Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01000Oomo
ogoo1P0017oo10003goo00<007ooOol017oo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol0
47oo00<007ooOol017oo00<007ooOol00Woo00<007ooOol00Woo10001Goo00<007ooOol02Woo00<0
07ooOol02Goo00<007ooOol01goo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo009o
o`03001oogoo00Ioo`03001oogoo00Eoo`03001oogoo009oo`03001oogoo00=oo`03001oogoo00ao
o`03001oogoo00Moo`03001oogoo009oo`03001oogoo009oo`@000Eoo`03001oogoo00Ioo`03001o
ogoo045oo`00EWoo00<007ooOol03Goo00<007ooOol00Woo00D007ooOomoo`0000=oo`03001oogoo
00Aoo`03001oogoo00Aoo`03001oogoo009oo`05001oogooOol00004Ool01@00Oomoogoo000017oo
00<007ooOol037oo00<007ooOol017oo00<007ooOol00Woo00<007ooOol00Woo0P004Goo00<007oo
Ool017oo0P000goo00D007ooOomoo`0000=oo`03001oogoo00=oo`8000Moo`@000aoo`03001oogoo
00Moo`03001oogoo009oo`04001oogooOol20003Ool00`00Oomoo`02Ool00`00Oomoo`06Ool20006
Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`0=Ool01000Oomoogoo0P000goo0P000goo
00D007ooOomoo`0000=oo`03001oogoo00=oo`8000Moo`03001oogoo045oo`00EGoo00<007oo0000
3Goo0`000Woo0`000goo0`001goo00<007ooOol00goo0P000goo0P0017oo10001Goo1@0037oo1P00
17oo100017oo0P0000Aoo`00000000eoo`03001oo`0000Eoo`03001oo`00008000Eoo`<000Eoo`80
0004Ool000000003Ool00`00Oomoo`02Ool00`00Oomoo`09Ool00`00Oomoo`03Ool00`00Oomoo`02
Ool40003Ool2000017oo000000000goo1`000goo0P0000Aoo`00000000Aoo`@000Ioo`03001oogoo
00ioo`<00003Ool007oo009oo`03001oo`00008000Eoo`<000Eoo`800004Ool000000002Ool7000o
Ool005Aoo`05001oogooOol0000QOol00`00Oomoo`0ZOol00`00Oomoo`0OOol01@00Oomoogoo0000
17oo00<007ooOol067oo00@007ooOomoo`8000aoo`04001oogooOol2000FOol00`00Oomoo`0IOol0
0`00Oomoo`0FOol00`00Oomoo`0IOol00`00Oomoo`11Ool005=oo`<00004Ool00000000POol00`00
Oomoo`0ZOol00`00Oomoo`0NOol3000017oo000000000goo00<007ooOol06Goo0`0000=oo`00Ool0
37oo0`0000=oo`00Ool05Goo00<007ooOol06Goo00<007ooOol05Woo00<007ooOol06Goo00<007oo
Ool0@Goo001hOol3000]Ool3000VOol2001ROol3000GOol2001OOol005Aoo`D00?mooeQoo`00ogoo
/Goo003oOonaOol00?mook5oo`00\
\>"],
  ImageRangeCache->{{{135, 422}, {263.188, 86.25}} -> {-20.1142, 4.95237, 
  0.104176, 0.0321963}},
  CellTags->"Mean and standard deviation chart"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.047619 0.0882906 0.210546 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -6 -9 ]
[.5 -0.0125 6 0 ]
[.7381 -0.0125 -6 -9 ]
[.7381 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -26 -21.5625 ]
[.5 -0.0125 26 -9 ]
[-0.0125 .08829 -6 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .19356 -18 -4.5 ]
[-0.0125 .19356 0 4.5 ]
[-0.0125 .29884 -6 -4.5 ]
[-0.0125 .29884 0 4.5 ]
[-0.0125 .40411 -18 -4.5 ]
[-0.0125 .40411 0 4.5 ]
[-0.0125 .50938 -6 -4.5 ]
[-0.0125 .50938 0 4.5 ]
[-0.0125 .61466 -18 -4.5 ]
[-0.0125 .61466 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -30.5625 -5 ]
[-0.01875 .30902 -18 5 ]
[.5 .63053 -101 0 ]
[.5 .63053 101 25.75 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .29961 m
1 .29961 L
s
0 .08829 m
1 .08829 L
s
0 .52974 m
1 .52974 L
s
0 g
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(10)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(15)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(20)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -87 -25.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(subgroup) show
111.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .08829 m
.00625 .08829 L
s
[(0)] -0.0125 .08829 1 0 Mshowa
0 .19356 m
.00625 .19356 L
s
[(0.5)] -0.0125 .19356 1 0 Mshowa
0 .29884 m
.00625 .29884 L
s
[(1)] -0.0125 .29884 1 0 Mshowa
0 .40411 m
.00625 .40411 L
s
[(1.5)] -0.0125 .40411 1 0 Mshowa
0 .50938 m
.00625 .50938 L
s
[(2)] -0.0125 .50938 1 0 Mshowa
0 .61466 m
.00625 .61466 L
s
[(2.5)] -0.0125 .61466 1 0 Mshowa
.125 Mabswid
0 .10935 m
.00375 .10935 L
s
0 .1304 m
.00375 .1304 L
s
0 .15145 m
.00375 .15145 L
s
0 .17251 m
.00375 .17251 L
s
0 .21462 m
.00375 .21462 L
s
0 .23567 m
.00375 .23567 L
s
0 .25673 m
.00375 .25673 L
s
0 .27778 m
.00375 .27778 L
s
0 .31989 m
.00375 .31989 L
s
0 .34095 m
.00375 .34095 L
s
0 .362 m
.00375 .362 L
s
0 .38306 m
.00375 .38306 L
s
0 .42516 m
.00375 .42516 L
s
0 .44622 m
.00375 .44622 L
s
0 .46727 m
.00375 .46727 L
s
0 .48833 m
.00375 .48833 L
s
0 .53044 m
.00375 .53044 L
s
0 .55149 m
.00375 .55149 L
s
0 .57255 m
.00375 .57255 L
s
0 .5936 m
.00375 .5936 L
s
0 .06724 m
.00375 .06724 L
s
0 .04618 m
.00375 .04618 L
s
0 .02513 m
.00375 .02513 L
s
0 .00407 m
.00375 .00407 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -90.2813 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
66 10.2813 translate
90 rotate
-66 -10.2813 translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .08829 m
1 .08829 L
s
gsave
.5 .63053 -162 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 33.75 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
75.000 12.813 moveto
(values) show
117.000 12.813 moveto
(for) show
141.000 12.813 moveto
(XbarS) show
177.000 12.813 moveto
(Control) show
225.000 12.813 moveto
(chart) show
255.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
63.000 26.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Initial) show
111.000 26.000 moveto
(Study) show
141.000 26.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.07143 .21266 m
.11905 .36568 L
.16667 .4043 L
.21429 .2986 L
.2619 .24904 L
.30952 .25335 L
.35714 .28933 L
.40476 .38891 L
.45238 .33615 L
.5 .36667 L
.54762 .37841 L
.59524 .2416 L
.64286 .23269 L
.69048 .33303 L
.7381 .24401 L
.78571 .38156 L
.83333 .29053 L
.88095 .22772 L
.92857 .28873 L
.97619 .2093 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[8]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012Q000`40O003h00Oogoo/Goo003oOona
Ool00?mook5oo`00jGoo10007goo0`00XGoo003]Ool00`00Oomoo`0MOol00`00Oomoo`2POol00>eo
o`03001oogoo01eoo`03001oogoo0:1oo`00cWoo1@001Goo0`0000Aoo`00001oo`800004Ool00000
0004Ool300000goo001oo`03Ool50005Ool40005Ool300000goo00000002Ool00`00Ool00002002N
Ool00<ioo`03001oogoo009oo`05001oogooOol00003Ool20003Ool20003Ool01000Oomoo`000goo
0P001Goo00<007ooOol01Goo00<007ooOol00Woo00D007ooOomoo`0000=oo`8000=oo`8000=oo`03
001oogoo09]oo`00dgoo00D007ooOomoo`0000Aoo`05001oogooOol00004Ool01000Oomoo`0017oo
00<007ooOol00goo00<007ooOol01Goo00<007ooOol00Woo00D007ooOomoo`0000Aoo`05001oogoo
Ool00004Ool00`00Oomoo`2KOol00<moo`@000Aoo`03001oogoo009oo`05001oogooOol00004Ool0
1000Oomoo`0017oo00<007ooOol00goo00<007ooOol01Goo00<007ooOol00Woo00D007ooOomoo`00
00Aoo`05001oogooOol00004Ool00`00Oomoo`2KOol00<ioo`03001oogoo009oo`05001oogooOol0
0004Ool01000Oomoogoo0P000goo00@007ooOol000=oo`8000Eoo`8000Ioo`03001oogoo009oo`05
001oogooOol00004Ool01000Oomoogoo0P000goo00<007ooOol0Vgoo003?Ool50002Ool20003Ool2
0003Ool00`00Ool000020004Ool300000goo00000003Ool2000017oo0000000017oo10000goo0P00
0goo0P000Woo0P0000Aoo`00000009ioo`00h7oo00<007ooOol0cGoo003POol00`00Oomoo`3=Ool0
0=moo`800<moo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol005eoo`@004Ao
o`@003moo`L000=oo`@003Yoo`L000=oo`@003Yoo`H000Aoo`@002Yoo`00G7oo00<007ooOol00Woo
00<007ooOol0@7oo00<007ooOol00Woo00<007ooOol0?goo00<007ooOol00goo00<007ooOol00Woo
00<007ooOol0>Woo00<007ooOol00goo00<007ooOol00Woo00<007ooOol0=goo00<007ooOol00Woo
00D007ooOomoo`0000Aoo`03001oogoo02Moo`00G7oo00<007ooOol00Woo00<007ooOol0AGoo00<0
07ooOol0?goo00<007ooOol00goo00<007ooOol00Woo00<007ooOol0>Woo00<007ooOol027oo00<0
07ooOol0>7oo00<007ooOol01Goo00<007ooOol00Woo00<007ooOol09goo001LOol00`00Oomoo`02
Ool00`00Oomoo`15Ool00`00Oomoo`0oOol00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`0j
Ool00`00Oomoo`08Ool00`00Oomoo`0iOol00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`0W
Ool005aoo`03001oogoo009oo`03001oogoo04Eoo`03001oogoo03moo`03001oogoo00=oo`03001o
ogoo009oo`03001oogoo03Yoo`03001oogoo00Qoo`03001oogoo03Yoo`03001oogoo00=oo`03001o
ogoo009oo`03001oogoo02Moo`00G7oo00<007ooOol00Woo00<007ooOol0@Goo1000@Woo00<007oo
Ool00goo00<007ooOol00Woo00<007ooOol0>Woo00<007ooOol017oo1000?Woo00<007ooOol00Woo
00<007ooOol00Woo00<007ooOol09goo001LOol00`00Oomoo`02Ool00`00Oomoo`11Ool00`00Oomo
o`13Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`0jOol00`00Oomoo`04Ool00`00Oomo
o`0kOol00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol09goo001LOol00`00Oomoo`02
Ool00`00Oomoo`11Ool00`00Oomoo`11Ool30005Ool00`00Oomoo`02Ool00`00Oomoo`0hOol30006
Ool00`00Oomoo`0kOol00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol09goo001MOol4
0014Ool50011Ool00`00Oomoo`04Ool4000mOol00`00Oomoo`04Ool5000jOol40005Ool4000ZOol0
0?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00F7oo
o`00<@00:7oo001HOol20006Ool00`00Oomoo`0;Ool00`00Oomoo`0;Ool00`00Oomoo`0<Ool00`00
Oomoo`0;Ool00`00Oomoo`0<Ool00`00Oomoo`0;Ool00`00Oomoo`0<Ool00`00Oomoo`0;Ool00`00
Oomoo`0;Ool00`00Oomoo`0<Ool00`00Oomoo`0;Ool00`00Oomoo`0<Ool00`00Oomoo`0;Ool00`00
Oomoo`0<Ool00`00Oomoo`0;Ool00`00Oomoo`0;Ool00`00Oomoo`0<Ool00`00Oomoo`0;Ool00`00
Oomoo`0<Ool00`00Oomoo`0;Ool00`00Oomoo`0]Ool005Qoo`03001oogoo00Eoo`03001oogoo04Eo
o`03001oogoo04Eoo`03001oogoo04Eoo`03001oogoo04Eoo`03001oogoo02eoo`00F7oo00<007oo
Ool0ogooEWoo001HOol00`00Oomoo`3oOomFOol005Qoo`03001oogoo0?mooeIoo`00F7oo00<007oo
Ool0ogooEWoo001HOol2003oOomGOol005Qoo`03001oogoo0?mooeIoo`00F7oo00<007ooOol0ogoo
EWoo001HOol00`00Oomoo`3oOomFOol005Qoo`03001oogoo0?mooeIoo`00F7oo00<007ooOol0ogoo
EWoo001HOol00`00Oomoo`3oOomFOol005Qoo`800?mooeMoo`00F7oo00<007ooOol0ogooEWoo001H
Ool00`00Oomoo`3oOomFOol005Qoo`03001oogoo0?mooeIoo`00F7oo00<007ooOol0ogooEWoo001H
Ool00`00Oomoo`3oOomFOol005Qoo`800?mooeMoo`00F7oo00<007ooOol0ogooEWoo001HOol00`00
Oomoo`3oOomFOol004ioo`@000Ioo`03001oogoo0?mooeIoo`00CGoo00<007ooOol00Woo00<007oo
Ool00goo00<007ooOol0ogooEWoo001=Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`3o
OomFOol004eoo`03001oogoo009oo`03001oogoo00=oo`03001oogoo0?mooeIoo`00CGoo00<007oo
Ool00Woo00<007ooOol00gooo`00<@00:7oo001=Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00
Oomoo`3oOomFOol004eoo`03001oogoo009oo`03001oogoo00=oo`03001oogoo0?mooeIoo`00CGoo
00<007ooOol00Woo00<007ooOol00goo00<007ooOol0ogooEWoo001>Ool40006Ool00`00Oomoo`3o
OomFOol005Qoo`03001oogoo0?mooeIoo`00F7oo0P00ogooEgoo001HOol00`00Oomoo`3oOomFOol0
05Qoo`03001oogoo0?mooeIoo`00F7oo00<007ooOol0ogooEWoo001HOol00`00Oomoo`3oOomFOol0
05Qoo`03001oogoo0?mooeIoo`00F7oo0P00ogooEgoo001HOol00`00Oomoo`3oOomFOol005Qoo`03
001oogoo0?mooeIoo`00F7oo00<007ooOol0ogooEWoo001HOol00`00Oomoo`3oOomFOol005Qoo`03
001oogoo0?mooeIoo`00F7oo00<007ooOol0ogooEWoo001HOol2003oOomGOol005Qoo`03001oogoo
0?mooeIoo`00F7oo00<007ooOol0ogooEWoo001HOol00`00Oomoo`3oOomFOol005Qoo`03001oogoo
0?mooeIoo`00F7oo00<007ooOol0ogooEWoo001HOol2003oOomGOol005Qoo`03001oogoo0?mooeIo
o`00F7oo00<007ooOol0ogooEWoo000lOol40006Ool20006Ool40006Ool00`00Oomoo`3oOomFOol0
03]oo`03001oogoo009oo`03001oogoo00=oo`8000Eoo`03001oogoo009oo`03001oogoo00=oo`03
001oogoo0?mooeIoo`00>goo00<007ooOol00Woo00<007ooOol03goo00<007ooOol00goo00<007oo
Ool0ogooEWoo000kOol00`00Oomoo`02Ool00`00Oomoo`0?Ool00`00Oomoo`03Ool3003oOomFOol0
03]oo`03001oogoo009oo`03001oogoo00moo`03001oogoo00=oo`03001oogoo0?mooeIoo`00>goo
00<007ooOol00Woo00<007ooOol02goo10001Woo00<007ooOol0ogooEWoo000kOol00`00Oomoo`02
Ool00`00Oomoo`0;Ool00`00Oomoo`07Ool00`00Oomoo`3oOomFOol003]oo`03001oogoo009oo`03
001oogoo00]oo`03001oogoo00Moo`03001oogoo0?mooeIoo`00?7oo10003Woo1@001Goo00<007oo
Ool0ogoo9Woo00<007ooOol0;Goo001HOol00`00Oomoo`0COol00`00Oomoo`3oOol?Ool00`00Oomo
o`0^Ool005Qoo`8001Aoo`03001oogoo0?moo`moo`03001oogoo02ioo`00F7oo00<007ooOol057oo
00<007ooOol0ogoo3Goo00<007ooOol0;goo001HOol00`00Oomoo`0DOol00`00Oomoo`3oOol=Ool0
0`00Oomoo`0_Ool005Qoo`03001oogoo01Aoo`03001oogoo0?moo`aoo`03001oogoo031oo`00F7oo
00<007ooOol057oo00<007ooOol0lGoo00<007ooOol05goo00<007ooOol0<7oo001HOol00`00Oomo
o`0EOol00`00Oomoo`2VOol30016Ool00`00Ool0000GOol00`00Oomoo`0aOol005Qoo`8001Ioo`03
001oogoo0:9oo`@0009oo`03001oogoo04Aoo`04001oogoo000EOol00`00Oomoo`0bOol005Qoo`03
001oogoo01Eoo`03001oogoo09eoo`D000Moo`03001oogoo049oo`05001oogooOol0000EOol00`00
Oomoo`0bOol005Qoo`03001oogoo01Ioo`03001oogoo09Uoo`<000aoo`03001oogoo045oo`03001o
ogoo00=oo`03001oogoo015oo`03001oogoo03=oo`00F7oo00<007ooOol05Woo00<007ooOol0VGoo
00<007ooOol03Goo00<007ooOol067oo00<007ooOol097oo00<007ooOol01Goo00<007ooOol047oo
00<007ooOol0<goo001HOol00`00Oomoo`0FOol00`00Oomoo`0dOol4001POol00`00Oomoo`0>Ool0
0`00Oomoo`0GOol2000VOol00`00Oomoo`06Ool00`00Oomoo`0>Ool00`00Oomoo`0dOol005Qoo`03
001oogoo01Moo`03001oogoo039oo`03001oogoo009oo`L005Uoo`03001oogoo00moo`03001oogoo
01Ioo`03001oo`0002Aoo`03001oogoo00Qoo`03001oogoo00aoo`03001oogoo03Eoo`00F7oo00<0
07ooOol05goo00<007ooOol0<Goo00<007ooOol02Woo1000EGoo00<007ooOol03goo00<007ooOol0
5Goo00@007ooOol002=oo`03001oogoo00Yoo`03001oogoo00]oo`03001oogoo03Eoo`00F7oo0P00
67oo00<007ooOol0<7oo00<007ooOol03goo0P00DWoo00<007ooOol04Goo00<007ooOol057oo00@0
07ooOol0029oo`03001oogoo00]oo`03001oogoo00Yoo`03001oogoo03Ioo`00F7oo00<007ooOol0
5goo00<007ooOol0;goo00<007ooOol04Woo00<007ooOol0Cgoo00<007ooOol04Goo00<007ooOol0
4goo00<007ooOol00Woo00<007ooOol07goo00<007ooOol037oo00<007ooOol02Goo00<007ooOol0
=Woo001HOol00`00Oomoo`0HOol00`00Oomoo`0]Ool00`00Oomoo`0DOol2001>Ool00`00Oomoo`0C
Ool00`00Oomoo`0BOol00`00Oomoo`02Ool00`00Oomoo`0NOol00`00Oomoo`0>Ool00`00Oomoo`07
Ool00`00Oomoo`0gOol005Qoo`03001oogoo01Qoo`03001oogoo02aoo`03001oogoo01Moo`03001o
ogoo04]oo`03001oogoo01=oo`03001oogoo015oo`03001oogoo00=oo`03001oogoo01eoo`03001o
ogoo011oo`03001oogoo00Ioo`03001oogoo03Moo`00F7oo00<007ooOol067oo00<007ooOol0:goo
00<007ooOol06Goo0P00Bgoo00<007ooOol057oo00<007ooOol047oo00<007ooOol017oo00<007oo
Ool06goo00<007ooOol04Woo00<007ooOol017oo00<007ooOol0>7oo001HOol00`00Oomoo`0IOol0
0`00Oomoo`0YOol00`00Oomoo`0LOol00`00Oomoo`17Ool00`00Oomoo`0EOol00`00Oomoo`0?Ool0
0`00Oomoo`05Ool00`00Oomoo`0KOol00`00Oomoo`0COol00`00Oomoo`02Ool00`00Oomoo`0iOol0
05Qoo`8001Yoo`03001oogoo02Qoo`03001oogoo01ioo`8004Moo`03001oogoo01Ioo`03001oogoo
00ioo`03001oogoo00Eoo`03001oogoo01Yoo`03001oogoo01Aoo`03001oogoo009oo`03001oogoo
03Uoo`00F7oo00<007ooOol06Goo00<007ooOol09goo00<007ooOol08Goo00<007ooOol0A7oo00<0
07ooOol05Woo00<007ooOol03Goo00<007ooOol01goo00<007ooOol067oo00<007ooOol05Woo00@0
07ooOol003aoo`00F7oo00<007ooOol06Woo00<007ooOol09Goo00<007ooOol08goo0P00@goo00<0
07ooOol067oo00<007ooOol037oo00<007ooOol01goo00<007ooOol05goo00<007ooOol067oo00<0
07oo0000?7oo001=Ool70004Ool00`00Oomoo`0JOol00`00Oomoo`0TOol00`00Oomoo`0VOol00`00
Oomoo`10Ool00`00Oomoo`0HOol00`00Oomoo`0;Ool00`00Oomoo`08Ool00`00Oomoo`0GOol00`00
Oomoo`0IOol00`00Oomoo`0kOol0051oo`03001oogoo00Eoo`03001oogoo01Yoo`03001oogoo02=o
o`03001oogoo02Moo`03001oogoo041oo`03001oogoo01Uoo`03001oogoo00Yoo`03001oogoo00Uo
o`03001oogoo01Eoo`03001oogoo05Qoo`00D7oo00<007ooOol01Goo00<007ooOol06Woo00<007oo
Ool08Woo00<007ooOol0:Goo00<007ooOol0?Woo00<007ooOol06Woo00<007ooOol02Goo00<007oo
Ool02Woo00<007ooOol057oo00<007ooOol0FGoo001@Ool00`00Oomoo`05Ool3000KOol00`00Oomo
o`0POol00`00Oomoo`0ZOol00`00Oomoo`0nOol00`00Oomoo`0KOol00`00Oomoo`08Ool00`00Oomo
o`0:Ool00`00Oomoo`0DOol00`00Oomoo`1IOol0051oo`03001oogoo00Eoo`0300003`0?01/03`03
00003`0?02003`0300003`0?02/03`0300003`0?03`03`0300003`0?01`03`0300003`0?00L03`03
00003`0?00`03`0300003`0?01803`0300003`0?03803bQoo`00;Goo00<007ooOol00P007Woo00<0
07ooOol01Goo00<007ooOol06goo00<007ooOol07goo00<007ooOol0;7oo00<007ooOol0?7oo00<0
07ooOol07Goo00<007ooOol01Woo00<007ooOol037oo00<007ooOol04Woo00<007ooOol0FWoo000/
Ool01@00Ool007oo00007goo00<007ooOol01Goo00<007ooOol077oo00<007ooOol07Woo00<007oo
Ool0;Goo00<007ooOol0>goo00<007ooOol07Goo00<007ooOol01Goo00<007ooOol03Goo00<007oo
Ool04Goo00<007ooOol0Fgoo000/Ool00`00Ool00002Ool00`00Oomoo`0JOol30007Ool00`00Oomo
o`0LOol00`00Oomoo`0MOol00`00Oomoo`0^Ool00`00Oomoo`0jOol00`00Oomoo`0OOol00`00Oomo
o`04Ool00`00Oomoo`0>Ool00`00Oomoo`0@Ool00`00Oomoo`1KOol002aoo`03001oo`00009oo`03
001oogoo01aoo`03001oogoo00Eoo`03001oogoo01aoo`03001oogoo01eoo`03001oogoo02moo`03
001oogoo03Uoo`03001oogoo01moo`03001oogoo00=oo`03001oogoo00moo`03001oogoo00moo`03
001oogoo05aoo`00;7oo00<007oo00000Woo00<007ooOol097oo00<007ooOol07Goo00<007ooOol0
6goo00<007ooOol0<7oo00<007ooOol0>Goo00<007ooOol087oo00<007ooOol00Woo00<007ooOol0
47oo00<007ooOol03Woo00<007ooOol0G7oo000/Ool200000goo0000000WOol2000NOol00`00Oomo
o`0KOol00`00Oomoo`0aOol00`00Oomoo`0gOol00`00Oomoo`0QOol01@00Oomoogoo00004goo00<0
07ooOol03Goo00<007ooOol0GGoo001HOol00`00Oomoo`0MOol00`00Oomoo`0KOol00`00Oomoo`0a
Ool00`00Oomoo`0gOol00`00Oomoo`0ROol01000Oomoo`004goo00<007ooOol037oo00<007ooOol0
GWoo001HOol00`00Oomoo`0MOol00`00Oomoo`0JOol00`00Oomoo`0bOol00`00Oomoo`0fOol00`00
Oomoo`0SOol00`00Ool0000EOol00`00Oomoo`0;Ool00`00Oomoo`1NOol005Qoo`03001oogoo01io
o`03001oogoo01Uoo`03001oogoo03=oo`03001oogoo03Eoo`03001oogoo02Aoo`8001Eoo`03001o
ogoo00Yoo`03001oogoo05moo`00F7oo00<007ooOol07Woo00<007ooOol067oo00<007ooOol0=7oo
00<007ooOol0=Goo00<007ooOol097oo00<007ooOol057oo00<007ooOol02Woo00<007ooOol0Ggoo
001HOol00`00Oomoo`0NOol00`00Oomoo`0HOol00`00Oomoo`0eOol00`00Oomoo`0BOol00`00Oomo
o`0NOol00`00Oomoo`0mOol00`00Oomoo`08Ool00`00Oomoo`1POol005Qoo`80021oo`03001oogoo
01Ioo`03001oogoo03Ioo`03001oogoo015oo`04001oo`00000NOol00`00Oomoo`0mOol00`00Oomo
o`08Ool00`00Oomoo`1POol005Qoo`03001oogoo01moo`03001oogoo01Ioo`03001oogoo03Moo`03
001oogoo00moo`03001oogoo009oo`8001aoo`03001oogoo03eoo`03001oogoo00Moo`03001oogoo
065oo`00F7oo00<007ooOol07goo00<007ooOol05Goo00<007ooOol0>7oo00<007ooOol03Woo00<0
07ooOol01Goo00<007ooOol067oo00<007ooOol0?goo00<007ooOol01Woo00<007ooOol0HGoo001H
Ool00`00Oomoo`0POol00`00Oomoo`0DOol00`00Oomoo`0iOol00`00Oomoo`0=Ool00`00Oomoo`06
Ool2000HOol00`00Oomoo`0oOol00`00Oomoo`05Ool00`00Oomoo`1ROol005Qoo`03001oogoo021o
o`03001oogoo01Aoo`03001oogoo03Uoo`03001oogoo00aoo`03001oogoo00Uoo`8001Ioo`03001o
ogoo03moo`03001oogoo00Aoo`03001oogoo06=oo`00F7oo00<007ooOol087oo00<007ooOol04goo
00<007ooOol0>Woo00<007ooOol02goo00<007ooOol037oo00<007ooOol04Woo00<007ooOol0@Goo
00<007ooOol00goo00<007ooOol0Hgoo001HOol2000QOol00`00Oomoo`0COol00`00Oomoo`0kOol0
0`00Oomoo`09Ool00`00Oomoo`0>Ool2000BOol00`00Oomoo`11Ool00`00Oomoo`02Ool00`00Oomo
o`1TOol005Qoo`03001oogoo025oo`03001oogoo015oo`03001oogoo03aoo`03001oogoo00Qoo`03
001oogoo015oo`8000moo`03001oogoo049oo`03001oogoo009oo`03001oogoo06Aoo`00F7oo00<0
07ooOol08Goo00<007ooOol04Goo00<007ooOol0?Goo00<007ooOol01Woo00<007ooOol057oo0`00
37oo00<007ooOol0@goo00@007ooOol006Moo`00F7oo00<007ooOol08Woo0P0047oo00<007ooOol0
?Woo00<007ooOol01Goo00<007ooOol067oo100027oo00<007ooOol0@goo00@007ooOol006Moo`00
F7oo00<007ooOol097oo00<007ooOol03Goo00<007ooOol0?goo00<007ooOol00goo00<007ooOol0
7Goo1@000Woo00<007ooOol0A7oo00<007oo0000J7oo001HOol00`00Oomoo`0UOol00`00Oomoo`0<
Ool00`00Oomoo`0oOol00`00Oomoo`03Ool00`00Oomoo`0ROol30017Ool2001XOol005Qoo`03001o
ogoo02Ioo`8000]oo`03001oogoo045oo`05001oogooOol0001_Ool00`00Oomoo`1WOol005Qoo`80
02Uoo`03001oogoo00Qoo`03001oogoo045oo`04001oogoo003JOol005Qoo`03001oogoo02Uoo`03
001oogoo00Ioo`03001oogoo04=oo`800=]oo`00F7oo00<007ooOol0:Woo0P001Woo00<007ooOol0
@goo00<007ooOol0fWoo000kOol70004Ool20006Ool40006Ool00`00Oomoo`0/Ool00`00Oomoo`02
Ool00`00Oomoo`3oOolROol003ioo`03001oogoo00Eoo`8000Eoo`03001oogoo009oo`03001oogoo
00=oo`03001oogoo02eoo`05001oogooOol0003oOolTOol003ioo`03001oogoo015oo`03001oogoo
00=oo`03001oogoo02ioo`<00?moobEoo`00?Woo00<007ooOol04Goo00<007ooOol00goo0`00<7oo
00<007ooOol0ogoo8goo000nOol00`00Oomoo`0AOol00`00Oomoo`03Ool00`00Oomoo`3oOomFOol0
03ioo`03001oogoo00eoo`@000Ioo`03001oogoo0?mooeIoo`00?Woo00<007ooOol03Goo00<007oo
Ool01goo00<007ooOol0ogooEWoo000lOol3000?Ool00`00Oomoo`07Ool00`00Oomoo`3oOomFOol0
03ioo`03001oogoo00eoo`D000Eoo`03001oogoo0?mooeIoo`00F7oo00<007ooOol0ogooEWoo001H
Ool2003oOomGOol005Qoo`03001oogoo0?mooeIoo`00F7oo00<007ooOol0ogooEWoo001HOol00`00
Oomoo`3oOomFOol005Qoo`03001oogoo0?mooeIoo`00F7oo00<007ooOol0ogooEWoo001HOol2003o
OomGOol005Qoo`03001oogoo0?mooeIoo`00F7oo00<007ooOol0ogooEWoo001HOol00`00Oomoo`3o
OomFOol005Qoo`03001oogoo0?mooeIoo`00F7oo00<007ooOol0ogooEWoo001HOol2003oOomGOol0
05Qoo`03001oogoo0?mooeIoo`00F7oo00<007ooOol0ogooEWoo001HOol00`00Oomoo`3oOomFOol0
05Qoo`03001oogoo0?mooeIoo`00F7oo00<007ooOol0ogooEWoo001HOol00`00Oomoo`3oOomFOol0
05Qoo`800?mooeMoo`00F7oo00<007ooOol0ogooEWoo001HOol00`00Oomoo`3oOomFOol004eoo`H0
00Eoo`03001oogoo0?mooeIoo`00CGoo00<007ooOol00Woo00<007ooOol00goo00<007ooOol0ogoo
EWoo001>Ool00`00Oomoo`07Ool00`00Oomoo`3oOomFOol004moo`03001oogoo00Ioo`<00?mooeIo
o`00D7oo00<007ooOol01Goo00<007ooOol0ogooEWoo001AOol00`00Oomoo`04Ool00`00Oomoo`3o
OomFOol004eoo`03001oogoo009oo`03001oogoo00=oo`03001oogoo0?mooeIoo`00CGoo00<007oo
Ool00Woo00<007ooOol00goo00<007ooOol0ogooEWoo001>Ool40006Ool00`00Oomoo`3oOomFOol0
05Qoo`0300003`0?0?l03bh03bQoo`00F7oo0P00ogooEgoo001HOol00`00Oomoo`3oOomFOol005Qo
o`03001oogoo0?mooeIoo`00F7oo00<007ooOol0ogooEWoo001HOol00`00Oomoo`3oOomFOol005Qo
o`03001oogoo0?mooeIoo`00F7oo0P00ogooEgoo001HOol00`00Oomoo`3oOomFOol005Qoo`03001o
ogoo0?mooeIoo`00F7oo00<007ooOol0ogooEWoo001HOol00`00Oomoo`3oOomFOol005Qoo`03001o
ogoo0?mooeIoo`00F7oo0P00ogooEgoo001HOol00`00Oomoo`3oOomFOol005Qoo`03001oogoo0?mo
oeIoo`00F7oo00<007ooOol0ogooEWoo001HOol00`00Oomoo`3oOomFOol005Qoo`03001oogoo0?mo
oeIoo`00F7oo00<007ooOol0ogooEWoo001HOol2003oOomGOol005Qoo`03001oogoo0?mooeIoo`00
F7oo00<007ooOol0ogooEWoo000kOol60005Ool20006Ool40006Ool00`00Oomoo`3oOomFOol003]o
o`03001oogoo009oo`03001oogoo00=oo`8000Eoo`03001oogoo009oo`03001oogoo00=oo`03001o
ogoo0?mooeIoo`00?7oo00<007ooOol04goo00<007ooOol00goo00<007ooOol0ogooEWoo000mOol0
0`00Oomoo`0BOol00`00Oomoo`03Ool3003oOomFOol003ioo`03001oogoo015oo`03001oogoo00=o
o`03001oogoo0?mooeIoo`00?goo00<007ooOol037oo1000ogooGgoo000kOol00`00Oomoo`02Ool0
0`00Oomoo`0;Ool00`00Oomoo`3oOomPOol003]oo`03001oogoo009oo`03001oogoo00]oo`03001o
ogoo0?moof1oo`00?7oo10003Woo1@00ogooGWoo003oOonaOol00?mook5oo`00bGoo0`00i7oo003;
Ool00`00Oomoo`3ROol00<]oo`03001oogoo0>9oo`00G7oo1`000Woo0`000Woo0`0000=oo`000000
1@001Goo10000Woo1`0017oo1@000Woo1`0037oo00<007oo00000P001Woo100017oo0`0000=oo`00
00000Woo0`0000=oo`0000001Goo0P00hgoo001OOol00`00Oomoo`04Ool00`00Oomoo`02Ool00`00
Oomoo`03Ool00`00Oomoo`05Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`04Ool01@00
Oomoogoo00001Woo00<007ooOol03Goo0P000goo00<007ooOol00Woo00<007ooOol00Woo00@007oo
Ool000=oo`80009oo`04001oogooOol20006Ool2003SOol005moo`03001oogoo00Aoo`03001oogoo
009oo`03001oogoo00=oo`03001oogoo00Eoo`03001oogoo00Moo`03001oogoo00Aoo`05001oogoo
Ool00006Ool00`00Oomoo`0=Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`05Ool00`00
Oomoo`02Ool01000Oomoo`0017oo00<007ooOol00goo00@007ooOol00>9oo`00Ggoo00<007ooOol0
17oo00<007ooOol00Woo00<007ooOol00goo00<007ooOol01Goo00<007ooOol01goo00<007ooOol0
1Goo10001Woo00<007ooOol04Woo00<007ooOol00Woo00<007ooOol01Goo00<007ooOol00Woo00@0
07ooOol000Aoo`03001oogoo00=oo`04001oogoo003ROol005moo`03001oogoo00Aoo`8000=oo`03
001oogoo00=oo`03001oogoo00Eoo`03001oogoo00Moo`03001oogoo00Aoo`05001oogooOol00006
Ool00`00Oomoo`0>Ool40005Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000goo0P00
17oo00<007ooOol00Woo00<007ooOol0ggoo001OOol00`00Oomoo`03Ool2000017oo0000000017oo
0`001Goo1`000goo0`001goo0`001goo00<007ooOol03Goo00<007ooOol00Woo00<007ooOol01`00
0Woo0P000goo0P000goo0`0000=oo`00Ool00Woo0`000Woo0`00h7oo001OOol00`00Oomoo`0GOol0
0`00Oomoo`0IOol00`00Oomoo`0=Ool01000Oomoogoo0P0017oo00<007ooOol04Woo00<007ooOol0
jGoo001LOol7000FOol00`00Oomoo`0IOol00`00Oomoo`0>Ool300000goo001oo`03Ool00`00Oomo
o`0BOol00`00Oomoo`3YOol0075oo`03001oogoo00moo`03001oogoo00eoo`<002eoo`800>]oo`00
LGoo00<007ooOol03goo00<007ooOol0ogoo:goo003oOonaOol00?mook5oo`00ogoo/Goo003oOona
Ool00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogooOWoo00<007ooOol0<7oo003oOomn
Ool2000aOol005eoo`D000moo`8000Ioo`D0009oo`L000Aoo`<00003Ool0000000=oo`@000Aoo`D0
00ioo`D000Aoo`@000Aoo`D000aoo`<00004Ool000000002Ool2000017oo000000001Goo1@000goo
1@0017oo00<007oo00000P003Woo10001Goo10000goo0`000Woo0`0017oo10000goo1@001Goo1000
0goo1`003Goo10000goo0`000Woo0`000goo1@000goo1@001Woo100017oo00<007ooOol0;goo001M
Ool00`00Oomoo`02Ool00`00Oomoo`0<Ool20005Ool01@00Oomoogoo00001Woo00<007ooOol017oo
00@007ooOomoo`8000=oo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`0<Ool00`00
Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0>Ool01@00Oomoogoo000017oo
0P000goo00D007ooOomoo`0000=oo`03001oogoo00=oo`03001oogoo00Eoo`8000=oo`03001oogoo
00Yoo`03001oogoo009oo`05001oogooOol00004Ool01@00Oomoogoo000017oo00<007ooOol00Woo
00<007ooOol00Woo00D007ooOomoo`0000Moo`03001oogoo009oo`03001oogoo00=oo`03001oogoo
00eoo`03001oogoo009oo`05001oogooOol00004Ool01@00Oomoogoo00000goo00<007ooOol00goo
00<007ooOol01Woo00<007ooOol00Woo00@007ooOomoo`80031oo`00HWoo00<007ooOol02goo00@0
07ooOol000Aoo`05001oogooOol00006Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01@00Oomoogoo
00003Goo00<007ooOol037oo00<007ooOol017oo00<007ooOol00Woo00<007ooOol00Woo00<007oo
Ool03goo00<007oo00001Goo00<007ooOol00Woo00D007ooOomoo`0000=oo`03001oogoo00=oo`03
001oogoo00Eoo`03001oogoo009oo`03001oogoo00Uoo`03001oogoo00Moo`03001oogoo009oo`05
001oogooOol00004Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`02
Ool00`00Oomoo`03Ool00`00Oomoo`0<Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01@00Oomoogoo
00000goo00<007ooOol00goo00<007ooOol01Woo00<007ooOol0>7oo001NOol4000>Ool01000Oomo
o`001Goo10001Woo00<007ooOol017oo00<007ooOol00Woo00@007ooOomoo`H000Aoo`@000moo`03
001oogoo00Aoo`03001oogoo009oo`03001oogoo009oo`03001oogoo011oo`03001oogoo00Aoo`03
001oogoo009oo`03001oogoo009oo`@000Eoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo
00Moo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00
Oomoo`05Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`0<Ool00`00Oomoo`07Ool00`00
Oomoo`02Ool00`00Oomoo`02Ool40005Ool00`00Oomoo`06Ool00`00Oomoo`0hOol005eoo`03001o
ogoo009oo`03001oogoo00Yoo`03001oogoo009oo`05001oogooOol00003Ool00`00Oomoo`04Ool0
0`00Oomoo`04Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00D007ooOomoo`0000Aoo`03001o
ogoo00aoo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo009oo`80015oo`03001oogoo00Ao
o`8000=oo`05001oogooOol00003Ool00`00Oomoo`03Ool20007Ool4000<Ool00`00Oomoo`07Ool0
0`00Oomoo`02Ool01000Oomoogoo0P000goo00<007ooOol00Woo00<007ooOol01Woo0P001Woo00<0
07ooOol00Woo00<007ooOol00goo00<007ooOol03Goo00@007ooOomoo`8000=oo`8000=oo`05001o
ogooOol00003Ool00`00Oomoo`03Ool20007Ool00`00Oomoo`0hOol005ioo`D000]oo`<0009oo`<0
00=oo`<000Moo`03001oogoo00=oo`8000=oo`8000Aoo`@000Eoo`D000aoo`H000Aoo`@000Aoo`80
0004Ool00000000=Ool00`00Ool00005Ool00`00Ool000020005Ool30005Ool2000017oo00000000
0goo00<007ooOol00Woo00<007ooOol02Goo00<007ooOol00goo00<007ooOol00Woo10000goo0P00
00Aoo`00000000=oo`L000=oo`800004Ool000000004Ool40006Ool00`00Oomoo`0>Ool300000goo
001oo`02Ool00`00Ool000020005Ool30005Ool2000017oo000000000Woo1`00=Woo0023Ool00`00
Oomoo`0ZOol00`00Oomoo`0OOol01@00Oomoogoo000017oo00<007ooOol067oo00@007ooOomoo`80
00aoo`04001oogooOol2000FOol00`00Oomoo`0IOol00`00Oomoo`0FOol00`00Oomoo`0IOol00`00
Oomoo`0hOol008=oo`03001oogoo02Yoo`03001oogoo01ioo`<00004Ool000000003Ool00`00Oomo
o`0IOol300000goo001oo`0<Ool300000goo001oo`0EOol00`00Oomoo`0IOol00`00Oomoo`0FOol0
0`00Oomoo`0IOol00`00Oomoo`0hOol0085oo`<002eoo`<002Ioo`80069oo`<001Moo`8005Ioo`00
ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo0000\
\>"],
  ImageRangeCache->{{{135, 422}, {447.125, 270.188}} -> {-20.7392, 5.37921, 
  0.104176, 0.0235613}},
  CellTags->"Mean and standard deviation chart"]
}, Closed]],

Cell[OutputFormData["\<\
{{\"\", \"X\", \"S\"}, {\"CL\", 4.9564, 
  1.0036873191578564}, 
 {\"LCL\", 3.5238377990509964, 0}, 
 {\"UCL\", 6.388962200949004, 
  2.0967006704920057}}\
\>", "\<\
      X         S

CL    4.9564    1.00369

LCL   3.52384   0

UCL   6.38896   2.0967\
\>"], "Output",
  CellLabel->"Out[8]//TableForm=",
  CellTags->"Mean and standard deviation chart"]
}, Closed]],

Cell["Standard values given", "Subsubsection",
  PageBreakBelow->False,
  CellTags->"Mean and standard deviation chart"],

Cell["\<\
Standard values are known: \[Mu] = 5, \[Sigma] = 1\
\>", "Text",
  CellTags->"Mean and standard deviation chart"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?XbarSReportShSG\)\)], "Input",
  CellLabel->"In[9]:=",
  CellTags->"Mean and standard deviation chart"],

Cell["\<\
XbarSReportShSG[list,mu,sig] give the short
   report for a XbarS chart, standard given.\
\>", "Print",
  CellLabel->"From In[9]:=",
  CellTags->"Mean and standard deviation chart"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(XbarSReportShSG[data1, 5, 1]\)], "Input",
  CellLabel->"In[10]:=",
  CellTags->"Mean and standard deviation chart"],

Cell[OutputFormData["\<\
{{\"\", \"X\", \"S\"}, {\"CL\", 5., 
  0.9399856029866251}, 
 {\"LCL\", 6.261123023689533, 0.}, 
 {\"UCL\", 3.738876976310466, 
  1.8457819755338352}}\
\>", "\<\
      X         S

CL    5.        0.939986

LCL   6.26112   0.

UCL   3.73888   1.84578\
\>"], "Output",
  CellLabel->"Out[10]//TableForm=",
  CellTags->"Mean and standard deviation chart"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?XbarSReportSG\)\)], "Input",
  CellLabel->"In[11]:=",
  CellTags->"Mean and standard deviation chart"],

Cell["\<\
XbarSReportSG[list,mu,sig] give the full
   report for a XbarS chart, standard given.\
\>", "Print",
  CellLabel->"From In[11]:=",
  CellTags->"Mean and standard deviation chart"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(XbarSReportSG[data1, 5, 1]\)], "Input",
  CellLabel->"In[12]:=",
  CellTags->"Mean and standard deviation chart"],

Cell[OutputFormData["\<\
{{\"Subgroup\", \"Xmean\", \"S\"}, 
 {1, 5.336, 0.5907029710438235}, 
 {2, 4.720000000000001, 
  1.3174976280813564}, {3, 5.272, 
  1.5008897361232105}, 
 {4, 4.8660000000000005, 
  0.9988643551553936}, {5, 5.346, 
  0.7634985265211717}, 
 {6, 4.811999999999999, 
  0.7839451511426037}, {7, 4.462, 
  0.9548403007833302}, {8, 5.382, 
  1.4278200166687676}, 
 {9, 4.99, 1.1772213045982476}, 
 {10, 5.06, 1.322176236361855}, 
 {11, 4.97, 1.3779150917237244}, 
 {12, 4.642, 0.7281277360463616}, 
 {13, 4.37, 0.6858206762704081}, 
 {14, 4.53, 1.1624112869376313}, 
 {15, 4.806, 0.7396147645903238}, 
 {16, 4.486000000000001, 
  1.3928854942169513}, {17, 4.994, 
  0.9605363085276891}, {18, 5.392, 
  0.6622461777919143}, {19, 4.76, 
  0.9519978991573459}, {20, 5.932, 
  0.5747347214150195}, {\"CL\", 5., 
  0.9399856029866251}, 
 {\"LCL\", 6.261123023689533, 0.}, 
 {\"UCL\", 3.738876976310466, 
  1.8457819755338352}}\
\>", "\<\
Subgroup   Xmean     S

1          5.336     0.590703

2          4.72      1.3175

3          5.272     1.50089

4          4.866     0.998864

5          5.346     0.763499

6          4.812     0.783945

7          4.462     0.95484

8          5.382     1.42782

9          4.99      1.17722

10         5.06      1.32218

11         4.97      1.37792

12         4.642     0.728128

13         4.37      0.685821

14         4.53      1.16241

15         4.806     0.739615

16         4.486     1.39289

17         4.994     0.960536

18         5.392     0.662246

19         4.76      0.951998

20         5.932     0.574735

CL         5.        0.939986

LCL        6.26112   0.

UCL        3.73888   1.84578\
\>"], "Output",
  CellLabel->"Out[12]//TableForm=",
  CellTags->"Mean and standard deviation chart"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?XbarSChartSG\)\)], "Input",
  CellLabel->"In[13]:=",
  CellTags->"Mean and standard deviation chart"],

Cell["\<\
XbarSChartSG[list,mu,sig] plot the XbarChart
   of the entries in list, standard given.\
\>", "Print",
  CellLabel->"From In[13]:=",
  CellTags->"Mean and standard deviation chart"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(XbarSChartSG[data1, 5, 1]\)], "Input",
  CellLabel->"In[14]:=",
  CellTags->"Mean and standard deviation chart"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.047619 -1.14676 0.28262 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -6 -9 ]
[.5 -0.0125 6 0 ]
[.7381 -0.0125 -6 -9 ]
[.7381 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -26 -21.5625 ]
[.5 -0.0125 26 -9 ]
[-0.0125 .12503 -18 -4.5 ]
[-0.0125 .12503 0 4.5 ]
[-0.0125 .26634 -6 -4.5 ]
[-0.0125 .26634 0 4.5 ]
[-0.0125 .40765 -18 -4.5 ]
[-0.0125 .40765 0 4.5 ]
[-0.0125 .54896 -6 -4.5 ]
[-0.0125 .54896 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -30.5625 -5 ]
[-0.01875 .30902 -18 5 ]
[.5 .63053 -101 0 ]
[.5 .63053 101 25.75 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .26634 m
1 .26634 L
s
0 g
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(10)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(15)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(20)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -87 -25.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(subgroup) show
111.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .12503 m
.00625 .12503 L
s
[(4.5)] -0.0125 .12503 1 0 Mshowa
0 .26634 m
.00625 .26634 L
s
[(5)] -0.0125 .26634 1 0 Mshowa
0 .40765 m
.00625 .40765 L
s
[(5.5)] -0.0125 .40765 1 0 Mshowa
0 .54896 m
.00625 .54896 L
s
[(6)] -0.0125 .54896 1 0 Mshowa
.125 Mabswid
0 .15329 m
.00375 .15329 L
s
0 .18156 m
.00375 .18156 L
s
0 .20982 m
.00375 .20982 L
s
0 .23808 m
.00375 .23808 L
s
0 .2946 m
.00375 .2946 L
s
0 .32287 m
.00375 .32287 L
s
0 .35113 m
.00375 .35113 L
s
0 .37939 m
.00375 .37939 L
s
0 .43591 m
.00375 .43591 L
s
0 .46418 m
.00375 .46418 L
s
0 .49244 m
.00375 .49244 L
s
0 .5207 m
.00375 .5207 L
s
0 .09677 m
.00375 .09677 L
s
0 .06851 m
.00375 .06851 L
s
0 .04025 m
.00375 .04025 L
s
0 .01198 m
.00375 .01198 L
s
0 .57722 m
.00375 .57722 L
s
0 .60549 m
.00375 .60549 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -90.2813 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
66 10.2813 translate
90 rotate
-66 -10.2813 translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(X) show
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 7.375 moveto
(\\217) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .12503 m
1 .12503 L
s
gsave
.5 .63053 -162 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 33.75 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(X) show
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 7.375 moveto
(\\217) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(values) show
117.000 12.813 moveto
(for) show
141.000 12.813 moveto
(XbarS) show
177.000 12.813 moveto
(Control) show
225.000 12.813 moveto
(chart) show
255.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
63.000 26.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Initial) show
111.000 26.000 moveto
(Study) show
141.000 26.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.07143 .3613 m
.11905 .18721 L
.16667 .34321 L
.21429 .22847 L
.2619 .36413 L
.30952 .21321 L
.35714 .11429 L
.40476 .3743 L
.45238 .26352 L
.5 .2833 L
.54762 .25786 L
.59524 .16516 L
.64286 .08829 L
.69048 .13351 L
.7381 .21151 L
.78571 .12107 L
.83333 .26465 L
.88095 .37713 L
.92857 .19851 L
.97619 .52974 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[14]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012Q000`40O003h00Oogoo/Goo003oOona
Ool00?mook5oo`00jGoo10007goo0`00XGoo003]Ool00`00Oomoo`0MOol00`00Oomoo`2POol00>eo
o`03001oogoo01eoo`03001oogoo0:1oo`00cWoo1@001Goo0`0000Aoo`00001oo`800004Ool00000
0004Ool300000goo001oo`03Ool50005Ool40005Ool300000goo00000002Ool00`00Ool00002002N
Ool00<ioo`03001oogoo009oo`05001oogooOol00003Ool20003Ool20003Ool01000Oomoo`000goo
0P001Goo00<007ooOol01Goo00<007ooOol00Woo00D007ooOomoo`0000=oo`8000=oo`8000=oo`03
001oogoo09]oo`00dgoo00D007ooOomoo`0000Aoo`05001oogooOol00004Ool01000Oomoo`0017oo
00<007ooOol00goo00<007ooOol01Goo00<007ooOol00Woo00D007ooOomoo`0000Aoo`05001oogoo
Ool00004Ool00`00Oomoo`2KOol00<moo`@000Aoo`03001oogoo009oo`05001oogooOol00004Ool0
1000Oomoo`0017oo00<007ooOol00goo00<007ooOol01Goo00<007ooOol00Woo00D007ooOomoo`00
00Aoo`05001oogooOol00004Ool00`00Oomoo`2KOol00<ioo`03001oogoo009oo`05001oogooOol0
0004Ool01000Oomoogoo0P000goo00@007ooOol000=oo`8000Eoo`8000Ioo`03001oogoo009oo`05
001oogooOol00004Ool01000Oomoogoo0P000goo00<007ooOol0Vgoo003?Ool50002Ool20003Ool2
0003Ool00`00Ool000020004Ool300000goo00000003Ool2000017oo0000000017oo10000goo0P00
0goo0P000Woo0P0000Aoo`00000009ioo`00h7oo00<007ooOol0cGoo003POol00`00Oomoo`3=Ool0
0=moo`800<moo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol005eoo`@004Ao
o`@003moo`L000=oo`@003Yoo`L000=oo`@003Yoo`H000Aoo`@002Yoo`00G7oo00<007ooOol00Woo
00<007ooOol0@7oo00<007ooOol00Woo00<007ooOol0?goo00<007ooOol00goo00<007ooOol00Woo
00<007ooOol0>Woo00<007ooOol00goo00<007ooOol00Woo00<007ooOol0=goo00<007ooOol00Woo
00D007ooOomoo`0000Aoo`03001oogoo02Moo`00G7oo00<007ooOol00Woo00<007ooOol0AGoo00<0
07ooOol0?goo00<007ooOol00goo00<007ooOol00Woo00<007ooOol0>Woo00<007ooOol027oo00<0
07ooOol0>7oo00<007ooOol01Goo00<007ooOol00Woo00<007ooOol09goo001LOol00`00Oomoo`02
Ool00`00Oomoo`15Ool00`00Oomoo`0oOol00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`0j
Ool00`00Oomoo`08Ool00`00Oomoo`0iOol00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`0W
Ool005aoo`03001oogoo009oo`03001oogoo04Eoo`03001oogoo03moo`03001oogoo00=oo`03001o
ogoo009oo`03001oogoo03Yoo`03001oogoo00Qoo`03001oogoo03Yoo`03001oogoo00=oo`03001o
ogoo009oo`03001oogoo02Moo`00G7oo00<007ooOol00Woo00<007ooOol0@Goo1000@Woo00<007oo
Ool00goo00<007ooOol00Woo00<007ooOol0>Woo00<007ooOol017oo1000?Woo00<007ooOol00Woo
00<007ooOol00Woo00<007ooOol09goo001LOol00`00Oomoo`02Ool00`00Oomoo`11Ool00`00Oomo
o`13Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`0jOol00`00Oomoo`04Ool00`00Oomo
o`0kOol00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol09goo001LOol00`00Oomoo`02
Ool00`00Oomoo`11Ool00`00Oomoo`11Ool30005Ool00`00Oomoo`02Ool00`00Oomoo`0hOol30006
Ool00`00Oomoo`0kOol00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol09goo001MOol4
0014Ool50011Ool00`00Oomoo`04Ool4000mOol00`00Oomoo`04Ool5000jOol40005Ool4000ZOol0
0?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00F7oo
o`00<@00:7oo001HOol00`00Oomoo`05Ool00`00Oomoo`0;Ool00`00Oomoo`0;Ool00`00Oomoo`0<
Ool00`00Oomoo`0;Ool00`00Oomoo`0<Ool00`00Oomoo`0;Ool00`00Oomoo`0<Ool00`00Oomoo`0;
Ool00`00Oomoo`0;Ool00`00Oomoo`0<Ool00`00Oomoo`0;Ool00`00Oomoo`0<Ool00`00Oomoo`0;
Ool00`00Oomoo`0<Ool00`00Oomoo`0;Ool00`00Oomoo`0;Ool00`00Oomoo`0<Ool00`00Oomoo`0;
Ool00`00Oomoo`0<Ool00`00Oomoo`0;Ool00`00Oomoo`0]Ool005Qoo`03001oogoo00Eoo`03001o
ogoo04Eoo`03001oogoo04Eoo`03001oogoo04Eoo`03001oogoo04Eoo`03001oogoo02eoo`00F7oo
0P00ogooEgoo001HOol00`00Oomoo`3oOomFOol005Qoo`03001oogoo0?mooeIoo`00F7oo00<007oo
Ool0ogooEWoo001HOol00`00Oomoo`3oOomFOol005Qoo`03001oogoo0?mooeIoo`00F7oo00<007oo
Ool0ogooEWoo001HOol00`00Oomoo`3oOomFOol005Qoo`03001oogoo0?mooeIoo`00F7oo0P00ogoo
Egoo001HOol00`00Oomoo`3oOomFOol005Qoo`03001oogoo0?mooeIoo`00F7oo00<007ooOol0ogoo
EWoo001HOol00`00Oomoo`3oOomFOol005Qoo`03001oogoo0?mooeIoo`00F7oo00<007ooOol0ogoo
EWoo001HOol00`00Oomoo`3oOomFOol005Qoo`03001oogoo0?mooeIoo`00F7oo0P00ogooEgoo001H
Ool00`00Oomoo`3oOomFOol005Qoo`03001oogoo0?mooeIoo`00F7oo00<007ooOol0ogooEWoo001H
Ool00`00Oomoo`3oOomFOol005Qoo`03001oogoo0?mooeIoo`00F7oo00<007ooOol0`7oo00<007oo
Ool0TWoo001HOol00`00Oomoo`2oOol00`00Ool0002COol005Qoo`800<1oo`04001oogoo002BOol0
05Qoo`03001oogoo0;ioo`03001oogoo009oo`80091oo`00F7oo00<007ooOol0_Woo00<007ooOol0
17oo00<007ooOol0SGoo001HOol00`00Oomoo`2mOol00`00Oomoo`06Ool00`00Oomoo`2<Ool005Qo
o`03001oogoo0;aoo`03001oogoo00Qoo`03001oogoo08]oo`00?Goo10001Goo0P001Woo10001Woo
00<007ooOol0JWoo00<007ooOol0Cgoo00<007ooOol02Goo00<007ooOol0RWoo000oOol00`00Oomo
o`04Ool20005Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`1ZOol00`00Oomoo`1>Ool0
0`00Oomoo`0;Ool00`00Oomoo`29Ool003moo`03001oogoo011oo`03001oogoo00=oo`03001oogoo
06Uoo`80051oo`03001oogoo00aoo`03001oogoo01ioo`03001oogoo06Moo`00>goo1P004Goo00<0
07ooOol00goo00<007ooOol0JGoo00<007oo0000CWoo00<007ooOol03Woo0P007Woo00<007ooOol0
Igoo000lOol01000Oomoo`004Woo00<007ooOol00gooo`00<@00:7oo000lOol01000Oomoo`003Woo
10001Woo00<007ooOol0J7oo00@007ooOol004eoo`03001oogoo019oo`03001oogoo01Uoo`03001o
o`0006Qoo`00?Goo00<007oo00003Woo00<007ooOol01goo00<007ooOol0Igoo00D007ooOomoo`00
04aoo`03001oogoo01Aoo`03001oogoo01Moo`04001oogoo001XOol003eoo`03001oo`0000ioo`03
001oogoo00Moo`03001oogoo06Moo`05001oogooOol0001;Ool00`00Oomoo`0FOol00`00Oomoo`0F
Ool01@00Oomoogoo0000Igoo000nOol2000>Ool50005Ool00`00Oomoo`1VOol00`00Oomoo`02Ool0
0`00Oomoo`19Ool00`00Oomoo`0FOol00`00Oomoo`0EOol00`00Oomoo`02Ool00`00Oomoo`1UOol0
05Qoo`03001oogoo06Ioo`03001oogoo00=oo`03001oogoo04Moo`03001oogoo01Qoo`03001oogoo
01Aoo`03001oogoo009oo`03001oogoo06Eoo`00F7oo00<007ooOol0IGoo00<007ooOol017oo00<0
07ooOol0Agoo00<007ooOol067oo00<007ooOol04goo00<007ooOol017oo00<007ooOol0I7oo001H
Ool00`00Oomoo`1UOol00`00Oomoo`04Ool00`00Oomoo`16Ool00`00Oomoo`0JOol00`00Oomoo`0B
Ool00`00Oomoo`04Ool00`00Oomoo`1TOol005Qoo`8006Eoo`03001oogoo00Eoo`03001oogoo04Eo
o`03001oogoo01]oo`03001oogoo015oo`03001oogoo00Eoo`03001oogoo06Aoo`00F7oo00<007oo
Ool0I7oo00<007ooOol01Goo00<007ooOol0AGoo00<007ooOol077oo00<007ooOol047oo00<007oo
Ool01Woo00<007ooOol0Hgoo001HOol00`00Oomoo`1SOol00`00Oomoo`06Ool00`00Oomoo`14Ool0
0`00Oomoo`0NOol00`00Oomoo`0>Ool00`00Oomoo`07Ool00`00Oomoo`1SOol005Qoo`03001oogoo
06=oo`03001oogoo00Moo`03001oogoo04=oo`03001oogoo01ioo`03001oogoo00ioo`03001oogoo
00Moo`03001oogoo06=oo`00F7oo00<007ooOol0HWoo00<007ooOol027oo00<007ooOol0@Woo00<0
07ooOol087oo00<007ooOol037oo00<007ooOol02Goo00<007ooOol0HWoo001HOol00`00Oomoo`1R
Ool00`00Oomoo`08Ool00`00Oomoo`11Ool00`00Oomoo`0QOol00`00Oomoo`0<Ool00`00Oomoo`09
Ool00`00Oomoo`1ROol005Qoo`03001oogoo065oo`03001oogoo00Uoo`03001oogoo045oo`03001o
ogoo029oo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo069oo`00F7oo00<007ooOol0HGoo
00<007ooOol02Goo00<007ooOol0@7oo00<007ooOol097oo00<007ooOol02Goo00<007ooOol02goo
00<007ooOol0HGoo001HOol00`00Oomoo`1POol00`00Oomoo`0;Ool00`00Oomoo`0oOol00`00Oomo
o`0TOol00`00Oomoo`08Ool00`00Oomoo`0<Ool00`00Oomoo`1QOol005Qoo`80065oo`03001oogoo
00]oo`03001oogoo03ioo`03001oogoo02Ioo`03001oogoo00Moo`03001oogoo00aoo`03001oogoo
065oo`00F7oo00<007ooOol0Ggoo00<007ooOol037oo00<007ooOol0?Woo00<007ooOol09Woo00<0
07ooOol01Woo00<007ooOol03Woo00<007ooOol0H7oo001HOol00`00Oomoo`0QOol00`00Oomoo`0k
Ool00`00Oomoo`0<Ool00`00Oomoo`0mOol00`00Oomoo`0XOol00`00Oomoo`05Ool00`00Oomoo`0>
Ool00`00Oomoo`1POol005Qoo`03001oogoo025oo`03001oogoo03Yoo`03001oogoo00eoo`03001o
ogoo03eoo`03001oogoo02Qoo`03001oogoo00Aoo`03001oogoo00moo`03001oogoo061oo`00F7oo
00<007ooOol087oo00<007oo0000>goo00<007ooOol03Goo00<007ooOol0?7oo00<007ooOol0:Woo
00<007ooOol00goo00<007ooOol047oo00<007ooOol0Ggoo001HOol00`00Oomoo`0POol00`00Ool0
000jOol00`00Oomoo`0?Ool00`00Oomoo`0kOol00`00Oomoo`0[Ool01@00Oomoogoo00004goo00<0
07ooOol08Goo00<007ooOol0>goo001HOol00`00Oomoo`0POol00`00Ool0000jOol00`00Oomoo`0?
Ool00`00Oomoo`0jOol00`00Oomoo`0/Ool01@00Oomoogoo000057oo00<007ooOol087oo00<007oo
Ool0>goo001HOol00`00Oomoo`0POol01000Oomoo`00>7oo00<007ooOol047oo00<007ooOol0>Woo
00<007ooOol0;Goo00<007oo00005Goo00<007ooOol07goo0P00?Goo001HOol2000POol01@00Oomo
ogoo0000>7oo00<007ooOol047oo00<007ooOol0>Goo00<007ooOol0;Woo00<007oo00005Goo00<0
07ooOol07goo0P00?Goo001HOol00`00Oomoo`0OOol01@00Oomoogoo0000=goo00<007ooOol04Goo
00<007ooOol0>Goo00<007ooOol0;goo00<007ooOol05Goo00<007ooOol07Woo00<007oo0000?7oo
001HOol00`00Oomoo`0OOol00`00Oomoo`02Ool00`00Oomoo`0dOol00`00Oomoo`0AOol00`00Oomo
o`0hOol00`00Oomoo`18Ool00`00Oomoo`0NOol00`00Ool0000lOol005Qoo`03001oogoo01moo`03
001oogoo009oo`03001oogoo03=oo`03001oogoo01=oo`03001oogoo03Ioo`03001oogoo04Uoo`03
001oogoo01eoo`04001oogoo000lOol005Qoo`03001oogoo01ioo`03001oogoo00=oo`03001oogoo
03=oo`03001oogoo01=oo`03001oogoo03Ioo`03001oogoo04Yoo`03001oogoo01aoo`04001oogoo
000lOol005Qoo`03001oogoo01ioo`03001oogoo00Aoo`03001oogoo039oo`03001oogoo01=oo`03
001oogoo03Eoo`03001oogoo04]oo`03001oogoo01aoo`04001oogoo000lOol005Qoo`03001oogoo
01ioo`03001oogoo00Aoo`03001oogoo01Ioo`03001oogoo01Qoo`03001oogoo01Aoo`03001oogoo
03Eoo`03001oogoo04]oo`03001oogoo01aoo`04001oogoo000lOol005Qoo`03001oogoo01ioo`03
001oogoo00Aoo`03001oogoo01Ioo`03001oogoo01Qoo`03001oogoo01Aoo`03001oogoo03Aoo`03
001oogoo04eoo`03001oogoo01Yoo`05001oogooOol0000lOol005Qoo`03001oogoo01eoo`03001o
ogoo00Eoo`03001oogoo01Eoo`03001oo`0001Uoo`03001oogoo01Eoo`03001oogoo03=oo`03001o
ogoo04eoo`03001oogoo01Yoo`03001oogoo009oo`03001oogoo03Uoo`00F7oo0P007Woo00<007oo
Ool01Woo00<007ooOol057oo00<007oo00006Goo00<007ooOol05Goo00<007ooOol0<Woo00<007oo
Ool0CWoo00<007ooOol06Woo00<007ooOol00Woo00<007ooOol0>Goo001HOol00`00Oomoo`0MOol0
0`00Oomoo`06Ool00`00Oomoo`0COol01000Oomoo`0067oo00<007ooOol05Woo00<007ooOol0<Woo
00<007ooOol0Cgoo00<007ooOol067oo00<007ooOol00goo00<007ooOol0>Goo001HOol00`00Oomo
o`0LOol00`00Oomoo`07Ool00`00Oomoo`0COol01@00Oomoogoo00005goo00<007ooOol05Woo00<0
07ooOol0<Goo00<007ooOol0D7oo00<007ooOol067oo00<007ooOol00goo00<007ooOol0>Goo001H
Ool00`00Oomoo`0LOol00`00Oomoo`08Ool00`00Oomoo`0BOol01@00Oomoogoo00005goo00<007oo
Ool05Woo00<007ooOol0<Goo00<007ooOol0D7oo00<007ooOol067oo00<007ooOol00goo00<007oo
Ool0>Goo001HOol00`00Oomoo`0LOol00`00Oomoo`08Ool00`00Oomoo`0AOol00`00Oomoo`03Ool0
0`00Oomoo`0COol00`00Oomoo`0GOol00`00Oomoo`0`Ool00`00Oomoo`1BOol00`00Oomoo`0GOol0
0`00Oomoo`03Ool00`00Oomoo`0iOol004ioo`@000Ioo`03001oogoo01aoo`03001oogoo00Qoo`03
001oogoo015oo`03001oogoo00=oo`03001oogoo01=oo`03001oogoo01Qoo`03001oogoo02moo`03
001oogoo059oo`03001oogoo01Ioo`03001oogoo00Aoo`03001oogoo03Uoo`00CGoo00<007ooOol0
0Woo00<007ooOol00goo00<007ooOol06goo00<007ooOol02Woo00<007ooOol03goo00<007ooOol0
17oo00<007ooOol04goo00<007ooOol067oo00<007ooOol0;Woo00<007ooOol0Dgoo00<007ooOol0
5Woo00<007ooOol01Goo00<007ooOol0>7oo001BOol00`00Oomoo`03Ool00`00Oomoo`0KOol00`00
Oomoo`0:Ool00`00Oomoo`0?Ool00`00Oomoo`05Ool00`00Oomoo`0AOol00`00Oomoo`0IOol00`00
Oomoo`0/Ool2001GOol00`00Oomoo`0EOol00`00Oomoo`05Ool00`00Oomoo`0hOol0059oo`03001o
ogoo00=oo`<001/03`0300003`0?00X03`0300003`0?00l03`0300003`0?00D03`0300003`0?0140
3`0300003`0?01T03`0300003`0?01403`8001L03`8005T03`0300003`0?01@03`0300003`0?00H0
3`0300003`0?01003bQoo`00DWoo00<007ooOol00goo00<007ooOol06goo00<007ooOol02goo00<0
07ooOol03Goo00<007ooOol01Woo00<007ooOol04Goo00<007ooOol06Goo00<007ooOol04Goo00@0
07oo000001=oo`8005]oo`03001oogoo01Aoo`03001oogoo00Ioo`03001oogoo03Qoo`00CWoo1000
1Woo00<007ooOol06Woo00<007ooOol037oo00<007ooOol03Goo00<007ooOol01goo00<007ooOol0
47oo00<007ooOol06Woo00<007ooOol03goo00<007ooOol00Woo0`003goo00<007ooOol0G7oo00<0
07ooOol04goo00<007ooOol01Woo00<007ooOol0>7oo001>Ool00`00Oomoo`07Ool00`00Oomoo`0J
Ool00`00Oomoo`0<Ool00`00Oomoo`0<Ool00`00Oomoo`08Ool00`00Oomoo`0?Ool00`00Oomoo`0K
Ool00`00Oomoo`0?Ool00`00Oomoo`05Ool2000;Ool2001OOol00`00Oomoo`0COol00`00Oomoo`06
Ool00`00Oomoo`0hOol004ioo`03001oogoo00Moo`03001oogoo01Yoo`03001oogoo00eoo`03001o
ogoo00]oo`03001oogoo00Qoo`03001oogoo00moo`03001oogoo01]oo`03001oogoo00ioo`03001o
ogoo00Qoo`<000Ioo`80069oo`03001oogoo015oo`03001oogoo00Moo`03001oogoo03Qoo`00CWoo
1@001Goo00<007ooOol06Goo00<007ooOol03Woo00<007ooOol02goo00<007ooOol02Goo00<007oo
Ool03Woo00<007ooOol06goo00<007ooOol03Woo00<007ooOol02goo0P000Woo0P00I7oo00<007oo
Ool04Goo00<007ooOol01goo00<007ooOol0>7oo001HOol00`00Oomoo`0IOol00`00Oomoo`0>Ool0
0`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0=Ool00`00Oomoo`0LOol00`00Oomoo`0=Ool0
0`00Oomoo`0>Ool2001VOol00`00Oomoo`0AOol00`00Oomoo`08Ool00`00Oomoo`0gOol005Qoo`03
001oogoo01Uoo`03001oogoo00moo`03001oogoo00Uoo`03001oogoo00]oo`03001oogoo00aoo`03
001oogoo01aoo`03001oogoo00eoo`03001oogoo07Moo`03001oogoo011oo`03001oogoo00Qoo`03
001oogoo03Moo`00F7oo00<007ooOol06Goo00<007ooOol03goo00<007ooOol027oo00<007ooOol0
37oo00<007ooOol037oo00<007ooOol07Goo00<007ooOol037oo00<007ooOol0Mgoo00<007ooOol0
3goo00<007ooOol02Goo00<007ooOol0=goo001HOol2000IOol00`00Oomoo`0@Ool00`00Oomoo`08
Ool00`00Oomoo`0<Ool00`00Oomoo`0;Ool00`00Oomoo`0NOol00`00Oomoo`0;Ool00`00Oomoo`1i
Ool00`00Oomoo`0>Ool00`00Oomoo`09Ool00`00Oomoo`0gOol005Qoo`03001oogoo01Qoo`03001o
ogoo015oo`03001oogoo00Moo`03001oogoo00eoo`03001oogoo00Yoo`03001oogoo01ioo`03001o
ogoo00]oo`03001oogoo07Uoo`03001oogoo00ioo`03001oogoo00Uoo`03001oogoo03Moo`00:Woo
00<007ooOol017oo00<007ooOol097oo00<007ooOol067oo00<007ooOol04Goo00<007ooOol01Woo
00<007ooOol03Woo00<007ooOol02Woo00<007ooOol07Woo00<007ooOol02Woo00<007ooOol0Ngoo
00<007ooOol037oo00<007ooOol02Woo00<007ooOol0=goo000XOol01000Ool0000017oo0P009Woo
00<007ooOol067oo00<007ooOol04Goo00<007ooOol01Woo00<007ooOol03Woo00<007ooOol02Goo
00<007ooOol07goo00<007ooOol02Woo00<007ooOol0Ngoo00<007ooOol037oo00<007ooOol02Woo
00<007ooOol0=goo000XOol01@00Ool007oo00000Woo00<007oo00009Woo00<007ooOol05goo00<0
07ooOol04Woo00<007ooOol01Goo00<007ooOol047oo00<007ooOol027oo00<007ooOol07goo00<0
07ooOol02Goo00<007ooOol0O7oo00<007ooOol037oo00<007ooOol02goo00<007ooOol0=Woo000X
Ool00`00Oomoo`02Ool2000YOol00`00Oomoo`0GOol00`00Oomoo`0COol00`00Oomoo`04Ool00`00
Oomoo`0@Ool00`00Oomoo`08Ool00`00Oomoo`0POol00`00Oomoo`08Ool00`00Oomoo`1mOol00`00
Oomoo`0;Ool00`00Oomoo`0;Ool00`00Oomoo`0fOol002Qoo`05001oo`00Ool00002Ool00`00Ool0
000VOol00`00Oomoo`0GOol00`00Oomoo`0COol00`00Oomoo`04Ool00`00Oomoo`0AOol00`00Oomo
o`07Ool00`00Oomoo`0POol00`00Oomoo`08Ool00`00Oomoo`1mOol00`00Oomoo`0:Ool00`00Oomo
o`0<Ool00`00Oomoo`0fOol002Qoo`04001oo`000004Ool2000VOol00`00Oomoo`0GOol00`00Oomo
o`0COol00`00Oomoo`03Ool00`00Oomoo`0BOol00`00Oomoo`06Ool00`00Oomoo`0QOol00`00Oomo
o`07Ool00`00Oomoo`1oOol00`00Oomoo`09Ool00`00Oomoo`0<Ool00`00Oomoo`0fOol002Yoo`03
001oogoo00Aoo`03001oogoo02Aoo`03001oogoo01Ioo`03001oogoo01Eoo`03001oogoo009oo`03
001oogoo019oo`03001oogoo00Ioo`03001oogoo025oo`03001oogoo00Moo`03001oogoo07moo`03
001oogoo00Uoo`03001oogoo00aoo`03001oogoo03Ioo`00F7oo0P005goo00<007ooOol05Goo00D0
07ooOomoo`0001Ioo`03001oogoo00Eoo`03001oogoo025oo`03001oogoo00Ioo`03001oogoo081o
o`03001oogoo00Qoo`03001oogoo00eoo`03001oogoo03Ioo`00F7oo00<007ooOol05Woo00<007oo
Ool05Goo00D007ooOomoo`0001Ioo`03001oogoo00Aoo`03001oogoo02=oo`03001oogoo00Eoo`03
001oogoo085oo`03001oogoo00Moo`03001oogoo00eoo`03001oogoo03Ioo`00F7oo00<007ooOol0
5Goo00<007ooOol05goo00@007ooOol001Ioo`03001oogoo00Aoo`03001oogoo02=oo`03001oogoo
00Eoo`03001oogoo085oo`03001oogoo00Moo`03001oogoo00ioo`03001oogoo03Eoo`00F7oo00<0
07ooOol05Goo00<007ooOol05goo00<007oo000067oo00<007ooOol00goo00<007ooOol08goo00<0
07ooOol017oo00<007ooOol0Pgoo00<007ooOol01Woo00<007ooOol03Woo00<007ooOol0=Goo001H
Ool00`00Oomoo`0EOol00`00Oomoo`0GOol00`00Ool0000HOol00`00Oomoo`02Ool00`00Oomoo`0T
Ool00`00Oomoo`04Ool00`00Oomoo`23Ool00`00Oomoo`05Ool00`00Oomoo`0?Ool00`00Oomoo`0e
Ool005Qoo`03001oogoo01Eoo`03001oogoo01Qoo`03001oogoo01Moo`03001oogoo009oo`03001o
ogoo02Aoo`03001oogoo00=oo`03001oogoo08Aoo`03001oogoo00Eoo`03001oogoo00moo`03001o
ogoo03Eoo`00F7oo00<007ooOol057oo00<007ooOol06Goo00<007ooOol067oo00D007ooOomoo`00
02Ioo`03001oogoo00=oo`03001oogoo08Eoo`03001oogoo00Aoo`03001oogoo00moo`03001oogoo
03Eoo`00F7oo00<007ooOol057oo00<007ooOol0=7oo00D007ooOomoo`0002Moo`05001oogooOol0
0028Ool00`00Oomoo`04Ool00`00Oomoo`0?Ool00`00Oomoo`0eOol005Qoo`8001Eoo`03001oogoo
03Eoo`03001oo`0002Qoo`05001oogooOol00029Ool00`00Oomoo`02Ool00`00Oomoo`0@Ool00`00
Oomoo`0eOol005Qoo`03001oogoo01Aoo`03001oogoo03Eoo`03001oo`0002Qoo`05001oogooOol0
0029Ool00`00Oomoo`02Ool00`00Oomoo`0AOol00`00Oomoo`0dOol005Qoo`03001oogoo01=oo`03
001oogoo03Ioo`03001oo`0002Qoo`04001oogoo002;Ool01@00Oomoogoo00004goo00<007ooOol0
=7oo001HOol00`00Oomoo`0COol00`00Oomoo`0gOol00`00Oomoo`0WOol01000Oomoo`00Rgoo00@0
07ooOol001Aoo`03001oogoo03Aoo`00F7oo00<007ooOol0CGoo00<007ooOol09goo00<007oo0000
S7oo00@007ooOol001Aoo`03001oogoo03Aoo`00F7oo00<007ooOol0N7oo0P00SGoo00<007oo0000
57oo00<007ooOol0=7oo001HOol00`00Oomoo`1hOol00`00Oomoo`2<Ool00`00Ool0000DOol00`00
Oomoo`0dOol005Qoo`03001oogoo07Qoo`03001oogoo08eoo`03001oogoo01=oo`03001oogoo03Ao
o`00F7oo00<007ooOol0ogoo2Goo00<007ooOol057oo00<007ooOol0<goo001HOol2003oOolQOol0
0`00Oomoo`0cOol005Qoo`03001oogoo0?moob1oo`03001oogoo03=oo`00F7oo00<007ooOol0ogoo
87oo00<007ooOol0<goo001HOol00`00Oomoo`3oOolPOol00`00Oomoo`0cOol005Qoo`03001oogoo
0?moob1oo`03001oogoo03=oo`00?7oo10001Woo0P001Woo10001Woo00<007ooOol0ogoo87oo00<0
07ooOol0<goo000kOol00`00Oomoo`02Ool00`00Oomoo`03Ool20005Ool00`00Oomoo`02Ool00`00
Oomoo`03Ool00`00Oomoo`3oOolQOol00`00Oomoo`0bOol0041oo`03001oogoo00moo`03001oogoo
00=oo`03001oogoo0?moob5oo`03001oogoo039oo`00@7oo00<007ooOol03goo00<007ooOol00goo
0`00ogoo8Goo00<007ooOol0<Woo0010Ool00`00Oomoo`0?Ool00`00Oomoo`03Ool00`00Oomoo`3o
OolQOol00`00Oomoo`0bOol003aoo`@000ioo`@000Ioo`03001oogoo0?moob5oo`03001oogoo039o
o`00?7oo00<007ooOol03goo00<007ooOol01goo00<007ooOol0ogoo8Goo00<007ooOol0<Woo000l
Ool00`00Oomoo`0?Ool00`00Oomoo`07Ool00`00Oomoo`3oOolQOol00`00Oomoo`0bOol003aoo`D0
00eoo`D000Eoo`03001oogoo0?moob9oo`03001oogoo035oo`00F7oo00<007ooOol0ogoo8Woo00<0
07ooOol0<Goo001HOol00`00Oomoo`3oOolROol00`00Oomoo`0aOol005Qoo`03001oogoo0?moob9o
o`03001oogoo035oo`00F7oo0P00ogoo8goo00<007ooOol0<Goo001HOol00`00Oomoo`3oOolROol0
0`00Oomoo`0aOol005Qoo`03001oogoo0?moob9oo`03001oogoo035oo`00F7oo00<007ooOol0ogoo
8Woo00<007ooOol0<Goo001HOol00`00Oomoo`3oOolSOol00`00Oomoo`0`Ool005Qoo`03001oogoo
0?moob=oo`03001oogoo031oo`00F7oo00<007ooOol0ogoo8goo00<007ooOol0<7oo001HOol00`00
Oomoo`3oOolSOol00`00Oomoo`0`Ool005Qoo`800?moobAoo`03001oogoo031oo`00F7oo00<007oo
Ool0ogoo8goo00<007ooOol0<7oo001HOol00`00Oomoo`3oOolSOol00`00Oomoo`0`Ool005Qoo`03
001oogoo0?moobAoo`03001oogoo02moo`00F7oo00<007ooOol0ogoo97oo00<007ooOol0;goo001H
Ool00`00Oomoo`3oOolTOol00`00Oomoo`0_Ool005Qoo`03001oogoo0?moobAoo`03001oogoo02mo
o`00F7oo00<007ooOol0ogoo97oo00<007ooOol0;goo001HOol00`00Oomoo`3oOolTOol00`00Oomo
o`0_Ool005Qoo`800?moobEoo`03001oogoo02moo`00F7oo00<007ooOol0ogoo9Goo00<007ooOol0
;Woo001HOol00`00Oomoo`3oOolUOol00`00Oomoo`0^Ool005Qoo`03001oogoo0?moobEoo`03001o
ogoo02ioo`00F7oo00<007ooOol0ogoo9Goo00<007ooOol0;Woo001HOol00`00Oomoo`3oOolUOol0
0`00Oomoo`0^Ool005Qoo`03001oogoo0?moobEoo`03001oogoo02ioo`00F7oo00<007ooOol0ogoo
9Goo00<007ooOol0;Woo001HOol00`00Oomoo`3oOolVOol00`00Oomoo`0]Ool005Qoo`800?moobMo
o`03001oogoo02eoo`00F7oo00<007ooOol0ogoo9Woo00<007ooOol0;Goo001HOol00`00Oomoo`3o
OolVOol00`00Oomoo`0]Ool005Qoo`03001oogoo0?mooeIoo`00F7oo00<007ooOol0ogooEWoo001?
Ool40005Ool00`00Oomoo`3oOomFOol004ioo`03001oogoo009oo`03001oogoo009oo`03001oogoo
0?mooeIoo`00CWoo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol0ogooEWoo001>Ool20003
Ool00`00Oomoo`02Ool3003oOomFOol004ioo`03001oo`00008000Eoo`03001oogoo0?mooeIoo`00
CWoo00<007ooOol01goo00<007ooOol0ogooEWoo001?Ool00`00Oomoo`06Ool00`00Oomoo`3oOomF
Ool0051oo`03001oogoo00Eoo`03001oogoo0?mooeIoo`00DGoo0`0017oo00<007ooOol0ogooEWoo
001HOol00`00Oomoo`3oOomFOol005Qoo`03001oogoo0?mooeIoo`00F7oo00<007ooOol0ogooEWoo
001HOol2003oOomGOol005Qoo`03001oogoo0?mooeIoo`00F7oo00<007ooOol0ogooEWoo001HOol0
0`00Oomoo`3oOomFOol005Qoo`03001oogoo0?mooeIoo`00F7oo00<007ooOol0ogooEWoo001HOol0
0`00Oomoo`3oOomFOol005Qoo`03001oogoo0?mooeIoo`00F7oo0P00ogooEgoo001HOol00`00Oomo
o`3oOomFOol005Qoo`03001oogoo0?mooeIoo`00F7oo00<007ooOol0ogooEWoo001HOol00`00Oomo
o`3oOomFOol00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol00<Uo
o`<00>Aoo`00bgoo00<007ooOol0hWoo003;Ool00`00Oomoo`3ROol005aoo`L0009oo`<0009oo`<0
0003Ool0000000D000Eoo`@0009oo`L000Aoo`D0009oo`L000aoo`03001oo`00008000Ioo`@000Ao
o`<00003Ool00000009oo`<00003Ool0000000Eoo`800>=oo`00Ggoo00<007ooOol017oo00<007oo
Ool00Woo00<007ooOol00goo00<007ooOol01Goo00<007ooOol00Woo00<007ooOol00Woo00<007oo
Ool017oo00D007ooOomoo`0000Ioo`03001oogoo00eoo`8000=oo`03001oogoo009oo`03001oogoo
009oo`04001oogoo0003Ool20002Ool01000Oomoogoo0P001Woo0P00hgoo001OOol00`00Oomoo`04
Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`05Ool00`00Oomoo`07Ool00`00Oomoo`04
Ool01@00Oomoogoo00001Woo00<007ooOol03Goo00<007ooOol00Woo00<007ooOol00Woo00<007oo
Ool01Goo00<007ooOol00Woo00@007ooOol000Aoo`03001oogoo00=oo`04001oogoo003ROol005mo
o`03001oogoo00Aoo`03001oogoo009oo`03001oogoo00=oo`03001oogoo00Eoo`03001oogoo00Mo
o`03001oogoo00Eoo`@000Ioo`03001oogoo019oo`03001oogoo009oo`03001oogoo00Eoo`03001o
ogoo009oo`04001oogoo0004Ool00`00Oomoo`03Ool01000Oomoo`00hWoo001OOol00`00Oomoo`04
Ool20003Ool00`00Oomoo`03Ool00`00Oomoo`05Ool00`00Oomoo`07Ool00`00Oomoo`04Ool01@00
Oomoogoo00001Woo00<007ooOol03Woo10001Goo00<007ooOol01Goo00<007ooOol00Woo00@007oo
Ool000=oo`8000Aoo`03001oogoo009oo`03001oogoo0=moo`00Ggoo00<007ooOol00goo0P0000Ao
o`00000000Aoo`<000Eoo`L000=oo`<000Moo`<000Moo`03001oogoo00eoo`03001oogoo009oo`03
001oogoo00L0009oo`8000=oo`8000=oo`<00003Ool007oo009oo`<0009oo`<00>1oo`00Ggoo00<0
07ooOol05goo00<007ooOol06Goo00<007ooOol03Goo00@007ooOomoo`8000Aoo`03001oogoo019o
o`03001oogoo0>Uoo`00G7oo1`005Woo00<007ooOol06Goo00<007ooOol03Woo0`0000=oo`00Ool0
0goo00<007ooOol04Woo00<007ooOol0jGoo001aOol00`00Oomoo`0?Ool00`00Oomoo`0=Ool3000]
Ool2003[Ool0075oo`03001oogoo00moo`03001oogoo0?moob]oo`00ogoo/Goo003oOonaOol00?mo
ok5oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol00?moogioo`03001oogoo
031oo`00ogooOWoo0P00<Goo001LOol3000017oo000000003Woo0P001Woo1@000Woo1`0017oo0`00
00=oo`0000000goo100017oo1@003Woo1@0017oo100017oo1@0037oo0`0000Aoo`000000009oo`80
0004Ool000000005Ool50003Ool50004Ool00`00Ool00002000>Ool40005Ool40003Ool30002Ool3
0004Ool40003Ool50005Ool40003Ool7000=Ool40003Ool30002Ool30003Ool50003Ool50006Ool4
0004Ool00`00Oomoo`0_Ool005eoo`05001oogooOol0000?Ool20005Ool01@00Oomoogoo00001Woo
00<007ooOol017oo00@007ooOomoo`8000=oo`03001oogoo009oo`05001oogooOol00004Ool00`00
Oomoo`0<Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0>Ool01@00
Oomoogoo000017oo0P000goo00D007ooOomoo`0000=oo`03001oogoo00=oo`03001oogoo00Eoo`80
00=oo`03001oogoo00Yoo`03001oogoo009oo`05001oogooOol00004Ool01@00Oomoogoo000017oo
00<007ooOol00Woo00<007ooOol00Woo00D007ooOomoo`0000Moo`03001oogoo009oo`03001oogoo
00=oo`03001oogoo00eoo`03001oogoo009oo`05001oogooOol00004Ool01@00Oomoogoo00000goo
00<007ooOol00goo00<007ooOol01Woo00<007ooOol00Woo00@007ooOomoo`80031oo`00GWoo00<0
07oo00003goo00@007ooOol000Aoo`05001oogooOol00006Ool00`00Oomoo`04Ool00`00Oomoo`02
Ool01@00Oomoogoo00003Goo00<007ooOol037oo00<007ooOol017oo00<007ooOol00Woo00<007oo
Ool00Woo00<007ooOol03goo00<007oo00001Goo00<007ooOol00Woo00D007ooOomoo`0000=oo`03
001oogoo00=oo`03001oogoo00Eoo`03001oogoo009oo`03001oogoo00Uoo`03001oogoo00Moo`03
001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`05
Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`0<Ool00`00Oomoo`07Ool00`00Oomoo`02
Ool01@00Oomoogoo00000goo00<007ooOol00goo00<007ooOol01Woo00<007ooOol0>7oo001OOol0
0`00Oomoo`0>Ool01000Oomoo`001Goo10001Woo00<007ooOol017oo00<007ooOol00Woo00@007oo
Oomoo`H000Aoo`@000moo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo009oo`03001oogoo
011oo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo009oo`@000Eoo`03001oogoo00Yoo`03
001oogoo00Uoo`03001oogoo00Moo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`02
Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`0<
Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`02Ool40005Ool00`00Oomoo`06Ool00`00
Oomoo`0hOol005moo`03001oogoo00eoo`03001oogoo009oo`05001oogooOol00003Ool00`00Oomo
o`04Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00D007ooOomoo`0000Ao
o`03001oogoo00aoo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo009oo`80015oo`03001o
ogoo00Aoo`8000=oo`05001oogooOol00003Ool00`00Oomoo`03Ool20007Ool4000<Ool00`00Oomo
o`07Ool00`00Oomoo`02Ool01000Oomoogoo0P000goo00<007ooOol00Woo00<007ooOol01Woo0P00
1Woo00<007ooOol00Woo00<007ooOol00goo00<007ooOol03Goo00@007ooOomoo`8000=oo`8000=o
o`05001oogooOol00003Ool00`00Oomoo`03Ool20007Ool00`00Oomoo`0hOol005ioo`03001oo`00
00eoo`<0009oo`<000=oo`<000Moo`03001oogoo00=oo`8000=oo`8000Aoo`@000Eoo`D000aoo`H0
00Aoo`@000Aoo`800004Ool00000000=Ool00`00Ool00005Ool00`00Ool000020005Ool30005Ool2
000017oo000000000goo00<007ooOol00Woo00<007ooOol02Goo00<007ooOol00goo00<007ooOol0
0Woo10000goo0P0000Aoo`00000000=oo`L000=oo`800004Ool000000004Ool40006Ool00`00Oomo
o`0>Ool300000goo001oo`02Ool00`00Ool000020005Ool30005Ool2000017oo000000000Woo1`00
=Woo001MOol01@00Oomoogoo00008Goo00<007ooOol0:Woo00<007ooOol07goo00D007ooOomoo`00
00Aoo`03001oogoo01Qoo`04001oogooOol2000<Ool01000Oomoogoo0P005Woo00<007ooOol06Goo
00<007ooOol05Woo00<007ooOol06Goo00<007ooOol0>7oo001LOol3000017oo0000000087oo00<0
07ooOol0:Woo00<007ooOol07Woo0`0000Aoo`00000000=oo`03001oogoo01Uoo`<00003Ool007oo
00aoo`<00003Ool007oo01Eoo`03001oogoo01Uoo`03001oogoo01Ioo`03001oogoo01Uoo`03001o
ogoo03Qoo`00PGoo0`00;Goo0`009Woo0P00HWoo0`005goo0P00EWoo001MOol5003oOom?Ool00?mo
ok5oo`00ogoo/Goo003oOonaOol00001\
\>"],
  ImageRangeCache->{{{135, 422}, {240, 63.0625}} -> {-20.7392, 4.7418, 
  0.104176, 0.0175527}},
  CellTags->"Mean and standard deviation chart"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.047619 -0.185657 0.476651 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -6 -9 ]
[.5 -0.0125 6 0 ]
[.7381 -0.0125 -6 -9 ]
[.7381 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -26 -21.5625 ]
[.5 -0.0125 26 -9 ]
[-0.0125 .005 -18 -4.5 ]
[-0.0125 .005 0 4.5 ]
[-0.0125 .10033 -18 -4.5 ]
[-0.0125 .10033 0 4.5 ]
[-0.0125 .19566 -18 -4.5 ]
[-0.0125 .19566 0 4.5 ]
[-0.0125 .29099 -6 -4.5 ]
[-0.0125 .29099 0 4.5 ]
[-0.0125 .38632 -18 -4.5 ]
[-0.0125 .38632 0 4.5 ]
[-0.0125 .48165 -18 -4.5 ]
[-0.0125 .48165 0 4.5 ]
[-0.0125 .57698 -18 -4.5 ]
[-0.0125 .57698 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -30.5625 -5 ]
[-0.01875 .30902 -18 5 ]
[.5 .63053 -101 0 ]
[.5 .63053 101 25.75 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .26239 m
1 .26239 L
s
0 g
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(10)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(15)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(20)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -87 -25.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(subgroup) show
111.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .005 m
.00625 .005 L
s
[(0.4)] -0.0125 .005 1 0 Mshowa
0 .10033 m
.00625 .10033 L
s
[(0.6)] -0.0125 .10033 1 0 Mshowa
0 .19566 m
.00625 .19566 L
s
[(0.8)] -0.0125 .19566 1 0 Mshowa
0 .29099 m
.00625 .29099 L
s
[(1)] -0.0125 .29099 1 0 Mshowa
0 .38632 m
.00625 .38632 L
s
[(1.2)] -0.0125 .38632 1 0 Mshowa
0 .48165 m
.00625 .48165 L
s
[(1.4)] -0.0125 .48165 1 0 Mshowa
0 .57698 m
.00625 .57698 L
s
[(1.6)] -0.0125 .57698 1 0 Mshowa
.125 Mabswid
0 .02884 m
.00375 .02884 L
s
0 .05267 m
.00375 .05267 L
s
0 .0765 m
.00375 .0765 L
s
0 .12417 m
.00375 .12417 L
s
0 .148 m
.00375 .148 L
s
0 .17183 m
.00375 .17183 L
s
0 .2195 m
.00375 .2195 L
s
0 .24333 m
.00375 .24333 L
s
0 .26716 m
.00375 .26716 L
s
0 .31483 m
.00375 .31483 L
s
0 .33866 m
.00375 .33866 L
s
0 .36249 m
.00375 .36249 L
s
0 .41016 m
.00375 .41016 L
s
0 .43399 m
.00375 .43399 L
s
0 .45782 m
.00375 .45782 L
s
0 .50549 m
.00375 .50549 L
s
0 .52932 m
.00375 .52932 L
s
0 .55315 m
.00375 .55315 L
s
0 .60082 m
.00375 .60082 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -90.2813 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
66 10.2813 translate
90 rotate
-66 -10.2813 translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -162 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 33.75 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
75.000 12.813 moveto
(values) show
117.000 12.813 moveto
(for) show
141.000 12.813 moveto
(XbarS) show
177.000 12.813 moveto
(Control) show
225.000 12.813 moveto
(chart) show
255.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
63.000 26.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Initial) show
111.000 26.000 moveto
(Study) show
141.000 26.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.07143 .0959 m
.11905 .44233 L
.16667 .52974 L
.21429 .29045 L
.2619 .17827 L
.30952 .18801 L
.35714 .26947 L
.40476 .49491 L
.45238 .37547 L
.5 .44456 L
.54762 .47113 L
.59524 .16141 L
.64286 .14124 L
.69048 .36841 L
.7381 .16688 L
.78571 .47826 L
.83333 .27218 L
.88095 .13 L
.92857 .26811 L
.97619 .08829 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[14]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012Q000`40O003h00Oogoo/Goo003oOona
Ool00?mook5oo`00jGoo10007goo0`00XGoo003]Ool00`00Oomoo`0MOol00`00Oomoo`2POol00>eo
o`03001oogoo01eoo`03001oogoo0:1oo`00cWoo1@001Goo0`0000Aoo`00001oo`800004Ool00000
0004Ool300000goo001oo`03Ool50005Ool40005Ool300000goo00000002Ool00`00Ool00002002N
Ool00<ioo`03001oogoo009oo`05001oogooOol00003Ool20003Ool20003Ool01000Oomoo`000goo
0P001Goo00<007ooOol01Goo00<007ooOol00Woo00D007ooOomoo`0000=oo`8000=oo`8000=oo`03
001oogoo09]oo`00dgoo00D007ooOomoo`0000Aoo`05001oogooOol00004Ool01000Oomoo`0017oo
00<007ooOol00goo00<007ooOol01Goo00<007ooOol00Woo00D007ooOomoo`0000Aoo`05001oogoo
Ool00004Ool00`00Oomoo`2KOol00<moo`@000Aoo`03001oogoo009oo`05001oogooOol00004Ool0
1000Oomoo`0017oo00<007ooOol00goo00<007ooOol01Goo00<007ooOol00Woo00D007ooOomoo`00
00Aoo`05001oogooOol00004Ool00`00Oomoo`2KOol00<ioo`03001oogoo009oo`05001oogooOol0
0004Ool01000Oomoogoo0P000goo00@007ooOol000=oo`8000Eoo`8000Ioo`03001oogoo009oo`05
001oogooOol00004Ool01000Oomoogoo0P000goo00<007ooOol0Vgoo003?Ool50002Ool20003Ool2
0003Ool00`00Ool000020004Ool300000goo00000003Ool2000017oo0000000017oo10000goo0P00
0goo0P000Woo0P0000Aoo`00000009ioo`00h7oo00<007ooOol0cGoo003POol00`00Oomoo`3=Ool0
0=moo`800<moo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol005eoo`@004Ao
o`@003moo`L000=oo`@003Yoo`L000=oo`@003Yoo`H000Aoo`@002Yoo`00G7oo00<007ooOol00Woo
00<007ooOol0@7oo00<007ooOol00Woo00<007ooOol0?goo00<007ooOol00goo00<007ooOol00Woo
00<007ooOol0>Woo00<007ooOol00goo00<007ooOol00Woo00<007ooOol0=goo00<007ooOol00Woo
00D007ooOomoo`0000Aoo`03001oogoo02Moo`00G7oo00<007ooOol00Woo00<007ooOol0AGoo00<0
07ooOol0?goo00<007ooOol00goo00<007ooOol00Woo00<007ooOol0>Woo00<007ooOol027oo00<0
07ooOol0>7oo00<007ooOol01Goo00<007ooOol00Woo00<007ooOol09goo001LOol00`00Oomoo`02
Ool00`00Oomoo`15Ool00`00Oomoo`0oOol00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`0j
Ool00`00Oomoo`08Ool00`00Oomoo`0iOol00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`0W
Ool005aoo`03001oogoo009oo`03001oogoo04Eoo`03001oogoo03moo`03001oogoo00=oo`03001o
ogoo009oo`03001oogoo03Yoo`03001oogoo00Qoo`03001oogoo03Yoo`03001oogoo00=oo`03001o
ogoo009oo`03001oogoo02Moo`00G7oo00<007ooOol00Woo00<007ooOol0@Goo1000@Woo00<007oo
Ool00goo00<007ooOol00Woo00<007ooOol0>Woo00<007ooOol017oo1000?Woo00<007ooOol00Woo
00<007ooOol00Woo00<007ooOol09goo001LOol00`00Oomoo`02Ool00`00Oomoo`11Ool00`00Oomo
o`13Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`0jOol00`00Oomoo`04Ool00`00Oomo
o`0kOol00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol09goo001LOol00`00Oomoo`02
Ool00`00Oomoo`11Ool00`00Oomoo`11Ool30005Ool00`00Oomoo`02Ool00`00Oomoo`0hOol30006
Ool00`00Oomoo`0kOol00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol09goo001MOol4
0014Ool50011Ool00`00Oomoo`04Ool4000mOol00`00Oomoo`04Ool5000jOol40005Ool4000ZOol0
0?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo000lOol40006Ool20007Ool4003o
OomNOol003]oo`03001oogoo009oo`03001oogoo00=oo`8000Uoo`03001oogoo0?mooeeoo`00>goo
00<007ooOol00Woo00<007ooOol03Woo00<007ooOol017ooo`00<@00:7oo000kOol00`00Oomoo`02
Ool00`00Oomoo`0:Ool60005Ool30005Ool00`00Oomoo`0;Ool00`00Oomoo`0;Ool00`00Oomoo`0<
Ool00`00Oomoo`0;Ool00`00Oomoo`0<Ool00`00Oomoo`0;Ool00`00Oomoo`0<Ool00`00Oomoo`0;
Ool00`00Oomoo`0;Ool00`00Oomoo`0<Ool00`00Oomoo`0;Ool00`00Oomoo`0<Ool00`00Oomoo`0;
Ool00`00Oomoo`0<Ool00`00Oomoo`0;Ool00`00Oomoo`0;Ool00`00Oomoo`0<Ool00`00Oomoo`0;
Ool00`00Oomoo`0<Ool00`00Oomoo`0;Ool00`00Oomoo`0]Ool003]oo`03001oogoo009oo`03001o
ogoo00]oo`04001oogoo0006Ool00`00Oomoo`05Ool00`00Oomoo`15Ool00`00Oomoo`15Ool00`00
Oomoo`15Ool00`00Oomoo`15Ool00`00Oomoo`0]Ool003]oo`03001oogoo009oo`03001oogoo00]o
o`04001oogoo0006Ool00`00Oomoo`3oOomFOol003]oo`03001oogoo009oo`03001oogoo00aoo`03
001oo`0000Ioo`03001oogoo0?mooeIoo`00>goo00<007ooOol00Woo00<007ooOol037oo00<007oo
00001Woo00<007ooOol0ogooEWoo000lOol4000@Ool20006Ool00`00Oomoo`3oOomFOol005Qoo`03
001oogoo0?mooeIoo`00F7oo0P00ogooEgoo001HOol00`00Oomoo`3oOomFOol005Qoo`03001oogoo
0?mooeIoo`00F7oo00<007ooOol0ogooEWoo001HOol00`00Oomoo`3oOomFOol005Qoo`03001oogoo
0?mooeIoo`00F7oo00<007ooOol0ogooEWoo001HOol00`00Oomoo`3oOomFOol005Qoo`800?mooeMo
o`00F7oo00<007ooOol0ogooEWoo001HOol00`00Oomoo`3oOomFOol005Qoo`03001oogoo0?mooeIo
o`00F7oo00<007ooOol0ogooEWoo001HOol00`00Oomoo`3oOomFOol005Qoo`03001oogoo0?mooeIo
o`00F7oo0P00ogooEgoo001HOol00`00Oomoo`3oOomFOol005Qoo`03001oogoo0?mooeIoo`00F7oo
00<007ooOol0ogooEWoo000lOol40006Ool20007Ool40005Ool00`00Oomoo`3oOolVOol00`00Oomo
o`0]Ool003]oo`03001oogoo009oo`03001oogoo00=oo`8000Ioo`03001oogoo009oo`03001oogoo
009oo`03001oogoo0?moobIoo`03001oogoo02eoo`00>goo00<007ooOol00Woo00<007ooOol02goo
00<007ooOol00Woo00<007ooOol00Woo00<007ooOol04goo00<007ooOol0ogoo3goo00<007ooOol0
;Woo000kOol00`00Oomoo`02Ool00`00Oomoo`0;Ool20003Ool00`00Oomoo`02Ool3000COol00`00
Oomoo`3oOol?Ool00`00Oomoo`0^Ool003]oo`03001oogoo009oo`03001oogoo00]oo`03001oo`00
008000Eoo`03001oogoo01=oo`03001oogoo0?moo`moo`03001oogoo02ioo`00>goo00<007ooOol0
0Woo00<007ooOol02goo00<007ooOol01goo00<007ooOol04goo00<007ooOol0ogoo3goo00<007oo
Ool0;Woo000kOol00`00Oomoo`02Ool00`00Oomoo`0<Ool00`00Oomoo`06Ool00`00Oomoo`0DOol0
0`00Oomoo`3oOol=Ool00`00Oomoo`0_Ool003]oo`03001oogoo009oo`03001oogoo00eoo`03001o
ogoo00Eoo`03001oogoo01Aoo`03001oogoo0?moo`eoo`03001oogoo02moo`00?7oo10004Goo0`00
17oo00<007ooOol057oo00<007ooOol0ogoo3Goo00<007ooOol0;goo001HOol00`00Oomoo`0DOol0
0`00Oomoo`3oOol=Ool00`00Oomoo`0_Ool005Qoo`8001Eoo`03001oogoo0?moo`aoo`03001oogoo
031oo`00F7oo00<007ooOol057oo00<007ooOol0ogoo37oo00<007ooOol0<7oo001HOol00`00Oomo
o`0DOol00`00Oomoo`3aOol00`00Oomoo`0GOol00`00Oomoo`0`Ool005Qoo`03001oogoo01Aoo`03
001oogoo0?5oo`03001oogoo01Moo`03001oogoo031oo`00F7oo00<007ooOol05Goo00<007ooOol0
kgoo00<007oo00005goo00<007ooOol0<Goo001HOol00`00Oomoo`0EOol00`00Oomoo`3_Ool00`00
Ool0000GOol00`00Oomoo`0aOol005Qoo`03001oogoo01Eoo`03001oogoo0:Moo`8004Ioo`03001o
o`0001Moo`03001oogoo035oo`00F7oo00<007ooOol05Goo00<007ooOol0YGoo0P0000=oo`00Ool0
A7oo00D007ooOomoo`0001Ioo`03001oogoo035oo`00F7oo0P005Woo00<007ooOol0Xgoo0P000goo
00<007ooOol0@goo00D007ooOomoo`0001Eoo`03001oogoo039oo`00F7oo00<007ooOol05Goo00<0
07ooOol0X7oo0`001Woo00<007ooOol0@Woo00D007ooOomoo`0001Eoo`03001oogoo039oo`00F7oo
00<007ooOol05Goo00<007ooOol0WWoo0P002Goo00<007ooOol0@Goo00<007ooOol00goo00<007oo
Ool04Woo00<007ooOol0<Woo001HOol00`00Oomoo`0FOol00`00Oomoo`2KOol2000;Ool00`00Oomo
o`11Ool00`00Oomoo`03Ool00`00Oomoo`0BOol00`00Oomoo`0bOol005Qoo`03001oogoo01Ioo`03
001oogoo09Uoo`8000eoo`03001oogoo045oo`03001oogoo00Aoo`03001oogoo011oo`03001oogoo
03=oo`00F7oo00<007ooOol05Woo00<007ooOol0VGoo00<007ooOol03Goo00<007ooOol067oo00<0
07ooOol097oo00<007ooOol01Goo00<007ooOol047oo00<007ooOol0<goo001HOol00`00Oomoo`0F
Ool00`00Oomoo`2IOol00`00Oomoo`0=Ool00`00Oomoo`0HOol00`00Oomoo`0TOol00`00Oomoo`05
Ool00`00Oomoo`0@Ool00`00Oomoo`0cOol005Qoo`8001Moo`03001oogoo09Uoo`03001oogoo00eo
o`03001oogoo01Qoo`03001oogoo02Aoo`03001oogoo00Ioo`03001oogoo00moo`03001oogoo03=o
o`00F7oo00<007ooOol05Woo00<007ooOol0V7oo00<007ooOol03Woo00<007ooOol05goo0P009Goo
00<007ooOol01goo00<007ooOol03Woo00<007ooOol0=7oo001HOol00`00Oomoo`0FOol00`00Oomo
o`0dOol3001QOol00`00Oomoo`0>Ool00`00Oomoo`0GOol00`00Ool0000TOol00`00Oomoo`07Ool0
0`00Oomoo`0>Ool00`00Oomoo`0dOol005Qoo`03001oogoo01Ioo`03001oogoo03Aoo`03001oogoo
00@005eoo`03001oogoo00moo`03001oogoo01Ioo`03001oo`0002Aoo`03001oogoo00Qoo`03001o
ogoo00eoo`03001oogoo03Aoo`00?7oo10001Woo0P001Woo10001Woo00<007ooOol05goo00<007oo
Ool0<Woo00<007ooOol01Goo1@00F7oo00<007ooOol03goo00<007ooOol05Woo00<007oo00008goo
00<007ooOol02Goo00<007ooOol037oo00<007ooOol0=Goo000kOol00`00Oomoo`02Ool00`00Oomo
o`03Ool20005Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`0GOol00`00Oomoo`0bOol0
0`00Oomoo`0:Ool3001EOol00`00Oomoo`0?Ool00`00Oomoo`0EOol01000Oomoo`008goo00<007oo
Ool02Goo00<007ooOol037oo00<007ooOol0=Goo000kOol00`00Oomoo`02Ool00`00Oomoo`0:Ool0
0`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`0GOol00`00Oomoo`0aOol00`00Oomoo`0>Ool0
0`00Oomoo`1BOol00`00Oomoo`0?Ool00`00Oomoo`0EOol01000Oomoo`008goo00<007ooOol02Woo
00<007ooOol02goo00<007ooOol0=Goo000kOol00`00Oomoo`02Ool00`00Oomoo`0:Ool00`00Oomo
o`02Ool00`00Oomoo`03Ool3000GOol00`00Oomoo`0aOol00`00Oomoo`0>Ool00`00Oomoo`1AOol0
0`00Oomoo`0AOol00`00Oomoo`0DOol01000Oomoo`008Woo00<007ooOol02goo00<007ooOol02goo
00<007ooOol0=Goo000kOol00`00Oomoo`02Ool00`00Oomoo`0;Ool40006Ool00`00Oomoo`0GOol0
0`00Oomoo`0`Ool00`00Oomoo`0@Ool00`00Oomoo`1@Ool00`00Oomoo`0AOol00`00Oomoo`0DOol0
1000Oomoo`008Woo00<007ooOol02goo00<007ooOol02Woo00<007ooOol0=Woo000kOol00`00Oomo
o`02Ool00`00Oomoo`0:Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`0GOol00`00Oomo
o`0`Ool00`00Oomoo`0AOol00`00Oomoo`1?Ool00`00Oomoo`0AOol00`00Oomoo`0COol00`00Oomo
o`02Ool00`00Oomoo`0OOol00`00Oomoo`0<Ool00`00Oomoo`09Ool00`00Oomoo`0fOol003]oo`03
001oogoo009oo`03001oogoo00Yoo`03001oogoo009oo`03001oogoo00=oo`03001oogoo01Moo`03
001oogoo02moo`03001oogoo019oo`03001oogoo04moo`03001oogoo015oo`03001oogoo01=oo`03
001oogoo009oo`03001oogoo01moo`03001oogoo00aoo`03001oogoo00Uoo`03001oogoo03Ioo`00
>goo00<007ooOol00Woo00<007ooOol02Woo00<007ooOol00Woo00<007ooOol00goo00<007ooOol0
67oo00<007ooOol0;Woo00<007ooOol04goo00<007ooOol0CWoo00<007ooOol04Goo00<007ooOol0
4goo00<007ooOol00Woo00<007ooOol07Woo00<007ooOol03Woo00<007ooOol027oo00<007ooOol0
=Woo000lOol4000>Ool40006Ool00`00Oomoo`0HOol00`00Oomoo`0^Ool00`00Oomoo`0COol00`00
Oomoo`1>Ool00`00Oomoo`0BOol00`00Oomoo`0BOol00`00Oomoo`02Ool00`00Oomoo`0NOol00`00
Oomoo`0>Ool00`00Oomoo`07Ool00`00Oomoo`0gOol005Qoo`03001oogoo01Qoo`03001oogoo02eo
o`03001oogoo01Eoo`03001oogoo04aoo`03001oogoo01=oo`03001oogoo019oo`03001oogoo009o
o`03001oogoo01ioo`03001oogoo00ioo`03001oogoo00Moo`03001oogoo03Moo`00F7oo0P006Goo
00<007ooOol0;Goo00<007ooOol05Woo00<007ooOol0Bgoo00<007ooOol04goo00<007ooOol04Goo
00<007ooOol00goo00<007ooOol07Goo00<007ooOol047oo00<007ooOol01Woo00<007ooOol0=goo
001HOol00`00Oomoo`0HOol00`00Oomoo`0/Ool00`00Oomoo`0GOol00`00Oomoo`1;Ool00`00Oomo
o`0COol00`00Oomoo`0AOol00`00Oomoo`04Ool00`00Oomoo`0LOol00`00Oomoo`0@Ool00`00Oomo
o`06Ool00`00Oomoo`0gOol005Qoo`03001oogoo01Qoo`03001oogoo02aoo`03001oogoo01Qoo`03
001oogoo04Yoo`03001oogoo01Aoo`03001oogoo011oo`03001oogoo00Aoo`03001oogoo01aoo`03
001oogoo011oo`03001oogoo00Eoo`03001oogoo03Qoo`00F7oo00<007ooOol067oo00<007ooOol0
:goo00<007ooOol06Woo00<007ooOol0BGoo00<007ooOol057oo00<007ooOol047oo00<007ooOol0
17oo00<007ooOol06goo00<007ooOol04Woo00<007ooOol017oo00<007ooOol0>7oo001HOol00`00
Oomoo`0HOol00`00Oomoo`0[Ool00`00Oomoo`0JOol00`00Oomoo`19Ool00`00Oomoo`0DOol00`00
Oomoo`0?Ool00`00Oomoo`05Ool00`00Oomoo`0KOol00`00Oomoo`0BOol00`00Oomoo`04Ool00`00
Oomoo`0hOol005Qoo`03001oogoo01Uoo`03001oogoo02Yoo`03001oogoo01]oo`03001oogoo04Mo
o`03001oogoo01Eoo`03001oogoo00moo`03001oogoo00Eoo`03001oogoo01]oo`03001oogoo019o
o`03001oogoo00Aoo`03001oogoo03Qoo`00F7oo00<007ooOol06Goo00<007ooOol0:Goo00<007oo
Ool077oo00<007ooOol0Agoo00<007ooOol05Goo00<007ooOol03goo00<007ooOol01Goo00<007oo
Ool06Woo00<007ooOol057oo00<007ooOol00Woo00<007ooOol0>Goo001HOol00`00Oomoo`0IOol0
0`00Oomoo`0YOol00`00Oomoo`0MOol00`00Oomoo`16Ool00`00Oomoo`0FOol00`00Oomoo`0>Ool0
0`00Oomoo`05Ool00`00Oomoo`0JOol00`00Oomoo`0DOol00`00Oomoo`02Ool00`00Oomoo`0iOol0
05Qoo`8001Yoo`03001oogoo02Qoo`03001oogoo01moo`03001oogoo04Eoo`03001oogoo01Ioo`03
001oogoo00eoo`03001oogoo00Moo`03001oogoo01Uoo`03001oogoo01Aoo`03001oogoo009oo`03
001oogoo03Uoo`00F7oo00<007ooOol06Goo00<007ooOol0:7oo00<007ooOol07goo00<007ooOol0
AGoo00<007ooOol05Woo00<007ooOol03Goo00<007ooOol01goo00<007ooOol067oo00<007ooOol0
5Woo00D007ooOomoo`0003]oo`00F7oo00<007ooOol06Goo00<007ooOol09goo00<007ooOol08Goo
00<007ooOol0A7oo00<007ooOol05Woo00<007ooOol03Goo00<007ooOol01goo00<007ooOol067oo
00<007ooOol05Woo00@007ooOol003aoo`00F7oo00<007ooOol06Goo00<007ooOol09goo00<007oo
Ool08Woo00<007ooOol0@goo00<007ooOol05Woo00<007ooOol03Goo00<007ooOol01goo00<007oo
Ool067oo00<007ooOol05goo00<007oo0000?7oo001HOol00`00Oomoo`0JOol00`00Oomoo`0UOol0
0`00Oomoo`0SOol00`00Oomoo`12Ool00`00Oomoo`0HOol00`00Oomoo`0<Ool00`00Oomoo`07Ool0
0`00Oomoo`0GOol00`00Oomoo`0HOol00`00Ool0000lOol005Qoo`0300003`0?01X03`0300003`0?
02D03`0300003`0?02@03`0300003`0?04403`0300003`0?01P03`0300003`0?00/03`0300003`0?
00P03`0300003`0?01L03`0300003`0?01P03`0300003`0001@03bQoo`00F7oo00<007ooOol06Woo
00<007ooOol09Goo00<007ooOol097oo00<007ooOol0@Goo00<007ooOol067oo00<007ooOol02goo
00<007ooOol027oo00<007ooOol05goo00<007ooOol06Goo00<007ooOol0>goo001HOol2000KOol0
0`00Oomoo`0TOol00`00Oomoo`0VOol00`00Oomoo`10Ool00`00Oomoo`0HOol00`00Oomoo`0;Ool0
0`00Oomoo`09Ool00`00Oomoo`0EOol00`00Oomoo`0JOol00`00Oomoo`0kOol005Qoo`03001oogoo
01Yoo`03001oogoo02Aoo`03001oogoo02Ioo`03001oogoo041oo`03001oogoo01Uoo`03001oogoo
00Yoo`03001oogoo00Uoo`03001oogoo01Eoo`03001oogoo05Qoo`00F7oo00<007ooOol06Woo00<0
07ooOol08goo00<007ooOol09goo00<007ooOol0@7oo00<007ooOol06Goo00<007ooOol02Goo00<0
07ooOol02Woo00<007ooOol05Goo00<007ooOol0F7oo001=Ool70004Ool00`00Oomoo`0JOol00`00
Oomoo`0SOol00`00Oomoo`0XOol00`00Oomoo`0nOol00`00Oomoo`0JOol00`00Oomoo`09Ool00`00
Oomoo`0:Ool00`00Oomoo`0EOol00`00Oomoo`1HOol0051oo`03001oogoo00Eoo`03001oogoo01Yo
o`03001oogoo029oo`03001oogoo02Uoo`03001oogoo03ioo`03001oogoo01Yoo`03001oogoo00Uo
o`03001oogoo00Yoo`03001oogoo01Aoo`03001oogoo05Uoo`00D7oo00<007ooOol01Goo00<007oo
Ool06goo00<007ooOol08Goo00<007ooOol0:Goo00<007ooOol0?Woo00<007ooOol06Woo00<007oo
Ool02Goo00<007ooOol02Woo00<007ooOol057oo00<007ooOol0FGoo001@Ool00`00Oomoo`05Ool0
0`00Oomoo`0KOol00`00Oomoo`0POol00`00Oomoo`0ZOol00`00Oomoo`0nOol00`00Oomoo`0KOol0
0`00Oomoo`08Ool00`00Oomoo`0:Ool00`00Oomoo`0DOol00`00Oomoo`1IOol0051oo`03001oogoo
00Eoo`<001]oo`03001oogoo021oo`03001oogoo02Yoo`03001oogoo03ioo`03001oogoo01]oo`03
001oogoo00Moo`03001oogoo00aoo`03001oogoo01=oo`03001oogoo05Uoo`00D7oo00<007ooOol0
1Goo00<007ooOol06goo00<007ooOol087oo00<007ooOol0:goo00<007ooOol0?Goo00<007ooOol0
6goo00<007ooOol01goo00<007ooOol037oo00<007ooOol04Woo00<007ooOol0FWoo001@Ool00`00
Oomoo`05Ool00`00Oomoo`0KOol00`00Oomoo`0POol00`00Oomoo`0[Ool00`00Oomoo`0lOol00`00
Oomoo`0LOol00`00Oomoo`07Ool00`00Oomoo`0<Ool00`00Oomoo`0BOol00`00Oomoo`1JOol004io
o`<000Moo`03001oogoo01]oo`03001oogoo01moo`03001oogoo02aoo`03001oogoo03aoo`03001o
ogoo01eoo`03001oogoo00Ioo`03001oogoo00aoo`03001oogoo019oo`03001oogoo05Yoo`00;Goo
00<007ooOol00P007Woo00<007ooOol01Goo00<007ooOol06goo00<007ooOol07goo00<007ooOol0
;7oo00<007ooOol0?7oo00<007ooOol07Goo00<007ooOol01Goo00<007ooOol03Goo00<007ooOol0
4Woo00<007ooOol0FWoo000/Ool01@00Ool007oo00009goo00<007ooOol077oo00<007ooOol07Woo
00<007ooOol0;7oo00<007ooOol0?7oo00<007ooOol07Goo00<007ooOol01Goo00<007ooOol03Goo
00<007ooOol04Goo00<007ooOol0Fgoo000/Ool00`00Ool00002Ool00`00Oomoo`0TOol00`00Oomo
o`0LOol00`00Oomoo`0NOol00`00Oomoo`0]Ool00`00Oomoo`0kOol00`00Oomoo`0MOol00`00Oomo
o`05Ool00`00Oomoo`0=Ool00`00Oomoo`0AOol00`00Oomoo`1KOol002aoo`03001oo`00009oo`03
001oogoo02Aoo`8001eoo`03001oogoo01ioo`03001oogoo02eoo`03001oogoo03]oo`03001oogoo
01eoo`03001oogoo00Eoo`03001oogoo00ioo`03001oogoo011oo`03001oogoo05]oo`00;7oo00<0
07oo00000Woo00<007ooOol097oo00<007ooOol077oo00<007ooOol07Goo00<007ooOol0;Woo00<0
07ooOol0>goo00<007ooOol07Woo00<007ooOol00goo00<007ooOol03goo00<007ooOol047oo00<0
07ooOol0Fgoo000/Ool200000goo0000000WOol00`00Oomoo`0LOol00`00Oomoo`0MOol00`00Oomo
o`0^Ool00`00Oomoo`0jOol00`00Oomoo`0OOol00`00Oomoo`03Ool00`00Oomoo`0?Ool00`00Oomo
o`0?Ool00`00Oomoo`1LOol005Qoo`03001oogoo01aoo`03001oogoo01eoo`03001oogoo02ioo`03
001oogoo03Yoo`03001oogoo01moo`03001oogoo00=oo`03001oogoo00moo`03001oogoo00moo`03
001oogoo05aoo`00F7oo00<007ooOol077oo00<007ooOol07Goo00<007ooOol0;goo00<007ooOol0
>Goo00<007ooOol07goo00<007ooOol00goo00<007ooOol03goo00<007ooOol03goo00<007ooOol0
G7oo001HOol00`00Oomoo`0LOol00`00Oomoo`0MOol00`00Oomoo`0_Ool00`00Oomoo`0iOol00`00
Oomoo`0POol00`00Oomoo`02Ool00`00Oomoo`0?Ool00`00Oomoo`0?Ool00`00Oomoo`1LOol005Qo
o`03001oogoo01eoo`03001oogoo01]oo`03001oogoo031oo`03001oogoo03Uoo`03001oogoo021o
o`05001oogooOol0000COol00`00Oomoo`0=Ool00`00Oomoo`1MOol005Qoo`8001ioo`03001oogoo
01]oo`03001oogoo031oo`03001oogoo03Uoo`03001oogoo021oo`05001oogooOol0000COol00`00
Oomoo`0=Ool00`00Oomoo`1MOol005Qoo`03001oogoo01eoo`03001oogoo01]oo`03001oogoo031o
o`03001oogoo03Qoo`03001oogoo025oo`05001oogooOol0000COol00`00Oomoo`0=Ool00`00Oomo
o`1MOol005Qoo`03001oogoo01eoo`03001oogoo01]oo`03001oogoo035oo`03001oogoo03Moo`03
001oogoo025oo`05001oogooOol0000COol00`00Oomoo`0=Ool00`00Oomoo`1MOol005Qoo`03001o
ogoo01eoo`03001oogoo01]oo`03001oogoo035oo`03001oogoo03Moo`03001oogoo029oo`03001o
o`0001Aoo`03001oogoo00eoo`03001oogoo05eoo`00F7oo00<007ooOol07Goo00<007ooOol06goo
00<007ooOol0<Goo00<007ooOol0=goo00<007ooOol08Woo00<007oo000057oo00<007ooOol037oo
00<007ooOol0GWoo001HOol00`00Oomoo`0MOol00`00Oomoo`0JOol00`00Oomoo`0bOol00`00Oomo
o`0gOol00`00Oomoo`0ROol00`00Ool0000DOol00`00Oomoo`0<Ool00`00Oomoo`1NOol005Qoo`03
001oogoo01ioo`03001oogoo01Uoo`03001oogoo039oo`03001oogoo03Moo`03001oogoo029oo`03
001oo`0001Eoo`03001oogoo00]oo`03001oogoo05ioo`00F7oo00<007ooOol07Woo00<007ooOol0
6Goo00<007ooOol0<goo00<007ooOol0=Goo00<007ooOol097oo00<007ooOol057oo00<007ooOol0
2goo00<007ooOol0GWoo001HOol2000OOol00`00Oomoo`0IOol00`00Oomoo`0cOol00`00Oomoo`0e
Ool00`00Oomoo`0TOol00`00Oomoo`0DOol00`00Oomoo`0:Ool00`00Oomoo`1OOol005Qoo`03001o
ogoo01ioo`03001oogoo01Uoo`03001oogoo03=oo`03001oogoo03Eoo`03001oogoo02Aoo`03001o
ogoo01Aoo`03001oogoo00Yoo`03001oogoo05moo`00F7oo00<007ooOol07Woo00<007ooOol067oo
00<007ooOol0=7oo00<007ooOol0=Goo00<007ooOol0>goo00<007ooOol02Woo00<007ooOol0Ggoo
000kOol70004Ool20005Ool60005Ool00`00Oomoo`0NOol00`00Oomoo`0HOol00`00Oomoo`0dOol0
0`00Oomoo`0eOol00`00Oomoo`0kOol00`00Oomoo`0:Ool00`00Oomoo`1OOol003ioo`03001oogoo
00Eoo`8000Eoo`03001oogoo009oo`03001oogoo00=oo`03001oogoo01ioo`03001oogoo01Qoo`03
001oogoo03Eoo`03001oogoo019oo`03001oogoo01moo`03001oogoo03]oo`03001oogoo00Uoo`03
001oogoo061oo`00?Woo00<007ooOol03Goo00<007ooOol01goo00<007ooOol07Woo00<007ooOol0
67oo00<007ooOol0=Goo00<007ooOol04Woo0P007goo00<007ooOol0?Goo00<007ooOol027oo00<0
07ooOol0H7oo000nOol00`00Oomoo`0>Ool00`00Oomoo`06Ool00`00Oomoo`0OOol00`00Oomoo`0G
Ool00`00Oomoo`0eOol00`00Oomoo`0AOol00`00Ool0000OOol00`00Oomoo`0mOol00`00Oomoo`08
Ool00`00Oomoo`1POol003ioo`03001oogoo00moo`03001oogoo00Eoo`<001moo`03001oogoo01Io
o`03001oogoo03Ioo`03001oogoo015oo`04001oogoo000NOol00`00Oomoo`0mOol00`00Oomoo`08
Ool00`00Oomoo`1POol003ioo`03001oogoo011oo`03001oogoo00Aoo`03001oogoo01moo`03001o
ogoo01Ioo`03001oogoo03Moo`03001oogoo00moo`03001oogoo009oo`03001oogoo01]oo`03001o
ogoo03eoo`03001oogoo00Moo`03001oogoo065oo`00?Woo00<007ooOol037oo00<007ooOol00Woo
00<007ooOol00goo00<007ooOol07goo00<007ooOol05Woo00<007ooOol0=goo00<007ooOol03goo
00<007ooOol00goo00<007ooOol06Woo00<007ooOol0?Goo00<007ooOol01goo00<007ooOol0HGoo
000lOol3000>Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`0OOol00`00Oomoo`0FOol0
0`00Oomoo`0gOol00`00Oomoo`0?Ool00`00Oomoo`03Ool00`00Oomoo`0JOol00`00Oomoo`0mOol0
0`00Oomoo`07Ool00`00Oomoo`1QOol003ioo`03001oogoo00eoo`@000Ioo`03001oogoo01moo`03
001oogoo01Ioo`03001oogoo03Moo`03001oogoo00ioo`03001oogoo00Eoo`03001oogoo01Uoo`03
001oogoo03eoo`03001oogoo00Moo`03001oogoo065oo`00F7oo00<007ooOol07goo00<007ooOol0
5Goo00<007ooOol0>7oo00<007ooOol03Woo00<007ooOol01Woo00<007ooOol05goo00<007ooOol0
?goo00<007ooOol01Goo00<007ooOol0HWoo001HOol00`00Oomoo`0POol00`00Oomoo`0DOol00`00
Oomoo`0iOol00`00Oomoo`0=Ool00`00Oomoo`06Ool00`00Oomoo`0GOol00`00Oomoo`0oOol00`00
Oomoo`05Ool00`00Oomoo`1ROol005Qoo`80025oo`03001oogoo01Aoo`03001oogoo03Uoo`03001o
ogoo00aoo`03001oogoo00Qoo`03001oogoo01Ioo`03001oogoo03moo`03001oogoo00Eoo`03001o
ogoo069oo`00F7oo00<007ooOol087oo00<007ooOol057oo00<007ooOol0>Goo00<007ooOol037oo
00<007ooOol02Goo00<007ooOol05Goo00<007ooOol0?goo00<007ooOol01Goo00<007ooOol0HWoo
001HOol00`00Oomoo`0POol00`00Oomoo`0DOol00`00Oomoo`0iOol00`00Oomoo`0;Ool00`00Oomo
o`0;Ool00`00Oomoo`0DOol00`00Oomoo`0oOol00`00Oomoo`05Ool00`00Oomoo`1ROol005Qoo`03
001oogoo021oo`03001oogoo01=oo`03001oogoo03Yoo`03001oogoo00]oo`03001oogoo00]oo`03
001oogoo01Aoo`03001oogoo03moo`03001oogoo00Aoo`03001oogoo06=oo`00F7oo00<007ooOol0
87oo00<007ooOol04goo00<007ooOol0>goo00<007ooOol02Woo00<007ooOol037oo00<007ooOol0
4Woo00<007ooOol0@7oo00<007ooOol017oo00<007ooOol0Hgoo001HOol00`00Oomoo`0POol00`00
Oomoo`0COol00`00Oomoo`0kOol00`00Oomoo`09Ool00`00Oomoo`0>Ool00`00Oomoo`0AOol00`00
Oomoo`11Ool00`00Oomoo`03Ool00`00Oomoo`1SOol005Qoo`03001oogoo021oo`03001oogoo01=o
o`03001oogoo03]oo`03001oogoo00Uoo`03001oogoo00ioo`03001oogoo015oo`03001oogoo045o
o`03001oogoo00=oo`03001oogoo06=oo`00F7oo0P008Woo00<007ooOol04Woo00<007ooOol0>goo
00<007ooOol027oo00<007ooOol047oo00<007ooOol047oo00<007ooOol0@Goo00<007ooOol00Woo
00<007ooOol0I7oo001HOol00`00Oomoo`0QOol00`00Oomoo`0AOol00`00Oomoo`0lOol00`00Oomo
o`08Ool00`00Oomoo`0AOol00`00Oomoo`0?Ool00`00Oomoo`11Ool00`00Oomoo`02Ool00`00Oomo
o`1TOol005Qoo`03001oogoo025oo`03001oogoo015oo`03001oogoo03eoo`03001oogoo00Moo`03
001oogoo019oo`03001oogoo00ioo`03001oogoo045oo`03001oogoo009oo`03001oogoo06Aoo`00
F7oo00<007ooOol08Goo00<007ooOol04Goo00<007ooOol0?Goo00<007ooOol01Woo00<007ooOol0
4goo00<007ooOol03Goo00<007ooOol0@Woo00<007ooOol00Woo00<007ooOol0I7oo001HOol00`00
Oomoo`0ROol00`00Oomoo`0@Ool00`00Oomoo`0mOol00`00Oomoo`06Ool00`00Oomoo`0DOol00`00
Oomoo`0<Ool00`00Oomoo`13Ool01000Oomoo`00Igoo001HOol00`00Oomoo`0ROol00`00Oomoo`0@
Ool00`00Oomoo`0mOol00`00Oomoo`05Ool00`00Oomoo`0FOol2000<Ool00`00Oomoo`13Ool01000
Oomoo`00Igoo001HOol00`00Oomoo`0SOol00`00Oomoo`0>Ool00`00Oomoo`0nOol00`00Oomoo`05
Ool00`00Oomoo`0HOol2000:Ool00`00Oomoo`13Ool01000Oomoo`00Igoo001HOol00`00Oomoo`0S
Ool00`00Oomoo`0>Ool00`00Oomoo`0oOol00`00Oomoo`04Ool00`00Oomoo`0JOol20008Ool00`00
Oomoo`13Ool01000Oomoo`00Igoo001HOol2000UOol00`00Oomoo`0=Ool00`00Oomoo`0oOol00`00
Oomoo`03Ool00`00Oomoo`0MOol00`00Oomoo`05Ool00`00Oomoo`13Ool00`00Ool0001XOol005Qo
o`03001oogoo02Aoo`03001oogoo00eoo`03001oogoo03moo`03001oogoo00=oo`03001oogoo01io
o`8000Aoo`03001oogoo04Aoo`03001oo`0006Qoo`00F7oo00<007ooOol09Goo00<007ooOol037oo
00<007ooOol0?goo00<007ooOol00goo00<007ooOol087oo0P000Woo00<007ooOol0A7oo00<007oo
0000J7oo000kOol70004Ool20007Ool40005Ool00`00Oomoo`0VOol00`00Oomoo`0;Ool00`00Oomo
o`0oOol00`00Oomoo`02Ool00`00Oomoo`0SOol30017Ool2001XOol003ioo`03001oogoo00Eoo`80
00Uoo`03001oogoo00Aoo`03001oogoo02Ioo`03001oogoo00Yoo`03001oogoo045oo`05001oogoo
Ool0000WOol00`00Oomoo`15Ool00`00Oomoo`1WOol003ioo`03001oogoo011oo`03001oogoo00Ao
o`03001oogoo02Moo`03001oogoo00Uoo`03001oogoo045oo`04001oogoo001`Ool00`00Oomoo`1W
Ool003ioo`03001oogoo00aoo`H000Eoo`03001oogoo02Moo`03001oogoo00Uoo`03001oogoo045o
o`04001oogoo001`Ool00`00Oomoo`1WOol003ioo`03001oogoo00eoo`04001oogoo0006Ool3000X
Ool00`00Oomoo`08Ool00`00Oomoo`11Ool01000Oomoo`00fWoo000nOol00`00Oomoo`0=Ool01000
Oomoo`001Woo00<007ooOol0:7oo00<007ooOol027oo00<007ooOol0@Goo00<007oo0000fgoo000n
Ool00`00Oomoo`0>Ool00`00Ool00006Ool00`00Oomoo`0YOol00`00Oomoo`06Ool00`00Oomoo`13
Ool2003KOol003aoo`<0011oo`03001oo`0000Ioo`03001oogoo02Yoo`03001oogoo00Eoo`03001o
ogoo04=oo`03001oogoo0=Yoo`00?Woo00<007ooOol03goo0P001Woo00<007ooOol0:Woo00<007oo
Ool01Goo00<007ooOol0@goo00<007ooOol0fWoo001HOol00`00Oomoo`0[Ool00`00Oomoo`04Ool0
0`00Oomoo`3oOolQOol005Qoo`03001oogoo02]oo`03001oogoo00Aoo`03001oogoo0?moob5oo`00
F7oo0P00;Goo00<007ooOol00Woo00<007ooOol0ogoo8Woo001HOol00`00Oomoo`0]Ool01@00Oomo
ogoo0000ogoo97oo001HOol00`00Oomoo`0]Ool01@00Oomoogoo0000ogoo97oo001HOol00`00Oomo
o`0^Ool01000Oomoo`00ogoo97oo001HOol00`00Oomoo`0^Ool01000Oomoo`00ogoo97oo001HOol0
0`00Oomoo`0_Ool2003oOolUOol005Qoo`03001oogoo02moo`800?moobEoo`00F7oo0P00<Goo00<0
07ooOol0ogoo8goo001HOol00`00Oomoo`3oOomFOol005Qoo`03001oogoo0?mooeIoo`00F7oo00<0
07ooOol0ogooEWoo001HOol00`00Oomoo`3oOomFOol005Qoo`03001oogoo0?mooeIoo`00F7oo00<0
07ooOol0ogooEWoo001HOol2003oOomGOol005Qoo`03001oogoo0?mooeIoo`00F7oo00<007ooOol0
ogooEWoo001HOol00`00Oomoo`3oOomFOol003]oo`L000Aoo`8000Moo`@000Eoo`03001oogoo0?mo
oeIoo`00?Woo00<007ooOol01Goo0P001Woo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol0
ogooEWoo000nOol00`00Oomoo`0=Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`3oOomF
Ool003ioo`03001oogoo00eoo`8000=oo`03001oogoo009oo`03001oogoo0?mooeIoo`00?Woo00<0
07ooOol03Goo00<007oo00000P001Goo0`00ogooEWoo000nOol00`00Oomoo`0=Ool00`00Oomoo`07
Ool00`00Oomoo`3oOomFOol003ioo`03001oogoo00ioo`03001oogoo00Ioo`03001oogoo0?mooeIo
o`00?7oo0`004Goo00<007ooOol01Goo00<007ooOol0ogooEWoo000nOol00`00Oomoo`0@Ool30004
Ool00`00Oomoo`3oOomFOol005Qoo`03001oogoo0?mooeIoo`00F7oo00<007ooOol0ogooEWoo001H
Ool2003oOomGOol005Qoo`03001oogoo0?mooeIoo`00F7oo00<007ooOol0ogooEWoo001HOol00`00
Oomoo`3oOomFOol005Qoo`03001oogoo0?mooeIoo`00F7oo00<007ooOol0ogooEWoo003oOonaOol0
0?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo0039Ool3003TOol00<]oo`03001o
ogoo0>9oo`00bgoo00<007ooOol0hWoo001LOol70002Ool30002Ool300000goo000000050005Ool4
0002Ool70004Ool50002Ool7000<Ool00`00Ool000020006Ool40004Ool300000goo00000002Ool3
00000goo00000005Ool2003SOol005moo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo00=o
o`03001oogoo00Eoo`03001oogoo009oo`03001oogoo009oo`03001oogoo00Aoo`05001oogooOol0
0006Ool00`00Oomoo`0=Ool20003Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomoo`000goo
0P000Woo00@007ooOomoo`8000Ioo`800>=oo`00Ggoo00<007ooOol017oo00<007ooOol00Woo00<0
07ooOol00goo00<007ooOol01Goo00<007ooOol01goo00<007ooOol017oo00D007ooOomoo`0000Io
o`03001oogoo00eoo`03001oogoo009oo`03001oogoo009oo`03001oogoo00Eoo`03001oogoo009o
o`04001oogoo0004Ool00`00Oomoo`03Ool01000Oomoo`00hWoo001OOol00`00Oomoo`04Ool00`00
Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`05Ool00`00Oomoo`07Ool00`00Oomoo`05Ool40006
Ool00`00Oomoo`0BOol00`00Oomoo`02Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`00
17oo00<007ooOol00goo00@007ooOol00>9oo`00Ggoo00<007ooOol017oo0P000goo00<007ooOol0
0goo00<007ooOol01Goo00<007ooOol01goo00<007ooOol017oo00D007ooOomoo`0000Ioo`03001o
ogoo00ioo`@000Eoo`03001oogoo00Eoo`03001oogoo009oo`04001oogoo0003Ool20004Ool00`00
Oomoo`02Ool00`00Oomoo`3OOol005moo`03001oogoo00=oo`800004Ool000000004Ool30005Ool7
0003Ool30007Ool30007Ool00`00Oomoo`0=Ool00`00Oomoo`02Ool00`00Oomoo`070002Ool20003
Ool20003Ool300000goo001oo`02Ool30002Ool3003POol005moo`03001oogoo01Moo`03001oogoo
01Uoo`03001oogoo00eoo`04001oogooOol20004Ool00`00Oomoo`0BOol00`00Oomoo`3YOol005ao
o`L001Ioo`03001oogoo01Uoo`03001oogoo00ioo`<00003Ool007oo00=oo`03001oogoo019oo`03
001oogoo0>Uoo`00LGoo00<007ooOol03goo00<007ooOol03Goo0`00;Goo0P00jgoo001aOol00`00
Oomoo`0?Ool00`00Oomoo`3oOol[Ool00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo
/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOomnOol00`00Oomoo`0`Ool00?moogioo`80035o
o`00GGoo1@003goo0P001Woo1@000Woo1`0017oo0`0000=oo`0000000goo100017oo1@003Woo1@00
17oo100017oo1@0037oo0`0000Aoo`000000009oo`800004Ool000000005Ool50003Ool50004Ool0
0`00Ool00002000>Ool40005Ool40003Ool30002Ool30004Ool40003Ool50005Ool40003Ool7000=
Ool40003Ool30002Ool30003Ool50003Ool50006Ool40004Ool00`00Oomoo`0_Ool005eoo`03001o
ogoo009oo`03001oogoo00aoo`8000Eoo`05001oogooOol00006Ool00`00Oomoo`04Ool01000Oomo
ogoo0P000goo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo00aoo`03001oogoo00Ao
o`03001oogoo009oo`03001oogoo009oo`03001oogoo00ioo`05001oogooOol00004Ool20003Ool0
1@00Oomoogoo00000goo00<007ooOol00goo00<007ooOol01Goo0P000goo00<007ooOol02Woo00<0
07ooOol00Woo00D007ooOomoo`0000Aoo`05001oogooOol00004Ool00`00Oomoo`02Ool00`00Oomo
o`02Ool01@00Oomoogoo00001goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol03Goo00<0
07ooOol00Woo00D007ooOomoo`0000Aoo`05001oogooOol00003Ool00`00Oomoo`03Ool00`00Oomo
o`06Ool00`00Oomoo`02Ool01000Oomoogoo0P00<7oo001ROol00`00Oomoo`0;Ool01000Oomoo`00
17oo00D007ooOomoo`0000Ioo`03001oogoo00Aoo`03001oogoo009oo`05001oogooOol0000=Ool0
0`00Oomoo`0<Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0?Ool0
0`00Ool00005Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00<007ooOol00goo00<007ooOol0
1Goo00<007ooOol00Woo00<007ooOol02Goo00<007ooOol01goo00<007ooOol00Woo00D007ooOomo
o`0000Aoo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo00Eoo`03001oogoo009oo`03001o
ogoo00=oo`03001oogoo00aoo`03001oogoo00Moo`03001oogoo009oo`05001oogooOol00003Ool0
0`00Oomoo`03Ool00`00Oomoo`06Ool00`00Oomoo`0hOol005ioo`@000ioo`04001oogoo0005Ool4
0006Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01000Oomoogoo1P0017oo10003goo00<007ooOol0
17oo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol047oo00<007ooOol017oo00<007ooOol0
0Woo00<007ooOol00Woo10001Goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol01goo00<0
07ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo00Eo
o`03001oogoo009oo`03001oogoo00=oo`03001oogoo00aoo`03001oogoo00Moo`03001oogoo009o
o`03001oogoo009oo`@000Eoo`03001oogoo00Ioo`03001oogoo03Qoo`00GGoo00<007ooOol00Woo
00<007ooOol02Woo00<007ooOol00Woo00D007ooOomoo`0000=oo`03001oogoo00Aoo`03001oogoo
00Aoo`03001oogoo009oo`05001oogooOol00004Ool01@00Oomoogoo000017oo00<007ooOol037oo
00<007ooOol017oo00<007ooOol00Woo00<007ooOol00Woo0P004Goo00<007ooOol017oo0P000goo
00D007ooOomoo`0000=oo`03001oogoo00=oo`8000Moo`@000aoo`03001oogoo00Moo`03001oogoo
009oo`04001oogooOol20003Ool00`00Oomoo`02Ool00`00Oomoo`06Ool20006Ool00`00Oomoo`02
Ool00`00Oomoo`03Ool00`00Oomoo`0=Ool01000Oomoogoo0P000goo0P000goo00D007ooOomoo`00
00=oo`03001oogoo00=oo`8000Moo`03001oogoo03Qoo`00GWoo1@002goo0`000Woo0`000goo0`00
1goo00<007ooOol00goo0P000goo0P0017oo10001Goo1@0037oo1P0017oo100017oo0P0000Aoo`00
000000eoo`03001oo`0000Eoo`03001oo`00008000Eoo`<000Eoo`800004Ool000000003Ool00`00
Oomoo`02Ool00`00Oomoo`09Ool00`00Oomoo`03Ool00`00Oomoo`02Ool40003Ool2000017oo0000
00000goo1`000goo0P0000Aoo`00000000Aoo`@000Ioo`03001oogoo00ioo`<00003Ool007oo009o
o`03001oo`00008000Eoo`<000Eoo`800004Ool000000002Ool7000fOol008=oo`03001oogoo02Yo
o`03001oogoo01moo`05001oogooOol00004Ool00`00Oomoo`0HOol01000Oomoogoo0P0037oo00@0
07ooOomoo`8001Ioo`03001oogoo01Uoo`03001oogoo01Ioo`03001oogoo01Uoo`03001oogoo03Qo
o`00Pgoo00<007ooOol0:Woo00<007ooOol07Woo0`0000Aoo`00000000=oo`03001oogoo01Uoo`<0
0003Ool007oo00aoo`<00003Ool007oo01Eoo`03001oogoo01Uoo`03001oogoo01Ioo`03001oogoo
01Uoo`03001oogoo03Qoo`00PGoo0`00;Goo0`009Woo0P00HWoo0`005goo0P00EWoo003oOonaOol0
0?mook5oo`00ogoo/Goo003oOonaOol00001\
\>"],
  ImageRangeCache->{{{135, 422}, {423.938, 247}} -> {-20.7392, 2.70951, 
  0.104176, 0.0104075}},
  CellTags->"Mean and standard deviation chart"]
}, Closed]],

Cell[OutputFormData["\<\
{{\"\", \"X\", \"S\"}, {\"CL\", 5., 
  0.9399856029866251}, 
 {\"LCL\", 6.261123023689533, 0.}, 
 {\"UCL\", 3.738876976310466, 
  1.8457819755338352}}\
\>", "\<\
      X         S

CL    5.        0.939986

LCL   6.26112   0.

UCL   3.73888   1.84578\
\>"], "Output",
  CellLabel->"Out[14]//TableForm=",
  CellTags->"Mean and standard deviation chart"]
}, Closed]],

Cell["Control Charts for Individual Measurements", "Section",
  PageWidth->PaperWidth,
  PageBreakBelow->False,
  CellTags->"Control Charts for Individual Measurements"],

Cell["Introduction", "Subsection",
  PageBreakBelow->False,
  CellTags->"Control Charts for Individual Measurements"],

Cell[TextData[{
  "In the ",
  Cell[BoxData[
      \(TraditionalForm\`X\&_\)]],
  " Chart only one value is taken for each subgroup (",
  StyleBox["m = ",
    FontSlant->"Italic"],
  "1).  The limits (UCL and LCL)  and center line (CL) are calculated \
depending on the situation",
  StyleBox[
  ": If standards values are unkown and must be estimated or if standars \
values are given.  ",
    FontFamily->"Times New Roman"],
  "Table 2 gives the formulae for both situation."
}], "Text",
  PageBreakBelow->False,
  CellTags->"Control Charts for Individual Measurements"],

Cell[TextData[{
  StyleBox["data",
    FontSlant->"Italic"],
  "  = {",
  Cell[BoxData[
      \(TraditionalForm\`X\_1\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`X\_2\)]],
  ", ...., ",
  Cell[BoxData[
      \(TraditionalForm\`X\_n\)]],
  "},"
}], "Text",
  PageBreakBelow->False,
  CellTags->"Control Charts for Individual Measurements"],

Cell[TextData[{
  StyleBox["The moving range is denoted by", "InlineFormula"],
  StyleBox[" MR",
    FontSlant->"Italic"],
  " =  {\[VerticalSeparator]",
  Cell[BoxData[
      \(TraditionalForm\`X\_1\)]],
  "- ",
  Cell[BoxData[
      \(TraditionalForm\`X\_2\)]],
  "\[VerticalSeparator], \[VerticalSeparator]",
  Cell[BoxData[
      \(TraditionalForm\`X\_2\)]],
  "- ",
  Cell[BoxData[
      \(TraditionalForm\`X\_3\)]],
  "\[VerticalSeparator]....,\[VerticalSeparator]",
  Cell[BoxData[
      \(TraditionalForm\`X\_\(n - 1\)\)]],
  "-",
  Cell[BoxData[
      \(TraditionalForm\`X\_n\)]],
  "\[VerticalSeparator]}"
}], "Text",
  PageBreakBelow->False,
  CellTags->"Control Charts for Individual Measurements"],

Cell[TextData[{
  "Table 2.- Formulae for X",
  StyleBox[" ",
    FontSlant->"Italic"],
  "charts for individuals."
}], "Text",
  PageBreakBelow->False,
  TextAlignment->Center,
  TextJustification->0,
  CellTags->"Control Charts for Individual Measurements"],

Cell[TextData[Cell[BoxData[GridBox[{
        {
          StyleBox[\(\(Stad\)\(.\)\),
            FontWeight->"Bold"], 
          StyleBox[\(CL\^1\),
            FontWeight->"Bold"], 
          StyleBox[\(\(UCL\  &\)\ LCL\^1\),
            FontWeight->"Bold"], 
          StyleBox[\(CL\^2\),
            FontWeight->"Bold"], 
          StyleBox[\(\(\ \)\(\(UCL\  &\)\ LCL\^2\)\),
            FontWeight->"Bold"]},
        {
          StyleBox["X",
            FontSlant->"Italic"], 
          StyleBox[
            RowBox[{" ", 
              OverscriptBox[
                StyleBox["X",
                  FontSlant->"Italic"], "_"]}],
            FontSlant->"Italic"], 
          RowBox[{
            RowBox[{\(\(X\&_\)\&_\), "\[PlusMinus]", 
              RowBox[{
                SubscriptBox[
                  StyleBox["E",
                    FontSlant->"Italic"], "2"], 
                StyleBox[\(MR\&_\),
                  FontSlant->"Italic"]}]}], "\[IndentingNewLine]", 
            RowBox[{
              StyleBox[\(E\_2\),
                FontSize->10,
                FontSlant->"Italic"], 
              StyleBox[" ",
                FontSize->10], 
              StyleBox["=",
                FontSize->10], 
              StyleBox[" ",
                FontSize->10], 
              StyleBox[\(3/1.128\),
                FontSize->10]}]}], 
          RowBox[{
            SubscriptBox[
              StyleBox["X",
                FontSlant->"Italic"], "0"], "or", " ", "\[Mu]"}], 
          RowBox[{
            SubscriptBox[
              StyleBox["X",
                FontSlant->"Italic"], "0"], "\[PlusMinus]", 
            RowBox[{"3", 
              StyleBox[" ",
                FontSlant->"Italic"], \(\[Sigma]\_\(\(0\)\(\ \ \)\)\)}]}]},
        {
          RowBox[{
            StyleBox[\(Moving\ range\),
              FontSize->10], ",", " ", 
            StyleBox["MR",
              FontSlant->"Italic"]}], 
          RowBox[{" ", 
            StyleBox[\(MR\&_\),
              FontSlant->"Italic"]}], 
          RowBox[{
            RowBox[{
              StyleBox[\(\(D\_4\) MR\&_\),
                FontSlant->"Italic"], 
              StyleBox[",",
                FontSlant->"Italic"], 
              RowBox[{
                SubscriptBox[
                  StyleBox["D",
                    FontSlant->"Italic"], "3"], 
                StyleBox[\(MR\&_\),
                  FontSlant->"Italic"]}]}], "\[IndentingNewLine]", 
            StyleBox[\(D\_4 = \ 3.267, D\_3 = \ 0\),
              FontSize->10,
              FontSlant->"Italic"]}], 
          RowBox[{
            RowBox[{
              SubscriptBox[
                StyleBox["R",
                  FontSlant->"Italic"], "0"], "or", " ", 
              StyleBox[\(d\_2\),
                FontSlant->"Italic"], 
              StyleBox[" ",
                FontSlant->"Italic"], \(\[Sigma]\_0\)}], 
            "\[IndentingNewLine]", 
            StyleBox[\(d\_2\  = \ 1.128\),
              FontSize->10,
              FontSlant->"Italic"]}], 
          RowBox[{
            RowBox[{
              RowBox[{
                SubscriptBox[
                  StyleBox["D",
                    FontSlant->"Italic"], "2"], \(\[Sigma]\_0\)}], ",", 
              RowBox[{
                StyleBox[\(D\_1\),
                  FontSlant->"Italic"], \(\[Sigma]\_0\)}]}], 
            "\[IndentingNewLine]", 
            StyleBox[\(D\_2 = \ 3.686, D\_1 = \ 0\),
              FontSize->10,
              FontSlant->"Italic"]}]}
        },
      GridFrame->True,
      RowLines->True,
      ColumnLines->True]]]], "Text",
  PageWidth->PaperWidth,
  PageBreakBelow->False,
  TextAlignment->Center,
  TextJustification->0,
  CellTags->"Control Charts for Individual Measurements"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        StyleBox[\(MR\&_\),
          FontSlant->"Italic"], TraditionalForm]],
    FontSize->10],
  StyleBox["  ",
    FontSize->10],
  StyleBox["denotes the average moving range of ",
    FontSize->10],
  StyleBox["n",
    FontSize->10,
    FontSlant->"Italic"],
  StyleBox[" =2 observations. ",
    FontSize->10],
  "\n",
  StyleBox["(1) No standards values given.",
    FontSize->10],
  Cell[BoxData[
      \(\(\(\ \)\(\(X\&_\)\&_\)\)\)],
    FontSize->10],
  StyleBox[",  and ",
    FontSize->10],
  Cell[BoxData[
      StyleBox[\(MR\&_\),
        FontSlant->"Italic"]],
    FontSize->10],
  StyleBox[" must be calculated.",
    FontSize->10],
  "\n",
  StyleBox["(2) ",
    FontSize->10],
  Cell[BoxData[
      SubscriptBox[
        StyleBox["X",
          FontSlant->"Italic"], "0"]],
    FontSize->10],
  StyleBox[",  ",
    FontSize->10],
  Cell[BoxData[
      RowBox[{
        StyleBox[\(R\_0\),
          FontSize->10,
          FontSlant->"Italic"], " "}]]],
  ", ",
  StyleBox["\[Mu],  ",
    FontSize->10],
  Cell[BoxData[
      \(\[Sigma]\_0\)],
    FontSize->10],
  StyleBox[", and are given standard values.",
    FontSize->10]
}], "Text",
  PageWidth->PaperWidth,
  PageBreakBelow->False,
  TextAlignment->Left,
  TextJustification->0,
  CellTags->"Control Charts for Individual Measurements"],

Cell["No standard values are given (Initial Study)", "Subsection",
  PageBreakBelow->False,
  CellTags->"Control Charts for Individual Measurements"],

Cell[TextData[{
  "Mean and deviation of process are calculated using ",
  StyleBox["data",
    FontSlant->"Italic"],
  " values"
}], "Text",
  CellTags->"Control Charts for Individual Measurements"],

Cell[TextData[{
  "XforIReportSh[",
  StyleBox["data",
    FontSlant->"Italic"],
  "] \tgives CL, LCL, UCL for X and MR\n\nXforIReport[",
  StyleBox["data",
    FontSlant->"Italic"],
  "] \tgives ",
  Cell[BoxData[
      FormBox[
        FormBox[\(X\&_\_k\),
          "TraditionalForm"], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`s\_k\)]],
  " CL, LCL, UCL for X and MR\n\nXforIChart[",
  StyleBox["data",
    FontSlant->"Italic"],
  "] \tplots the Control Charts for X and MR"
}], "DefinitionBox",
  CellTags->"Control Charts for Individual Measurements"],

Cell["Standard values are given", "Subsection",
  PageBreakBelow->False,
  CellTags->"Control Charts for Individual Measurements"],

Cell[TextData[{
  "Mean, ",
  StyleBox["mu",
    FontSlant->"Italic"],
  ",  and deviation, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sigma]\_0\)]],
  ",  of process are supposed that are known."
}], "Text",
  CellTags->"Control Charts for Individual Measurements"],

Cell[TextData[{
  "XforIReportShSG[",
  StyleBox["data",
    FontSlant->"Italic"],
  ", ",
  StyleBox["mu, sig",
    FontSlant->"Italic"],
  "] \tgives CL, LCL, UCL for X and MR\n\nXforIReportSG[",
  StyleBox["data",
    FontSlant->"Italic"],
  ", ",
  StyleBox["mu, sig",
    FontSlant->"Italic"],
  "] \tgives ",
  Cell[BoxData[
      FormBox[
        FormBox[\(X\&_\_k\),
          "TraditionalForm"], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          OverscriptBox[
            StyleBox["MR",
              FontSlant->"Italic"], "_"], "k"], TraditionalForm]]],
  " CL, LCL, UCL for X and for MR\n\nXforIChartSG[",
  StyleBox["data",
    FontSlant->"Italic"],
  ", ",
  StyleBox["mu, sig",
    FontSlant->"Italic"],
  "]\t\t plots the Control Charts for X and MR"
}], "DefinitionBox",
  CellTags->"Control Charts for Individual Measurements"],

Cell["Example", "Subsection",
  CellTags->"Control Charts for Individual Measurements"],

Cell[BoxData[
    \(\(data2\  = \ 
        {33.75, \ 33.05, \ 34.00, \ 33.81, \ 33.46, \ 34.02, \ 33.68, \ 
          33.27, \ 33.49, \ 33.20, \ 33.62, \ 33.00, \ 33.54, \ 33.12, \ 
          33.84};\)\)], "Input",
  CellLabel->"In[15]:=",
  CellTags->"Control Charts for Individual Measurements"],

Cell["No standard given", "Subsubsection",
  CellTags->"Control Charts for Individual Measurements"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(\[IndentingNewLine]\)\(?XforIReportSh\)\)\)], "Input",
  CellLabel->"In[16]:=",
  CellTags->"Control Charts for Individual Measurements"],

Cell["\<\
XbarSReportSh[list] give the short report
   for a XforI chart, no standard given.\
\>", "Print",
  CellLabel->"From In[16]:=",
  CellTags->"Control Charts for Individual Measurements"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(XforIReportSh[data2]\)], "Input",
  CellLabel->"In[17]:=",
  CellTags->"Control Charts for Individual Measurements"],

Cell[OutputFormData["\<\
{{\"\", \"X\", \"MR\"}, {\"CL\", 33.52333333333333, 
  0.480714285714286}, 
 {\"LCL\", 34.801826626190476, 0}, 
 {\"UCL\", 32.24484004047619, 
  1.5704935714285722}}\
\>", "\<\
      X         MR

CL    33.5233   0.480714

LCL   34.8018   0

UCL   32.2448   1.57049\
\>"], "Output",
  CellLabel->"Out[17]//TableForm=",
  CellTags->"Control Charts for Individual Measurements"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?XforIReport\)\)], "Input",
  CellLabel->"In[18]:=",
  CellTags->"Control Charts for Individual Measurements"],

Cell["\<\
XforIReport[list] give the full report for a
   XforI chart, no standard given.\
\>", "Print",
  CellLabel->"From In[18]:=",
  CellTags->"Control Charts for Individual Measurements"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(XforIReport[data2]\)], "Input",
  CellLabel->"In[19]:=",
  CellTags->"Control Charts for Individual Measurements"],

Cell[OutputFormData["\<\
{{\"Subgroup\", \"X\", \"MR\"}, {1, 33.75, 0}, 
 {2, 33.05, 0.7000000000000028}, 
 {3, 34., 0.9500000000000028}, 
 {4, 33.81, 0.18999999999999773}, 
 {5, 33.46, 0.3500000000000014}, 
 {6, 34.02, 0.5600000000000023}, 
 {7, 33.68, 0.3400000000000034}, 
 {8, 33.27, 0.4099999999999966}, 
 {9, 33.49, 0.21999999999999886}, 
 {10, 33.2, 0.28999999999999915}, 
 {11, 33.62, 0.4199999999999946}, 
 {12, 33., 0.6199999999999974}, 
 {13, 33.54, 0.5399999999999991}, 
 {14, 33.12, 0.4200000000000017}, 
 {15, 33.84, 0.720000000000006}, 
 {\"CL\", 33.52333333333333, 
  0.480714285714286}, 
 {\"LCL\", 34.801826626190476, 0}, 
 {\"UCL\", 32.24484004047619, 
  1.5704935714285722}}\
\>", "\<\
Subgroup   X         MR

1          33.75     0

2          33.05     0.7

3          34.       0.95

4          33.81     0.19

5          33.46     0.35

6          34.02     0.56

7          33.68     0.34

8          33.27     0.41

9          33.49     0.22

10         33.2      0.29

11         33.62     0.42

12         33.       0.62

13         33.54     0.54

14         33.12     0.42

15         33.84     0.72

CL         33.5233   0.480714

LCL        34.8018   0

UCL        32.2448   1.57049\
\>"], "Output",
  CellLabel->"Out[19]//TableForm=",
  CellTags->"Control Charts for Individual Measurements"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(\[IndentingNewLine]\)\(?XforIChart\)\)\)], "Input",
  CellLabel->"In[20]:=",
  CellTags->"Control Charts for Individual Measurements"],

Cell["\<\
XforIChart[list] plot the X an MR Charts of
   the entries in list, no standard given.\
\>", "Print",
  CellLabel->"From In[20]:=",
  CellTags->"Control Charts for Individual Measurements"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(XforIChart[data2]\)], "Input",
  CellLabel->"In[21]:=",
  CellTags->"Control Charts for Individual Measurements"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0634921 -5.47864 0.172646 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.15079 -0.0125 -3 -9 ]
[.15079 -0.0125 3 0 ]
[.27778 -0.0125 -3 -9 ]
[.27778 -0.0125 3 0 ]
[.40476 -0.0125 -3 -9 ]
[.40476 -0.0125 3 0 ]
[.53175 -0.0125 -3 -9 ]
[.53175 -0.0125 3 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.78571 -0.0125 -6 -9 ]
[.78571 -0.0125 6 0 ]
[.9127 -0.0125 -6 -9 ]
[.9127 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -26 -21.5625 ]
[.5 -0.0125 26 -9 ]
[-0.0125 .04602 -12 -4.5 ]
[-0.0125 .04602 0 4.5 ]
[-0.0125 .13234 -24 -4.5 ]
[-0.0125 .13234 0 4.5 ]
[-0.0125 .21867 -12 -4.5 ]
[-0.0125 .21867 0 4.5 ]
[-0.0125 .30499 -24 -4.5 ]
[-0.0125 .30499 0 4.5 ]
[-0.0125 .39131 -12 -4.5 ]
[-0.0125 .39131 0 4.5 ]
[-0.0125 .47763 -24 -4.5 ]
[-0.0125 .47763 0 4.5 ]
[-0.0125 .56396 -12 -4.5 ]
[-0.0125 .56396 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -36.5625 -5 ]
[-0.01875 .30902 -24 5 ]
[.5 .63053 -119 0 ]
[.5 .63053 119 25.75 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .30902 m
1 .30902 L
s
0 .52974 m
1 .52974 L
s
0 .08829 m
1 .08829 L
s
0 g
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.15079 0 m
.15079 .00625 L
s
[(2)] .15079 -0.0125 0 1 Mshowa
.27778 0 m
.27778 .00625 L
s
[(4)] .27778 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(6)] .40476 -0.0125 0 1 Mshowa
.53175 0 m
.53175 .00625 L
s
[(8)] .53175 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(10)] .65873 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(12)] .78571 -0.0125 0 1 Mshowa
.9127 0 m
.9127 .00625 L
s
[(14)] .9127 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.18254 0 m
.18254 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.34127 0 m
.34127 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.5 0 m
.5 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.81746 0 m
.81746 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -87 -25.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(subgroup) show
111.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .04602 m
.00625 .04602 L
s
[(32)] -0.0125 .04602 1 0 Mshowa
0 .13234 m
.00625 .13234 L
s
[(32.5)] -0.0125 .13234 1 0 Mshowa
0 .21867 m
.00625 .21867 L
s
[(33)] -0.0125 .21867 1 0 Mshowa
0 .30499 m
.00625 .30499 L
s
[(33.5)] -0.0125 .30499 1 0 Mshowa
0 .39131 m
.00625 .39131 L
s
[(34)] -0.0125 .39131 1 0 Mshowa
0 .47763 m
.00625 .47763 L
s
[(34.5)] -0.0125 .47763 1 0 Mshowa
0 .56396 m
.00625 .56396 L
s
[(35)] -0.0125 .56396 1 0 Mshowa
.125 Mabswid
0 .06328 m
.00375 .06328 L
s
0 .08055 m
.00375 .08055 L
s
0 .09781 m
.00375 .09781 L
s
0 .11508 m
.00375 .11508 L
s
0 .14961 m
.00375 .14961 L
s
0 .16687 m
.00375 .16687 L
s
0 .18414 m
.00375 .18414 L
s
0 .2014 m
.00375 .2014 L
s
0 .23593 m
.00375 .23593 L
s
0 .25319 m
.00375 .25319 L
s
0 .27046 m
.00375 .27046 L
s
0 .28772 m
.00375 .28772 L
s
0 .32225 m
.00375 .32225 L
s
0 .33952 m
.00375 .33952 L
s
0 .35678 m
.00375 .35678 L
s
0 .37405 m
.00375 .37405 L
s
0 .40858 m
.00375 .40858 L
s
0 .42584 m
.00375 .42584 L
s
0 .44311 m
.00375 .44311 L
s
0 .46037 m
.00375 .46037 L
s
0 .4949 m
.00375 .4949 L
s
0 .51216 m
.00375 .51216 L
s
0 .52943 m
.00375 .52943 L
s
0 .54669 m
.00375 .54669 L
s
0 .02876 m
.00375 .02876 L
s
0 .01149 m
.00375 .01149 L
s
0 .58122 m
.00375 .58122 L
s
0 .59849 m
.00375 .59849 L
s
0 .61575 m
.00375 .61575 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -96.2813 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
66 10.2813 translate
90 rotate
-66 -10.2813 translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(X) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -180 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 33.75 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(X) show
75.000 12.813 moveto
(values) show
117.000 12.813 moveto
(for) show
141.000 12.813 moveto
(individuals) show
213.000 12.813 moveto
(Control) show
261.000 12.813 moveto
(chart) show
291.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
63.000 26.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Initial) show
111.000 26.000 moveto
(Study) show
141.000 26.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.0873 .34815 m
.15079 .2273 L
.21429 .39131 L
.27778 .35851 L
.34127 .29808 L
.40476 .39476 L
.46825 .33606 L
.53175 .26528 L
.59524 .30326 L
.65873 .25319 L
.72222 .32571 L
.78571 .21867 L
.84921 .31189 L
.9127 .23938 L
.97619 .36369 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[21]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012Q000`40O003h00Oogoo/Goo003oOona
Ool00?mook5oo`00hGoo10007goo0`00ZGoo003UOol00`00Oomoo`0MOol00`00Oomoo`2XOol00>Eo
o`03001oogoo01eoo`03001oogoo0:Qoo`00aWoo1@001Goo0`0000Aoo`00001oo`800004Ool00000
0004Ool300000goo001oo`03Ool50005Ool40005Ool300000goo00000002Ool00`00Ool00002002V
Ool00<Ioo`03001oogoo009oo`05001oogooOol00003Ool20003Ool20003Ool01000Oomoo`000goo
0P001Goo00<007ooOol01Goo00<007ooOol00Woo00D007ooOomoo`0000=oo`8000=oo`8000=oo`03
001oogoo0:=oo`00bgoo00D007ooOomoo`0000Aoo`05001oogooOol00004Ool01000Oomoo`0017oo
00<007ooOol00goo00<007ooOol01Goo00<007ooOol00Woo00D007ooOomoo`0000Aoo`05001oogoo
Ool00004Ool00`00Oomoo`2SOol00<Moo`@000Aoo`03001oogoo009oo`05001oogooOol00004Ool0
1000Oomoo`0017oo00<007ooOol00goo00<007ooOol01Goo00<007ooOol00Woo00D007ooOomoo`00
00Aoo`05001oogooOol00004Ool00`00Oomoo`2SOol00<Ioo`03001oogoo009oo`05001oogooOol0
0004Ool01000Oomoogoo0P000goo00@007ooOol000=oo`8000Eoo`8000Ioo`03001oogoo009oo`05
001oogooOol00004Ool01000Oomoogoo0P000goo00<007ooOol0Xgoo0037Ool50002Ool20003Ool2
0003Ool00`00Ool000020004Ool300000goo00000003Ool2000017oo0000000017oo10000goo0P00
0goo0P000Woo0P0000Aoo`0000000:Ioo`00f7oo00<007ooOol0eGoo003HOol00`00Oomoo`3EOol0
0=Moo`800=Moo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol005Eoo`@0025o
o`H002=oo`@0029oo`@0029oo`@001eoo`L000=oo`@001Qoo`L0009oo`H001Qoo`L000Aoo`@004Ao
o`00E7oo00<007ooOol00Woo00<007ooOol07Woo00<007ooOol00Woo00<007ooOol08goo00<007oo
Ool087oo00<007ooOol00Woo00<007ooOol07Woo00<007ooOol00Woo00<007ooOol07Goo00<007oo
Ool00goo00<007ooOol00Woo00<007ooOol067oo00<007ooOol00goo00<007ooOol00Woo00<007oo
Ool06Goo00<007ooOol01goo00<007ooOol0@goo001DOol00`00Oomoo`02Ool00`00Oomoo`0OOol0
0`00Oomoo`0WOol00`00Oomoo`0POol00`00Oomoo`02Ool00`00Oomoo`0NOol00`00Oomoo`02Ool0
0`00Oomoo`0MOol00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`0HOol00`00Oomoo`04Ool0
0`00Oomoo`0MOol00`00Oomoo`07Ool00`00Oomoo`13Ool005Aoo`03001oogoo009oo`03001oogoo
021oo`03001oogoo029oo`H0025oo`8000=oo`03001oogoo01ioo`03001oogoo009oo`03001oogoo
01eoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo01Qoo`03001oogoo00Eoo`03001oogoo
01aoo`03001oogoo00=oo`H004Aoo`00E7oo00<007ooOol00Woo00<007ooOol08Goo00<007ooOol0
8Woo00@007ooOol0029oo`03001oo`000080029oo`@0021oo`03001oogoo00=oo`03001oogoo009o
o`03001oogoo01Qoo`03001oogoo00Ioo`03001oogoo01]oo`03001oogoo00Aoo`04001oogoo0015
Ool005Aoo`03001oogoo009oo`03001oogoo029oo`03001oogoo025oo`04001oogoo000ROol00`00
Oomoo`0SOol00`00Oomoo`02Ool00`00Oomoo`0MOol00`00Oomoo`03Ool00`00Oomoo`02Ool00`00
Oomoo`0HOol00`00Oomoo`07Ool00`00Oomoo`0JOol00`00Oomoo`04Ool01000Oomoo`00AGoo001D
Ool00`00Oomoo`02Ool00`00Oomoo`0NOol00`00Oomoo`02Ool00`00Oomoo`0QOol00`00Ool0000S
Ool00`00Oomoo`0ROol00`00Oomoo`02Ool00`00Oomoo`0MOol00`00Oomoo`03Ool00`00Oomoo`02
Ool00`00Oomoo`0HOol00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`0IOol00`00Oomoo`05
Ool00`00Ool00015Ool005Aoo`03001oogoo009oo`03001oogoo01ioo`03001oogoo009oo`03001o
ogoo025oo`03001oo`0002Aoo`03001oogoo025oo`03001oogoo009oo`03001oogoo01]oo`<000Eo
o`03001oogoo009oo`03001oogoo01Ioo`<000Eoo`03001oogoo009oo`03001oogoo01Moo`<000Mo
o`03001oo`0004Eoo`00EGoo10008Woo10009Goo0P009Goo0`008Goo100087oo00<007ooOol017oo
10006goo00<007ooOol017oo100077oo00<007ooOol01Woo0P00AGoo003oOonaOol00?mook5oo`00
ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol0051oool00340031oo`00D7oo00<0
07ooOol017oo00<007ooOol01goo00<007ooOol01goo00<007ooOol01Woo00<007ooOol01goo00<0
07ooOol01goo00<007ooOol01Woo00<007ooOol01goo00<007ooOol01Woo00<007ooOol01goo00<0
07ooOol01goo00<007ooOol01Woo00<007ooOol01goo00<007ooOol01goo00<007ooOol01Woo00<0
07ooOol01goo00<007ooOol01Woo00<007ooOol01goo00<007ooOol01goo00<007ooOol01Woo00<0
07ooOol01goo00<007ooOol01goo00<007ooOol01Woo00<007ooOol01goo00<007ooOol01Woo00<0
07ooOol01goo00<007ooOol01goo00<007ooOol01Woo00<007ooOol01goo00<007ooOol01goo00<0
07ooOol01Woo00<007ooOol0=Goo001@Ool00`00Oomoo`04Ool00`00Oomoo`0TOol00`00Oomoo`0S
Ool00`00Oomoo`0TOol00`00Oomoo`0SOol00`00Oomoo`0TOol00`00Oomoo`0SOol00`00Oomoo`0T
Ool00`00Oomoo`18Ool0051oo`800?mooemoo`00D7oo00<007ooOol0ogooGWoo001@Ool00`00Oomo
o`3oOomNOol0051oo`03001oogoo0?mooeioo`00D7oo00<007ooOol0ogooGWoo001@Ool2003oOomO
Ool0051oo`03001oogoo0?mooeioo`00?7oo100017oo1P001Woo00<007ooOol0ogooGWoo000kOol0
0`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol017oo00<007ooOol0ogooGWoo0010Ool0
0`00Oomoo`02Ool00`00Oomoo`08Ool00`00Oomoo`3oOomNOol0041oo`03001oogoo00=oo`03001o
ogoo00Moo`03001oogoo0?mooeioo`00?Woo0P001goo00<007ooOol01Woo0`00ogooGWoo0010Ool0
0`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`3oOomNOol0041oo`05001oogooOol00004Ool0
0`00Oomoo`04Ool00`00Oomoo`3oOomNOol003]oo`03001oogoo009oo`05001oogooOol00004Ool0
0`00Oomoo`04Ool00`00Oomoo`3oOomNOol003aoo`@000Eoo`@000Moo`03001oogoo0?mooeioo`00
D7oo0P00ogooGgoo001@Ool00`00Oomoo`3oOomNOol0051oo`03001oogoo0?mooeioo`00D7oo00<0
07ooOol0ogooGWoo001@Ool00`00Oomoo`3oOomNOol0051oo`800?mooemoo`00D7oo00<007ooOol0
ogooGWoo001@Ool00`00Oomoo`3oOomNOol0051oo`0300003`0?0?l03bh03c1oo`00D7oo00<007oo
Ool0ogooGWoo001@Ool2003oOomOOol0051oo`03001oogoo0?mooeioo`00D7oo00<007ooOol0ogoo
GWoo001@Ool00`00Oomoo`3oOomNOol0051oo`03001oogoo0?mooeioo`00D7oo00<007ooOol0ogoo
GWoo001@Ool2003oOomOOol002Yoo`@000Aoo`H000Eoo`8000Ioo`@000Moo`03001oogoo0?mooeio
o`00:Goo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo00=oo`8000Eoo`03001oogoo
009oo`03001oogoo00Aoo`03001oogoo0?mooeioo`00;Woo00<007ooOol00Woo00<007ooOol04goo
00<007ooOol017oo00<007ooOol0ogooGWoo000^Ool00`00Oomoo`03Ool00`00Oomoo`0BOol00`00
Oomoo`04Ool00`00Oomoo`3oOomNOol002aoo`8000Moo`03001oogoo015oo`03001oogoo00Aoo`<0
0?mooeioo`00;Woo00<007ooOol01Goo00<007ooOol037oo10001goo00<007ooOol0ogooGWoo000^
Ool01@00Oomoogoo000017oo00<007ooOol02goo00<007ooOol027oo00<007ooOol0ogooGWoo000Y
Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol02goo00<007ooOol027oo00<007oo
Ool0ogooGWoo000ZOol40005Ool4000>Ool50006Ool00`00Oomoo`3oOomNOol0051oo`800?mooemo
o`00D7oo00<007ooOol0ogooGWoo001@Ool00`00Oomoo`3oOomNOol0051oo`03001oogoo0?mooeio
o`00D7oo00<007ooOol0ogooGWoo001@Ool2003oOomOOol0051oo`03001oogoo0?mooeioo`00D7oo
00<007ooOol0ogooGWoo001@Ool00`00Oomoo`3oOomNOol0051oo`03001oogoo0?mooeioo`00D7oo
00<007ooOol0ogooGWoo001@Ool2003oOomOOol0051oo`03001oogoo0?mooeioo`00D7oo00<007oo
Ool0ogooGWoo001@Ool00`00Oomoo`3oOomNOol0051oo`03001oogoo0?mooeioo`00D7oo0P00ogoo
Ggoo001@Ool00`00Oomoo`3oOomNOol003aoo`@000Eoo`@000Moo`03001oogoo0?mooeioo`00>goo
00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo00Aoo`03001oogoo0?mooeioo`00@7oo
00<007ooOol01Woo00<007ooOol017oo00<007ooOol0ogooGWoo0010Ool00`00Oomoo`06Ool00`00
Oomoo`04Ool3003[Ool00`00Oomoo`1_Ool003ioo`8000Moo`8000Moo`03001oogoo0>Yoo`03001o
o`00071oo`00@7oo00<007ooOol01Woo00<007ooOol017oo00<007ooOol0jWoo00<007oo0000L7oo
0010Ool00`00Oomoo`06Ool00`00Oomoo`04Ool00`00Oomoo`0[Ool00`00Oomoo`2kOol01@00Oomo
ogoo0000Kgoo000kOol00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol017oo00<007oo
Ool0:Woo0P00_Goo00<007ooOol00Woo00<007ooOol0K7oo000lOol40005Ool40007Ool2000[Ool0
0`00Ool0002kOol00`00Oomoo`04Ool00`00Oomoo`1[Ool0051oo`03001oogoo02Uoo`04001oogoo
002jOol00`00Oomoo`05Ool00`00Oomoo`0POol00`00Oomoo`18Ool0051oo`03001oogoo02Uoo`05
001oogooOol0002iOol00`00Oomoo`06Ool00`00Oomoo`0NOol00`00Ool00019Ool0051oo`03001o
ogoo02Qoo`03001oogoo009oo`03001oogoo0;Ioo`03001oogoo00Qoo`03001oogoo01aoo`04001o
ogoo0019Ool0051oo`03001oogoo02Qoo`03001oogoo009oo`03001oogoo0;Ioo`03001oogoo00Qo
o`03001oogoo01]oo`03001oogoo009oo`03001oogoo04Ioo`00D7oo0P00:7oo00<007ooOol017oo
00<007ooOol0U7oo00<007ooOol07Goo00<007ooOol02Woo00<007ooOol06Woo00<007ooOol00Woo
00<007ooOol0AWoo001@Ool00`00Oomoo`0WOol00`00Oomoo`04Ool00`00Oomoo`2COol00`00Ool0
000MOol00`00Oomoo`0<Ool00`00Oomoo`0HOol00`00Oomoo`04Ool00`00Oomoo`15Ool0051oo`03
001oogoo02Ioo`03001oogoo00Eoo`03001oogoo099oo`05001oogooOol0000LOol00`00Oomoo`0=
Ool00`00Oomoo`0FOol00`00Oomoo`05Ool00`00Oomoo`15Ool0051oo`03001oogoo02Ioo`03001o
ogoo00Ioo`03001oogoo08moo`8000Eoo`03001oogoo01Qoo`03001oogoo00ioo`03001oogoo01Eo
o`03001oogoo00Moo`03001oogoo04Aoo`00D7oo00<007ooOol09Goo00<007ooOol01goo00<007oo
Ool0K7oo00<007ooOol07goo00<007ooOol01Goo00<007ooOol067oo00<007ooOol03goo00<007oo
Ool04goo00<007ooOol027oo00<007ooOol0A7oo001@Ool00`00Oomoo`0UOol00`00Oomoo`08Ool0
0`00Oomoo`1ZOol01000Ool000007Woo00<007ooOol01goo00<007ooOol05Woo00<007ooOol04Goo
00<007ooOol04Goo00<007ooOol02Woo00<007ooOol0@goo001@Ool2000UOol00`00Oomoo`09Ool0
0`00Oomoo`1YOol00`00Oomoo`02Ool2000KOol00`00Oomoo`09Ool00`00Oomoo`0EOol00`00Oomo
o`0AOol00`00Oomoo`0@Ool00`00Oomoo`0;Ool00`00Oomoo`13Ool0051oo`03001oogoo02Aoo`03
001oogoo00Uoo`03001oogoo06Qoo`03001oogoo00Eoo`03001oogoo01Moo`03001oogoo00]oo`03
001oogoo01=oo`03001oogoo01=oo`03001oogoo00moo`03001oogoo00aoo`03001oogoo049oo`00
D7oo00<007ooOol08goo00<007ooOol02goo00<007ooOol0Igoo00<007ooOol01Woo0P005Goo0P00
3goo00<007ooOol04Goo00<007ooOol05Goo00<007ooOol03Goo00<007ooOol03Goo00<007ooOol0
@Woo001@Ool00`00Oomoo`0SOol00`00Oomoo`0;Ool00`00Oomoo`1VOol00`00Oomoo`09Ool2000B
Ool00`00Oomoo`0@Ool00`00Oomoo`0@Ool00`00Oomoo`0FOol00`00Oomoo`0;Ool00`00Oomoo`0?
Ool00`00Oomoo`11Ool0051oo`03001oogoo029oo`03001oogoo00eoo`03001oogoo06Aoo`03001o
ogoo00aoo`03001oogoo00ioo`03001oogoo019oo`03001oogoo00ioo`03001oogoo01Moo`03001o
ogoo00Yoo`03001oogoo011oo`03001oogoo045oo`00D7oo0P008goo00<007ooOol03Goo00<007oo
Ool0Hgoo00<007ooOol03Woo0P003Goo00<007ooOol04goo00<007ooOol03Woo00<007ooOol067oo
00<007ooOol027oo00<007ooOol04Woo00<007ooOol0@7oo001@Ool00`00Oomoo`0QOol00`00Oomo
o`0>Ool00`00Oomoo`1ROol00`00Oomoo`0AOol2000:Ool00`00Oomoo`0EOol00`00Oomoo`0<Ool0
0`00Oomoo`0JOol00`00Oomoo`06Ool00`00Oomoo`0COol00`00Oomoo`10Ool002Yoo`@000Eoo`@0
00Ioo`8000Ioo`@000Moo`03001oogoo021oo`03001oogoo011oo`03001oogoo061oo`03001oogoo
01Aoo`03001oogoo00Eoo`8001Uoo`03001oogoo00Yoo`03001oogoo01]oo`03001oogoo00Eoo`03
001oogoo01Eoo`03001oogoo03moo`00:Goo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001o
ogoo00=oo`8000Eoo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo021oo`03001oogoo011o
o`03001oogoo02moo`03001oogoo02eoo`03001oogoo01Ioo`8000Aoo`03001oogoo01Yoo`03001o
ogoo00Uoo`03001oogoo01aoo`03001oogoo00=oo`03001oogoo01Ioo`03001oogoo03moo`006Goo
00<007ooOol017oo00<007ooOol02goo00<007ooOol01Woo00<007ooOol03goo00<007ooOol017oo
00<007ooOol07goo00<007ooOol04Woo00<007ooOol0;Goo00<007oo0000;Woo00<007ooOol067oo
0P0000=oo`00Ool07Goo00<007ooOol01goo00<007ooOol07Woo00<007ooOol00Woo00<007ooOol0
5goo00<007ooOol0?Woo000IOol20004Ool2000=Ool00`00Oomoo`06Ool00`00Oomoo`0?Ool00`00
Oomoo`04Ool3000OOol00`00Oomoo`0BOol00`00Oomoo`0/Ool01000Oomoo`00;Goo00<007ooOol0
6goo00<007ooOol07Woo00<007ooOol01Woo00<007ooOol07goo00@007ooOol001Yoo`03001oogoo
03ioo`006Goo00<007oo00000Woo00<007oo00002goo0P001goo0P004Woo00<007ooOol017oo00<0
000?00l07P0?00<0000?00l04`0?00<0000?00l0:`0?00<0000?00l00P0?00<0000?00l0:@0?00<0
000?00l0?P0?00<0000?00l0100?00<0000?00l0800?00<0000?0000700?00<0000?00l03@0?<7oo
000LOol2000@Ool00`00Oomoo`06Ool00`00Oomoo`0;Ool40007Ool00`00Oomoo`0NOol00`00Oomo
o`0DOol00`00Oomoo`0YOol00`00Oomoo`04Ool00`00Oomoo`0WOol00`00Oomoo`10Ool00`00Oomo
o`02Ool00`00Oomoo`0ROol00`00Oomoo`0KOol00`00Oomoo`0mOol001Uoo`03001oo`00009oo`03
001oo`0000eoo`03001oogoo00Ioo`03001oogoo00]oo`03001oogoo00Qoo`03001oogoo01eoo`03
001oogoo01Eoo`03001oogoo02Moo`8000Moo`03001oogoo02Ioo`03001oogoo045oo`03001oogoo
009oo`03001oogoo045oo`03001oogoo03aoo`006Goo0P0017oo0P0027oo00<007ooOol00Woo00D0
07ooOomoo`0000Aoo`03001oogoo00]oo`03001oogoo00Qoo`03001oogoo01eoo`03001oogoo01Eo
o`03001oogoo02Ioo`03001oogoo00Qoo`03001oogoo02Aoo`03001oogoo04=oo`04001oogoo0014
Ool00`00Oomoo`0lOol001Uoo`03001oogoo00Aoo`03001oogoo00Moo`@000Eoo`@000ioo`D000Io
o`8001eoo`03001oogoo01Moo`03001oogoo02Aoo`03001oogoo00Yoo`03001oogoo029oo`03001o
ogoo04Eoo`03001oo`0004Eoo`03001oogoo03]oo`00D7oo00<007ooOol077oo00<007ooOol05goo
00<007ooOol08goo00<007ooOol02goo00<007ooOol08Goo00<007ooOol0Agoo00<007ooOol0A7oo
00<007ooOol0>goo001@Ool00`00Oomoo`0KOol00`00Oomoo`0IOol00`00Oomoo`0QOol00`00Oomo
o`0=Ool00`00Oomoo`0POol00`00Oomoo`2?Ool00`00Oomoo`0jOol0051oo`03001oogoo01]oo`03
001oogoo01Uoo`03001oogoo021oo`03001oogoo00moo`03001oogoo01ioo`03001oogoo091oo`03
001oogoo03Yoo`00D7oo00<007ooOol06Woo00<007ooOol06Woo00<007ooOol07goo00<007ooOol0
47oo00<007ooOol07Goo00<007ooOol0TWoo00<007ooOol0>Goo001@Ool00`00Oomoo`0JOol00`00
Oomoo`0KOol00`00Oomoo`0MOol00`00Oomoo`0BOol00`00Oomoo`0KOol00`00Oomoo`2COol00`00
Oomoo`0iOol0051oo`8001Yoo`03001oogoo01aoo`03001oogoo01aoo`03001oogoo01Aoo`03001o
ogoo01Uoo`03001oogoo09Eoo`03001oogoo03Qoo`00D7oo00<007ooOol06Goo00<007ooOol07Goo
00<007ooOol06Goo0P005goo00<007ooOol067oo00<007ooOol0UWoo00<007ooOol0>7oo001@Ool0
0`00Oomoo`0HOol00`00Oomoo`0NOol00`00Oomoo`0HOol00`00Oomoo`0HOol00`00Oomoo`0FOol0
0`00Oomoo`2HOol00`00Oomoo`0gOol0051oo`03001oogoo03Uoo`03001oogoo01Moo`03001oogoo
01Uoo`03001oogoo01Aoo`8009]oo`03001oogoo03Moo`00D7oo00<007ooOol0>Woo00<007ooOol0
5Goo00<007ooOol06goo00<007ooOol04Woo00<007ooOol0W7oo00<007ooOol0=Woo001@Ool2000k
Ool00`00Oomoo`0DOol00`00Oomoo`0MOol00`00Oomoo`0@Ool00`00Oomoo`2MOol00`00Oomoo`0f
Ool0051oo`03001oogoo03]oo`03001oogoo015oo`80021oo`03001oogoo00moo`03001oogoo09mo
o`03001oogoo03Eoo`00D7oo00<007ooOol0>goo00<007ooOol03goo0P008goo00<007ooOol03Goo
00<007ooOol0X7oo00<007ooOol0=Goo001@Ool00`00Oomoo`0kOol00`00Oomoo`0=Ool2000VOol0
0`00Oomoo`0;Ool00`00Oomoo`3IOol0051oo`03001oogoo03aoo`03001oogoo00Yoo`8002Qoo`03
001oogoo00Yoo`03001oogoo0=Yoo`00D7oo0P00?Goo00<007ooOol027oo0P00:goo00<007ooOol0
27oo00<007ooOol0fgoo001@Ool00`00Oomoo`0lOol00`00Oomoo`06Ool2000^Ool00`00Oomoo`06
Ool00`00Oomoo`3LOol003aoo`@000Ioo`@000Ioo`03001oogoo03eoo`03001oogoo00=oo`80031o
o`03001oogoo00Aoo`800=moo`00>goo00<007ooOol00Woo00<007ooOol01Goo00<007ooOol01Goo
00<007ooOol0?Goo00@007ooOomoo`8003=oo`03001oogoo009oo`03001oogoo0=moo`00@7oo00<0
07ooOol01Goo00<007ooOol01Goo00<007ooOol0?Woo0`00=Woo00@007ooOol00>9oo`00@7oo00@0
07ooOomoo`H000Ioo`<003ioo`03001oogoo03Ioo`03001oo`000>=oo`00?Woo0P001Goo00@007oo
Ool000Moo`03001oogoo07Qoo`03001oogoo0>9oo`00@7oo00<007ooOol00Woo00@007ooOol000Mo
o`03001oogoo0?mooeioo`00@7oo00<007ooOol00goo00<007oo00001goo00<007ooOol0ogooGWoo
000kOol00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Ool00007Ool00`00Oomoo`3oOomNOol003ao
o`@000Moo`8000Moo`03001oogoo0?mooeioo`00D7oo0P00ogooGgoo001@Ool00`00Oomoo`3oOomN
Ool0051oo`03001oogoo0?mooeioo`00D7oo00<007ooOol0ogooGWoo001@Ool00`00Oomoo`3oOomN
Ool0051oo`800?mooemoo`00D7oo00<007ooOol0ogooGWoo001@Ool00`00Oomoo`3oOomNOol0051o
o`03001oogoo0?mooeioo`00D7oo00<007ooOol0ogooGWoo001@Ool2003oOomOOol0051oo`03001o
ogoo0?mooeioo`00D7oo00<007ooOol0ogooGWoo001@Ool00`00Oomoo`3oOomNOol0051oo`03001o
ogoo0?mooeioo`00D7oo0P00ogooGgoo001@Ool00`00Oomoo`3oOomNOol002Yoo`@000Ioo`@000Eo
o`8000Ioo`@000Moo`03001oogoo0?mooeioo`00:Goo00<007ooOol00Woo00<007ooOol01Goo00<0
07ooOol017oo0P001Goo00<007ooOol00Woo00<007ooOol017oo00<007ooOol0ogooGWoo000^Ool0
0`00Oomoo`05Ool00`00Oomoo`0@Ool00`00Oomoo`04Ool00`00Oomoo`3oOomNOol002ioo`04001o
ogooOol6000AOol00`00Oomoo`04Ool00`00Oomoo`3oOomNOol002aoo`8000Eoo`04001oogoo000B
Ool00`00Oomoo`04Ool3003oOomNOol002ioo`03001oogoo009oo`04001oogoo000>Ool40007Ool0
0`00Oomoo`3oOomNOol002ioo`03001oogoo00=oo`03001oo`0000ioo`03001oogoo00Qoo`03001o
ogoo0?mooeioo`00:Goo00<007ooOol00Woo00<007ooOol00goo00<007oo00003Woo00<007ooOol0
27oo00<007ooOol0ogooGWoo000ZOol40007Ool2000>Ool50006Ool00`00Oomoo`3oOomNOol0051o
o`800?mooemoo`00D7oo00<007ooOol0ogooGWoo001@Ool00`00Oomoo`3oOomNOol0051oo`03001o
ogoo0?mooeioo`00D7oo00<007ooOol0ogooGWoo001@Ool2003oOomOOol0051oo`03001oogoo0?mo
oeioo`00D7oo00<007ooOol0ogooGWoo001@Ool00`00Oomoo`3oOomNOol0051oo`03001oogoo0?mo
oeioo`00D7oo0P00o`0?;`0?<7oo001@Ool00`00Oomoo`3oOomNOol0051oo`03001oogoo0?mooeio
o`00D7oo00<007ooOol0ogooGWoo001@Ool00`00Oomoo`3oOomNOol0051oo`800?mooemoo`00D7oo
00<007ooOol0ogooGWoo000lOol40005Ool40007Ool00`00Oomoo`3oOomNOol003]oo`03001oogoo
009oo`05001oogooOol00004Ool00`00Oomoo`04Ool00`00Oomoo`3oOomNOol0041oo`03001oogoo
00Ioo`03001oogoo00Aoo`03001oogoo0?mooeioo`00@7oo00<007ooOol01Woo00<007ooOol017oo
00<007ooOol0ogooGWoo000nOol20009Ool00`00Oomoo`04Ool3003oOomNOol0041oo`03001oogoo
009oo`@000Moo`03001oogoo0?mooeioo`00@7oo00<007ooOol00Woo00<007ooOol027oo00<007oo
Ool0ogooGWoo000kOol00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`08Ool00`00Oomoo`3o
OomNOol003aoo`@000Eoo`D000Ioo`03001oogoo0?mooeioo`00D7oo0P00ogooGgoo001@Ool00`00
Oomoo`3oOomNOol0051oo`03001oogoo0?mooeioo`00D7oo00<007ooOol0ogooGWoo001@Ool00`00
Oomoo`3oOomNOol0051oo`800?mooemoo`00D7oo00<007ooOol0ogooGWoo001@Ool00`00Oomoo`3o
OomNOol0051oo`03001oogoo0?mooeioo`00D7oo00<007ooOol0ogooGWoo001@Ool2003oOomOOol0
051oo`03001oogoo0?mooeioo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol0
0?mook5oo`00YWoo0`00ogoo27oo002XOol00`00Oomoo`3oOol6Ool00:Qoo`03001oogoo0?moo`Io
o`00>Goo1`000Woo0`000Woo0`0000=oo`0000001@001Goo10000Woo1`0017oo1@000Woo1`0037oo
00<007oo00000P001Woo100017oo0`0000=oo`0000000Woo0`0000=oo`0000001Goo0P00ogoo1goo
000lOol00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`05Ool00`00Oomo
o`02Ool00`00Oomoo`02Ool00`00Oomoo`04Ool01@00Oomoogoo00001Woo00<007ooOol03Goo0P00
0goo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol000=oo`80009oo`04001oogooOol20006
Ool2003oOol7Ool003aoo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo00=oo`03001oogoo
00Eoo`03001oogoo00Moo`03001oogoo00Aoo`05001oogooOol00006Ool00`00Oomoo`0=Ool00`00
Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`0017oo00<0
07ooOol00goo00@007ooOol00?moo`Ioo`00?7oo00<007ooOol017oo00<007ooOol00Woo00<007oo
Ool00goo00<007ooOol01Goo00<007ooOol01goo00<007ooOol01Goo10001Woo00<007ooOol04Woo
00<007ooOol00Woo00<007ooOol01Goo00<007ooOol00Woo00@007ooOol000Aoo`03001oogoo00=o
o`04001oogoo003oOol6Ool003aoo`03001oogoo00Aoo`8000=oo`03001oogoo00=oo`03001oogoo
00Eoo`03001oogoo00Moo`03001oogoo00Aoo`05001oogooOol00006Ool00`00Oomoo`0>Ool40005
Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000goo0P0017oo00<007ooOol00Woo00<0
07ooOol0ogoo0goo000lOol00`00Oomoo`03Ool2000017oo0000000017oo0`001Goo1`000goo0`00
1goo0`001goo00<007ooOol03Goo00<007ooOol00Woo00<007ooOol01`000Woo0P000goo0P000goo
0`0000=oo`00Ool00Woo0`000Woo0`00ogoo17oo000lOol00`00Oomoo`0GOol00`00Oomoo`0IOol0
0`00Oomoo`0=Ool01000Oomoogoo0P0017oo00<007ooOol04Woo00<007ooOol0ogoo3Goo000iOol7
000FOol00`00Oomoo`0IOol00`00Oomoo`0>Ool300000goo001oo`03Ool00`00Oomoo`0BOol00`00
Oomoo`3oOol=Ool004ioo`03001oogoo00moo`03001oogoo00eoo`<002eoo`800?moo`moo`00CWoo
00<007ooOol03goo00<007ooOol0ogooCWoo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol0
0?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogooTGoo00<007ooOol07Goo003oOonAOol2
000NOol003Uoo`<00004Ool00000000>Ool20006Ool50002Ool70004Ool300000goo00000003Ool4
0004Ool5000>Ool50004Ool40004Ool5000<Ool70002Ool30002Ool30002Ool300000goo00000002
Ool70005Ool20004Ool70003Ool300000goo00000004Ool300000goo00000003Ool50002Ool70003
Ool5000>Ool40005Ool40003Ool30002Ool30004Ool40003Ool50005Ool40003Ool7000=Ool40003
Ool30002Ool30003Ool50003Ool50006Ool40004Ool00`00Oomoo`0LOol003Yoo`05001oogooOol0
000?Ool20005Ool01@00Oomoogoo00001Woo00<007ooOol017oo00@007ooOomoo`8000=oo`03001o
ogoo009oo`05001oogooOol00004Ool00`00Oomoo`0<Ool00`00Oomoo`04Ool00`00Oomoo`02Ool0
0`00Oomoo`02Ool00`00Oomoo`0@Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01000Oomoo`000goo
0P001Woo00<007ooOol01Woo0P001goo00<007ooOol00goo00@007ooOomoo`8000Aoo`04001oogoo
Ool20003Ool01@00Oomoogoo00001Woo00<007ooOol017oo00<007ooOol00Woo00<007ooOol02Woo
00<007ooOol00Woo00D007ooOomoo`0000Aoo`05001oogooOol00004Ool00`00Oomoo`02Ool00`00
Oomoo`02Ool01@00Oomoogoo00001goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol03Goo
00<007ooOol00Woo00D007ooOomoo`0000Aoo`05001oogooOol00003Ool00`00Oomoo`03Ool00`00
Oomoo`06Ool00`00Oomoo`02Ool01000Oomoogoo0P007Goo000kOol00`00Ool0000?Ool01000Oomo
o`0017oo00D007ooOomoo`0000Ioo`03001oogoo00Aoo`03001oogoo009oo`05001oogooOol0000=
Ool00`00Oomoo`0<Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0@
Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01000Oomoo`0017oo00<007ooOol017oo00<007ooOol0
1Goo00@007ooOol000Ioo`03001oogoo00=oo`03001oogoo009oo`03001oogoo009oo`03001oogoo
009oo`05001oogooOol00003Ool00`00Oomoo`04Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00
Oomoo`07Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol00Woo00<007ooOol01Woo
00<007ooOol01Goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol037oo00<007ooOol01goo
00<007ooOol00Woo00D007ooOomoo`0000=oo`03001oogoo00=oo`03001oogoo00Ioo`03001oogoo
02Eoo`00?7oo00<007ooOol03Woo00@007ooOol000Eoo`@000Ioo`03001oogoo00Aoo`03001oogoo
009oo`04001oogooOol60004Ool4000?Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`02
Ool00`00Oomoo`0@Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01000Oomoo`0017oo00<007ooOol0
17oo00<007ooOol01Goo00@007ooOol000Ioo`03001oogoo00=oo`03001oogoo009oo`03001oogoo
009oo`03001oogoo009oo`03001oogoo009oo`@000Ioo`03001oogoo00Eoo`@000aoo`03001oogoo
00Moo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00
Oomoo`05Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`0<Ool00`00Oomoo`07Ool00`00
Oomoo`02Ool00`00Oomoo`02Ool40005Ool00`00Oomoo`06Ool00`00Oomoo`0UOol003aoo`03001o
ogoo00eoo`03001oogoo009oo`05001oogooOol00003Ool00`00Oomoo`04Ool00`00Oomoo`04Ool0
0`00Oomoo`02Ool01@00Oomoogoo000017oo00D007ooOomoo`0000Aoo`03001oogoo00aoo`03001o
ogoo00Aoo`03001oogoo009oo`03001oogoo009oo`80015oo`03001oogoo00Aoo`8000=oo`04001o
ogoo0003Ool20006Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`03
Ool01000Oomoogoo0P0017oo00<007ooOol00Woo00D007ooOomoo`0000=oo`03001oogoo00Aoo`03
001oogoo00Aoo`03001oogoo009oo`03001oogoo00Uoo`03001oogoo00Moo`03001oogoo009oo`04
001oogooOol20003Ool00`00Oomoo`02Ool00`00Oomoo`06Ool20006Ool00`00Oomoo`02Ool00`00
Oomoo`03Ool00`00Oomoo`0=Ool01000Oomoogoo0P000goo0P000goo00D007ooOomoo`0000=oo`03
001oogoo00=oo`8000Moo`03001oogoo02Eoo`00>goo00<007oo00003Goo0`000Woo0`000goo0`00
1goo00<007ooOol00goo0P000goo0P0017oo10001Goo1@0037oo1P0017oo100017oo0P0000Aoo`00
000000aoo`<000Eoo`800004Ool000000004Ool300000goo001oo`03Ool30005Ool30002Ool30002
Ool30006Ool300000goo001oo`02Ool20003Ool20004Ool30007Ool00`00Oomoo`05Ool5000;Ool0
0`00Oomoo`03Ool00`00Oomoo`02Ool40003Ool2000017oo000000000goo1`000goo0P0000Aoo`00
000000Aoo`@000Ioo`03001oogoo00ioo`<00003Ool007oo009oo`03001oo`00008000Eoo`<000Eo
o`800004Ool000000002Ool7000SOol003Yoo`05001oogooOol0000QOol00`00Oomoo`0ZOol00`00
Oomoo`0eOol00`00Oomoo`0QOol00`00Oomoo`0FOol00`00Oomoo`0FOol01000Oomoogoo0P005Woo
00<007ooOol06Goo00<007ooOol05Woo00<007ooOol06Goo00<007ooOol09Goo000iOol3000017oo
0000000087oo00<007ooOol0:Woo00<007ooOol0=Goo00<007ooOol08Goo00<007ooOol05Woo00<0
07ooOol05goo0`0000=oo`00Ool05Goo00<007ooOol06Goo00<007ooOol05Woo00<007ooOol06Goo
00<007ooOol09Goo001NOol3000]Ool3000POol00`00Oomoo`0@Ool20006Ool00`00Oomoo`0?Ool0
0`00Oomoo`07Ool2000FOol3001>Ool3000GOol20013Ool00;5oo`03001oogoo01Qoo`03001oogoo
00moo`03001oogoo0<moo`00ogoo/Goo003oOonaOol00?mook5oo`00\
\>"],
  ImageRangeCache->{{{135, 422}, {240, 63.0625}} -> {-15.1243, 32.8534, 
  0.0781317, 0.0287336}},
  CellTags->"Control Charts for Individual Measurements"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0680272 0.0882906 0.281092 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.15986 -0.0125 -3 -9 ]
[.15986 -0.0125 3 0 ]
[.29592 -0.0125 -3 -9 ]
[.29592 -0.0125 3 0 ]
[.43197 -0.0125 -3 -9 ]
[.43197 -0.0125 3 0 ]
[.56803 -0.0125 -3 -9 ]
[.56803 -0.0125 3 0 ]
[.70408 -0.0125 -6 -9 ]
[.70408 -0.0125 6 0 ]
[.84014 -0.0125 -6 -9 ]
[.84014 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -26 -21.5625 ]
[.5 -0.0125 26 -9 ]
[-0.0125 .08829 -6 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .22884 -18 -4.5 ]
[-0.0125 .22884 0 4.5 ]
[-0.0125 .36938 -6 -4.5 ]
[-0.0125 .36938 0 4.5 ]
[-0.0125 .50993 -18 -4.5 ]
[-0.0125 .50993 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -30.5625 -8 ]
[-0.01875 .30902 -18 8 ]
[.5 .63053 -128 0 ]
[.5 .63053 128 25.75 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .22342 m
1 .22342 L
s
0 .08829 m
1 .08829 L
s
0 .52974 m
1 .52974 L
s
0 g
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.15986 0 m
.15986 .00625 L
s
[(2)] .15986 -0.0125 0 1 Mshowa
.29592 0 m
.29592 .00625 L
s
[(4)] .29592 -0.0125 0 1 Mshowa
.43197 0 m
.43197 .00625 L
s
[(6)] .43197 -0.0125 0 1 Mshowa
.56803 0 m
.56803 .00625 L
s
[(8)] .56803 -0.0125 0 1 Mshowa
.70408 0 m
.70408 .00625 L
s
[(10)] .70408 -0.0125 0 1 Mshowa
.84014 0 m
.84014 .00625 L
s
[(12)] .84014 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(14)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05782 0 m
.05782 .00375 L
s
.09184 0 m
.09184 .00375 L
s
.12585 0 m
.12585 .00375 L
s
.19388 0 m
.19388 .00375 L
s
.22789 0 m
.22789 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.32993 0 m
.32993 .00375 L
s
.36395 0 m
.36395 .00375 L
s
.39796 0 m
.39796 .00375 L
s
.46599 0 m
.46599 .00375 L
s
.5 0 m
.5 .00375 L
s
.53401 0 m
.53401 .00375 L
s
.60204 0 m
.60204 .00375 L
s
.63605 0 m
.63605 .00375 L
s
.67007 0 m
.67007 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77211 0 m
.77211 .00375 L
s
.80612 0 m
.80612 .00375 L
s
.87415 0 m
.87415 .00375 L
s
.90816 0 m
.90816 .00375 L
s
.94218 0 m
.94218 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -87 -25.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(subgroup) show
111.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .08829 m
.00625 .08829 L
s
[(0)] -0.0125 .08829 1 0 Mshowa
0 .22884 m
.00625 .22884 L
s
[(0.5)] -0.0125 .22884 1 0 Mshowa
0 .36938 m
.00625 .36938 L
s
[(1)] -0.0125 .36938 1 0 Mshowa
0 .50993 m
.00625 .50993 L
s
[(1.5)] -0.0125 .50993 1 0 Mshowa
.125 Mabswid
0 .1164 m
.00375 .1164 L
s
0 .14451 m
.00375 .14451 L
s
0 .17262 m
.00375 .17262 L
s
0 .20073 m
.00375 .20073 L
s
0 .25695 m
.00375 .25695 L
s
0 .28505 m
.00375 .28505 L
s
0 .31316 m
.00375 .31316 L
s
0 .34127 m
.00375 .34127 L
s
0 .39749 m
.00375 .39749 L
s
0 .4256 m
.00375 .4256 L
s
0 .45371 m
.00375 .45371 L
s
0 .48182 m
.00375 .48182 L
s
0 .06018 m
.00375 .06018 L
s
0 .03207 m
.00375 .03207 L
s
0 .00396 m
.00375 .00396 L
s
0 .53804 m
.00375 .53804 L
s
0 .56615 m
.00375 .56615 L
s
0 .59426 m
.00375 .59426 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -93.2813 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
69 10.2813 translate
90 rotate
-69 -10.2813 translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(MR) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .08829 m
1 .08829 L
s
gsave
.5 .63053 -189 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 33.75 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Moving) show
105.000 12.813 moveto
(Range) show
141.000 12.813 moveto
(for) show
165.000 12.813 moveto
(individual) show
231.000 12.813 moveto
(Control) show
279.000 12.813 moveto
(chart) show
309.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
63.000 26.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Initial) show
111.000 26.000 moveto
(Study) show
141.000 26.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.09184 .28505 m
.15986 .35533 L
.22789 .1417 L
.29592 .18667 L
.36395 .2457 L
.43197 .18386 L
.5 .20354 L
.56803 .15013 L
.63605 .16981 L
.70408 .20635 L
.77211 .26257 L
.84014 .24008 L
.90816 .20635 L
.97619 .29068 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[21]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012Q000`40O003h00Oogoo/Goo003oOona
Ool00?mook5oo`00eWoo10007goo0`00]7oo003JOol00`00Oomoo`0MOol00`00Oomoo`2cOol00=Yo
o`03001oogoo01eoo`03001oogoo0;=oo`00^goo1@001Goo0`0000Aoo`00001oo`800004Ool00000
0004Ool300000goo001oo`03Ool50005Ool40005Ool300000goo00000002Ool00`00Ool00002002a
Ool00;]oo`03001oogoo009oo`05001oogooOol00003Ool20003Ool20003Ool01000Oomoo`000goo
0P001Goo00<007ooOol01Goo00<007ooOol00Woo00D007ooOomoo`0000=oo`8000=oo`8000=oo`03
001oogoo0:ioo`00`7oo00D007ooOomoo`0000Aoo`05001oogooOol00004Ool01000Oomoo`0017oo
00<007ooOol00goo00<007ooOol01Goo00<007ooOol00Woo00D007ooOomoo`0000Aoo`05001oogoo
Ool00004Ool00`00Oomoo`2^Ool00;aoo`@000Aoo`03001oogoo009oo`05001oogooOol00004Ool0
1000Oomoo`0017oo00<007ooOol00goo00<007ooOol01Goo00<007ooOol00Woo00D007ooOomoo`00
00Aoo`05001oogooOol00004Ool00`00Oomoo`2^Ool00;]oo`03001oogoo009oo`05001oogooOol0
0004Ool01000Oomoogoo0P000goo00@007ooOol000=oo`8000Eoo`8000Ioo`03001oogoo009oo`05
001oogooOol00004Ool01000Oomoogoo0P000goo00<007ooOol0[Woo002lOol50002Ool20003Ool2
0003Ool00`00Ool000020004Ool300000goo00000003Ool2000017oo0000000017oo10000goo0P00
0goo0P000Woo0P0000Aoo`0000000;5oo`00cGoo00<007ooOol0h7oo003=Ool00`00Oomoo`3POol0
0<aoo`800>9oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol004Yoo`@002Ao
o`H002Eoo`@002Eoo`@002Eoo`@001moo`L000=oo`@001aoo`L0009oo`H001Yoo`L000Aoo`@003ao
o`00BGoo00<007ooOol00Woo00<007ooOol08Goo00<007ooOol00Woo00<007ooOol09Goo00<007oo
Ool08goo00<007ooOol00Woo00<007ooOol08Goo00<007ooOol00Woo00<007ooOol07goo00<007oo
Ool00goo00<007ooOol00Woo00<007ooOol077oo00<007ooOol00goo00<007ooOol00Woo00<007oo
Ool06goo00<007ooOol01goo00<007ooOol0>goo0019Ool00`00Oomoo`02Ool00`00Oomoo`0ROol0
0`00Oomoo`0YOol00`00Oomoo`0SOol00`00Oomoo`02Ool00`00Oomoo`0QOol00`00Oomoo`02Ool0
0`00Oomoo`0OOol00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`0LOol00`00Oomoo`04Ool0
0`00Oomoo`0OOol00`00Oomoo`07Ool00`00Oomoo`0kOol004Uoo`03001oogoo009oo`03001oogoo
02=oo`03001oogoo02Aoo`H002Aoo`8000=oo`03001oogoo025oo`03001oogoo009oo`03001oogoo
01moo`03001oogoo00=oo`03001oogoo009oo`03001oogoo01aoo`03001oogoo00Eoo`03001oogoo
01ioo`03001oogoo00=oo`H003aoo`00BGoo00<007ooOol00Woo00<007ooOol097oo00<007ooOol0
97oo00@007ooOol002Eoo`03001oo`00008002Eoo`@0029oo`03001oogoo00=oo`03001oogoo009o
o`03001oogoo01aoo`03001oogoo00Ioo`03001oogoo01eoo`03001oogoo00Aoo`04001oogoo000m
Ool004Uoo`03001oogoo009oo`03001oogoo02Eoo`03001oogoo02=oo`04001oogoo000UOol00`00
Oomoo`0VOol00`00Oomoo`02Ool00`00Oomoo`0OOol00`00Oomoo`03Ool00`00Oomoo`02Ool00`00
Oomoo`0LOol00`00Oomoo`07Ool00`00Oomoo`0LOol00`00Oomoo`04Ool01000Oomoo`00?Goo0019
Ool00`00Oomoo`02Ool00`00Oomoo`0QOol00`00Oomoo`02Ool00`00Oomoo`0SOol00`00Ool0000V
Ool00`00Oomoo`0UOol00`00Oomoo`02Ool00`00Oomoo`0OOol00`00Oomoo`03Ool00`00Oomoo`02
Ool00`00Oomoo`0LOol00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`0KOol00`00Oomoo`05
Ool00`00Ool0000mOol004Uoo`03001oogoo009oo`03001oogoo025oo`03001oogoo009oo`03001o
ogoo02=oo`03001oo`0002Moo`03001oogoo02Aoo`03001oogoo009oo`03001oogoo01eoo`<000Eo
o`03001oogoo009oo`03001oogoo01Yoo`<000Eoo`03001oogoo009oo`03001oogoo01Uoo`<000Mo
o`03001oo`0003eoo`00BWoo10009Goo10009goo0P00:7oo0`0097oo10008Woo00<007ooOol017oo
10007goo00<007ooOol017oo10007Woo00<007ooOol01Woo0P00?Goo003oOonaOol00?mook5oo`00
ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol004Eoool0034003]oo`00AGoo0P00
1Goo00<007ooOol027oo00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol0
27oo00<007ooOol01goo00<007ooOol01goo00<007ooOol027oo00<007ooOol01goo00<007ooOol0
1goo00<007ooOol027oo00<007ooOol01goo00<007ooOol01goo00<007ooOol027oo00<007ooOol0
1goo00<007ooOol01goo00<007ooOol01goo00<007ooOol027oo00<007ooOol01goo00<007ooOol0
1goo00<007ooOol027oo00<007ooOol01goo00<007ooOol01goo00<007ooOol027oo00<007ooOol0
1goo00<007ooOol01goo00<007ooOol027oo00<007ooOol01goo00<007ooOol0@7oo0015Ool00`00
Oomoo`04Ool00`00Oomoo`0VOol00`00Oomoo`0WOol00`00Oomoo`0VOol00`00Oomoo`0VOol00`00
Oomoo`0VOol00`00Oomoo`0WOol00`00Oomoo`0VOol00`00Oomoo`10Ool004Eoo`03001oogoo0?mo
ofUoo`00AGoo00<007ooOol0ogooJGoo0015Ool00`00Oomoo`3oOomYOol004Eoo`03001oogoo0?mo
ofUoo`00AGoo00<007ooOol0ogooJGoo0015Ool00`00Oomoo`3oOomYOol004Eoo`800?moofYoo`00
AGoo00<007ooOol0ogooJGoo0015Ool00`00Oomoo`3oOomYOol004Eoo`03001oogoo0?moofUoo`00
AGoo00<007ooOol0ogooJGoo0015Ool00`00Oomoo`3oOomYOol004Eoo`03001oogoo0?moofUoo`00
AGoo00<007ooOol0ogooJGoo0015Ool00`00Oomoo`3oOomYOol004Eoo`800?moofYoo`00AGoo00<0
07ooOol0ogooJGoo0015Ool00`00Oomoo`3oOomYOol004Eoo`03001oogoo0?moofUoo`00AGoo00<0
07ooOol0ogooJGoo000jOol40007Ool00`00Oomoo`3oOomYOol003Uoo`03001oogoo009oo`03001o
ogoo00Aoo`03001oogoo0?moofUoo`00>Goo00<007ooOol00Woo00<007ooOol017oo00<007ooOol0
ogooJGoo000iOol00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`3oOomYOol003Uoo`03001o
ogoo009oo`03001oogoo00Aoool0034003]oo`00>Goo00<007ooOol00Woo00<007ooOol017oo00<0
07ooOol0ogooJGoo000iOol00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`3oOomYOol003Uo
o`03001oogoo009oo`03001oogoo00Aoo`03001oogoo0?moofUoo`00>Woo10001goo00<007ooOol0
ogooJGoo0015Ool00`00Oomoo`3oOomYOol004Eoo`03001oogoo0?moofUoo`00AGoo00<007ooOol0
ogooJGoo0015Ool2003oOomZOol004Eoo`03001oogoo0?moofUoo`00AGoo00<007ooOol0ogooJGoo
0015Ool00`00Oomoo`3oOomYOol004Eoo`03001oogoo0?moofUoo`00AGoo00<007ooOol0ogooJGoo
0015Ool00`00Oomoo`3oOomYOol004Eoo`03001oogoo0?moofUoo`00AGoo00<007ooOol0@Woo00<0
07ooOol0ogoo97oo0015Ool20013Ool3003oOolTOol004Eoo`03001oogoo045oo`04001oogooOol2
001ROol2002mOol004Eoo`03001oogoo045oo`03001oogoo00=oo`03001oogoo05ioo`03001oogoo
00@00;Uoo`00AGoo00<007ooOol0@Goo00<007ooOol017oo0P00G7oo0P001goo0`00]Woo0015Ool0
0`00Oomoo`10Ool00`00Oomoo`07Ool00`00Oomoo`1HOol00`00Oomoo`0:Ool4002bOol004Eoo`03
001oogoo041oo`03001oogoo00Qoo`8005Moo`03001oogoo00moo`<00:moo`00AGoo00<007ooOol0
@7oo00<007ooOol02Woo0P00E7oo00<007ooOol04goo1000Zgoo0015Ool00`00Oomoo`0oOol00`00
Oomoo`0=Ool00`00Oomoo`1?Ool2000JOol2002YOol004Eoo`80041oo`03001oogoo00ioo`8004io
o`03001oogoo01aoo`800:Moo`00AGoo00<007ooOol0?goo00<007ooOol047oo00<007ooOol0BWoo
00<007ooOol07goo0P00YGoo0015Ool00`00Oomoo`0nOol00`00Oomoo`0BOol20019Ool00`00Oomo
o`0ROol2002SOol004Eoo`03001oogoo03ioo`03001oogoo01Aoo`8002Uoo`8001Yoo`8002Moo`80
0:5oo`00AGoo00<007ooOol0?Woo00<007ooOol05Woo00<007ooOol09Goo00<007ooOol010005Goo
00<007ooOol0:Goo00<007ooOol0WWoo0015Ool00`00Oomoo`0mOol00`00Oomoo`0HOol00`00Oomo
o`0SOol00`00Oomoo`05Ool3000AOol00`00Oomoo`0[Ool2002NOol004Eoo`03001oogoo03eoo`03
001oogoo01Uoo`03001oogoo025oo`03001oogoo00Uoo`@000aoo`03001oogoo02ioo`8009aoo`00
AGoo00<007ooOol0?Goo00<007ooOol06Woo00<007ooOol07goo00<007ooOol03Woo0`001goo0P00
<goo0P00VWoo0015Ool00`00Oomoo`0lOol00`00Oomoo`0LOol00`00Oomoo`0LOol2000DOol40002
Ool00`00Oomoo`0eOol2002HOol004Eoo`8003eoo`03001oogoo01eoo`8001]oo`03001oogoo01Qo
o`8003Yoo`8009Ioo`00AGoo00<007ooOol0?7oo00<007ooOol07goo00<007ooOol05goo00<007oo
Ool0Egoo00<007ooOol0>goo00<007ooOol0EGoo0015Ool00`00Oomoo`0kOol00`00Oomoo`0QOol0
0`00Oomoo`0EOol00`00Oomoo`1IOol00`00Oomoo`0hOol200000goo001oo`1EOol004Eoo`03001o
ogoo03]oo`03001oogoo029oo`03001oogoo01=oo`03001oogoo05]oo`8003Ioo`8000Aoo`03001o
ogoo05=oo`00AGoo00<007ooOol0>goo00<007ooOol08goo00<007ooOol04Goo00<007ooOol0GWoo
00<007ooOol0<Goo0P001Woo00<007ooOol0Dgoo000XOol40006Ool20006Ool40007Ool00`00Oomo
o`0jOol00`00Oomoo`0UOol00`00Oomoo`0?Ool00`00Oomoo`1POol00`00Oomoo`0^Ool20009Ool0
0`00Oomoo`1BOol002Moo`03001oogoo009oo`03001oogoo00=oo`8000Eoo`03001oogoo009oo`03
001oogoo00Aoo`0300003`0?03X03`0300003`0?02H03`0300003`0?00d03`0300003`0?06803`03
00003`0?02`03`0300003`0?00X03`0300003`0?01H03c]oo`009goo00<007ooOol00Woo00<007oo
Ool03goo00<007ooOol017oo00<007ooOol0>Woo00<007ooOol09goo00<007ooOol02goo00<007oo
Ool0I7oo0P00:Woo0P003Woo00<007ooOol0D7oo000WOol00`00Oomoo`02Ool00`00Oomoo`0?Ool0
0`00Oomoo`04Ool3000iOol00`00Oomoo`0YOol00`00Oomoo`08Ool2001YOol00`00Oomoo`0UOol2
000AOol00`00Oomoo`1?Ool002Moo`03001oogoo009oo`03001oogoo00moo`03001oogoo00Aoo`03
001oogoo03Uoo`03001oogoo02Yoo`8000Moo`03001oogoo06Yoo`03001oogoo029oo`8001=oo`03
001oogoo04moo`009goo00<007ooOol00Woo00<007ooOol02goo10001goo00<007ooOol0>Goo00<0
07ooOol0;7oo00<007ooOol00goo00<007ooOol0K7oo00<007ooOol07goo0P005Woo00<007ooOol0
CWoo000WOol00`00Oomoo`02Ool00`00Oomoo`0;Ool00`00Oomoo`08Ool00`00Oomoo`0hOol00`00
Oomoo`0^Ool01@00Oomoogoo0000L7oo00<007ooOol077oo0P006Goo00<007ooOol0CGoo000WOol0
0`00Oomoo`02Ool00`00Oomoo`0;Ool00`00Oomoo`08Ool00`00Oomoo`0hOol00`00Oomoo`0_Ool0
0`00Ool0001bOol2000JOol2000LOol00`00Oomoo`1<Ool002Qoo`@000ioo`D000Ioo`03001oogoo
03Qoo`03001oogoo031oo`03001oogoo07=oo`03001oogoo01=oo`@001moo`03001oogoo04]oo`00
AGoo00<007ooOol0>7oo00<007ooOol0Ygoo00<007ooOol03goo0`008goo00<007ooOol0Bgoo0015
Ool00`00Oomoo`0gOol00`00Oomoo`2YOol00`00Oomoo`0:Ool4000WOol00`00Oomoo`1:Ool004Eo
o`03001oogoo03Moo`03001oogoo0:Yoo`8000Moo`<002aoo`03001oogoo04Uoo`00AGoo0P00>7oo
00<007ooOol0[7oo00<007ooOol01000<7oo00<007ooOol0B7oo0015Ool00`00Oomoo`0fOol00`00
Oomoo`2^Ool2000eOol00`00Oomoo`17Ool004Eoo`03001oogoo03Ioo`03001oogoo0>Ioo`03001o
ogoo04Ioo`00AGoo00<007ooOol0=Woo00<007ooOol0iWoo00<007ooOol0AWoo0015Ool00`00Oomo
o`0eOol00`00Oomoo`3XOol00`00Oomoo`15Ool004Eoo`03001oogoo03Eoo`03001oogoo0>Uoo`03
001oogoo04Aoo`00AGoo00<007ooOol0=Goo00<007ooOol0jWoo00<007ooOol0@goo000GOol00`00
Oomoo`04Ool00`00Oomoo`0TOol00`00Oomoo`0dOol00`00Oomoo`3/Ool00`00Oomoo`12Ool001Mo
o`P002Ioo`8001Yoo`03001oogoo01Qoo`03001oogoo0>aoo`03001oogoo049oo`005goo0P001Goo
00<007ooOol097oo00<007ooOol06Woo00<007ooOol05goo00<007ooOol0kGoo00<007ooOol0@Goo
000IOol3000YOol00`00Oomoo`0KOol00`00Oomoo`0EOol00`00Oomoo`3_Ool00`00Oomoo`10Ool0
01aoo`03001oogoo02Ioo`03001oogoo01aoo`03001oogoo01Aoo`03001oogoo0?mooc=oo`006Goo
0`00:Goo00<007ooOol07Goo00<007ooOol04goo00<007ooOol0ogoo<goo000GOol20005Ool00`00
Oomoo`0TOol00`00Oomoo`0NOol00`00Oomoo`0AOol00`00Oomoo`3oOoldOol001Moo`P002Ioo`03
001oogoo01moo`03001oogoo011oo`03001oogoo0?moocAoo`005goo00<007ooOol017oo00<007oo
Ool097oo00<007ooOol087oo00<007ooOol03goo00<007ooOol0ogoo=7oo0015Ool00`00Oomoo`0Q
Ool00`00Oomoo`0=Ool00`00Oomoo`3oOoleOol001Moo`03001oogoo00Aoo`03001oogoo02Aoo`80
02=oo`03001oogoo00aoo`03001oogoo0?moocEoo`005goo20009Woo00<007ooOol08goo00<007oo
Ool02goo00<007ooOol0ogoo=Goo000GOol01@00Oomoogoo00000Woo00<007ooOol097oo00<007oo
Ool08goo00<007ooOol02Woo00<007ooOol0ogoo=Woo000GOol01@00Oomoogoo0000:Goo00<007oo
Ool097oo00<007ooOol02Goo00<007ooOol0ogoo=Woo000GOol01@00Oomoogoo0000:Goo00<007oo
Ool09Goo00<007ooOol027oo00<007ooOol0ogoo=Woo000HOol300000goo001oo`0WOol00`00Oomo
o`0VOol00`00Oomoo`06Ool00`00Oomoo`3oOolgOol001eoo`8002Ioo`03001oogoo02Moo`03001o
ogoo00Eoo`03001oogoo0?moocMoo`007Woo00<007ooOol097oo00<007ooOol0:7oo00<007ooOol0
17oo00<007ooOol0ogoo=goo0015Ool2000ZOol00`00Oomoo`02Ool00`00Oomoo`3oOolhOol004Eo
o`03001oogoo02Yoo`05001oogooOol0003oOoljOol004Eoo`03001oogoo02]oo`04001oogoo003o
OoljOol004Eoo`03001oogoo02aoo`800?mooc]oo`00AGoo00<007ooOol0;Goo00<007ooOol0ogoo
>Goo000iOol70005Ool00`00Oomoo`3oOomYOol003aoo`03001oogoo00Ioo`03001oogoo0?moofUo
o`00?7oo00<007ooOol01Woo00<007ooOol0ogooJGoo000lOol00`00Oomoo`06Ool00`00Oomoo`3o
OomYOol003aoo`03001oogoo00Ioo`<00?moofUoo`00?7oo00<007ooOol01Woo00<007ooOol0ogoo
JGoo000lOol00`00Oomoo`06Ool00`00Oomoo`3oOomYOol003Yoo`<000Qoo`03001oogoo0?moofUo
o`00?7oo00<007ooOol01Woo00<007ooOol0ogooJGoo0015Ool00`00Oomoo`3oOomYOol004Eoo`03
001oogoo0?moofUoo`00AGoo00<007ooOol0ogooJGoo0015Ool2003oOomZOol004Eoo`03001oogoo
0?moofUoo`00AGoo00<007ooOol0ogooJGoo0015Ool00`00Oomoo`3oOomYOol004Eoo`03001oogoo
0?moofUoo`00AGoo00<007ooOol0ogooJGoo0015Ool00`00Oomoo`3oOomYOol004Eoo`03001oogoo
0?moofUoo`00AGoo00<007ooOol0ogooJGoo0015Ool2003oOomZOol004Eoo`03001oogoo0?moofUo
o`00AGoo00<007ooOol0ogooJGoo0015Ool00`00Oomoo`3oOomYOol004Eoo`03001oogoo0?moofUo
o`00AGoo00<007ooOol0ogooJGoo0015Ool00`00Oomoo`3oOomYOol004Eoo`03001oogoo0?moofUo
o`00AGoo0P00ogooJWoo0015Ool00`00Oomoo`3oOomYOol004Eoo`03001oogoo0?moofUoo`00AGoo
00<007ooOol0ogooJGoo0015Ool00`00Oomoo`3oOomYOol004Eoo`03001oogoo0?moofUoo`00AGoo
00<007ooOol0ogooJGoo0015Ool00`00Oomoo`3oOomYOol004Eoo`03001oogoo0?moofUoo`00AGoo
0P00ogooJWoo0015Ool00`00Oomoo`3oOomYOol004Eoo`03001oogoo0?moofUoo`00AGoo00<007oo
Ool0ogooJGoo0015Ool00`00Oomoo`3oOomYOol002Moo`L000Aoo`8000Ioo`@000Moo`03001oogoo
0?moofUoo`00:Woo00<007ooOol01Goo0P001Goo00<007ooOol00Woo00<007ooOol017oo00<007oo
Ool0ogooJGoo000ZOol00`00Oomoo`0AOol00`00Oomoo`04Ool00`00Oomoo`3oOomYOol002Yoo`03
001oogoo015oo`03001oogoo00Aoo`<00?moofUoo`00:Woo00<007ooOol04Goo00<007ooOol017oo
00<007ooOol0ogooJGoo000ZOol00`00Oomoo`0=Ool40007Ool00`00Oomoo`3oOomYOol002Yoo`03
001oogoo00eoo`03001oogoo00Qoo`03001oogoo0?moofUoo`00:7oo0`003goo00<007ooOol027oo
00<007ooOol0ogooJGoo000ZOol00`00Oomoo`0=Ool50006Ool00`00Oomoo`3oOomYOol004Eoo`03
00003`0?0?l03bh03c]oo`00AGoo00<007ooOol0ogooJGoo0015Ool00`00Oomoo`3oOomYOol004Eo
o`800?moofYoo`00AGoo00<007ooOol0ogooJGoo0015Ool00`00Oomoo`3oOomYOol004Eoo`03001o
ogoo0?moofUoo`00AGoo00<007ooOol0ogooJGoo0015Ool00`00Oomoo`3oOomYOol004Eoo`03001o
ogoo0?moofUoo`00AGoo00<007ooOol0ogooJGoo0015Ool2003oOomZOol004Eoo`03001oogoo0?mo
ofUoo`00AGoo00<007ooOol0ogooJGoo0015Ool00`00Oomoo`3oOomYOol004Eoo`03001oogoo0?mo
ofUoo`00AGoo00<007ooOol0ogooJGoo0015Ool00`00Oomoo`3oOomYOol004Eoo`03001oogoo0?mo
ofUoo`00AGoo00<007ooOol0ogooJGoo0015Ool2003oOomZOol004Eoo`03001oogoo0?moofUoo`00
AGoo00<007ooOol0ogooJGoo0015Ool00`00Oomoo`3oOomYOol004Eoo`03001oogoo0?moofUoo`00
AGoo00<007ooOol0ogooJGoo0015Ool00`00Oomoo`3oOomYOol004Eoo`03001oogoo0?moofUoo`00
ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00SWoo0`00ogoo87oo
002@Ool00`00Oomoo`3oOolNOol0091oo`03001oogoo0?mooaioo`008Goo1`000Woo0`000Woo0`00
00=oo`0000001@001Goo10000Woo1`0017oo1@000Woo1`0037oo00<007oo00000P001Woo100017oo
0`0000=oo`0000000Woo0`0000=oo`0000001Goo0P00ogoo7goo000TOol00`00Oomoo`04Ool00`00
Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`05Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00
Oomoo`04Ool01@00Oomoogoo00001Woo00<007ooOol03Goo0P000goo00<007ooOol00Woo00<007oo
Ool00Woo00@007ooOol000=oo`80009oo`04001oogooOol20006Ool2003oOolOOol002Aoo`03001o
ogoo00Aoo`03001oogoo009oo`03001oogoo00=oo`03001oogoo00Eoo`03001oogoo00Moo`03001o
ogoo00Aoo`05001oogooOol00006Ool00`00Oomoo`0=Ool00`00Oomoo`02Ool00`00Oomoo`02Ool0
0`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`0017oo00<007ooOol00goo00@007ooOol00?mo
oaioo`0097oo00<007ooOol017oo00<007ooOol00Woo00<007ooOol00goo00<007ooOol01Goo00<0
07ooOol01goo00<007ooOol01Goo10001Woo00<007ooOol04Woo00<007ooOol00Woo00<007ooOol0
1Goo00<007ooOol00Woo00@007ooOol000Aoo`03001oogoo00=oo`04001oogoo003oOolNOol002Ao
o`03001oogoo00Aoo`8000=oo`03001oogoo00=oo`03001oogoo00Eoo`03001oogoo00Moo`03001o
ogoo00Aoo`05001oogooOol00006Ool00`00Oomoo`0>Ool40005Ool00`00Oomoo`05Ool00`00Oomo
o`02Ool01000Oomoo`000goo0P0017oo00<007ooOol00Woo00<007ooOol0ogoo6goo000TOol00`00
Oomoo`03Ool2000017oo0000000017oo0`001Goo1`000goo0`001goo0`001goo00<007ooOol03Goo
00<007ooOol00Woo00<007ooOol01`000Woo0P000goo0P000goo0`0000=oo`00Ool00Woo0`000Woo
0`00ogoo77oo000TOol00`00Oomoo`0GOol00`00Oomoo`0IOol00`00Oomoo`0=Ool01000Oomoogoo
0P0017oo00<007ooOol04Woo00<007ooOol0ogoo9Goo000QOol7000FOol00`00Oomoo`0IOol00`00
Oomoo`0>Ool300000goo001oo`03Ool00`00Oomoo`0BOol00`00Oomoo`3oOolUOol003Ioo`03001o
ogoo00moo`03001oogoo00eoo`<002eoo`800?moobMoo`00=Woo00<007ooOol03goo00<007ooOol0
ogooIWoo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOona
Ool004moo`@002Uoo`@00?mooc5oo`00Dgoo00<007ooOol0:Woo00<007ooOol0ogoo4Goo00<007oo
Ool06Woo001COol00`00Oomoo`0ZOol00`00Oomoo`3oOolAOol2000KOol0021oo`<000=oo`<000=o
o`@000Ioo`8000Aoo`L0009oo`<0009oo`<0009oo`<00003Ool007oo00]oo`<000=oo`8000=oo`D0
009oo`<0009oo`<0009oo`<00003Ool007oo00Aoo`@000ioo`D000Aoo`@000Aoo`D000aoo`L0009o
o`<0009oo`<0009oo`<00003Ool00000009oo`L000Eoo`8000Aoo`L000=oo`<00003Ool0000000Ao
o`<00003Ool0000000=oo`D0009oo`L000eoo`@000Eoo`@000=oo`<0009oo`<000Aoo`@000=oo`D0
00Eoo`@000=oo`L000eoo`@000=oo`<0009oo`<000=oo`D000=oo`D000Ioo`@000Aoo`03001oogoo
01Uoo`008Goo00<007ooOol00goo00D007ooOomoo`0000Aoo`03001oogoo00=oo`8000Moo`03001o
ogoo00Aoo`03001oogoo009oo`04001oogoo0003Ool2000=Ool00`00Oomoo`02Ool01@00Oomoogoo
00000goo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol000=oo`8000Aoo`03001oogoo009o
o`03001oogoo00aoo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo009oo`03001oogoo011o
o`03001oogoo00Aoo`03001oogoo009oo`04001oogoo0003Ool20006Ool00`00Oomoo`06Ool20007
Ool00`00Oomoo`03Ool01000Oomoogoo0P0017oo00@007ooOomoo`8000=oo`05001oogooOol00006
Ool00`00Oomoo`0=Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00D007ooOomoo`0000Aoo`03
001oogoo009oo`03001oogoo009oo`05001oogooOol00007Ool00`00Oomoo`02Ool00`00Oomoo`03
Ool00`00Oomoo`0=Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00D007ooOomoo`0000=oo`03
001oogoo00=oo`03001oogoo00Ioo`03001oogoo009oo`04001oogooOol2000JOol0025oo`04001o
ogoo0002Ool01@00Oomoogoo000017oo00<007ooOol00Woo00@007ooOol000Ioo`03001oogoo00Ao
o`03001oogoo009oo`04001oogoo0004Ool00`00Oomoo`0;Ool01@00Oomoogoo000017oo00D007oo
Oomoo`0000Aoo`03001oogoo009oo`04001oogoo0004Ool00`00Oomoo`02Ool00`00Oomoo`0AOol0
0`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0@Ool00`00Oomoo`04Ool0
0`00Oomoo`02Ool01000Oomoo`0017oo00<007ooOol017oo00<007ooOol01Goo00@007ooOol000Io
o`03001oogoo00=oo`03001oogoo009oo`03001oogoo009oo`03001oogoo009oo`05001oogooOol0
0003Ool00`00Oomoo`04Ool00`00Oomoo`0<Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01@00Oomo
ogoo000017oo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol01Goo00<007ooOol00Woo00<0
07ooOol00goo00<007ooOol037oo00<007ooOol01goo00<007ooOol00Woo00D007ooOomoo`0000=o
o`03001oogoo00=oo`03001oogoo00Ioo`03001oogoo029oo`008Goo00L007oo001oo`00Ool00003
Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomoo`001Woo00<007ooOol017oo00<007ooOol0
0Woo00@007ooOol000Aoo`03001oogoo00]oo`@000Ioo`@000Aoo`03001oogoo009oo`04001oogoo
0004Ool00`00Oomoo`02Ool6000>Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`02Ool0
0`00Oomoo`0@Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01000Oomoo`0017oo00<007ooOol017oo
00<007ooOol01Goo00@007ooOol000Ioo`03001oogoo00=oo`03001oogoo009oo`03001oogoo009o
o`03001oogoo009oo`03001oogoo009oo`@000Ioo`03001oogoo00aoo`03001oogoo00Moo`03001o
ogoo009oo`05001oogooOol00004Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`05Ool0
0`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`0<Ool00`00Oomoo`07Ool00`00Oomoo`02Ool0
0`00Oomoo`02Ool40005Ool00`00Oomoo`06Ool00`00Oomoo`0ROol0025oo`07001oo`00Ool007oo
00000goo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo00=oo`03001oogoo00Aoo`80
00=oo`04001oogoo0003Ool2000=Ool01@00Oomoogoo000017oo00D007ooOomoo`0000Aoo`8000=o
o`04001oogoo0003Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`0<Ool00`00Oomoo`04Ool00`00
Oomoo`02Ool00`00Oomoo`02Ool2000AOol00`00Oomoo`04Ool20003Ool01000Oomoo`000goo0P00
1Woo00<007ooOol017oo00<007ooOol00Woo00<007ooOol00goo00<007ooOol00goo00@007ooOomo
o`8000Aoo`03001oogoo009oo`05001oogooOol00003Ool00`00Oomoo`04Ool00`00Oomoo`0<Ool0
0`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomoogoo0P000goo00<007ooOol00Woo00<007ooOol0
1Woo0P001Woo00<007ooOol00Woo00<007ooOol00goo00<007ooOol03Goo00@007ooOomoo`8000=o
o`8000=oo`05001oogooOol00003Ool00`00Oomoo`03Ool20007Ool00`00Oomoo`0ROol0025oo`07
001oo`00Ool007oo000017oo10000goo0`000Woo0`000Woo0`001Goo0P0000Aoo`00000000Aoo`<0
0003Ool0000000aoo`05001oogooOol00005Ool30004Ool2000017oo0000000017oo0`0000=oo`00
000017oo10003Goo1P0017oo100017oo0P0000Aoo`00000000aoo`<000Eoo`800004Ool000000004
Ool300000goo001oo`03Ool30005Ool30002Ool30002Ool30006Ool300000goo001oo`02Ool20003
Ool20004Ool30007Ool00`00Oomoo`0<Ool00`00Oomoo`03Ool00`00Oomoo`02Ool40003Ool20000
17oo000000000goo1`000goo0P0000Aoo`00000000Aoo`@000Ioo`03001oogoo00ioo`<00003Ool0
07oo009oo`03001oo`00008000Eoo`<000Eoo`800004Ool000000002Ool7000POol0025oo`8000=o
o`8003Uoo`05001oogooOol0000cOol00`00Oomoo`0eOol00`00Oomoo`0QOol00`00Oomoo`0FOol0
0`00Oomoo`0=Ool01000Oomoogoo0P005Woo00<007ooOol06Goo00<007ooOol05Woo00<007ooOol0
6Goo00<007ooOol08Woo000POol30003Ool3000gOol5000dOol00`00Oomoo`0eOol00`00Oomoo`0Q
Ool00`00Oomoo`0FOol00`00Oomoo`0>Ool300000goo001oo`0EOol00`00Oomoo`0IOol00`00Oomo
o`0FOol00`00Oomoo`0IOol00`00Oomoo`0ROol003moo`03001oogoo05Qoo`<0021oo`03001oogoo
011oo`8000Ioo`03001oogoo00moo`03001oogoo00Moo`8001Ioo`<004Eoo`<001Moo`80041oo`00
?goo00<007ooOol0Ngoo00<007ooOol067oo00<007ooOol03goo00<007ooOol0`goo003oOonaOol0
0?mook5oo`00ogoo/Goo0000\
\>"],
  ImageRangeCache->{{{135, 422}, {423.938, 247}} -> {-13.5691, 3.61997, 
  0.0729229, 0.0176481}},
  CellTags->"Control Charts for Individual Measurements"]
}, Closed]],

Cell[OutputFormData["\<\
{{\"\", \"X\", \"MR\"}, {\"CL\", 33.52333333333333, 
  0.480714285714286}, 
 {\"LCL\", 34.801826626190476, 0}, 
 {\"UCL\", 32.24484004047619, 
  1.5704935714285722}}\
\>", "\<\
      X         MR

CL    33.5233   0.480714

LCL   34.8018   0

UCL   32.2448   1.57049\
\>"], "Output",
  CellLabel->"Out[21]//TableForm=",
  LineSpacing->{1, 0},
  CellTags->"Control Charts for Individual Measurements"]
}, Closed]],

Cell["Standard given", "Subsubsection",
  CellTags->"Control Charts for Individual Measurements"],

Cell["\<\
Standard values are known: \[Mu] = 33.5, \[Sigma] = 0.4.\
\>", "Text",
  CellTags->"Control Charts for Individual Measurements"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(\[IndentingNewLine]\)\(?XforIReportShSG\)\)\)], "Input",
  CellLabel->"In[22]:=",
  CellTags->"Control Charts for Individual Measurements"],

Cell["\<\
XforIReportShSG[mu,sig] give the short
   report for a XforI chart, standard given.\
\>", "Print",
  CellLabel->"From In[22]:=",
  CellTags->"Control Charts for Individual Measurements"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(XforIReportShSG[33.5, 0.4]\)], "Input",
  CellLabel->"In[23]:=",
  CellTags->"Control Charts for Individual Measurements"],

Cell[OutputFormData["\<\
{{\"\", \"X\", \"MR\"}, {\"CL\", 33.5, 0.4512}, 
 {\"LCL\", 34.7, 0}, {\"UCL\", 32.3, 
  1.4744000000000002}}\
\>", "\<\
      X      MR

CL    33.5   0.4512

LCL   34.7   0

UCL   32.3   1.4744\
\>"], "Output",
  CellLabel->"Out[23]//TableForm=",
  CellTags->"Control Charts for Individual Measurements"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?XforIReportSG\)\)], "Input",
  CellLabel->"In[24]:=",
  CellTags->"Control Charts for Individual Measurements"],

Cell["\<\
XforISReportSG[list,mu,sig] give the full
   report for a XforI chart, standard given.\
\>", "Print",
  CellLabel->"From In[24]:=",
  CellTags->"Control Charts for Individual Measurements"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(XforIReportSG[data2, \ 33.5, 0.4]\)], "Input",
  CellLabel->"In[25]:=",
  CellTags->"Control Charts for Individual Measurements"],

Cell[OutputFormData["\<\
{{\"Subgroup\", \"X\", \"MR\"}, {1, 33.75, 0}, 
 {2, 33.05, 0.7000000000000028}, 
 {3, 34., 0.9500000000000028}, 
 {4, 33.81, 0.18999999999999773}, 
 {5, 33.46, 0.3500000000000014}, 
 {6, 34.02, 0.5600000000000023}, 
 {7, 33.68, 0.3400000000000034}, 
 {8, 33.27, 0.4099999999999966}, 
 {9, 33.49, 0.21999999999999886}, 
 {10, 33.2, 0.28999999999999915}, 
 {11, 33.62, 0.4199999999999946}, 
 {12, 33., 0.6199999999999974}, 
 {13, 33.54, 0.5399999999999991}, 
 {14, 33.12, 0.4200000000000017}, 
 {15, 33.84, 0.720000000000006}, 
 {\"CL\", 33.5, 0.4512}, {\"LCL\", 34.7, 0}, 
 {\"UCL\", 32.3, 1.4744000000000002}}\
\>", "\<\
Subgroup   X       MR

1          33.75   0

2          33.05   0.7

3          34.     0.95

4          33.81   0.19

5          33.46   0.35

6          34.02   0.56

7          33.68   0.34

8          33.27   0.41

9          33.49   0.22

10         33.2    0.29

11         33.62   0.42

12         33.     0.62

13         33.54   0.54

14         33.12   0.42

15         33.84   0.72

CL         33.5    0.4512

LCL        34.7    0

UCL        32.3    1.4744\
\>"], "Output",
  CellLabel->"Out[25]//TableForm=",
  CellTags->"Control Charts for Individual Measurements"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?XforIChartSG\)\)], "Input",
  CellLabel->"In[26]:=",
  CellTags->"Control Charts for Individual Measurements"],

Cell["\<\
XforIChartSG[list,mu,sig] plot the X and MR
   Charts of the entries in list, standard
   given.\
\>", "Print",
  CellLabel->"From In[26]:=",
  CellTags->"Control Charts for Individual Measurements"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(XforIChartSG[data2, \ 33.5, 0.4]\)], "Input",
  CellLabel->"In[27]:=",
  CellTags->"Control Charts for Individual Measurements"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0634921 -5.85293 0.183939 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.15079 -0.0125 -3 -9 ]
[.15079 -0.0125 3 0 ]
[.27778 -0.0125 -3 -9 ]
[.27778 -0.0125 3 0 ]
[.40476 -0.0125 -3 -9 ]
[.40476 -0.0125 3 0 ]
[.53175 -0.0125 -3 -9 ]
[.53175 -0.0125 3 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.78571 -0.0125 -6 -9 ]
[.78571 -0.0125 6 0 ]
[.9127 -0.0125 -6 -9 ]
[.9127 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -26 -21.5625 ]
[.5 -0.0125 26 -9 ]
[-0.0125 .03311 -12 -4.5 ]
[-0.0125 .03311 0 4.5 ]
[-0.0125 .12508 -24 -4.5 ]
[-0.0125 .12508 0 4.5 ]
[-0.0125 .21705 -12 -4.5 ]
[-0.0125 .21705 0 4.5 ]
[-0.0125 .30902 -24 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .40099 -12 -4.5 ]
[-0.0125 .40099 0 4.5 ]
[-0.0125 .49296 -24 -4.5 ]
[-0.0125 .49296 0 4.5 ]
[-0.0125 .58493 -12 -4.5 ]
[-0.0125 .58493 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -36.5625 -5 ]
[-0.01875 .30902 -24 5 ]
[.5 .63053 -119 0 ]
[.5 .63053 119 25.75 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .30902 m
1 .30902 L
s
0 .52974 m
1 .52974 L
s
0 .08829 m
1 .08829 L
s
0 g
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.15079 0 m
.15079 .00625 L
s
[(2)] .15079 -0.0125 0 1 Mshowa
.27778 0 m
.27778 .00625 L
s
[(4)] .27778 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(6)] .40476 -0.0125 0 1 Mshowa
.53175 0 m
.53175 .00625 L
s
[(8)] .53175 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(10)] .65873 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(12)] .78571 -0.0125 0 1 Mshowa
.9127 0 m
.9127 .00625 L
s
[(14)] .9127 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.18254 0 m
.18254 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.34127 0 m
.34127 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.5 0 m
.5 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.81746 0 m
.81746 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -87 -25.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(subgroup) show
111.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .03311 m
.00625 .03311 L
s
[(32)] -0.0125 .03311 1 0 Mshowa
0 .12508 m
.00625 .12508 L
s
[(32.5)] -0.0125 .12508 1 0 Mshowa
0 .21705 m
.00625 .21705 L
s
[(33)] -0.0125 .21705 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(33.5)] -0.0125 .30902 1 0 Mshowa
0 .40099 m
.00625 .40099 L
s
[(34)] -0.0125 .40099 1 0 Mshowa
0 .49296 m
.00625 .49296 L
s
[(34.5)] -0.0125 .49296 1 0 Mshowa
0 .58493 m
.00625 .58493 L
s
[(35)] -0.0125 .58493 1 0 Mshowa
.125 Mabswid
0 .0515 m
.00375 .0515 L
s
0 .0699 m
.00375 .0699 L
s
0 .08829 m
.00375 .08829 L
s
0 .10668 m
.00375 .10668 L
s
0 .14347 m
.00375 .14347 L
s
0 .16187 m
.00375 .16187 L
s
0 .18026 m
.00375 .18026 L
s
0 .19865 m
.00375 .19865 L
s
0 .23544 m
.00375 .23544 L
s
0 .25384 m
.00375 .25384 L
s
0 .27223 m
.00375 .27223 L
s
0 .29062 m
.00375 .29062 L
s
0 .32741 m
.00375 .32741 L
s
0 .3458 m
.00375 .3458 L
s
0 .3642 m
.00375 .3642 L
s
0 .38259 m
.00375 .38259 L
s
0 .41938 m
.00375 .41938 L
s
0 .43777 m
.00375 .43777 L
s
0 .45617 m
.00375 .45617 L
s
0 .47456 m
.00375 .47456 L
s
0 .51135 m
.00375 .51135 L
s
0 .52974 m
.00375 .52974 L
s
0 .54814 m
.00375 .54814 L
s
0 .56653 m
.00375 .56653 L
s
0 .01472 m
.00375 .01472 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -96.2813 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
66 10.2813 translate
90 rotate
-66 -10.2813 translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(X) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -180 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 33.75 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(X) show
75.000 12.813 moveto
(values) show
117.000 12.813 moveto
(for) show
141.000 12.813 moveto
(individuals) show
213.000 12.813 moveto
(Control) show
261.000 12.813 moveto
(chart) show
291.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
63.000 26.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Initial) show
111.000 26.000 moveto
(Study) show
141.000 26.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.0873 .355 m
.15079 .22624 L
.21429 .40099 L
.27778 .36604 L
.34127 .30166 L
.40476 .40467 L
.46825 .34213 L
.53175 .26671 L
.59524 .30718 L
.65873 .25384 L
.72222 .33109 L
.78571 .21705 L
.84921 .31637 L
.9127 .23912 L
.97619 .37156 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[27]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012Q000`40O003h00Oogoo/Goo003oOona
Ool00?mook5oo`00hGoo10007goo0`00ZGoo003UOol00`00Oomoo`0MOol00`00Oomoo`2XOol00>Eo
o`03001oogoo01eoo`03001oogoo0:Qoo`00aWoo1@001Goo0`0000Aoo`00001oo`800004Ool00000
0004Ool300000goo001oo`03Ool50005Ool40005Ool300000goo00000002Ool00`00Ool00002002V
Ool00<Ioo`03001oogoo009oo`05001oogooOol00003Ool20003Ool20003Ool01000Oomoo`000goo
0P001Goo00<007ooOol01Goo00<007ooOol00Woo00D007ooOomoo`0000=oo`8000=oo`8000=oo`03
001oogoo0:=oo`00bgoo00D007ooOomoo`0000Aoo`05001oogooOol00004Ool01000Oomoo`0017oo
00<007ooOol00goo00<007ooOol01Goo00<007ooOol00Woo00D007ooOomoo`0000Aoo`05001oogoo
Ool00004Ool00`00Oomoo`2SOol00<Moo`@000Aoo`03001oogoo009oo`05001oogooOol00004Ool0
1000Oomoo`0017oo00<007ooOol00goo00<007ooOol01Goo00<007ooOol00Woo00D007ooOomoo`00
00Aoo`05001oogooOol00004Ool00`00Oomoo`2SOol00<Ioo`03001oogoo009oo`05001oogooOol0
0004Ool01000Oomoogoo0P000goo00@007ooOol000=oo`8000Eoo`8000Ioo`03001oogoo009oo`05
001oogooOol00004Ool01000Oomoogoo0P000goo00<007ooOol0Xgoo0037Ool50002Ool20003Ool2
0003Ool00`00Ool000020004Ool300000goo00000003Ool2000017oo0000000017oo10000goo0P00
0goo0P000Woo0P0000Aoo`0000000:Ioo`00f7oo00<007ooOol0eGoo003HOol00`00Oomoo`3EOol0
0=Moo`800=Moo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol005Eoo`@0025o
o`H002=oo`@0029oo`@0029oo`@001eoo`L000=oo`@001Qoo`L0009oo`H001Qoo`L000Aoo`@004Ao
o`00E7oo00<007ooOol00Woo00<007ooOol07Woo00<007ooOol00Woo00<007ooOol08goo00<007oo
Ool087oo00<007ooOol00Woo00<007ooOol07Woo00<007ooOol00Woo00<007ooOol07Goo00<007oo
Ool00goo00<007ooOol00Woo00<007ooOol067oo00<007ooOol00goo00<007ooOol00Woo00<007oo
Ool06Goo00<007ooOol01goo00<007ooOol0@goo001DOol00`00Oomoo`02Ool00`00Oomoo`0OOol0
0`00Oomoo`0WOol00`00Oomoo`0POol00`00Oomoo`02Ool00`00Oomoo`0NOol00`00Oomoo`02Ool0
0`00Oomoo`0MOol00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`0HOol00`00Oomoo`04Ool0
0`00Oomoo`0MOol00`00Oomoo`07Ool00`00Oomoo`13Ool005Aoo`03001oogoo009oo`03001oogoo
021oo`03001oogoo029oo`H0025oo`8000=oo`03001oogoo01ioo`03001oogoo009oo`03001oogoo
01eoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo01Qoo`03001oogoo00Eoo`03001oogoo
01aoo`03001oogoo00=oo`H004Aoo`00E7oo00<007ooOol00Woo00<007ooOol08Goo00<007ooOol0
8Woo00@007ooOol0029oo`03001oo`000080029oo`@0021oo`03001oogoo00=oo`03001oogoo009o
o`03001oogoo01Qoo`03001oogoo00Ioo`03001oogoo01]oo`03001oogoo00Aoo`04001oogoo0015
Ool005Aoo`03001oogoo009oo`03001oogoo029oo`03001oogoo025oo`04001oogoo000ROol00`00
Oomoo`0SOol00`00Oomoo`02Ool00`00Oomoo`0MOol00`00Oomoo`03Ool00`00Oomoo`02Ool00`00
Oomoo`0HOol00`00Oomoo`07Ool00`00Oomoo`0JOol00`00Oomoo`04Ool01000Oomoo`00AGoo001D
Ool00`00Oomoo`02Ool00`00Oomoo`0NOol00`00Oomoo`02Ool00`00Oomoo`0QOol00`00Ool0000S
Ool00`00Oomoo`0ROol00`00Oomoo`02Ool00`00Oomoo`0MOol00`00Oomoo`03Ool00`00Oomoo`02
Ool00`00Oomoo`0HOol00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`0IOol00`00Oomoo`05
Ool00`00Ool00015Ool005Aoo`03001oogoo009oo`03001oogoo01ioo`03001oogoo009oo`03001o
ogoo025oo`03001oo`0002Aoo`03001oogoo025oo`03001oogoo009oo`03001oogoo01]oo`<000Eo
o`03001oogoo009oo`03001oogoo01Ioo`<000Eoo`03001oogoo009oo`03001oogoo01Moo`<000Mo
o`03001oo`0004Eoo`00EGoo10008Woo10009Goo0P009Goo0`008Goo100087oo00<007ooOol017oo
10006goo00<007ooOol017oo100077oo00<007ooOol01Woo0P00AGoo003oOonaOol00?mook5oo`00
ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol0051oool00340031oo`00D7oo00<0
07ooOol017oo00<007ooOol01goo00<007ooOol01goo00<007ooOol01Woo00<007ooOol01goo00<0
07ooOol01goo00<007ooOol01Woo00<007ooOol01goo00<007ooOol01Woo00<007ooOol01goo00<0
07ooOol01goo00<007ooOol01Woo00<007ooOol01goo00<007ooOol01goo00<007ooOol01Woo00<0
07ooOol01goo00<007ooOol01Woo00<007ooOol01goo00<007ooOol01goo00<007ooOol01Woo00<0
07ooOol01goo00<007ooOol01goo00<007ooOol01Woo00<007ooOol01goo00<007ooOol01Woo00<0
07ooOol01goo00<007ooOol01goo00<007ooOol01Woo00<007ooOol01goo00<007ooOol01goo00<0
07ooOol01Woo00<007ooOol0=Goo001@Ool00`00Oomoo`04Ool00`00Oomoo`0TOol00`00Oomoo`0S
Ool00`00Oomoo`0TOol00`00Oomoo`0SOol00`00Oomoo`0TOol00`00Oomoo`0SOol00`00Oomoo`0T
Ool00`00Oomoo`18Ool0051oo`03001oogoo0?mooeioo`00D7oo0P00ogooGgoo001@Ool00`00Oomo
o`3oOomNOol003aoo`@000Aoo`H000Ioo`03001oogoo0?mooeioo`00>goo00<007ooOol00Woo00D0
07ooOomoo`0000Aoo`03001oogoo00Aoo`03001oogoo0?mooeioo`00@7oo00<007ooOol00Woo00<0
07ooOol027oo00<007ooOol0ogooGWoo0010Ool00`00Oomoo`03Ool00`00Oomoo`07Ool00`00Oomo
o`3oOomNOol003ioo`8000Moo`03001oogoo00Ioo`<00?mooeioo`00@7oo00<007ooOol01Goo00<0
07ooOol01Goo00<007ooOol0ogooGWoo0010Ool01@00Oomoogoo000017oo00<007ooOol017oo00<0
07ooOol0ogooGWoo000kOol00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol017oo00<0
07ooOol0ogooGWoo000lOol40005Ool40007Ool00`00Oomoo`3oOomNOol0051oo`800?mooemoo`00
D7oo00<007ooOol0ogooGWoo001@Ool00`00Oomoo`3oOomNOol0051oo`03001oogoo0?mooeioo`00
D7oo00<007ooOol0ogooGWoo001@Ool00`00Oomoo`3oOomNOol0051oo`800?mooemoo`00D7oo00<0
07ooOol0ogooGWoo001@Ool00`00Oomoo`3oOomNOol0051oo`03001oogoo0?mooeioo`00D7oo00<0
07ooOol0ogooGWoo001@Ool00`00Oomoo`3oOomNOol0051oo`800?l03bl03c1oo`00D7oo00<007oo
Ool0ogooGWoo001@Ool00`00Oomoo`3oOomNOol0051oo`03001oogoo0?mooeioo`00D7oo00<007oo
Ool0ogooGWoo001@Ool2003oOomOOol0051oo`03001oogoo0?mooeioo`00:Woo100017oo1P001Goo
0P001Woo10001goo00<007ooOol0ogooGWoo000YOol00`00Oomoo`02Ool01@00Oomoogoo000017oo
00<007ooOol00goo0P001Goo00<007ooOol00Woo00<007ooOol017oo00<007ooOol0ogooGWoo000^
Ool00`00Oomoo`02Ool00`00Oomoo`0COol00`00Oomoo`04Ool00`00Oomoo`3oOomNOol002ioo`03
001oogoo00=oo`03001oogoo019oo`03001oogoo00Aoo`03001oogoo0?mooeioo`00;7oo0P001goo
00<007ooOol04Goo00<007ooOol017oo0`00ogooGWoo000^Ool00`00Oomoo`05Ool00`00Oomoo`0<
Ool40007Ool00`00Oomoo`3oOomNOol002ioo`05001oogooOol00004Ool00`00Oomoo`0;Ool00`00
Oomoo`08Ool00`00Oomoo`3oOomNOol002Uoo`03001oogoo009oo`05001oogooOol00004Ool00`00
Oomoo`0;Ool00`00Oomoo`08Ool00`00Oomoo`3oOomNOol002Yoo`@000Eoo`@000ioo`D000Ioo`03
001oogoo0?mooeioo`00D7oo0P00ogooGgoo001@Ool00`00Oomoo`3oOomNOol0051oo`03001oogoo
0?mooeioo`00D7oo00<007ooOol0ogooGWoo001@Ool00`00Oomoo`3oOomNOol0051oo`03001oogoo
0?mooeioo`00D7oo0P00ogooGgoo001@Ool00`00Oomoo`3oOomNOol0051oo`03001oogoo0?mooeio
o`00D7oo00<007ooOol0ogooGWoo001@Ool00`00Oomoo`3oOomNOol0051oo`800?mooemoo`00D7oo
00<007ooOol0ogooGWoo001@Ool00`00Oomoo`3oOomNOol0051oo`03001oogoo0?mooeioo`00D7oo
00<007ooOol0ogooGWoo001@Ool00`00Oomoo`3oOomNOol0051oo`800?mooemoo`00D7oo00<007oo
Ool0ogooGWoo000lOol40005Ool40007Ool00`00Oomoo`3oOomNOol003]oo`03001oogoo009oo`05
001oogooOol00004Ool00`00Oomoo`04Ool00`00Oomoo`3oOomNOol0041oo`03001oogoo00Ioo`03
001oogoo00Aoo`03001oogoo0?mooeioo`00@7oo00<007ooOol01Woo00<007ooOol017oo00<007oo
Ool0ogooGWoo000nOol20007Ool20007Ool3003[Ool00`00Oomoo`1_Ool0041oo`03001oogoo00Io
o`03001oogoo00Aoo`03001oogoo0>Yoo`03001oo`00071oo`00@7oo00<007ooOol01Woo00<007oo
Ool017oo00<007ooOol0:goo00<007ooOol0_7oo00<007oo0000L7oo000kOol00`00Oomoo`02Ool0
1@00Oomoogoo000017oo00<007ooOol017oo00<007ooOol0:goo00<007ooOol0^goo00D007ooOomo
o`0006moo`00?7oo10001Goo10001goo00<007ooOol0:Woo00<007oo0000_7oo00<007ooOol00Woo
00<007ooOol0K7oo001@Ool2000[Ool00`00Ool0002kOol00`00Oomoo`03Ool00`00Oomoo`1/Ool0
051oo`03001oogoo02Uoo`04001oogoo002kOol00`00Oomoo`04Ool00`00Oomoo`0POol00`00Oomo
o`18Ool0051oo`03001oogoo02Uoo`05001oogooOol0002iOol00`00Oomoo`06Ool00`00Oomoo`0N
Ool2001:Ool0051oo`03001oogoo02Qoo`03001oogoo009oo`03001oogoo0;Moo`03001oogoo00Io
o`03001oogoo01eoo`04001oogoo0019Ool0051oo`03001oogoo02Qoo`03001oogoo00=oo`03001o
ogoo0;Eoo`03001oogoo00Qoo`03001oogoo01aoo`04001oogoo0019Ool0051oo`03001oogoo02Mo
o`03001oogoo00Aoo`03001oogoo0;Aoo`03001oogoo00Yoo`03001oogoo01Yoo`03001oogoo009o
o`03001oogoo04Ioo`00D7oo0P00:7oo00<007ooOol017oo00<007ooOol0U7oo00<007ooOol07Goo
00<007ooOol02Woo00<007ooOol06Goo00<007ooOol00goo00<007ooOol0AWoo001@Ool00`00Oomo
o`0VOol00`00Oomoo`06Ool00`00Oomoo`2BOol00`00Ool0000MOol00`00Oomoo`0<Ool00`00Oomo
o`0GOol00`00Oomoo`05Ool00`00Oomoo`15Ool0051oo`03001oogoo02Ioo`03001oogoo00Ioo`03
001oogoo095oo`05001oogooOol0000LOol00`00Oomoo`0=Ool00`00Oomoo`0EOol00`00Oomoo`06
Ool00`00Oomoo`15Ool0051oo`03001oogoo02Eoo`03001oogoo00Moo`03001oogoo08moo`8000Ao
o`03001oogoo01Uoo`03001oogoo00ioo`03001oogoo01Eoo`03001oogoo00Moo`03001oogoo04Ao
o`00D7oo00<007ooOol09Goo00<007ooOol027oo00<007ooOol0Jgoo00<007ooOol07goo00<007oo
Ool01Goo00<007ooOol067oo00<007ooOol03goo00<007ooOol04goo00<007ooOol027oo00<007oo
Ool0A7oo001@Ool2000UOol00`00Oomoo`09Ool00`00Oomoo`1ZOol01000Ool000007Woo00<007oo
Ool01goo00<007ooOol05Woo00<007ooOol04Goo00<007ooOol04Goo00<007ooOol02Woo00<007oo
Ool0@goo001@Ool00`00Oomoo`0TOol00`00Oomoo`09Ool00`00Oomoo`1YOol00`00Oomoo`02Ool2
000KOol00`00Oomoo`09Ool00`00Oomoo`0EOol00`00Oomoo`0AOol00`00Oomoo`0@Ool00`00Oomo
o`0;Ool00`00Oomoo`13Ool0051oo`03001oogoo02=oo`03001oogoo00]oo`03001oogoo06Moo`03
001oogoo00Eoo`03001oogoo01Moo`03001oogoo00]oo`03001oogoo01=oo`03001oogoo01=oo`03
001oogoo00moo`03001oogoo00aoo`03001oogoo049oo`00D7oo00<007ooOol08goo00<007ooOol0
2goo00<007ooOol0Igoo00<007ooOol01Woo0P005Goo0P003goo00<007ooOol04Goo00<007ooOol0
5Goo00<007ooOol03Goo00<007ooOol03Goo00<007ooOol0@Woo001@Ool00`00Oomoo`0ROol00`00
Oomoo`0<Ool00`00Oomoo`1VOol00`00Oomoo`09Ool2000BOol00`00Oomoo`0?Ool00`00Oomoo`0A
Ool00`00Oomoo`0EOol00`00Oomoo`0<Ool00`00Oomoo`0?Ool00`00Oomoo`11Ool0051oo`03001o
ogoo029oo`03001oogoo00eoo`03001oogoo06Aoo`03001oogoo00aoo`03001oogoo00ioo`03001o
ogoo015oo`03001oogoo00moo`03001oogoo01Moo`03001oogoo00Yoo`03001oogoo011oo`03001o
ogoo045oo`00D7oo0P008Woo00<007ooOol03Woo00<007ooOol0Hgoo00<007ooOol03Woo0P003Goo
00<007ooOol04goo00<007ooOol03Woo00<007ooOol067oo00<007ooOol027oo00<007ooOol04Woo
00<007ooOol0@7oo001@Ool00`00Oomoo`0QOol00`00Oomoo`0?Ool00`00Oomoo`1QOol00`00Oomo
o`0AOol2000:Ool00`00Oomoo`0EOol00`00Oomoo`0<Ool00`00Oomoo`0IOol00`00Oomoo`08Ool0
0`00Oomoo`0BOol00`00Oomoo`10Ool002Yoo`@000Eoo`@000Ioo`8000Ioo`@000Moo`03001oogoo
021oo`03001oogoo011oo`03001oogoo061oo`03001oogoo01Aoo`03001oogoo00Eoo`8001Uoo`03
001oogoo00]oo`03001oogoo01Yoo`03001oogoo00Ioo`03001oogoo01Aoo`03001oogoo03moo`00
6Goo00<007ooOol017oo00<007ooOol01Woo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001o
ogoo00=oo`8000Eoo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo021oo`03001oogoo011o
o`03001oogoo02moo`03001oogoo02eoo`03001oogoo01Ioo`8000Aoo`03001oogoo01Yoo`03001o
ogoo00Uoo`03001oogoo01aoo`03001oogoo00Aoo`03001oogoo01Eoo`03001oogoo03moo`006Goo
0P0017oo0P003Goo00<007ooOol01Woo00<007ooOol03goo00<007ooOol017oo00<007ooOol07goo
00<007ooOol04Woo00<007ooOol0;Goo00<007oo0000;Woo00<007ooOol067oo0P0000=oo`00Ool0
77oo00<007ooOol027oo00<007ooOol07Goo00<007ooOol00goo00<007ooOol05Woo00<007ooOol0
?goo000IOol00`00Ool00002Ool00`00Ool0000=Ool00`00Oomoo`06Ool00`00Oomoo`0?Ool00`00
Oomoo`04Ool3000O00l00`0000l03`0B00l00`0000l03`0/00l0100000l03`00;@0?00<0000?00l0
6`0?00<0000?00l07@0?00<0000?00l01`0?00<0000?00l07P0?00D0000?00l03`0001X03`030000
3`0?00h03c1oo`0077oo0P003Woo0P001goo0P004Woo00<007ooOol017oo00<007ooOol07Woo00<0
07ooOol04goo00<007ooOol0:goo00<007ooOol00Woo00<007ooOol0:Goo00<007ooOol0?Goo00<0
07ooOol01Goo00<007ooOol087oo00@007ooOol001Yoo`03001oogoo03ioo`006Goo00<007oo0000
0Woo00<007oo00003Goo00<007ooOol01Woo00<007ooOol02goo10001goo00<007ooOol07Woo00<0
07ooOol057oo00<007ooOol0:Goo00<007ooOol00goo00<007ooOol0:7oo00<007ooOol0?goo00<0
07ooOol017oo00<007ooOol087oo00<007oo000077oo00<007ooOol0?Goo000IOol20004Ool2000=
Ool00`00Oomoo`06Ool00`00Oomoo`0;Ool00`00Oomoo`08Ool00`00Oomoo`0MOol00`00Oomoo`0E
Ool00`00Oomoo`0XOol00`00Oomoo`05Ool00`00Oomoo`0VOol00`00Oomoo`11Ool00`00Oomoo`02
Ool00`00Oomoo`0ROol00`00Oomoo`0KOol00`00Oomoo`0mOol001Uoo`03001oogoo00Aoo`03001o
ogoo00Ioo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`0;Ool00`00Oomoo`08Ool0
0`00Oomoo`0MOol00`00Oomoo`0EOol00`00Oomoo`0WOol00`00Oomoo`07Ool00`00Oomoo`0TOol0
0`00Oomoo`13Ool01@00Oomoogoo0000@goo00<007ooOol0?7oo000ZOol40005Ool4000>Ool50006
Ool00`00Oomoo`0LOol00`00Oomoo`0GOol00`00Oomoo`0UOol00`00Oomoo`08Ool00`00Oomoo`0S
Ool00`00Oomoo`14Ool01000Oomoo`00A7oo00<007ooOol0?7oo001@Ool2000MOol00`00Oomoo`0G
Ool00`00Oomoo`0TOol00`00Oomoo`0:Ool00`00Oomoo`0QOol00`00Oomoo`16Ool00`00Ool00015
Ool00`00Oomoo`0kOol0051oo`03001oogoo01]oo`03001oogoo01Qoo`03001oogoo02=oo`03001o
ogoo00aoo`03001oogoo021oo`03001oogoo04Moo`03001oogoo04Aoo`03001oogoo03]oo`00D7oo
00<007ooOol06goo00<007ooOol06Goo00<007ooOol08Goo00<007ooOol03Goo00<007ooOol07goo
00<007ooOol0T7oo00<007ooOol0>Woo001@Ool00`00Oomoo`0JOol00`00Oomoo`0JOol00`00Oomo
o`0POol00`00Oomoo`0?Ool00`00Oomoo`0MOol00`00Oomoo`2AOol00`00Oomoo`0jOol0051oo`03
001oogoo01Yoo`03001oogoo01]oo`03001oogoo01ioo`03001oogoo011oo`03001oogoo01aoo`03
001oogoo09=oo`03001oogoo03Uoo`00D7oo00<007ooOol06Goo00<007ooOol077oo00<007ooOol0
7Goo00<007ooOol04Woo00<007ooOol06Woo00<007ooOol0U7oo00<007ooOol0>Goo001@Ool2000J
Ool00`00Oomoo`0LOol00`00Oomoo`0LOol00`00Oomoo`0DOol00`00Oomoo`0HOol00`00Oomoo`2F
Ool00`00Oomoo`0hOol0051oo`03001oogoo01Qoo`03001oogoo01ioo`03001oogoo01Yoo`03001o
ogoo01Eoo`03001oogoo01Moo`03001oogoo09Moo`03001oogoo03Qoo`00D7oo00<007ooOol067oo
00<007ooOol07Woo00<007ooOol06Goo00<007ooOol05goo00<007ooOol05Goo00<007ooOol0VGoo
00<007ooOol0=goo001@Ool00`00Oomoo`0iOol00`00Oomoo`0HOol00`00Oomoo`0HOol00`00Oomo
o`0DOol00`00Oomoo`2JOol00`00Oomoo`0gOol0051oo`03001oogoo03Yoo`03001oogoo01Ioo`03
001oogoo01Yoo`03001oogoo019oo`03001oogoo09aoo`03001oogoo03Ioo`00D7oo0P00>goo00<0
07ooOol05Goo00<007ooOol077oo00<007ooOol047oo00<007ooOol0WGoo00<007ooOol0=Woo001@
Ool00`00Oomoo`0jOol00`00Oomoo`0DOol00`00Oomoo`0MOol00`00Oomoo`0?Ool00`00Oomoo`2O
Ool00`00Oomoo`0eOol0051oo`03001oogoo03]oo`03001oogoo015oo`80025oo`03001oogoo00eo
o`03001oogoo0:1oo`03001oogoo03Eoo`00D7oo00<007ooOol0>goo00<007ooOol03goo0P008goo
00<007ooOol037oo00<007ooOol0fGoo001@Ool00`00Oomoo`0kOol00`00Oomoo`0=Ool2000VOol0
0`00Oomoo`0:Ool00`00Oomoo`3JOol0051oo`03001oogoo03aoo`03001oogoo00Yoo`8002Uoo`03
001oogoo00Qoo`03001oogoo0=]oo`00D7oo0P00?Goo00<007ooOol027oo0P00:goo00<007ooOol0
1goo00<007ooOol0g7oo001@Ool00`00Oomoo`0mOol00`00Oomoo`05Ool2000^Ool00`00Oomoo`05
Ool00`00Oomoo`3MOol003aoo`@000Ioo`@000Ioo`03001oogoo03eoo`03001oogoo00=oo`80035o
o`03001oogoo00=oo`03001oogoo0=ioo`00>goo00<007ooOol00Woo00<007ooOol01Goo00<007oo
Ool01Goo00<007ooOol0?Goo00@007ooOomoo`8003=oo`03001oogoo009oo`03001oogoo0=moo`00
@7oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol0?Woo0`00=Woo00@007ooOol00>9oo`00
@7oo00@007ooOomoo`H000Ioo`<003ioo`03001oogoo03Ioo`03001oo`000>=oo`00?Woo0P001Goo
00@007ooOol000Moo`03001oogoo07Qoo`03001oogoo0>9oo`00@7oo00<007ooOol00Woo00@007oo
Ool000Moo`03001oogoo0?mooeioo`00@7oo00<007ooOol00goo00<007oo00001goo00<007ooOol0
ogooGWoo000kOol00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Ool00007Ool00`00Oomoo`3oOomN
Ool003aoo`@000Moo`8000Moo`03001oogoo0?mooeioo`00D7oo0P00ogooGgoo001@Ool00`00Oomo
o`3oOomNOol0051oo`03001oogoo0?mooeioo`00D7oo00<007ooOol0ogooGWoo001@Ool00`00Oomo
o`3oOomNOol0051oo`800?mooemoo`00D7oo00<007ooOol0ogooGWoo001@Ool00`00Oomoo`3oOomN
Ool0051oo`03001oogoo0?mooeioo`00D7oo00<007ooOol0ogooGWoo001@Ool00`00Oomoo`3oOomN
Ool0051oo`800?mooemoo`00D7oo00<007ooOol0ogooGWoo001@Ool00`00Oomoo`3oOomNOol0051o
o`03001oogoo0?mooeioo`00D7oo00<007ooOol0ogooGWoo001@Ool00`00Oomoo`3oOomNOol0051o
o`800?mooemoo`00D7oo00<007ooOol0ogooGWoo000ZOol40006Ool40005Ool20006Ool40007Ool0
0`00Oomoo`3oOomNOol002Uoo`03001oogoo009oo`03001oogoo00Eoo`03001oogoo00Aoo`8000Eo
o`03001oogoo009oo`03001oogoo00Aoo`03001oogoo0?mooeioo`00;Woo00<007ooOol01Goo00<0
07ooOol047oo00<007ooOol017oo00<007ooOol0ogooGWoo000^Ool01000Oomoogoo1P004Goo00<0
07ooOol017oo0`00ogooGWoo000/Ool20005Ool01000Oomoo`004Woo00<007ooOol017oo00<007oo
Ool0ogooGWoo000^Ool00`00Oomoo`02Ool01000Oomoo`003Woo10001goo00<007ooOol0ogooGWoo
000^Ool00`00Oomoo`03Ool00`00Ool0000>Ool00`00Oomoo`08Ool00`00Oomoo`3oOomNOol002Uo
o`03001oogoo009oo`03001oogoo00=oo`03001oo`0000ioo`03001oogoo00Qoo`03001oogoo0?mo
oeioo`00:Woo10001goo0P003Woo1@001Woo00<007ooOol0ogooGWoo001@Ool2003oOomOOol0051o
o`03001oogoo0?mooeioo`00D7oo00<007ooOol0ogooGWoo001@Ool00`00Oomoo`3oOomNOol0051o
o`03001oogoo0?mooeioo`00D7oo0P00o`0?;`0?<7oo001@Ool00`00Oomoo`3oOomNOol0051oo`03
001oogoo0?mooeioo`00D7oo00<007ooOol0ogooGWoo001@Ool00`00Oomoo`3oOomNOol0051oo`03
001oogoo0?mooeioo`00D7oo0P00ogooGgoo001@Ool00`00Oomoo`3oOomNOol0051oo`03001oogoo
0?mooeioo`00D7oo00<007ooOol0ogooGWoo001@Ool00`00Oomoo`3oOomNOol0051oo`800?mooemo
o`00D7oo00<007ooOol0ogooGWoo001@Ool00`00Oomoo`3oOomNOol003aoo`@000Eoo`@000Moo`03
001oogoo0?mooeioo`00>goo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo00Aoo`03
001oogoo0?mooeioo`00@7oo00<007ooOol01Woo00<007ooOol017oo00<007ooOol0ogooGWoo0010
Ool00`00Oomoo`06Ool00`00Oomoo`04Ool3003oOomNOol003ioo`8000Uoo`03001oogoo00Aoo`03
001oogoo0?mooeioo`00@7oo00<007ooOol00Woo10001goo00<007ooOol0ogooGWoo0010Ool00`00
Oomoo`02Ool00`00Oomoo`08Ool00`00Oomoo`3oOomNOol003]oo`03001oogoo009oo`03001oogoo
009oo`03001oogoo00Qoo`03001oogoo0?mooeioo`00?7oo10001Goo1@001Woo00<007ooOol0ogoo
GWoo001@Ool2003oOomOOol0051oo`03001oogoo0?mooeioo`00D7oo00<007ooOol0ogooGWoo001@
Ool00`00Oomoo`3oOomNOol0051oo`03001oogoo0?mooeioo`00ogoo/Goo003oOonaOol00?mook5o
o`00ogoo/Goo003oOonaOol00?mook5oo`00YWoo0`00ogoo27oo002XOol00`00Oomoo`3oOol6Ool0
0:Qoo`03001oogoo0?moo`Ioo`00>Goo1`000Woo0`000Woo0`0000=oo`0000001@001Goo10000Woo
1`0017oo1@000Woo1`0037oo00<007oo00000P001Woo100017oo0`0000=oo`0000000Woo0`0000=o
o`0000001Goo0P00ogoo1goo000lOol00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`03Ool0
0`00Oomoo`05Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`04Ool01@00Oomoogoo0000
1Woo00<007ooOol03Goo0P000goo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol000=oo`80
009oo`04001oogooOol20006Ool2003oOol7Ool003aoo`03001oogoo00Aoo`03001oogoo009oo`03
001oogoo00=oo`03001oogoo00Eoo`03001oogoo00Moo`03001oogoo00Aoo`05001oogooOol00006
Ool00`00Oomoo`0=Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`05Ool00`00Oomoo`02
Ool01000Oomoo`0017oo00<007ooOol00goo00@007ooOol00?moo`Ioo`00?7oo00<007ooOol017oo
00<007ooOol00Woo00<007ooOol00goo00<007ooOol01Goo00<007ooOol01goo00<007ooOol01Goo
10001Woo00<007ooOol04Woo00<007ooOol00Woo00<007ooOol01Goo00<007ooOol00Woo00@007oo
Ool000Aoo`03001oogoo00=oo`04001oogoo003oOol6Ool003aoo`03001oogoo00Aoo`8000=oo`03
001oogoo00=oo`03001oogoo00Eoo`03001oogoo00Moo`03001oogoo00Aoo`05001oogooOol00006
Ool00`00Oomoo`0>Ool40005Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000goo0P00
17oo00<007ooOol00Woo00<007ooOol0ogoo0goo000lOol00`00Oomoo`03Ool2000017oo00000000
17oo0`001Goo1`000goo0`001goo0`001goo00<007ooOol03Goo00<007ooOol00Woo00<007ooOol0
1`000Woo0P000goo0P000goo0`0000=oo`00Ool00Woo0`000Woo0`00ogoo17oo000lOol00`00Oomo
o`0GOol00`00Oomoo`0IOol00`00Oomoo`0=Ool01000Oomoogoo0P0017oo00<007ooOol04Woo00<0
07ooOol0ogoo3Goo000iOol7000FOol00`00Oomoo`0IOol00`00Oomoo`0>Ool300000goo001oo`03
Ool00`00Oomoo`0BOol00`00Oomoo`3oOol=Ool004ioo`03001oogoo00moo`03001oogoo00eoo`<0
02eoo`800?moo`moo`00CWoo00<007ooOol03goo00<007ooOol0ogooCWoo003oOonaOol00?mook5o
o`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogooTGoo00<0
07ooOol07Goo003oOonAOol2000NOol003Uoo`<00004Ool00000000>Ool20006Ool50002Ool70004
Ool300000goo00000003Ool40004Ool5000>Ool50004Ool40004Ool5000<Ool70002Ool30002Ool3
0002Ool300000goo00000002Ool70005Ool20004Ool70003Ool300000goo00000004Ool300000goo
00000003Ool50002Ool70003Ool5000>Ool40005Ool40003Ool30002Ool30004Ool40003Ool50005
Ool40003Ool7000=Ool40003Ool30002Ool30003Ool50003Ool50006Ool40004Ool00`00Oomoo`0L
Ool003Yoo`05001oogooOol0000?Ool20005Ool01@00Oomoogoo00001Woo00<007ooOol017oo00@0
07ooOomoo`8000=oo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`0<Ool00`00Oomo
o`04Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0@Ool00`00Oomoo`04Ool00`00Oomo
o`02Ool01000Oomoo`000goo0P001Woo00<007ooOol01Woo0P001goo00<007ooOol00goo00@007oo
Oomoo`8000Aoo`04001oogooOol20003Ool01@00Oomoogoo00001Woo00<007ooOol017oo00<007oo
Ool00Woo00<007ooOol02Woo00<007ooOol00Woo00D007ooOomoo`0000Aoo`05001oogooOol00004
Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01@00Oomoogoo00001goo00<007ooOol00Woo00<007oo
Ool00goo00<007ooOol03Goo00<007ooOol00Woo00D007ooOomoo`0000Aoo`05001oogooOol00003
Ool00`00Oomoo`03Ool00`00Oomoo`06Ool00`00Oomoo`02Ool01000Oomoogoo0P007Goo000kOol0
0`00Ool0000?Ool01000Oomoo`0017oo00D007ooOomoo`0000Ioo`03001oogoo00Aoo`03001oogoo
009oo`05001oogooOol0000=Ool00`00Oomoo`0<Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00
Oomoo`02Ool00`00Oomoo`0@Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01000Oomoo`0017oo00<0
07ooOol017oo00<007ooOol01Goo00@007ooOol000Ioo`03001oogoo00=oo`03001oogoo009oo`03
001oogoo009oo`03001oogoo009oo`05001oogooOol00003Ool00`00Oomoo`04Ool00`00Oomoo`09
Ool00`00Oomoo`09Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007oo
Ool00Woo00<007ooOol01Woo00<007ooOol01Goo00<007ooOol00Woo00<007ooOol00goo00<007oo
Ool037oo00<007ooOol01goo00<007ooOol00Woo00D007ooOomoo`0000=oo`03001oogoo00=oo`03
001oogoo00Ioo`03001oogoo02Eoo`00?7oo00<007ooOol03Woo00@007ooOol000Eoo`@000Ioo`03
001oogoo00Aoo`03001oogoo009oo`04001oogooOol60004Ool4000?Ool00`00Oomoo`04Ool00`00
Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0@Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01000
Oomoo`0017oo00<007ooOol017oo00<007ooOol01Goo00@007ooOol000Ioo`03001oogoo00=oo`03
001oogoo009oo`03001oogoo009oo`03001oogoo009oo`03001oogoo009oo`@000Ioo`03001oogoo
00Eoo`@000aoo`03001oogoo00Moo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`02
Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`0<
Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`02Ool40005Ool00`00Oomoo`06Ool00`00
Oomoo`0UOol003aoo`03001oogoo00eoo`03001oogoo009oo`05001oogooOol00003Ool00`00Oomo
o`04Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00D007ooOomoo`0000Ao
o`03001oogoo00aoo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo009oo`80015oo`03001o
ogoo00Aoo`8000=oo`04001oogoo0003Ool20006Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00
Oomoo`03Ool00`00Oomoo`03Ool01000Oomoogoo0P0017oo00<007ooOol00Woo00D007ooOomoo`00
00=oo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo00Uoo`03001oogoo
00Moo`03001oogoo009oo`04001oogooOol20003Ool00`00Oomoo`02Ool00`00Oomoo`06Ool20006
Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`0=Ool01000Oomoogoo0P000goo0P000goo
00D007ooOomoo`0000=oo`03001oogoo00=oo`8000Moo`03001oogoo02Eoo`00>goo00<007oo0000
3Goo0`000Woo0`000goo0`001goo00<007ooOol00goo0P000goo0P0017oo10001Goo1@0037oo1P00
17oo100017oo0P0000Aoo`00000000aoo`<000Eoo`800004Ool000000004Ool300000goo001oo`03
Ool30005Ool30002Ool30002Ool30006Ool300000goo001oo`02Ool20003Ool20004Ool30007Ool0
0`00Oomoo`05Ool5000;Ool00`00Oomoo`03Ool00`00Oomoo`02Ool40003Ool2000017oo00000000
0goo1`000goo0P0000Aoo`00000000Aoo`@000Ioo`03001oogoo00ioo`<00003Ool007oo009oo`03
001oo`00008000Eoo`<000Eoo`800004Ool000000002Ool7000SOol003Yoo`05001oogooOol0000Q
Ool00`00Oomoo`0ZOol00`00Oomoo`0eOol00`00Oomoo`0QOol00`00Oomoo`0FOol00`00Oomoo`0F
Ool01000Oomoogoo0P005Woo00<007ooOol06Goo00<007ooOol05Woo00<007ooOol06Goo00<007oo
Ool09Goo000iOol3000017oo0000000087oo00<007ooOol0:Woo00<007ooOol0=Goo00<007ooOol0
8Goo00<007ooOol05Woo00<007ooOol05goo0`0000=oo`00Ool05Goo00<007ooOol06Goo00<007oo
Ool05Woo00<007ooOol06Goo00<007ooOol09Goo001NOol3000]Ool3000POol00`00Oomoo`0@Ool2
0006Ool00`00Oomoo`0?Ool00`00Oomoo`07Ool2000FOol3001>Ool3000GOol20013Ool00;5oo`03
001oogoo01Qoo`03001oogoo00moo`03001oogoo0<moo`00ogoo/Goo003oOonaOol00?mook5oo`00
\
\>"],
  ImageRangeCache->{{{135, 422}, {240, 63.0625}} -> {-15.1243, 32.8712, 
  0.0781317, 0.0269695}},
  CellTags->"Control Charts for Individual Measurements"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0680272 0.0882906 0.299412 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.15986 -0.0125 -3 -9 ]
[.15986 -0.0125 3 0 ]
[.29592 -0.0125 -3 -9 ]
[.29592 -0.0125 3 0 ]
[.43197 -0.0125 -3 -9 ]
[.43197 -0.0125 3 0 ]
[.56803 -0.0125 -3 -9 ]
[.56803 -0.0125 3 0 ]
[.70408 -0.0125 -6 -9 ]
[.70408 -0.0125 6 0 ]
[.84014 -0.0125 -6 -9 ]
[.84014 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -26 -21.5625 ]
[.5 -0.0125 26 -9 ]
[-0.0125 .08829 -6 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .238 -18 -4.5 ]
[-0.0125 .238 0 4.5 ]
[-0.0125 .3877 -6 -4.5 ]
[-0.0125 .3877 0 4.5 ]
[-0.0125 .53741 -18 -4.5 ]
[-0.0125 .53741 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -30.5625 -8 ]
[-0.01875 .30902 -18 8 ]
[.5 .63053 -128 0 ]
[.5 .63053 128 25.75 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .22339 m
1 .22339 L
s
0 .08829 m
1 .08829 L
s
0 .52974 m
1 .52974 L
s
0 g
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.15986 0 m
.15986 .00625 L
s
[(2)] .15986 -0.0125 0 1 Mshowa
.29592 0 m
.29592 .00625 L
s
[(4)] .29592 -0.0125 0 1 Mshowa
.43197 0 m
.43197 .00625 L
s
[(6)] .43197 -0.0125 0 1 Mshowa
.56803 0 m
.56803 .00625 L
s
[(8)] .56803 -0.0125 0 1 Mshowa
.70408 0 m
.70408 .00625 L
s
[(10)] .70408 -0.0125 0 1 Mshowa
.84014 0 m
.84014 .00625 L
s
[(12)] .84014 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(14)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05782 0 m
.05782 .00375 L
s
.09184 0 m
.09184 .00375 L
s
.12585 0 m
.12585 .00375 L
s
.19388 0 m
.19388 .00375 L
s
.22789 0 m
.22789 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.32993 0 m
.32993 .00375 L
s
.36395 0 m
.36395 .00375 L
s
.39796 0 m
.39796 .00375 L
s
.46599 0 m
.46599 .00375 L
s
.5 0 m
.5 .00375 L
s
.53401 0 m
.53401 .00375 L
s
.60204 0 m
.60204 .00375 L
s
.63605 0 m
.63605 .00375 L
s
.67007 0 m
.67007 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77211 0 m
.77211 .00375 L
s
.80612 0 m
.80612 .00375 L
s
.87415 0 m
.87415 .00375 L
s
.90816 0 m
.90816 .00375 L
s
.94218 0 m
.94218 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -87 -25.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(subgroup) show
111.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .08829 m
.00625 .08829 L
s
[(0)] -0.0125 .08829 1 0 Mshowa
0 .238 m
.00625 .238 L
s
[(0.5)] -0.0125 .238 1 0 Mshowa
0 .3877 m
.00625 .3877 L
s
[(1)] -0.0125 .3877 1 0 Mshowa
0 .53741 m
.00625 .53741 L
s
[(1.5)] -0.0125 .53741 1 0 Mshowa
.125 Mabswid
0 .11823 m
.00375 .11823 L
s
0 .14817 m
.00375 .14817 L
s
0 .17811 m
.00375 .17811 L
s
0 .20806 m
.00375 .20806 L
s
0 .26794 m
.00375 .26794 L
s
0 .29788 m
.00375 .29788 L
s
0 .32782 m
.00375 .32782 L
s
0 .35776 m
.00375 .35776 L
s
0 .41764 m
.00375 .41764 L
s
0 .44758 m
.00375 .44758 L
s
0 .47753 m
.00375 .47753 L
s
0 .50747 m
.00375 .50747 L
s
0 .05835 m
.00375 .05835 L
s
0 .02841 m
.00375 .02841 L
s
0 .56735 m
.00375 .56735 L
s
0 .59729 m
.00375 .59729 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -93.2813 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
69 10.2813 translate
90 rotate
-69 -10.2813 translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(MR) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .08829 m
1 .08829 L
s
gsave
.5 .63053 -189 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 33.75 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Moving) show
105.000 12.813 moveto
(Range) show
141.000 12.813 moveto
(for) show
165.000 12.813 moveto
(individual) show
231.000 12.813 moveto
(Control) show
279.000 12.813 moveto
(chart) show
309.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
63.000 26.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Initial) show
111.000 26.000 moveto
(Study) show
141.000 26.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.09184 .29788 m
.15986 .37273 L
.22789 .14518 L
.29592 .19308 L
.36395 .25596 L
.43197 .19009 L
.5 .21105 L
.56803 .15416 L
.63605 .17512 L
.70408 .21404 L
.77211 .27393 L
.84014 .24997 L
.90816 .21404 L
.97619 .30387 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[27]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012Q000`40O003h00Oogoo/Goo003oOona
Ool00?mook5oo`00eWoo10007goo0`00]7oo003JOol00`00Oomoo`0MOol00`00Oomoo`2cOol00=Yo
o`03001oogoo01eoo`03001oogoo0;=oo`00^goo1@001Goo0`0000Aoo`00001oo`800004Ool00000
0004Ool300000goo001oo`03Ool50005Ool40005Ool300000goo00000002Ool00`00Ool00002002a
Ool00;]oo`03001oogoo009oo`05001oogooOol00003Ool20003Ool20003Ool01000Oomoo`000goo
0P001Goo00<007ooOol01Goo00<007ooOol00Woo00D007ooOomoo`0000=oo`8000=oo`8000=oo`03
001oogoo0:ioo`00`7oo00D007ooOomoo`0000Aoo`05001oogooOol00004Ool01000Oomoo`0017oo
00<007ooOol00goo00<007ooOol01Goo00<007ooOol00Woo00D007ooOomoo`0000Aoo`05001oogoo
Ool00004Ool00`00Oomoo`2^Ool00;aoo`@000Aoo`03001oogoo009oo`05001oogooOol00004Ool0
1000Oomoo`0017oo00<007ooOol00goo00<007ooOol01Goo00<007ooOol00Woo00D007ooOomoo`00
00Aoo`05001oogooOol00004Ool00`00Oomoo`2^Ool00;]oo`03001oogoo009oo`05001oogooOol0
0004Ool01000Oomoogoo0P000goo00@007ooOol000=oo`8000Eoo`8000Ioo`03001oogoo009oo`05
001oogooOol00004Ool01000Oomoogoo0P000goo00<007ooOol0[Woo002lOol50002Ool20003Ool2
0003Ool00`00Ool000020004Ool300000goo00000003Ool2000017oo0000000017oo10000goo0P00
0goo0P000Woo0P0000Aoo`0000000;5oo`00cGoo00<007ooOol0h7oo003=Ool00`00Oomoo`3POol0
0<aoo`800>9oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol004Yoo`@002Ao
o`H002Eoo`@002Eoo`@002Eoo`@001moo`L000=oo`@001aoo`L0009oo`H001Yoo`L000Aoo`@003ao
o`00BGoo00<007ooOol00Woo00<007ooOol08Goo00<007ooOol00Woo00<007ooOol09Goo00<007oo
Ool08goo00<007ooOol00Woo00<007ooOol08Goo00<007ooOol00Woo00<007ooOol07goo00<007oo
Ool00goo00<007ooOol00Woo00<007ooOol077oo00<007ooOol00goo00<007ooOol00Woo00<007oo
Ool06goo00<007ooOol01goo00<007ooOol0>goo0019Ool00`00Oomoo`02Ool00`00Oomoo`0ROol0
0`00Oomoo`0YOol00`00Oomoo`0SOol00`00Oomoo`02Ool00`00Oomoo`0QOol00`00Oomoo`02Ool0
0`00Oomoo`0OOol00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`0LOol00`00Oomoo`04Ool0
0`00Oomoo`0OOol00`00Oomoo`07Ool00`00Oomoo`0kOol004Uoo`03001oogoo009oo`03001oogoo
02=oo`03001oogoo02Aoo`H002Aoo`8000=oo`03001oogoo025oo`03001oogoo009oo`03001oogoo
01moo`03001oogoo00=oo`03001oogoo009oo`03001oogoo01aoo`03001oogoo00Eoo`03001oogoo
01ioo`03001oogoo00=oo`H003aoo`00BGoo00<007ooOol00Woo00<007ooOol097oo00<007ooOol0
97oo00@007ooOol002Eoo`03001oo`00008002Eoo`@0029oo`03001oogoo00=oo`03001oogoo009o
o`03001oogoo01aoo`03001oogoo00Ioo`03001oogoo01eoo`03001oogoo00Aoo`04001oogoo000m
Ool004Uoo`03001oogoo009oo`03001oogoo02Eoo`03001oogoo02=oo`04001oogoo000UOol00`00
Oomoo`0VOol00`00Oomoo`02Ool00`00Oomoo`0OOol00`00Oomoo`03Ool00`00Oomoo`02Ool00`00
Oomoo`0LOol00`00Oomoo`07Ool00`00Oomoo`0LOol00`00Oomoo`04Ool01000Oomoo`00?Goo0019
Ool00`00Oomoo`02Ool00`00Oomoo`0QOol00`00Oomoo`02Ool00`00Oomoo`0SOol00`00Ool0000V
Ool00`00Oomoo`0UOol00`00Oomoo`02Ool00`00Oomoo`0OOol00`00Oomoo`03Ool00`00Oomoo`02
Ool00`00Oomoo`0LOol00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`0KOol00`00Oomoo`05
Ool00`00Ool0000mOol004Uoo`03001oogoo009oo`03001oogoo025oo`03001oogoo009oo`03001o
ogoo02=oo`03001oo`0002Moo`03001oogoo02Aoo`03001oogoo009oo`03001oogoo01eoo`<000Eo
o`03001oogoo009oo`03001oogoo01Yoo`<000Eoo`03001oogoo009oo`03001oogoo01Uoo`<000Mo
o`03001oo`0003eoo`00BWoo10009Goo10009goo0P00:7oo0`0097oo10008Woo00<007ooOol017oo
10007goo00<007ooOol017oo10007Woo00<007ooOol01Woo0P00?Goo003oOonaOol00?mook5oo`00
ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol004Eoool0034003]oo`00AGoo00<0
07ooOol017oo00<007ooOol027oo00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<0
07ooOol027oo00<007ooOol01goo00<007ooOol01goo00<007ooOol027oo00<007ooOol01goo00<0
07ooOol01goo00<007ooOol027oo00<007ooOol01goo00<007ooOol01goo00<007ooOol027oo00<0
07ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol027oo00<007ooOol01goo00<0
07ooOol01goo00<007ooOol027oo00<007ooOol01goo00<007ooOol01goo00<007ooOol027oo00<0
07ooOol01goo00<007ooOol01goo00<007ooOol027oo00<007ooOol01goo00<007ooOol0@7oo0015
Ool00`00Oomoo`04Ool00`00Oomoo`0VOol00`00Oomoo`0WOol00`00Oomoo`0VOol00`00Oomoo`0V
Ool00`00Oomoo`0VOol00`00Oomoo`0WOol00`00Oomoo`0VOol00`00Oomoo`10Ool004Eoo`03001o
ogoo0?moofUoo`00AGoo00<007ooOol0ogooJGoo0015Ool00`00Oomoo`3oOomYOol004Eoo`03001o
ogoo0?moofUoo`00AGoo00<007ooOol0ogooJGoo0015Ool2003oOomZOol004Eoo`03001oogoo0?mo
ofUoo`00AGoo00<007ooOol0ogooJGoo0015Ool00`00Oomoo`3oOomYOol004Eoo`03001oogoo0?mo
ofUoo`00AGoo00<007ooOol0ogooJGoo0015Ool00`00Oomoo`3oOomYOol004Eoo`03001oogoo0?mo
ofUoo`00AGoo00<007ooOol0ogooJGoo0015Ool2003oOomZOol004Eoo`03001oogoo0?moofUoo`00
AGoo00<007ooOol0ogooJGoo0015Ool00`00Oomoo`3oOomYOol004Eoo`03001oogoo0?moofUoo`00
AGoo00<007ooOol0ogooJGoo000jOol40007Ool00`00Oomoo`3oOomYOol003Uoo`03001oogoo009o
o`03001oogoo00Aoo`03001oogoo0?moofUoo`00>Goo00<007ooOol00Woo00<007ooOol017oo00<0
07ooOol0ogooJGoo000iOol00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`3oOomYOol003Uo
o`03001oogoo009oo`03001oogoo00Aoool0034003]oo`00>Goo00<007ooOol00Woo00<007ooOol0
17oo00<007ooOol0ogooJGoo000iOol00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`3oOomY
Ool003Uoo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo0?moofUoo`00>Woo10001goo00<0
07ooOol0ogooJGoo0015Ool00`00Oomoo`3oOomYOol004Eoo`03001oogoo0?moofUoo`00AGoo00<0
07ooOol0ogooJGoo0015Ool00`00Oomoo`3oOomYOol004Eoo`800?moofYoo`00AGoo00<007ooOol0
ogooJGoo0015Ool00`00Oomoo`3oOomYOol004Eoo`03001oogoo0?moofUoo`00AGoo00<007ooOol0
ogooJGoo0015Ool00`00Oomoo`3oOomYOol004Eoo`03001oogoo0?moofUoo`00AGoo00<007ooOol0
ogooJGoo0015Ool00`00Oomoo`12Ool00`00Oomoo`3oOolTOol004Eoo`8004=oo`<00?moobAoo`00
AGoo00<007ooOol0@Goo00D007ooOomoo`0006=oo`800;eoo`00AGoo00<007ooOol0@Goo00<007oo
Ool00Woo0P00H7oo00<007ooOol00`00^Woo0015Ool00`00Oomoo`11Ool00`00Oomoo`04Ool00`00
Oomoo`1LOol00`00Oomoo`04Ool3002gOol004Eoo`03001oogoo041oo`03001oogoo00Ioo`8005]o
o`03001oogoo00Qoo`<00;Aoo`00AGoo00<007ooOol0@7oo00<007ooOol027oo00<007ooOol0Egoo
00<007ooOol037oo0`00/Goo0015Ool00`00Oomoo`10Ool00`00Oomoo`09Ool2001EOol2000BOol3
002^Ool004Eoo`03001oogoo041oo`03001oogoo00]oo`03001oogoo055oo`03001oogoo01Eoo`<0
0:]oo`00AGoo00<007ooOol0?goo00<007ooOol03Goo0P00D7oo00<007ooOol06Goo0P00ZGoo0015
Ool20010Ool00`00Oomoo`0?Ool00`00Oomoo`1<Ool00`00Oomoo`0LOol2002WOol004Eoo`03001o
ogoo03moo`03001oogoo011oo`8004]oo`03001oogoo01moo`800:Eoo`00AGoo00<007ooOol0?Woo
00<007ooOol04goo00<007ooOol0Agoo00<007ooOol08Woo00<007ooOol0XWoo0015Ool00`00Oomo
o`0nOol00`00Oomoo`0DOol2000YOol2000KOol00`00Oomoo`0TOol2002ROol004Eoo`03001oogoo
03ioo`03001oogoo01Ioo`03001oogoo02Eoo`03001oogoo00<001Moo`03001oogoo02Moo`800:1o
o`00AGoo00<007ooOol0?Goo00<007ooOol067oo00<007ooOol08goo00<007ooOol017oo0`004goo
00<007ooOol0:Woo00<007ooOol0WGoo0015Ool00`00Oomoo`0mOol00`00Oomoo`0IOol00`00Oomo
o`0QOol00`00Oomoo`08Ool3000>Ool2000^Ool2002MOol004Eoo`03001oogoo03eoo`03001oogoo
01Yoo`03001oogoo01moo`03001oogoo00aoo`<000Yoo`03001oogoo031oo`8009]oo`00AGoo00<0
07ooOol0?Goo00<007ooOol06goo00<007ooOol07Goo00<007ooOol047oo0`001Woo00<007ooOol0
<goo00<007ooOol0V7oo0015Ool2000mOol00`00Oomoo`0MOol00`00Oomoo`0KOol00`00Oomoo`0D
Ool30002Ool00`00Oomoo`0eOol2002HOol004Eoo`03001oogoo03aoo`03001oogoo01ioo`03001o
ogoo01Uoo`03001oogoo01Qoo`8003Yoo`8009Ioo`00AGoo00<007ooOol0?7oo00<007ooOol07goo
00<007ooOol05goo00<007ooOol0Egoo00<007ooOol0>goo00<007ooOol0EGoo0015Ool00`00Oomo
o`0kOol00`00Oomoo`0QOol00`00Oomoo`0EOol00`00Oomoo`1IOol00`00Oomoo`0hOol200000goo
001oo`1EOol004Eoo`0300003`0?03/03`0300003`0?02803`0300003`0?01803`8005d03`030000
3`0?03D03`8000@03`0300003`0?01P03c]oo`00:7oo10001Woo0P001Woo10001goo00<007ooOol0
>goo00<007ooOol08goo0P004Goo00<007ooOol0GWoo0P00<goo0P001Woo00<007ooOol0Dgoo000W
Ool00`00Oomoo`02Ool00`00Oomoo`03Ool20005Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00
Oomoo`0jOol00`00Oomoo`0VOol00`00Oomoo`0=Ool00`00Oomoo`1QOol00`00Oomoo`0^Ool20009
Ool00`00Oomoo`1BOol002Moo`03001oogoo009oo`03001oogoo00moo`03001oogoo00Aoo`03001o
ogoo03Yoo`03001oogoo02Moo`03001oogoo00]oo`03001oogoo06=oo`03001oogoo02aoo`03001o
ogoo00Yoo`03001oogoo055oo`009goo00<007ooOol00Woo00<007ooOol03goo00<007ooOol017oo
00<007ooOol0>Woo00<007ooOol0:7oo00<007ooOol02Goo00<007ooOol0IGoo00<007ooOol0:Goo
0P003Woo00<007ooOol0D7oo000WOol00`00Oomoo`02Ool00`00Oomoo`0?Ool00`00Oomoo`04Ool3
000iOol00`00Oomoo`0ZOol00`00Oomoo`07Ool00`00Oomoo`1WOol00`00Oomoo`0VOol2000@Ool0
0`00Oomoo`1@Ool002Moo`03001oogoo009oo`03001oogoo00]oo`@000Moo`03001oogoo03Uoo`03
001oogoo02]oo`03001oogoo00Eoo`03001oogoo06Uoo`03001oogoo02=oo`8001=oo`03001oogoo
04moo`009goo00<007ooOol00Woo00<007ooOol02goo00<007ooOol027oo00<007ooOol0>Goo00<0
07ooOol0;7oo00<007ooOol00goo00<007ooOol0Jgoo0P008Goo0P005Woo00<007ooOol0CWoo000W
Ool00`00Oomoo`02Ool00`00Oomoo`0;Ool00`00Oomoo`08Ool00`00Oomoo`0iOol00`00Oomoo`0]
Ool01@00Oomoogoo0000L7oo00<007ooOol077oo0P006Goo00<007ooOol0CGoo000XOol4000>Ool5
0006Ool00`00Oomoo`0hOol00`00Oomoo`0_Ool00`00Ool0001bOol00`00Oomoo`0IOol2000LOol0
0`00Oomoo`1<Ool004Eoo`03001oogoo03Qoo`03001oogoo031oo`03001oogoo079oo`03001oogoo
01Eoo`<001ioo`03001oogoo04aoo`00AGoo00<007ooOol0>7oo00<007ooOol0YWoo00<007ooOol0
4Goo0`008Woo00<007ooOol0Bgoo0015Ool00`00Oomoo`0gOol00`00Oomoo`2XOol00`00Oomoo`0=
Ool3000VOol00`00Oomoo`1:Ool004Eoo`03001oogoo03Moo`03001oogoo0:Uoo`8000Yoo`<002Yo
o`03001oogoo04Uoo`00AGoo0P00>7oo00<007ooOol0Zgoo00<007ooOol017oo0`00;Goo00<007oo
Ool0BGoo0015Ool00`00Oomoo`0fOol00`00Oomoo`2]Ool00`00Oomoo`03000aOol00`00Oomoo`18
Ool004Eoo`03001oogoo03Ioo`03001oogoo0:ioo`8003Eoo`03001oogoo04Moo`00AGoo00<007oo
Ool0=Woo00<007ooOol0iWoo00<007ooOol0AWoo000GOol00`00Oomoo`04Ool00`00Oomoo`0TOol0
0`00Oomoo`0fOol00`00Oomoo`3WOol00`00Oomoo`15Ool001Moo`P002Ioo`03001oogoo03Eoo`03
001oogoo0>Qoo`03001oogoo04Eoo`005goo0P001Goo00<007ooOol097oo00<007ooOol0=Goo00<0
07ooOol0jGoo00<007ooOol0A7oo000IOol3000YOol00`00Oomoo`0eOol00`00Oomoo`3ZOol00`00
Oomoo`13Ool001aoo`03001oogoo02Ioo`03001oogoo03Aoo`03001oogoo0>aoo`03001oogoo049o
o`006Goo0`00:Goo0P006Woo00<007ooOol067oo00<007ooOol0k7oo00<007ooOol0@Woo000GOol2
0005Ool00`00Oomoo`0TOol00`00Oomoo`0JOol00`00Oomoo`0GOol00`00Oomoo`3]Ool00`00Oomo
o`11Ool001Moo`P002Ioo`03001oogoo01]oo`03001oogoo01Eoo`03001oogoo0>moo`03001oogoo
041oo`005goo00<007ooOol017oo00<007ooOol097oo00<007ooOol077oo00<007ooOol057oo00<0
07ooOol0ogoo<goo0015Ool00`00Oomoo`0LOol00`00Oomoo`0DOol00`00Oomoo`3oOolcOol001Mo
o`03001oogoo00Aoo`03001oogoo02Aoo`03001oogoo01eoo`03001oogoo019oo`03001oogoo0?mo
ocAoo`005goo20009Woo00<007ooOol07Woo00<007ooOol04Goo00<007ooOol0ogoo=7oo000GOol0
1@00Oomoogoo00000Woo00<007ooOol097oo00<007ooOol07goo00<007ooOol047oo00<007ooOol0
ogoo=7oo000GOol01@00Oomoogoo0000:Goo00<007ooOol087oo00<007ooOol03goo00<007ooOol0
ogoo=7oo000GOol01@00Oomoogoo0000:Goo0P008Woo00<007ooOol03Goo00<007ooOol0ogoo=Goo
000HOol300000goo001oo`0WOol00`00Oomoo`0ROol00`00Oomoo`0<Ool00`00Oomoo`3oOoleOol0
01eoo`8002Ioo`03001oogoo02=oo`03001oogoo00]oo`03001oogoo0?moocEoo`007Woo00<007oo
Ool097oo00<007ooOol08goo00<007ooOol02Woo00<007ooOol0ogoo=Woo0015Ool00`00Oomoo`0T
Ool00`00Oomoo`09Ool00`00Oomoo`3oOolfOol004Eoo`03001oogoo02Eoo`03001oogoo00Qoo`03
001oogoo0?moocIoo`00AGoo00<007ooOol09Woo00<007ooOol01Woo00<007ooOol0ogoo=goo0015
Ool00`00Oomoo`0WOol00`00Oomoo`05Ool00`00Oomoo`3oOolgOol004Eoo`03001oogoo02Qoo`03
001oogoo00Aoo`03001oogoo0?moocMoo`00AGoo0P00:Woo00<007ooOol00goo00<007ooOol0ogoo
=goo0015Ool00`00Oomoo`0ZOol01@00Oomoogoo0000ogoo>Woo0015Ool00`00Oomoo`0ZOol01@00
Oomoogoo0000ogoo>Woo0015Ool00`00Oomoo`0[Ool01000Oomoo`00ogoo>Woo0015Ool00`00Oomo
o`0/Ool2003oOolkOol004Eoo`03001oogoo02eoo`03001oogoo0?moocUoo`00>Goo1`001Goo00<0
07ooOol0ogooJGoo000lOol00`00Oomoo`06Ool00`00Oomoo`3oOomYOol003aoo`03001oogoo00Io
o`03001oogoo0?moofUoo`00?7oo00<007ooOol01Woo0`00ogooJGoo000lOol00`00Oomoo`06Ool0
0`00Oomoo`3oOomYOol003aoo`03001oogoo00Ioo`03001oogoo0?moofUoo`00?7oo00<007ooOol0
1Woo00<007ooOol0ogooJGoo000jOol30008Ool00`00Oomoo`3oOomYOol003aoo`03001oogoo00Io
o`03001oogoo0?moofUoo`00AGoo00<007ooOol0ogooJGoo0015Ool00`00Oomoo`3oOomYOol004Eo
o`03001oogoo0?moofUoo`00AGoo0P00ogooJWoo0015Ool00`00Oomoo`3oOomYOol004Eoo`03001o
ogoo0?moofUoo`00AGoo00<007ooOol0ogooJGoo0015Ool00`00Oomoo`3oOomYOol004Eoo`03001o
ogoo0?moofUoo`00AGoo00<007ooOol0ogooJGoo0015Ool00`00Oomoo`3oOomYOol004Eoo`03001o
ogoo0?moofUoo`00AGoo0P00ogooJWoo0015Ool00`00Oomoo`3oOomYOol004Eoo`03001oogoo0?mo
ofUoo`00AGoo00<007ooOol0ogooJGoo0015Ool00`00Oomoo`3oOomYOol004Eoo`03001oogoo0?mo
ofUoo`00AGoo00<007ooOol0ogooJGoo0015Ool00`00Oomoo`3oOomYOol004Eoo`03001oogoo0?mo
ofUoo`00AGoo0P00ogooJWoo0015Ool00`00Oomoo`3oOomYOol004Eoo`03001oogoo0?moofUoo`00
AGoo00<007ooOol0ogooJGoo0015Ool00`00Oomoo`3oOomYOol004Eoo`03001oogoo0?moofUoo`00
AGoo00<007ooOol0ogooJGoo0015Ool00`00Oomoo`3oOomYOol004Eoo`03001oogoo0?moofUoo`00
AGoo00<007ooOol0ogooJGoo0015Ool2003oOomZOol004Eoo`03001oogoo0?moofUoo`00AGoo00<0
07ooOol0ogooJGoo0015Ool00`00Oomoo`3oOomYOol004Eoo`03001oogoo0?moofUoo`009goo1`00
17oo0P001Woo10001goo00<007ooOol0ogooJGoo000ZOol00`00Oomoo`05Ool20005Ool00`00Oomo
o`02Ool00`00Oomoo`04Ool00`0000l03`3o00l^00lkOol002Yoo`03001oogoo015oo`03001oogoo
00Aoo`03001oogoo0?moofUoo`00:Woo00<007ooOol04Goo00<007ooOol017oo00<007ooOol0ogoo
JGoo000ZOol00`00Oomoo`0AOol00`00Oomoo`04Ool3003oOomYOol002Yoo`03001oogoo00eoo`@0
00Moo`03001oogoo0?moofUoo`00:Woo00<007ooOol03Goo00<007ooOol027oo00<007ooOol0ogoo
JGoo000XOol3000?Ool00`00Oomoo`08Ool00`00Oomoo`3oOomYOol002Yoo`03001oogoo00eoo`D0
00Ioo`03001oogoo0?moofUoo`00AGoo00<007ooOol0ogooJGoo0015Ool00`00Oomoo`3oOomYOol0
04Eoo`03001oogoo0?moofUoo`00AGoo00<007ooOol0ogooJGoo0015Ool2003oOomZOol004Eoo`03
001oogoo0?moofUoo`00AGoo00<007ooOol0ogooJGoo0015Ool00`00Oomoo`3oOomYOol004Eoo`03
001oogoo0?moofUoo`00AGoo00<007ooOol0ogooJGoo0015Ool00`00Oomoo`3oOomYOol004Eoo`03
001oogoo0?moofUoo`00AGoo00<007ooOol0ogooJGoo0015Ool2003oOomZOol004Eoo`03001oogoo
0?moofUoo`00AGoo00<007ooOol0ogooJGoo0015Ool00`00Oomoo`3oOomYOol004Eoo`03001oogoo
0?moofUoo`00AGoo00<007ooOol0ogooJGoo0015Ool00`00Oomoo`3oOomYOol00?mook5oo`00ogoo
/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol008ioo`<00?moob1oo`00T7oo00<007oo
Ool0ogoo7Woo002@Ool00`00Oomoo`3oOolNOol0025oo`L0009oo`<0009oo`<00003Ool0000000D0
00Eoo`@0009oo`L000Aoo`D0009oo`L000aoo`03001oo`00008000Ioo`@000Aoo`<00003Ool00000
009oo`<00003Ool0000000Eoo`800?mooamoo`0097oo00<007ooOol017oo00<007ooOol00Woo00<0
07ooOol00goo00<007ooOol01Goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol017oo00D0
07ooOomoo`0000Ioo`03001oogoo00eoo`8000=oo`03001oogoo009oo`03001oogoo009oo`04001o
ogoo0003Ool20002Ool01000Oomoogoo0P001Woo0P00ogoo7goo000TOol00`00Oomoo`04Ool00`00
Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`05Ool00`00Oomoo`07Ool00`00Oomoo`04Ool01@00
Oomoogoo00001Woo00<007ooOol03Goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol01Goo
00<007ooOol00Woo00@007ooOol000Aoo`03001oogoo00=oo`04001oogoo003oOolNOol002Aoo`03
001oogoo00Aoo`03001oogoo009oo`03001oogoo00=oo`03001oogoo00Eoo`03001oogoo00Moo`03
001oogoo00Eoo`@000Ioo`03001oogoo019oo`03001oogoo009oo`03001oogoo00Eoo`03001oogoo
009oo`04001oogoo0004Ool00`00Oomoo`03Ool01000Oomoo`00ogoo7Woo000TOol00`00Oomoo`04
Ool20003Ool00`00Oomoo`03Ool00`00Oomoo`05Ool00`00Oomoo`07Ool00`00Oomoo`04Ool01@00
Oomoogoo00001Woo00<007ooOol03Woo10001Goo00<007ooOol01Goo00<007ooOol00Woo00@007oo
Ool000=oo`8000Aoo`03001oogoo009oo`03001oogoo0?mooa]oo`0097oo00<007ooOol00goo0P00
00Aoo`00000000Aoo`<000Eoo`L000=oo`<000Moo`<000Moo`03001oogoo00eoo`03001oogoo009o
o`03001oogoo00L0009oo`8000=oo`8000=oo`<00003Ool007oo009oo`<0009oo`<00?mooaaoo`00
97oo00<007ooOol05goo00<007ooOol06Goo00<007ooOol03Goo00@007ooOomoo`8000Aoo`03001o
ogoo019oo`03001oogoo0?moobEoo`008Goo1`005Woo00<007ooOol06Goo00<007ooOol03Woo0`00
00=oo`00Ool00goo00<007ooOol04Woo00<007ooOol0ogoo9Goo000fOol00`00Oomoo`0?Ool00`00
Oomoo`0=Ool3000]Ool2003oOolWOol003Ioo`03001oogoo00moo`03001oogoo0?moofIoo`00ogoo
/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo001?Ool4000Y
Ool4003oOolaOol005=oo`03001oogoo02Yoo`03001oogoo0?mooa5oo`03001oogoo01Yoo`00Dgoo
00<007ooOol0:Woo00<007ooOol0ogoo4Goo0P006goo000POol30003Ool30003Ool40006Ool20004
Ool70002Ool30002Ool30002Ool300000goo001oo`0;Ool30003Ool20003Ool50002Ool30002Ool3
0002Ool300000goo001oo`04Ool4000>Ool50004Ool40004Ool5000<Ool70002Ool30002Ool30002
Ool300000goo00000002Ool70005Ool20004Ool70003Ool300000goo00000004Ool300000goo0000
0003Ool50002Ool7000=Ool40005Ool40003Ool30002Ool30004Ool40003Ool50005Ool40003Ool7
000=Ool40003Ool30002Ool30003Ool50003Ool50006Ool40004Ool00`00Oomoo`0IOol0025oo`03
001oogoo00=oo`05001oogooOol00004Ool00`00Oomoo`03Ool20007Ool00`00Oomoo`04Ool00`00
Oomoo`02Ool01000Oomoo`000goo0P003Goo00<007ooOol00Woo00D007ooOomoo`0000=oo`03001o
ogoo009oo`03001oogoo009oo`04001oogoo0003Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`0<
Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0@Ool00`00Oomoo`04
Ool00`00Oomoo`02Ool01000Oomoo`000goo0P001Woo00<007ooOol01Woo0P001goo00<007ooOol0
0goo00@007ooOomoo`8000Aoo`04001oogooOol20003Ool01@00Oomoogoo00001Woo00<007ooOol0
3Goo00<007ooOol00Woo00D007ooOomoo`0000Aoo`05001oogooOol00004Ool00`00Oomoo`02Ool0
0`00Oomoo`02Ool01@00Oomoogoo00001goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol0
3Goo00<007ooOol00Woo00D007ooOomoo`0000Aoo`05001oogooOol00003Ool00`00Oomoo`03Ool0
0`00Oomoo`06Ool00`00Oomoo`02Ool01000Oomoogoo0P006Woo000QOol01000Oomoo`000Woo00D0
07ooOomoo`0000Aoo`03001oogoo009oo`04001oogoo0006Ool00`00Oomoo`04Ool00`00Oomoo`02
Ool01000Oomoo`0017oo00<007ooOol02goo00D007ooOomoo`0000Aoo`05001oogooOol00004Ool0
0`00Oomoo`02Ool01000Oomoo`0017oo00<007ooOol00Woo00<007ooOol04Goo00<007ooOol017oo
00<007ooOol00Woo00<007ooOol00Woo00<007ooOol047oo00<007ooOol017oo00<007ooOol00Woo
00@007ooOol000Aoo`03001oogoo00Aoo`03001oogoo00Eoo`04001oogoo0006Ool00`00Oomoo`03
Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00<007oo
Ool017oo00<007ooOol037oo00<007ooOol01goo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03
001oogoo009oo`03001oogoo00Ioo`03001oogoo00Eoo`03001oogoo009oo`03001oogoo00=oo`03
001oogoo00aoo`03001oogoo00Moo`03001oogoo009oo`05001oogooOol00003Ool00`00Oomoo`03
Ool00`00Oomoo`06Ool00`00Oomoo`0ROol0025oo`07001oo`00Ool007oo00000goo00<007ooOol0
0Woo00<007ooOol00Woo00@007ooOol000Ioo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo
0004Ool00`00Oomoo`0;Ool40006Ool40004Ool00`00Oomoo`02Ool01000Oomoo`0017oo00<007oo
Ool00Woo1P003Woo00<007ooOol017oo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol047oo
00<007ooOol017oo00<007ooOol00Woo00@007ooOol000Aoo`03001oogoo00Aoo`03001oogoo00Eo
o`04001oogoo0006Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`02
Ool00`00Oomoo`02Ool40006Ool00`00Oomoo`0<Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01@00
Oomoogoo000017oo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol01Goo00<007ooOol00Woo
00<007ooOol00goo00<007ooOol037oo00<007ooOol01goo00<007ooOol00Woo00<007ooOol00Woo
10001Goo00<007ooOol01Woo00<007ooOol08Woo000QOol01`00Ool007oo001oo`0000=oo`03001o
ogoo009oo`05001oogooOol00004Ool00`00Oomoo`03Ool00`00Oomoo`04Ool20003Ool01000Oomo
o`000goo0P003Goo00D007ooOomoo`0000Aoo`05001oogooOol00004Ool20003Ool01000Oomoo`00
0goo0P0017oo00<007ooOol00Woo00<007ooOol037oo00<007ooOol017oo00<007ooOol00Woo00<0
07ooOol00Woo0P004Goo00<007ooOol017oo0P000goo00@007ooOol000=oo`8000Ioo`03001oogoo
00Aoo`03001oogoo009oo`03001oogoo00=oo`03001oogoo00=oo`04001oogooOol20004Ool00`00
Oomoo`02Ool01@00Oomoogoo00000goo00<007ooOol017oo00<007ooOol037oo00<007ooOol01goo
00<007ooOol00Woo00@007ooOomoo`8000=oo`03001oogoo009oo`03001oogoo00Ioo`8000Ioo`03
001oogoo009oo`03001oogoo00=oo`03001oogoo00eoo`04001oogooOol20003Ool20003Ool01@00
Oomoogoo00000goo00<007ooOol00goo0P001goo00<007ooOol08Woo000QOol01`00Ool007oo001o
o`0000Aoo`@000=oo`<0009oo`<0009oo`<000Eoo`800004Ool000000004Ool300000goo0000000<
Ool01@00Oomoogoo00001Goo0`0017oo0P0000Aoo`00000000Aoo`<00003Ool0000000Aoo`@000eo
o`H000Aoo`@000Aoo`800004Ool00000000<Ool30005Ool2000017oo0000000017oo0`0000=oo`00
Ool00goo0`001Goo0`000Woo0`000Woo0`001Woo0`0000=oo`00Ool00Woo0P000goo0P0017oo0`00
1goo00<007ooOol037oo00<007ooOol00goo00<007ooOol00Woo10000goo0P0000Aoo`00000000=o
o`L000=oo`800004Ool000000004Ool40006Ool00`00Oomoo`0>Ool300000goo001oo`02Ool00`00
Ool000020005Ool30005Ool2000017oo000000000Woo1`0087oo000QOol20003Ool2000iOol01@00
Oomoogoo0000<goo00<007ooOol0=Goo00<007ooOol08Goo00<007ooOol05Woo00<007ooOol03Goo
00@007ooOomoo`8001Ioo`03001oogoo01Uoo`03001oogoo01Ioo`03001oogoo01Uoo`03001oogoo
029oo`0087oo0`000goo0`00=goo1@00=7oo00<007ooOol0=Goo00<007ooOol08Goo00<007ooOol0
5Woo00<007ooOol03Woo0`0000=oo`00Ool05Goo00<007ooOol06Goo00<007ooOol05Woo00<007oo
Ool06Goo00<007ooOol08Woo000oOol00`00Oomoo`1HOol3000POol00`00Oomoo`0@Ool20006Ool0
0`00Oomoo`0?Ool00`00Oomoo`07Ool2000FOol30015Ool3000GOol20010Ool003moo`03001oogoo
07]oo`03001oogoo01Qoo`03001oogoo00moo`03001oogoo0<=oo`00ogoo/Goo003oOonaOol00?mo
ok5oo`00\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {-3.72004, -0.693034, 
  0.0727476, 0.0165284}},
  CellTags->"Control Charts for Individual Measurements"]
}, Closed]],

Cell[OutputFormData["\<\
{{\"\", \"X\", \"MR\"}, {\"CL\", 33.5, 0.4512}, 
 {\"LCL\", 34.7, 0}, {\"UCL\", 32.3, 
  1.4744000000000002}}\
\>", "\<\
      X      MR

CL    33.5   0.4512

LCL   34.7   0

UCL   32.3   1.4744\
\>"], "Output",
  CellLabel->"Out[27]//TableForm=",
  CellTags->"Control Charts for Individual Measurements"]
}, Closed]],

Cell["Cusum Chart ", "Section",
  CellTags->"Cusum Chart"],

Cell["Introduction", "Subsection",
  PageBreakBelow->False,
  CellTags->"Cusum Chart"],

Cell[TextData[{
  "Cusum Control Chart is useful when we are interested in detecting small \
shifts. It is typically used with individual observations {",
  Cell[BoxData[
      \(TraditionalForm\`X\_1\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`X\_2\)]],
  ", ...., ",
  Cell[BoxData[
      \(TraditionalForm\`X\_n\)]],
  "}. If ",
  Cell[BoxData[
      \(TraditionalForm\`\[Mu]\_0\)]],
  " is the target of the process mean, the cumulative sum is formed by \
plotting the quantity ",
  Cell[BoxData[
      \(TraditionalForm\`C\_k\)]],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sum]\+\(j = 1\)\%k\((x\&_\_j - \[Mu]\_0)\)\)]],
  " against the sample ",
  StyleBox["k",
    FontSlant->"Italic"],
  ".  It is very effective with samples of size ",
  StyleBox["m",
    FontSlant->"Italic"],
  " = 1. In this case  \n",
  Cell[BoxData[
      \(TraditionalForm\`C\_k\)]],
  " = ",
  Cell[BoxData[
      \(TraditionalForm
      \`\((x\_k - \[Mu]\_0)\) + 
        \[Sum]\+\(j = 1\)\%\(k - 1\)\((x\_j - \[Mu]\_0)\)\)]],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`\((x\_k - \[Mu]\_0)\) - C\_\(k - 1\)\)]],
  ", with ",
  Cell[BoxData[
      \(TraditionalForm\`C\_0\)]],
  " = 0. \nBut ",
  Cell[BoxData[
      \(TraditionalForm\`C\_i\)]],
  "  is not a control chart because it doesn't have limits. The procedure to \
represent a cusum chart is using the called Tabular Cusum method. The tabular \
cusum works accumulating deviation from the target ",
  Cell[BoxData[
      \(TraditionalForm\`\[Mu]\_0\)]],
  " computing the statistics ",
  Cell[BoxData[
      \(TraditionalForm\`\(C\_i\%+\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(C\_i\%-\)\)]],
  " -called ",
  StyleBox["one-sided upper",
    FontWeight->"Bold"],
  " and ",
  StyleBox["lower cusums",
    FontWeight->"Bold"],
  ", respectively- as follows:\n",
  Cell[BoxData[
      StyleBox[
        \(\(C\_k\%+\) = 
          max[0, x\_k - \((\[Mu]\_0 + K)\)\  + \(C\_\(k - 1\)\%+\)]\),
        "InlineFormula"]]],
  ",\n",
  Cell[BoxData[
      StyleBox[
        \(\(C\_k\%-\) = 
          max[0, \((\[Mu]\_0 - K)\) - x\_k\  + \(C\_\(k - 1\)\%-\)]\),
        "InlineFormula"]]],
  "\nwith  ",
  Cell[BoxData[
      \(TraditionalForm\`\(C\_0\%+\)\)]],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`\(C\_0\%-\)\)]],
  " = 0. \n",
  StyleBox["K",
    FontFamily->"Courier New"],
  " (called ",
  StyleBox["reference value",
    FontWeight->"Bold"],
  ") is a constant often chosen in the center between the target ",
  Cell[BoxData[
      \(TraditionalForm\`\[Mu]\_0\)]],
  " and the out-of-control value ",
  Cell[BoxData[
      \(TraditionalForm\`\[Mu]\_1\)]],
  ". So, if the shift is expressed in standard deviation units as ",
  Cell[BoxData[
      \(TraditionalForm\`\[Mu]\_1\)]],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`\[Mu]\_0\)]],
  " + \[Delta]\[Sigma], them \n",
  StyleBox["K",
    FontFamily->"Courier New"],
  " = ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(\[Delta]\/2\),
          "InlineFormula"], TraditionalForm]]],
  " \[Sigma] = ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          FractionBox[
            RowBox[{"\[VerticalSeparator]", 
              RowBox[{
                RowBox[{
                  FormBox[\(\[Mu]\_1\),
                    "TraditionalForm"], " ", "-", " ", 
                  FormBox[\(\[Mu]\_0\),
                    "TraditionalForm"]}], "\[VerticalSeparator]"}]}], "2"],
          "InlineFormula"], TraditionalForm]]],
  "\nIf  ",
  Cell[BoxData[
      \(TraditionalForm\`\(C\_k\%+\)\)]],
  " or ",
  Cell[BoxData[
      \(TraditionalForm\`\(C\_k\%-\)\)]],
  " exceeds the ",
  StyleBox["decision interval",
    FontWeight->"Bold"],
  "  ",
  StyleBox["H",
    FontSlant->"Italic"],
  ", the process is considered to be out of control.  The election of ",
  StyleBox["H",
    FontSlant->"Italic"],
  " is very important. It is usually taken H = 5 \[Sigma].  ",
  Cell[BoxData[
      \(TraditionalForm\`\(C\_k\%+\)\)]],
  " or ",
  Cell[BoxData[
      \(TraditionalForm\`\(C\_k\%-\)\)]],
  " . It also is convenient to calculate ",
  Cell[BoxData[
      \(TraditionalForm\`\(N\^+\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(N\^-\)\)]],
  ". These indicate the number of consecutive periods that the cusums  ",
  Cell[BoxData[
      \(TraditionalForm\`\(C\_k\%+\)\)]],
  " or ",
  Cell[BoxData[
      \(TraditionalForm\`\(C\_k\%-\)\)]],
  " have been nonzero. "
}], "Text",
  PageBreakBelow->False,
  CellTags->"Cusum Chart"],

Cell["Cusum Chart", "Subsection",
  CellTags->"Cusum Chart"],

Cell[TextData[{
  "CusumReport[",
  StyleBox["data",
    FontSlant->"Italic"],
  ", ",
  StyleBox["mu, sig",
    FontSlant->"Italic"],
  "] \t\tgives {",
  StyleBox["k",
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`X\_k\)]],
  " ,",
  Cell[BoxData[
      \(TraditionalForm\`C\_k\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\(C\_k\%+\)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\(N\^+\)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\(C\_k\%-\)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\(N\^-\)\)]],
  "}\n\nCusumChart[",
  StyleBox["data",
    FontSlant->"Italic"],
  ", ",
  StyleBox["mu, sig, ",
    FontSlant->"Italic"],
  " ",
  StyleBox["H",
    FontSlant->"Italic"],
  "] \tplots the TabularCusum Chart and ",
  Cell[BoxData[
      \(TraditionalForm\`C\_k\)]]
}], "DefinitionBox",
  CellTags->"Cusum Chart"],

Cell["Example", "Subsection",
  CellTags->"Cusum Chart"],

Cell[BoxData[
    \(\(data3\  = 
        {9.45, 7.99, 9.29, 11.66, 12.16, 10.18, 8.04, 11.46, 9.2, 10.34, 
          9.03, 11.47, 10.51, 9.4, 10.08, 9.37, 10.62, 10.31, 8.52, 10.84, 
          10.9, 9.33, 12.29, 11.5, 10.6, 11.08, 10.38, 11.62, 11.31, 10.52};
      \)\)], "Input",
  CellLabel->"In[28]:=",
  CellTags->"Cusum Chart"],

Cell[TextData[{
  "The cusum report assuming  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Mu]\_0\)]],
  " = 10, \[Sigma] = 1 is"
}], "Text",
  CellTags->"Cusum Chart"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(\[IndentingNewLine]\)\(?CusumReport\)\)\)], "Input",
  CellLabel->"In[29]:=",
  CellTags->"Cusum Chart"],

Cell["\<\
Cusum[list,mu,sig] give k, Xk, Ck, C+,
   N+,C-,N- of the entries in list.\
\>", "Print",
  CellLabel->"From In[29]:=",
  CellTags->"Cusum Chart"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(CusumReport[data3, 10, 1]\)], "Input",
  CellLabel->"In[30]:=",
  PageWidth->WindowWidth,
  CellTags->"Cusum Chart"],

Cell[OutputFormData["\<\
{{\"k\", \"Xk\", \"Ck\", \"C+\", \"N+\", \"C-\", \"N-\"}, 
 {1, 9.45, -0.5500000000000007, 0, 0, 
  0.05000000000000071, 1}, 
 {2, 7.99, -2.5600000000000005, 0, 0, 
  1.5600000000000005, 2}, 
 {3, 9.29, -3.2700000000000014, 0, 0, 
  1.7700000000000014, 3}, 
 {4, 11.66, -1.6100000000000012, 
  1.1600000000000001, 1, 0, 0}, 
 {5, 12.16, 0.5499999999999989, 
  2.8200000000000003, 2, 0, 0}, 
 {6, 10.18, 0.7299999999999986, 2.5, 3, 0, 
  0}, {7, 8.04, -1.2300000000000022, 
  0.03999999999999915, 4, 
  1.4600000000000009, 1}, 
 {8, 11.46, 0.22999999999999865, 1., 5, 0, 
  0}, {9, 9.2, -0.5700000000000021, 0, 0, 
  0.3000000000000007, 1}, 
 {10, 10.34, -0.2300000000000022, 0, 0, 0, 
  0}, {11, 9.03, -1.2000000000000028, 0, 0, 
  0.47000000000000064, 1}, 
 {12, 11.47, 0.2699999999999978, 
  0.9700000000000006, 1, 0, 0}, 
 {13, 10.51, 0.7799999999999976, 
  0.9800000000000004, 2, 0, 0}, 
 {14, 9.4, 0.17999999999999794, 0, 0, 
  0.09999999999999964, 1}, 
 {15, 10.08, 0.259999999999998, 0, 0, 0, 
  0}, {16, 9.37, -0.37000000000000277, 0, 
  0, 0.13000000000000078, 1}, 
 {17, 10.62, 0.24999999999999645, 
  0.11999999999999922, 1, 0, 0}, 
 {18, 10.31, 0.559999999999997, 0, 0, 0, 
  0}, {19, 8.52, -0.9200000000000035, 0, 0, 
  0.9800000000000004, 1}, 
 {20, 10.84, -0.08000000000000362, 
  0.33999999999999986, 1, 0, 0}, 
 {21, 10.9, 0.8199999999999967, 
  0.7400000000000002, 2, 0, 0}, 
 {22, 9.33, 0.1499999999999968, 0, 0, 
  0.16999999999999993, 1}, 
 {23, 12.29, 2.439999999999996, 
  1.7899999999999991, 1, 0, 0}, 
 {24, 11.5, 3.939999999999996, 
  2.789999999999999, 2, 0, 0}, 
 {25, 10.6, 4.539999999999996, 
  2.889999999999999, 3, 0, 0}, 
 {26, 11.08, 5.619999999999996, 
  3.469999999999999, 4, 0, 0}, 
 {27, 10.38, 5.9999999999999964, 
  3.3499999999999996, 5, 0, 0}, 
 {28, 11.62, 7.619999999999996, 
  4.469999999999999, 6, 0, 0}, 
 {29, 11.31, 8.929999999999996, 
  5.279999999999999, 7, 0, 0}, 
 {30, 10.52, 9.449999999999996, 
  5.299999999999999, 8, 0, 0}}\
\>", "\<\
k    Xk      Ck      C+     N+   C-     N-

1    9.45    -0.55   0      0    0.05   1

2    7.99    -2.56   0      0    1.56   2

3    9.29    -3.27   0      0    1.77   3

4    11.66   -1.61   1.16   1    0      0

5    12.16   0.55    2.82   2    0      0

6    10.18   0.73    2.5    3    0      0

7    8.04    -1.23   0.04   4    1.46   1

8    11.46   0.23    1.     5    0      0

9    9.2     -0.57   0      0    0.3    1

10   10.34   -0.23   0      0    0      0

11   9.03    -1.2    0      0    0.47   1

12   11.47   0.27    0.97   1    0      0

13   10.51   0.78    0.98   2    0      0

14   9.4     0.18    0      0    0.1    1

15   10.08   0.26    0      0    0      0

16   9.37    -0.37   0      0    0.13   1

17   10.62   0.25    0.12   1    0      0

18   10.31   0.56    0      0    0      0

19   8.52    -0.92   0      0    0.98   1

20   10.84   -0.08   0.34   1    0      0

21   10.9    0.82    0.74   2    0      0

22   9.33    0.15    0      0    0.17   1

23   12.29   2.44    1.79   1    0      0

24   11.5    3.94    2.79   2    0      0

25   10.6    4.54    2.89   3    0      0

26   11.08   5.62    3.47   4    0      0

27   10.38   6.      3.35   5    0      0

28   11.62   7.62    4.47   6    0      0

29   11.31   8.93    5.28   7    0      0

30   10.52   9.45    5.3    8    0      0\
\>"], "Output",
  CellLabel->"Out[30]//TableForm=",
  PageWidth->WindowWidth,
  LineSpacing->{1, 0},
  CellTags->"Cusum Chart"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?CusumChart\)\)], "Input",
  CellLabel->"In[31]:=",
  CellTags->"Cusum Chart"],

Cell["\<\
CusumChart[list,mu,sig] plots the tabular
   cusum Chart of the entries in list.\
\>", "Print",
  CellLabel->"From In[31]:=",
  CellTags->"Cusum Chart"]
}, Closed]],

Cell[TextData[{
  "The tabular cusum chart assuming  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Mu]\_0\)]],
  " = 10, \[Sigma] = 1 and H=5 is"
}], "Text",
  CellTags->"Cusum Chart"],

Cell[CellGroupData[{

Cell[BoxData[
    \(CusumChart[\ data3, 10, 1, 5]\)], "Input",
  CellLabel->"In[32]:=",
  CellTags->"Cusum Chart"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.031746 0.309017 0.0515028 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.18254 -0.0125 -3 -9 ]
[.18254 -0.0125 3 0 ]
[.34127 -0.0125 -6 -9 ]
[.34127 -0.0125 6 0 ]
[.5 -0.0125 -6 -9 ]
[.5 -0.0125 6 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -26 -21.5625 ]
[.5 -0.0125 26 -9 ]
[-0.0125 .10301 -12 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -12 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .41202 -6 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -6 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -24.5625 -39.6875 ]
[-0.01875 .30902 -12 39.6875 ]
[.5 .63053 -59 0 ]
[.5 .63053 59 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .56653 m
1 .56653 L
s
0 .0515 m
1 .0515 L
s
0 g
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(5)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(10)] .34127 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(15)] .5 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(20)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(25)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(30)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -87 -25.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(subgroup) show
111.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .10301 m
.00625 .10301 L
s
[(-4)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-2)] -0.0125 .20601 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0)] -0.0125 .30902 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(2)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(4)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(6)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .02575 m
.00375 .02575 L
s
0 .0515 m
.00375 .0515 L
s
0 .07725 m
.00375 .07725 L
s
0 .12876 m
.00375 .12876 L
s
0 .15451 m
.00375 .15451 L
s
0 .18026 m
.00375 .18026 L
s
0 .23176 m
.00375 .23176 L
s
0 .25751 m
.00375 .25751 L
s
0 .28327 m
.00375 .28327 L
s
0 .33477 m
.00375 .33477 L
s
0 .36052 m
.00375 .36052 L
s
0 .38627 m
.00375 .38627 L
s
0 .43777 m
.00375 .43777 L
s
0 .46353 m
.00375 .46353 L
s
0 .48928 m
.00375 .48928 L
s
0 .54078 m
.00375 .54078 L
s
0 .56653 m
.00375 .56653 L
s
0 .59228 m
.00375 .59228 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -118.969 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
100.688 10.2813 translate
90 rotate
-100.688 -10.2813 translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(<) show
69.000 12.813 moveto
(-) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(C) show
87.000 9.063 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
103.688 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(C) show
109.688 9.063 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(+) show
120.375 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(->) show
138.375 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .30902 m
1 .30902 L
s
gsave
.5 .63053 -120 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Cusum) show
99.000 12.813 moveto
(Control) show
147.000 12.813 moveto
(chart) show
177.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.05556 .30644 m
.0873 .22867 L
.11905 .21786 L
.15079 .36876 L
.18254 .45425 L
.21429 .43777 L
.24603 .23588 L
.27778 .36052 L
.30952 .29357 L
.34127 .30902 L
.37302 .28481 L
.40476 .35897 L
.43651 .35949 L
.46825 .30387 L
.5 .30902 L
.53175 .30232 L
.56349 .3152 L
.59524 .30902 L
.62698 .25854 L
.65873 .32653 L
.69048 .34713 L
.72222 .30026 L
.75397 .40121 L
.78571 .45271 L
.81746 .45786 L
.84921 .48773 L
.88095 .48155 L
.9127 .53923 L
.94444 .58095 L
.97619 .58198 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[32]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012Q000`40O003h00Oogoo/Goo003oOona
Ool00?mook5oo`00iGoo10007goo0`00YGoo003YOol00`00Oomoo`0MOol00`00Oomoo`2TOol00>Uo
o`03001oogoo01eoo`03001oogoo0:Aoo`00bWoo1@001Goo0`0000Aoo`00001oo`800004Ool00000
0004Ool300000goo001oo`03Ool50005Ool40005Ool300000goo00000002Ool00`00Ool00002002R
Ool00<Yoo`03001oogoo009oo`05001oogooOol00003Ool20003Ool20003Ool01000Oomoo`000goo
0P001Goo00<007ooOol01Goo00<007ooOol00Woo00D007ooOomoo`0000=oo`8000=oo`8000=oo`03
001oogoo09moo`00cgoo00D007ooOomoo`0000Aoo`05001oogooOol00004Ool01000Oomoo`0017oo
00<007ooOol00goo00<007ooOol01Goo00<007ooOol00Woo00D007ooOomoo`0000Aoo`05001oogoo
Ool00004Ool00`00Oomoo`2OOol00<]oo`@000Aoo`03001oogoo009oo`05001oogooOol00004Ool0
1000Oomoo`0017oo00<007ooOol00goo00<007ooOol01Goo00<007ooOol00Woo00D007ooOomoo`00
00Aoo`05001oogooOol00004Ool00`00Oomoo`2OOol00<Yoo`03001oogoo009oo`05001oogooOol0
0004Ool01000Oomoogoo0P000goo00@007ooOol000=oo`8000Eoo`8000Ioo`03001oogoo009oo`05
001oogooOol00004Ool01000Oomoogoo0P000goo00<007ooOol0Wgoo003;Ool50002Ool20003Ool2
0003Ool00`00Ool000020004Ool300000goo00000003Ool2000017oo0000000017oo10000goo0P00
0goo0P000Woo0P0000Aoo`0000000:9oo`00g7oo00<007ooOol0dGoo003LOol00`00Oomoo`3AOol0
0=]oo`800==oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol004]oo`@0035o
o`@002]oo`L000=oo`@002Moo`L000=oo`@002Moo`H000Aoo`@002Moo`H000Aoo`@002Qoo`@000Eo
o`@001moo`00BWoo00<007ooOol00Woo00<007ooOol0;Goo00<007ooOol00Woo00<007ooOol0:goo
00<007ooOol00goo00<007ooOol00Woo00<007ooOol09goo00<007ooOol00goo00<007ooOol00Woo
00<007ooOol097oo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo02Aoo`03001oogoo
009oo`05001oogooOol00004Ool00`00Oomoo`0TOol00`00Oomoo`02Ool01@00Oomoogoo000017oo
00<007ooOol077oo001:Ool00`00Oomoo`02Ool00`00Oomoo`0bOol00`00Oomoo`0[Ool00`00Oomo
o`03Ool00`00Oomoo`02Ool00`00Oomoo`0WOol00`00Oomoo`08Ool00`00Oomoo`0UOol00`00Oomo
o`05Ool00`00Oomoo`02Ool00`00Oomoo`0UOol00`00Oomoo`0:Ool00`00Oomoo`0YOol01@00Oomo
ogoo000017oo00<007ooOol077oo001:Ool00`00Oomoo`02Ool00`00Oomoo`0bOol00`00Oomoo`0[
Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`0WOol00`00Oomoo`08Ool00`00Oomoo`0V
Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`0VOol00`00Oomoo`09Ool00`00Oomoo`0Y
Ool01@00Oomoogoo000017oo00<007ooOol077oo001:Ool00`00Oomoo`02Ool00`00Oomoo`0bOol0
0`00Oomoo`0[Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`0WOol00`00Oomoo`08Ool0
0`00Oomoo`0WOol00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`0WOol00`00Oomoo`08Ool0
0`00Oomoo`0WOol20004Ool00`00Oomoo`02Ool00`00Oomoo`0LOol004Yoo`03001oogoo009oo`03
001oogoo02ioo`@002ioo`03001oogoo00=oo`03001oogoo009oo`03001oogoo02Moo`03001oogoo
00Aoo`@002]oo`03001oogoo009oo`03001oogoo009oo`03001oogoo02Qoo`03001oogoo00=oo`@0
02aoo`05001oogooOol00004Ool00`00Oomoo`0LOol004Yoo`03001oogoo009oo`03001oogoo02io
o`03001oogoo02moo`03001oogoo00=oo`03001oogoo009oo`03001oogoo02Moo`03001oogoo00Ao
o`03001oogoo02Qoo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`0TOol00`00Oomo
o`02Ool00`00Oomoo`02Ool00`00Oomoo`0]Ool01@00Oomoogoo000017oo00<007ooOol077oo001:
Ool00`00Oomoo`02Ool00`00Oomoo`0^Ool00`00Oomoo`0]Ool30005Ool00`00Oomoo`02Ool00`00
Oomoo`0UOol30006Ool00`00Oomoo`0XOol00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007oo
Ool097oo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol0:7oo00<007ooOol00Woo00D007oo
Oomoo`0000Aoo`03001oogoo01aoo`00Bgoo1000<Goo1@00;Goo00<007ooOol017oo1000:Woo00<0
07ooOol017oo1@009goo10001Goo1000:7oo10001Goo1@009goo10001Goo10007goo003oOonaOol0
0?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol004Eoool0050001ao
o`00AGoo00<007ooOol01Goo00<007ooOol027oo00<007ooOol01goo00<007ooOol027oo00<007oo
Ool01goo00<007ooOol027oo00<007ooOol027oo00<007ooOol01goo00<007ooOol027oo00<007oo
Ool01goo00<007ooOol027oo00<007ooOol027oo00<007ooOol01goo00<007ooOol027oo00<007oo
Ool01goo00<007ooOol027oo00<007ooOol027oo00<007ooOol01goo00<007ooOol027oo00<007oo
Ool01goo00<007ooOol027oo00<007ooOol027oo00<007ooOol01goo00<007ooOol027oo00<007oo
Ool01goo00<007ooOol027oo00<007ooOol027oo00<007ooOol01goo00<007ooOol027oo00<007oo
Ool01goo00<007ooOol027oo00<007ooOol08Woo0015Ool00`00Oomoo`05Ool00`00Oomoo`0bOol0
0`00Oomoo`0bOol00`00Oomoo`0bOol00`00Oomoo`0bOol00`00Oomoo`0bOol00`00Oomoo`0bOol0
0`00Oomoo`0ROol004Eoo`03001oogoo0?moofUoo`00AGoo00<007ooOol0ogooJGoo0015Ool00`00
Oomoo`3oOomYOol004Eoo`03001oogoo0?moofUoo`00AGoo00<007ooOol0ogooJGoo0015Ool00`00
Oomoo`3oOomYOol004Eoo`800?moofYoo`00AGoo00<007ooOol0ogooJGoo0015Ool00`00Oomoo`3o
OomYOol004Eoo`03001oogoo0?moofUoo`00AGoo00<007ooOol0ogooJGoo0015Ool00`00Oomoo`3o
OomYOol004Eoo`03001oogoo0?moofUoo`00AGoo00<007ooOol0ogooJGoo0015Ool2003o00m>00lL
Ool004Eoo`03001oogoo0?moofUoo`00AGoo00<007ooOol0ogooJGoo0015Ool00`00Oomoo`3oOomY
Ool004Eoo`03001oogoo0?moofUoo`00AGoo00<007ooOol0ogooJGoo0015Ool00`00Oomoo`3oOomY
Ool004Eoo`03001oogoo0?moofUoo`00AGoo00<007ooOol0ogooJGoo0015Ool2003oOomZOol004Eo
o`03001oogoo0?moofUoo`00AGoo00<007ooOol0ogooJGoo0015Ool00`00Oomoo`3oOomYOol004Eo
o`03001oogoo0?moofUoo`00>goo10001Woo00<007ooOol0ogooJGoo000mOol00`00Oomoo`05Ool0
0`00Oomoo`3oOomYOol003eoo`03001oogoo00Eoo`03001oogoo0?moofUoo`00>Goo1P001Woo00<0
07ooOol0ogooJGoo000`Ool60004Ool01000Oomoo`001goo0`00ogooJGoo000jOol01000Oomoo`00
1goo00<007ooOol0ogooJGoo000kOol00`00Ool00007Ool00`00Oomoo`3oOomYOol003]oo`03001o
o`0000Moo`03001oogoo0?moofUoo`00?7oo0P001goo00<007ooOol0ogooJGoo0015Ool00`00Oomo
o`3oOomYOol004Eoo`03001oogoo0?moofUoo`00AGoo00<007ooOol0ogooJGoo0015Ool2003oOomZ
Ool004Eoo`03001oogoo0?moofUoo`00AGoo00<007ooOol0ogooJGoo0015Ool00`00Oomoo`3oOomY
Ool004Eoo`03001oogoo0?moofUoo`00AGoo00<007ooOol0ogooJGoo000SOol00`00Oomoo`0OOol0
0`00Oomoo`3oOomYOol002=oo`03001oogoo01moo`03001oogoo0?moofUoo`008Woo00<007oo0000
87oo00<007ooOol0ogooJGoo000QOol01@00Oomoogoo00007goo0P00ogooJWoo000QOol01@00Oomo
ogoo00007goo00<007ooOol0ogooJGoo000POol00`00Oomoo`03Ool00`00Oomoo`0LOol00`00Oomo
o`3oOomYOol004Eoo`03001oogoo0?moofUoo`00AGoo00<007ooOol0ogooJGoo0015Ool00`00Oomo
o`3oOomYOol004Eoo`03001oogoo0?moofUoo`008goo00<007ooOol07goo00<007ooOol0ogooJGoo
000SOol00`00Oomoo`0OOol2003oOomZOol002=oo`03001oogoo01moo`03001oogoo0?moofUoo`00
8goo00<007ooOol07goo00<007ooOol0ogooJGoo000SOol00`00Oomoo`0OOol00`00Oomoo`3oOomY
Ool002=oo`03001oogoo01moo`03001oogoo0?moofUoo`00>Goo1P001Woo00<007ooOol0ogooJGoo
000iOol00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`3oOomYOol003Yoo`03001oogoo00Qo
o`03001oogoo0?moofUoo`00>goo00<007ooOol01goo00<007ooOol0ogooJGoo000`Ool60006Ool0
0`00Oomoo`06Ool3003oOomYOol003eoo`03001oogoo00Eoo`03001oogoo0?moofUoo`00>Goo00<0
07ooOol00Woo00<007ooOol017oo00<007ooOol0ogooJGoo000iOol00`00Oomoo`02Ool00`00Oomo
o`04Ool00`00Oomoo`3oOomYOol003Yoo`@000Moo`03001oogoo02Aoo`800?mood=oo`00AGoo00<0
07ooOol087oo100000=oo`00Ool0ogoo@Woo0015Ool00`00Oomoo`0LOol40005Ool00`00Oomoo`3o
Oom1Ool0025oo`@0021oo`03001oogoo01Yoo`8000Yoo`03001oogoo0?mood1oo`0087oo00<007oo
Ool00Woo00<007ooOol07Goo00<007ooOol06Woo00<007ooOol02Goo00<007ooOol0ogoo@7oo000O
Ool00`00Oomoo`04Ool00`00Oomoo`0LOol2000JOol00`00Oomoo`0:Ool00`00Oomoo`3oOom0Ool0
01moo`03001oogoo00Aoo`03001oogoo01aoo`03001oogoo01Uoo`03001oogoo00Yoo`03001oogoo
02Ioo`03001oogoo0?mooaMoo`007goo00<007ooOol017oo00<007ooOol077oo00<007ooOol067oo
00<007ooOol02goo00<007ooOol09Woo00<007ooOol0ogoo5goo000POol00`00Oomoo`03Ool00`00
Oomoo`0LOol00`00Oomoo`0HOol00`00Oomoo`0<Ool00`00Oomoo`0UOol2003oOolHOol001moo`<0
00=oo`03001oogoo01eoo`03001oogoo01Qoo`03001oogoo00aoo`03001oogoo02Eoo`800?mooaQo
o`00AGoo00<007ooOol05goo00<007ooOol03Goo00<007ooOol097oo00<007oo0000ogoo67oo0015
Ool00`00Oomoo`0GOol00`00Oomoo`0=Ool00`00Oomoo`0TOol00`00Ool0003oOolHOol001moo`03
001oogoo02=oo`03001oogoo01Moo`03001oogoo00eoo`03001oogoo02Aoo`04001oogoo003oOolG
Ool001moo`03001oogoo02=oo`8001Moo`03001oogoo00moo`03001oogoo02=oo`04001oogoo001l
Ool00`00Oomoo`2GOol001moo`03001oogoo02=oo`03001oogoo01Ioo`03001oogoo00moo`03001o
ogoo02=oo`04001oogoo001kOol2002IOol001moo`03001oogoo02=oo`03001oogoo01Eoo`03001o
ogoo011oo`03001oogoo02=oo`04001oogoo001kOol00`00Ool0002HOol001moo`03001oogoo02=o
o`03001oogoo01Eoo`03001oogoo011oo`03001oogoo02=oo`05001oogooOol0001iOol01000Oomo
o`00V7oo0015Ool00`00Oomoo`0EOol00`00Oomoo`0@Ool00`00Oomoo`0ROol00`00Oomoo`02Ool0
0`00Oomoo`1gOol01@00Oomoogoo0000Ugoo0015Ool00`00Oomoo`0DOol00`00Oomoo`0BOol00`00
Oomoo`0QOol00`00Oomoo`02Ool00`00Oomoo`1fOol00`00Oomoo`02Ool00`00Oomoo`2EOol004Eo
o`03001oogoo01Aoo`03001oogoo019oo`03001oogoo025oo`03001oogoo009oo`03001oogoo07Eo
o`03001oogoo00Aoo`03001oogoo09Aoo`00AGoo00<007ooOol04goo00<007ooOol04goo00<007oo
Ool08Goo00<007ooOol00goo00<007ooOol0M7oo00<007ooOol017oo00<007ooOol0U7oo0015Ool0
0`00Oomoo`0COol00`00Oomoo`0COol00`00Oomoo`0QOol00`00Oomoo`03Ool00`00Oomoo`1cOol0
0`00Oomoo`06Ool00`00Oomoo`2COol004Eoo`8001Aoo`03001oogoo01=oo`03001oogoo025oo`03
001oogoo00=oo`03001oogoo02Aoo`03001oogoo04aoo`03001oogoo00Ioo`03001oogoo09=oo`00
AGoo00<007ooOol04Woo00<007ooOol05Goo00<007ooOol07goo00<007ooOol017oo00<007ooOol0
8Woo0`00CGoo00<007ooOol027oo00<007ooOol0TWoo0015Ool00`00Oomoo`0BOol00`00Oomoo`0E
Ool00`00Oomoo`0OOol00`00Oomoo`05Ool00`00Oomoo`0POol01@00Oomoogoo0000C7oo00<007oo
Ool027oo00<007ooOol0TWoo0015Ool00`00Oomoo`0BOol00`00Oomoo`0EOol00`00Oomoo`0OOol0
0`00Oomoo`05Ool00`00Oomoo`0=Ool2000@Ool00`00Oomoo`02Ool00`00Oomoo`19Ool00`00Oomo
o`0:Ool00`00Oomoo`2AOol004Eoo`03001oogoo015oo`03001oogoo01Ioo`03001oogoo01moo`03
001oogoo00Eoo`03001oogoo00eoo`04001oo`00000<Ool20006Ool00`00Oomoo`17Ool00`00Oomo
o`0;Ool00`00Oomoo`2AOol003Yoo`@000Moo`03001oogoo015oo`03001oogoo01Ioo`03001oogoo
01moo`03001oogoo00Eoo`03001oogoo00aoo`03001oogoo009oo`8000Uoo`03001oogoo00Ioo`03
001oogoo04Moo`03001oogoo00aoo`03001oogoo01Ioo`03001oogoo07Moo`00>Goo00<007ooOol0
0Woo00<007ooOol017oo00<007ooOol047oo00<007ooOol067oo00<007ooOol07Woo00<007ooOol0
1Woo00<007ooOol02goo00<007ooOol017oo0P001Woo00<007ooOol01goo00<007ooOol0;Woo1000
57oo00<007ooOol03Goo00<007ooOol05Goo0P00NGoo000iOol00`00Oomoo`02Ool00`00Oomoo`04
Ool00`00Oomoo`0@Ool00`00Oomoo`0HOol00`00Oomoo`0NOol00`00Oomoo`06Ool00`00Oomoo`0:
Ool00`00Oomoo`07Ool20002Ool2000;Ool00`00Oomoo`0IOol60008Ool60004Ool2000BOol00`00
Oomoo`0>Ool00`00Oomoo`0DOol00`00Ool0001hOol003Uoo`03001oogoo009oo`03001oogoo00Ao
ool0050001aoo`00>Goo00<007ooOol00Woo00<007ooOol017oo00<007ooOol0:goo00<007ooOol0
7Goo00<007ooOol027oo00<007ooOol027oo00<007ooOol06Woo00<007ooOol05goo00<007ooOol0
6goo0P0017oo1P005Goo00<007ooOol04Woo00@007ooOol007Qoo`00>Goo00<007ooOol00Woo00<0
07ooOol017oo00<007ooOol0:goo00<007ooOol07Goo00<007ooOol027oo00<007ooOol027oo00<0
07ooOol06Woo00<007ooOol05Woo00<007ooOol07Woo10006goo00<007ooOol04Goo00<007ooOol0
0Woo00<007ooOol0MGoo000iOol00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`0/Ool00`00
Oomoo`0LOol00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`0JOol00`00Oomoo`0FOol00`00
Oomoo`0nOol00`00Oomoo`0?Ool00`00Oomoo`03Ool00`00Oomoo`1eOol003Uoo`03001oogoo009o
o`03001oogoo00Aoo`03001oogoo02aoo`03001oogoo01aoo`03001oogoo00Qoo`03001oogoo00Mo
o`03001oogoo01aoo`03001oogoo01Aoo`03001oogoo03moo`03001oogoo00moo`03001oogoo00=o
o`03001oogoo07Eoo`00>Woo10001goo00<007ooOol0;7oo00<007ooOol077oo00<007ooOol02Goo
00<007ooOol01Woo00<007ooOol077oo00<007ooOol057oo00<007ooOol0@7oo00<007ooOol03Goo
00<007ooOol01Goo00<007ooOol0M7oo0015Ool00`00Oomoo`0/Ool00`00Oomoo`0LOol00`00Oomo
o`09Ool00`00Oomoo`05Ool00`00Oomoo`0NOol00`00Oomoo`0BOol00`00Oomoo`11Ool00`00Oomo
o`0<Ool00`00Oomoo`06Ool00`00Oomoo`1dOol0025oo`@0021oo`03001oogoo02aoo`03001oogoo
01]oo`03001oogoo00Yoo`03001oogoo00Eoo`03001oogoo01ioo`03001oogoo019oo`03001oogoo
049oo`8000aoo`03001oogoo00Ioo`03001oogoo07Aoo`0087oo00<007ooOol00Woo00<007ooOol0
7Goo00<007ooOol0;Goo00<007ooOol06Woo00<007ooOol02Woo00<007ooOol017oo00<007ooOol0
7goo00<007ooOol04Goo00<007ooOol0AGoo00<007ooOol027oo00<007ooOol027oo00<007ooOol0
Lgoo000OOol00`00Oomoo`04Ool00`00Oomoo`0LOol2000^Ool00`00Oomoo`0JOol00`00Oomoo`0;
Ool00`00Oomoo`03Ool00`00Oomoo`0POol00`00Oomoo`0?Ool00`00Oomoo`17Ool20008Ool00`00
Oomoo`08Ool00`00Oomoo`1cOol001moo`03001oogoo00Aoo`03001oogoo01aoo`03001oogoo02eo
o`03001oogoo01Yoo`03001oogoo00]oo`03001oogoo009oo`03001oogoo025oo`03001oogoo00mo
o`03001oogoo04Uoo`8000Eoo`03001oogoo00Uoo`03001oogoo07=oo`007goo00<007ooOol017oo
00<007ooOol077oo00<007ooOol0;Goo00<007ooOol06Woo00<007ooOol02goo00<007ooOol00Woo
00<007ooOol08Woo00<007ooOol03Goo00<007ooOol0C7oo00D007ooOomoo`0000eoo`03001oogoo
079oo`0087oo00<007ooOol00goo00<007ooOol077oo00<007ooOol0;Goo00<007ooOol06Woo00<0
07ooOol02goo00<007ooOol00Woo00<007ooOol08Woo00<007ooOol03Goo00<007ooOol0CGoo0P00
00=oo`00Ool037oo00<007ooOol0LWoo000OOol30003Ool00`00Oomoo`0MOol00`00Oomoo`0^Ool0
0`00Oomoo`0HOol00`00Oomoo`0=Ool01000Oomoo`009Goo00<007ooOol037oo00<007ooOol0D7oo
00<007ooOol037oo00<007ooOol0LWoo0015Ool00`00Oomoo`0^Ool00`00Oomoo`0HOol00`00Oomo
o`0=Ool01000Oomoo`009Woo00<007ooOol02goo00<007ooOol0Ggoo00<007ooOol0LWoo0015Ool0
0`00Oomoo`0^Ool00`00Oomoo`0HOol00`00Oomoo`0=Ool00`00Ool0000WOol00`00Oomoo`0:Ool0
0`00Oomoo`1QOol00`00Oomoo`1aOol001moo`03001oogoo02=oo`03001oogoo02ioo`03001oogoo
01Qoo`03001oogoo00eoo`03001oo`0002Qoo`03001oogoo00Uoo`03001oogoo065oo`03001oogoo
075oo`007goo00<007ooOol08goo00<007ooOol0;Woo00<007ooOol067oo00<007ooOol03Woo00<0
07ooOol09goo3000I7oo00<007ooOol0LGoo000MOol5000SOol2000`Ool00`00Oomoo`0GOol00`00
Oomoo`0>Ool00`00Oomoo`2HOol00`00Oomoo`1`Ool001moo`03001oogoo02=oo`03001oogoo02mo
o`03001oogoo01Moo`03001oogoo0:Uoo`03001oogoo071oo`007goo00<007ooOol08goo00<007oo
Ool0;goo00<007ooOol05Woo00<007ooOol0ZWoo00<007ooOol0L7oo0015Ool00`00Oomoo`0_Ool0
0`00Oomoo`0FOol00`00Oomoo`2[Ool00`00Oomoo`1_Ool004Eoo`03001oogoo031oo`03001oogoo
01Eoo`03001oogoo0:]oo`03001oogoo06moo`00AGoo00<007ooOol0<7oo00<007ooOol05Goo00<0
07ooOol0Zgoo00<007ooOol0Kgoo0015Ool00`00Oomoo`0aOol00`00Oomoo`0DOol00`00Oomoo`2/
Ool00`00Oomoo`1^Ool004Eoo`03001oogoo035oo`03001oogoo01Aoo`03001oogoo0:aoo`03001o
ogoo06ioo`00AGoo0P00<Woo00<007ooOol057oo00<007ooOol0[7oo00<007ooOol0KWoo0015Ool0
0`00Oomoo`0bOol00`00Oomoo`0BOol00`00Oomoo`2^Ool00`00Oomoo`1]Ool004Eoo`03001oogoo
039oo`03001oogoo019oo`03001oogoo0:ioo`03001oogoo06eoo`00AGoo00<007ooOol0<Woo00<0
07ooOol04Woo00<007ooOol0[Woo00<007ooOol0KGoo0015Ool00`00Oomoo`0cOol00`00Oomoo`0A
Ool00`00Oomoo`2_Ool00`00Oomoo`1/Ool003Uoo`H000Ioo`03001oogoo03=oo`03001oogoo015o
o`03001oogoo0:moo`03001oogoo06aoo`00>Goo00<007ooOol00Woo00<007ooOol017oo00<007oo
Ool0=7oo00<007ooOol047oo00<007ooOol0/7oo00<007ooOol0Jgoo000SOol00`00Oomoo`0DOol0
0`00Oomoo`08Ool00`00Oomoo`0dOol00`00Oomoo`0?Ool00`00Oomoo`2aOol00`00Oomoo`1[Ool0
02=oo`03001oogoo01Eoo`03001oogoo00Moo`03001oogoo03Aoo`03001oogoo00moo`03001oogoo
0;9oo`03001oogoo06Yoo`008goo00<007ooOol05Woo00<007ooOol01Woo0`00=Goo00<007ooOol0
3Woo00<007ooOol0/Woo00<007ooOol0JWoo000SOol00`00Oomoo`0GOol00`00Oomoo`05Ool00`00
Oomoo`0eOol00`00Oomoo`0>Ool00`00Oomoo`2cOol00`00Oomoo`1YOol002=oo`03001oogoo01=o
o`03001oogoo009oo`03001oogoo00Aoo`03001oogoo03Eoo`03001oogoo00ioo`03001oogoo0;Ao
o`03001oogoo06Qoo`008goo00<007ooOol04goo00<007ooOol00Woo00<007ooOol017oo00<007oo
Ool0=Woo00<007ooOol03Goo00<007ooOol0]7oo00<007ooOol0J7oo000jOol40007Ool00`00Oomo
o`0fOol00`00Oomoo`0=Ool00`00Oomoo`2eOol00`00Oomoo`1WOol004Eoo`03001oogoo03Moo`03
001oogoo00]oo`03001oogoo0;Ioo`03001oogoo06Moo`00AGoo00<007ooOol0=goo00<007ooOol0
2goo00<007ooOol0]goo00<007ooOol0IWoo000POol00`00Oomoo`03Ool00`00Oomoo`0LOol00`00
Oomoo`0gOol00`00Oomoo`0;Ool00`00Oomoo`2gOol00`00Oomoo`1VOol0025oo`05001oogooOol0
000OOol2000iOol00`00Oomoo`0:Ool00`00Oomoo`2hOol00`00Oomoo`1UOol0025oo`05001oogoo
Ool0000OOol00`00Oomoo`0hOol00`00Oomoo`08Ool2002lOol00`00Oomoo`1TOol0029oo`03001o
o`00021oo`03001oogoo03Qoo`03001oogoo00Ioo`800;ioo`03001oogoo06Aoo`008goo00<007oo
Ool07goo00<007ooOol0>Goo00<007ooOol00goo0P00`Goo00<007ooOol0Hgoo000SOol00`00Oomo
o`0OOol00`00Oomoo`0iOol01000Oomoogoo0P00`goo00<007ooOol0Hgoo0015Ool00`00Oomoo`0j
Ool30036Ool3001ROol004Eoo`03001oogoo03Yoo`03001oogoo0<Uoo`H005aoo`00AGoo00<007oo
Ool0ogoo3Goo0`00FGoo0015Ool00`00Oomoo`3oOol@Ool00`00Oomoo`1FOol004Eoo`800?mooa9o
o`03001oogoo05Eoo`00AGoo00<007ooOol0ogoo4Woo00<007ooOol0E7oo0015Ool00`00Oomoo`3o
OolCOol00`00Oomoo`1COol004Eoo`03001oogoo0?mooaAoo`8005=oo`00AGoo00<007ooOol0ogoo
5Woo00<007ooOol0D7oo0015Ool00`00Oomoo`3oOolGOol00`00Oomoo`1?Ool004Eoo`03001oogoo
0?mooaQoo`03001oogoo00Moo`<004Aoo`00AGoo00<007ooOol0ogoo6Goo00@007ooOomoo`D000=o
o`03001oogoo045oo`00AGoo0P00ogoo6goo0`0027oo00<007ooOol0@Goo0015Ool00`00Oomoo`3o
OolVOol00`00Oomoo`10Ool004Eoo`03001oogoo0?moobIoo`03001oogoo041oo`00AGoo00<007oo
Ool0ogoo9goo00<007ooOol0?goo0015Ool00`00Oomoo`3oOolWOol00`00Oomoo`0oOol004Eoo`03
001oogoo0?moobQoo`03001oogoo03ioo`00>goo10001Woo00<007ooOol0ogoo:Goo00<007ooOol0
?Goo000mOol00`00Oomoo`05Ool00`00Oomoo`3oOolYOol00`00Oomoo`0mOol003eoo`03001oogoo
00Eoo`03001oogoo0?moobYoo`03001oogoo03aoo`00>Goo1P001Woo0`00ogoo:Woo00<007ooOol0
?7oo000jOol01000Oomoo`001goo00<007ooOol0ogoo:goo00<007ooOol0>goo000jOol01000Oomo
o`001goo00<007ooOol0ogoo;7oo00<007ooOol0>Woo000kOol00`00Ool00007Ool00`00Oomoo`3o
Ool/Ool00`00Oomoo`0jOol003]oo`03001oo`0000Moo`03001oogoo0?moobeoo`03001oogoo03Uo
o`00?7oo0P001goo00<007ooOol0ogoo;Goo00<007ooOol0>Goo0015Ool00`00Oomoo`3oOol^Ool0
0`00Oomoo`0hOol004Eoo`03001oogoo0?moobioo`03001oogoo03Qoo`00AGoo00<007ooOol0ogoo
;goo00<007ooOol0=goo0015Ool2003oOolaOol00`00Oomoo`0fOol004Eoo`03001oogoo0?mooc1o
o`03001oogoo03Ioo`00AGoo00<007ooOol0ogoo<Goo00<007ooOol0=Goo0015Ool00`00Oomoo`3o
OolbOol00`00Oomoo`0dOol004Eoo`03001oogoo0?mooc=oo`03001oogoo03=oo`00AGoo00<007oo
Ool0ogoo<goo00<007ooOol0<goo0015Ool00`00Oomoo`3oOoldOol00`00Oomoo`0bOol004Eoo`03
001oogoo0?moocEoo`03001oogoo035oo`00AGoo0P00o`0?=P0?00<0000?00l05@0?77oo0015Ool0
0`00Oomoo`3oOolfOol00`00Oomoo`0`Ool004Eoo`03001oogoo0?moocMoo`03001oogoo02moo`00
AGoo00<007ooOol0ogoo>7oo00<007ooOol0;Woo0015Ool00`00Oomoo`3oOolhOol00`00Oomoo`0^
Ool004Eoo`03001oogoo0?moocUoo``002Aoo`00AGoo00<007ooOol0ogooJGoo0015Ool00`00Oomo
o`3oOomYOol004Eoo`03001oogoo0?moofUoo`00AGoo0P00ogooJWoo0015Ool00`00Oomoo`3oOomY
Ool004Eoo`03001oogoo0?moofUoo`00AGoo00<007ooOol0ogooJGoo0015Ool00`00Oomoo`3oOomY
Ool003]oo`@000Ioo`03001oogoo0?moofUoo`00>Woo00<007ooOol00Woo00<007ooOol00goo00<0
07ooOol0ogooJGoo000jOol00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`3oOomYOol003Yo
o`8000=oo`03001oogoo00=oo`<00?moofUoo`00>Woo00<007oo00000P00ogooLWoo000jOol00`00
Oomoo`3oOomdOol003]oo`03001oogoo0?moog=oo`00?7oo00<007ooOol0ogooLWoo000mOol3003o
OomaOol00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo002JOol40005Ool30000
0goo00000002Ool50005Ool300000goo00000003000017oo000007oo0P0037oo10001Goo10000goo
0`000Woo0`0017oo10000goo1@001Goo10000goo1`003Goo10000goo0`000Woo0`000goo1@000goo
1@001Woo1000Kgoo002IOol00`00Oomoo`02Ool01@00Oomoogoo00000goo0P000goo00<007ooOol0
0Woo00D007ooOomoo`0000=oo`80009oo`04001oogoo0002Ool00`00Oomoo`0:Ool00`00Oomoo`02
Ool01@00Oomoogoo000017oo00D007ooOomoo`0000Aoo`03001oogoo009oo`03001oogoo009oo`05
001oogooOol00007Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`0=Ool00`00Oomoo`02
Ool01@00Oomoogoo000017oo00D007ooOomoo`0000=oo`03001oogoo00=oo`03001oogoo00Ioo`03
001oogoo009oo`03001oogoo06aoo`00V7oo00<007ooOol01goo00<007ooOol00Woo00<007ooOol0
1Woo00D007ooOomoo`0000Aoo`04001oogoo0002Ool01000Oomoo`002goo00<007ooOol01goo00<0
07ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo00Eo
o`03001oogoo009oo`03001oogoo00=oo`03001oogoo00aoo`03001oogoo00Moo`03001oogoo009o
o`05001oogooOol00003Ool00`00Oomoo`03Ool00`00Oomoo`06Ool00`00Oomoo`1aOol009Qoo`03
001oogoo00Moo`03001oogoo009oo`03001oogoo009oo`@000Aoo`03001oogoo009oo`04001oogoo
0002Ool01000Oomoo`002goo00<007ooOol01goo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03
001oogoo009oo`03001oogoo00Ioo`03001oogoo00Eoo`03001oogoo009oo`03001oogoo00=oo`03
001oogoo00aoo`03001oogoo00Moo`03001oogoo009oo`03001oogoo009oo`@000Eoo`03001oogoo
00Ioo`03001oogoo075oo`00V7oo00<007ooOol01goo00<007ooOol00Woo00D007ooOomoo`0000Ao
o`05001oogooOol00004Ool00`00Oomoo`0200001Goo000007oo00002goo00<007ooOol01goo00<0
07ooOol00Woo00@007ooOomoo`8000=oo`03001oogoo009oo`03001oogoo00Ioo`8000Ioo`03001o
ogoo009oo`03001oogoo00=oo`03001oogoo00eoo`04001oogooOol20003Ool20003Ool01@00Oomo
ogoo00000goo00<007ooOol00goo0P001goo00<007ooOol0LGoo002HOol00`00Oomoo`03Ool00`00
Oomoo`020003Ool20004Ool50002Ool20003Ool200001Goo000007oo00000Woo00<007ooOol02Woo
00<007ooOol00goo00<007ooOol00Woo10000goo0P0000Aoo`00000000=oo`L000=oo`800004Ool0
00000004Ool40006Ool00`00Oomoo`0>Ool300000goo001oo`02Ool00`00Ool000020005Ool30005
Ool2000017oo000000000Woo1`00Kgoo002IOol01000Oomoogoo0P00<7oo00@007ooOomoo`8001Io
o`03001oogoo01Uoo`03001oogoo01Ioo`03001oogoo01Uoo`03001oogoo075oo`00VWoo0`0000=o
o`00Ool0<7oo0`0000=oo`00Ool05Goo00<007ooOol06Goo00<007ooOol05Woo00<007ooOol06Goo
00<007ooOol0LGoo003oOol6Ool3000GOol2002?Ool00?mook5oo`00ogoo/Goo003oOonaOol00?mo
ok5oo`00\
\>"],
  ImageRangeCache->{{{135, 422}, {283.438, 106.5}} -> {-26.4875, 1.18294, 
  0.141834, 0.0874256}},
  CellTags->"Cusum Chart"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.031746 0.166031 0.0462739 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.18254 -0.0125 -3 -9 ]
[.18254 -0.0125 3 0 ]
[.34127 -0.0125 -6 -9 ]
[.34127 -0.0125 6 0 ]
[.5 -0.0125 -6 -9 ]
[.5 -0.0125 6 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -26 -21.5625 ]
[.5 -0.0125 26 -9 ]
[-0.0125 .07348 -12 -4.5 ]
[-0.0125 .07348 0 4.5 ]
[-0.0125 .16603 -6 -4.5 ]
[-0.0125 .16603 0 4.5 ]
[-0.0125 .25858 -6 -4.5 ]
[-0.0125 .25858 0 4.5 ]
[-0.0125 .35113 -6 -4.5 ]
[-0.0125 .35113 0 4.5 ]
[-0.0125 .44367 -6 -4.5 ]
[-0.0125 .44367 0 4.5 ]
[-0.0125 .53622 -6 -4.5 ]
[-0.0125 .53622 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -24.5625 -7.34375 ]
[-0.01875 .30902 -12 7.34375 ]
[.5 .63053 -28.3438 0 ]
[.5 .63053 28.3438 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(5)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(10)] .34127 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(15)] .5 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(20)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(25)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(30)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -87 -25.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(subgroup) show
111.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .07348 m
.00625 .07348 L
s
[(-2)] -0.0125 .07348 1 0 Mshowa
0 .16603 m
.00625 .16603 L
s
[(0)] -0.0125 .16603 1 0 Mshowa
0 .25858 m
.00625 .25858 L
s
[(2)] -0.0125 .25858 1 0 Mshowa
0 .35113 m
.00625 .35113 L
s
[(4)] -0.0125 .35113 1 0 Mshowa
0 .44367 m
.00625 .44367 L
s
[(6)] -0.0125 .44367 1 0 Mshowa
0 .53622 m
.00625 .53622 L
s
[(8)] -0.0125 .53622 1 0 Mshowa
.125 Mabswid
0 .09662 m
.00375 .09662 L
s
0 .11976 m
.00375 .11976 L
s
0 .14289 m
.00375 .14289 L
s
0 .18917 m
.00375 .18917 L
s
0 .2123 m
.00375 .2123 L
s
0 .23544 m
.00375 .23544 L
s
0 .28172 m
.00375 .28172 L
s
0 .30485 m
.00375 .30485 L
s
0 .32799 m
.00375 .32799 L
s
0 .37426 m
.00375 .37426 L
s
0 .3974 m
.00375 .3974 L
s
0 .42054 m
.00375 .42054 L
s
0 .46681 m
.00375 .46681 L
s
0 .48995 m
.00375 .48995 L
s
0 .51308 m
.00375 .51308 L
s
0 .05035 m
.00375 .05035 L
s
0 .02721 m
.00375 .02721 L
s
0 .00407 m
.00375 .00407 L
s
0 .55936 m
.00375 .55936 L
s
0 .5825 m
.00375 .5825 L
s
0 .60563 m
.00375 .60563 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -86.625 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
68.3438 10.2813 translate
90 rotate
-68.3438 -10.2813 translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(C) show
69.000 14.313 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
73.688 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .16603 m
1 .16603 L
s
gsave
.5 .63053 -89.3438 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(C) show
69.000 14.313 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
79.688 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(values) show
115.688 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.05556 .14058 m
.0873 .04757 L
.11905 .01472 L
.15079 .09153 L
.18254 .19148 L
.21429 .19981 L
.24603 .10911 L
.27778 .17667 L
.30952 .13965 L
.34127 .15539 L
.37302 .1105 L
.40476 .17852 L
.43651 .20212 L
.46825 .17436 L
.5 .17806 L
.53175 .14891 L
.56349 .1776 L
.59524 .19194 L
.62698 .12346 L
.65873 .16233 L
.69048 .20398 L
.72222 .17297 L
.75397 .27894 L
.78571 .34835 L
.81746 .37611 L
.84921 .42609 L
.88095 .44367 L
.9127 .51864 L
.94444 .57926 L
.97619 .60332 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[32]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012Q000`40O003h00Oogoo/Goo003oOona
Ool00?mook5oo`00iGoo10007goo0`00YGoo003YOol00`00Oomoo`0MOol00`00Oomoo`2TOol00>Uo
o`03001oogoo01eoo`03001oogoo0:Aoo`00bWoo1@001Goo0`0000Aoo`00001oo`800004Ool00000
0004Ool300000goo001oo`03Ool50005Ool40005Ool300000goo00000002Ool00`00Ool00002002R
Ool00<Yoo`03001oogoo009oo`05001oogooOol00003Ool20003Ool20003Ool01000Oomoo`000goo
0P001Goo00<007ooOol01Goo00<007ooOol00Woo00D007ooOomoo`0000=oo`8000=oo`8000=oo`03
001oogoo09moo`00cgoo00D007ooOomoo`0000Aoo`05001oogooOol00004Ool01000Oomoo`0017oo
00<007ooOol00goo00<007ooOol01Goo00<007ooOol00Woo00D007ooOomoo`0000Aoo`05001oogoo
Ool00004Ool00`00Oomoo`2OOol00<]oo`@000Aoo`03001oogoo009oo`05001oogooOol00004Ool0
1000Oomoo`0017oo00<007ooOol00goo00<007ooOol01Goo00<007ooOol00Woo00D007ooOomoo`00
00Aoo`05001oogooOol00004Ool00`00Oomoo`2OOol00<Yoo`03001oogoo009oo`05001oogooOol0
0004Ool01000Oomoogoo0P000goo00@007ooOol000=oo`8000Eoo`8000Ioo`03001oogoo009oo`05
001oogooOol00004Ool01000Oomoogoo0P000goo00<007ooOol0Wgoo003;Ool50002Ool20003Ool2
0003Ool00`00Ool000020004Ool300000goo00000003Ool2000017oo0000000017oo10000goo0P00
0goo0P000Woo0P0000Aoo`0000000:9oo`00g7oo00<007ooOol0dGoo003LOol00`00Oomoo`3AOol0
0=]oo`800==oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol004]oo`@0035o
o`@002]oo`L000=oo`@002Moo`L000=oo`@002Moo`H000Aoo`@002Moo`H000Aoo`@002Qoo`@000Eo
o`@001moo`00BWoo00<007ooOol00Woo00<007ooOol0;Goo00<007ooOol00Woo00<007ooOol0:goo
00<007ooOol00goo00<007ooOol00Woo00<007ooOol09goo00<007ooOol00goo00<007ooOol00Woo
00<007ooOol097oo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo02Aoo`03001oogoo
009oo`05001oogooOol00004Ool00`00Oomoo`0TOol00`00Oomoo`02Ool01@00Oomoogoo000017oo
00<007ooOol077oo001:Ool00`00Oomoo`02Ool00`00Oomoo`0bOol00`00Oomoo`0[Ool00`00Oomo
o`03Ool00`00Oomoo`02Ool00`00Oomoo`0WOol00`00Oomoo`08Ool00`00Oomoo`0UOol00`00Oomo
o`05Ool00`00Oomoo`02Ool00`00Oomoo`0UOol00`00Oomoo`0:Ool00`00Oomoo`0YOol01@00Oomo
ogoo000017oo00<007ooOol077oo001:Ool00`00Oomoo`02Ool00`00Oomoo`0bOol00`00Oomoo`0[
Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`0WOol00`00Oomoo`08Ool00`00Oomoo`0V
Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`0VOol00`00Oomoo`09Ool00`00Oomoo`0Y
Ool01@00Oomoogoo000017oo00<007ooOol077oo001:Ool00`00Oomoo`02Ool00`00Oomoo`0bOol0
0`00Oomoo`0[Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`0WOol00`00Oomoo`08Ool0
0`00Oomoo`0WOol00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`0WOol00`00Oomoo`08Ool0
0`00Oomoo`0WOol20004Ool00`00Oomoo`02Ool00`00Oomoo`0LOol004Yoo`03001oogoo009oo`03
001oogoo02ioo`@002ioo`03001oogoo00=oo`03001oogoo009oo`03001oogoo02Moo`03001oogoo
00Aoo`@002]oo`03001oogoo009oo`03001oogoo009oo`03001oogoo02Qoo`03001oogoo00=oo`@0
02aoo`05001oogooOol00004Ool00`00Oomoo`0LOol004Yoo`03001oogoo009oo`03001oogoo02io
o`03001oogoo02moo`03001oogoo00=oo`03001oogoo009oo`03001oogoo02Moo`03001oogoo00Ao
o`03001oogoo02Qoo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`0TOol00`00Oomo
o`02Ool00`00Oomoo`02Ool00`00Oomoo`0]Ool01@00Oomoogoo000017oo00<007ooOol077oo001:
Ool00`00Oomoo`02Ool00`00Oomoo`0^Ool00`00Oomoo`0]Ool30005Ool00`00Oomoo`02Ool00`00
Oomoo`0UOol30006Ool00`00Oomoo`0XOol00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007oo
Ool097oo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol0:7oo00<007ooOol00Woo00D007oo
Oomoo`0000Aoo`03001oogoo01aoo`00Bgoo1000<Goo1@00;Goo00<007ooOol017oo1000:Woo00<0
07ooOol017oo1@009goo10001Goo1000:7oo10001Goo1@009goo10001Goo10007goo003oOonaOol0
0?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol004Eoool0050001ao
o`00AGoo00<007ooOol01Goo00<007ooOol027oo00<007ooOol01goo00<007ooOol027oo00<007oo
Ool01goo00<007ooOol027oo00<007ooOol027oo00<007ooOol01goo00<007ooOol027oo00<007oo
Ool01goo00<007ooOol027oo00<007ooOol027oo00<007ooOol01goo00<007ooOol027oo00<007oo
Ool01goo00<007ooOol027oo00<007ooOol027oo00<007ooOol01goo00<007ooOol027oo00<007oo
Ool01goo00<007ooOol027oo00<007ooOol027oo00<007ooOol01goo00<007ooOol027oo00<007oo
Ool01goo00<007ooOol027oo00<007ooOol027oo00<007ooOol01goo00<007ooOol027oo00<007oo
Ool01goo00<007ooOol027oo00<007ooOol08Woo0015Ool20006Ool00`00Oomoo`0bOol00`00Oomo
o`0bOol00`00Oomoo`0bOol00`00Oomoo`0bOol00`00Oomoo`0bOol00`00Oomoo`0bOol00`00Oomo
o`0ROol004Eoo`03001oogoo0?moofUoo`00AGoo00<007ooOol0ogooJGoo0015Ool00`00Oomoo`0U
Ool00`00Oomoo`3oOom1Ool004Eoo`03001oogoo02Aoo`800?mood=oo`00AGoo00<007ooOol08goo
00@007ooOol00?mood9oo`00AGoo00<007ooOol08Woo00D007ooOomoo`000?mood9oo`00AGoo0P00
8Woo00<007ooOol00goo00<007ooOol0ogoo?goo0015Ool00`00Oomoo`0POol00`00Oomoo`04Ool0
0`00Oomoo`3oOoloOol004Eoo`03001oogoo01moo`03001oogoo00Eoo`03001oogoo0?moocmoo`00
AGoo00<007ooOol07Woo00<007ooOol01goo00<007ooOol0ogoo?Woo0015Ool00`00Oomoo`0MOol0
0`00Oomoo`08Ool00`00Oomoo`3oOolnOol004Eoo`03001oogoo01aoo`03001oogoo00Uoo`03001o
ogoo0?moocioo`00AGoo00<007ooOol06goo00<007ooOol02goo00<007ooOol0ogoo?Goo0015Ool0
0`00Oomoo`0JOol00`00Oomoo`0<Ool00`00Oomoo`3oOolmOol004Eoo`8001]oo`03001oogoo00eo
o`03001oogoo0?moocaoo`00AGoo00<007ooOol06Goo00<007ooOol03Woo00<007ooOol0ogoo?7oo
0015Ool00`00Oomoo`0IOol00`00Oomoo`0>Ool00`00Oomoo`3oOollOol004Eoo`03001oogoo01Uo
o`03001oogoo00moo`03001oogoo0?mooc]oo`00>Goo1P001Woo00<007ooOol067oo00<007ooOol0
47oo00<007ooOol0ogoo>goo000iOol00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`0HOol0
0`00Oomoo`0AOol00`00Oomoo`3oOoljOol003Yoo`03001oogoo00Qoo`03001oogoo01Qoo`03001o
ogoo015oo`03001oogoo0?moocYoo`00>goo00<007ooOol01goo00<007ooOol05goo00<007ooOol0
4Woo00<007ooOol0ogoo>Woo000`Ool60006Ool00`00Oomoo`06Ool3000GOol00`00Oomoo`0COol0
0`00Oomoo`3oOoliOol003eoo`03001oogoo00Eoo`03001oogoo01Moo`03001oogoo01=oo`03001o
ogoo0?moocUoo`00>Goo00<007ooOol00Woo00<007ooOol017oo00<007ooOol05Woo00<007ooOol0
57oo00<007ooOol0ogoo>Goo000iOol00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`0FOol0
0`00Oomoo`0EOol00`00Oomoo`3oOolhOol003Yoo`@000Moo`03001oogoo01Ioo`03001oogoo01Eo
o`03001oogoo0?moocQoo`00AGoo00<007ooOol05Goo00<007ooOol05goo00<007ooOol0ogoo=goo
0015Ool00`00Oomoo`0EOol00`00Oomoo`0GOol00`00Oomoo`3oOolgOol004Eoo`8001Ioo`03001o
ogoo01Moo`03001oogoo0?moocMoo`00AGoo00<007ooOol05Goo00<007ooOol067oo00<007ooOol0
ogoo=Woo0015Ool00`00Oomoo`0DOol00`00Oomoo`0IOol00`00Oomoo`3oOolfOol004Eoo`03001o
ogoo01Aoo`03001oogoo01Uoo`03001oogoo0?moocIoo`00AGoo00<007ooOol057oo00<007ooOol0
6Woo00<007ooOol0ogoo=Goo0015Ool00`00Oomoo`0COol00`00Oomoo`0KOol00`00Oomoo`0KOol0
0`00Oomoo`0XOol00`00Oomoo`3[Ool004Eoo`03001oogoo01=oo`03001oogoo01]oo`03001oogoo
01]oo`8002Qoo`800>eoo`00AGoo00<007ooOol04goo00<007ooOol077oo00<007ooOol06Goo00<0
07oo0000:7oo00<007oo0000k7oo0015Ool2000COol00`00Oomoo`0MOol00`00Oomoo`0IOol01000
Oomoo`009Woo00@007ooOol00>aoo`00AGoo00<007ooOol04Woo00<007ooOol07Goo00<007ooOol0
6Goo00@007ooOol002Eoo`03001oogoo009oo`03001oogoo04moo`03001oogoo09Moo`00AGoo00<0
07ooOol04Woo00<007ooOol07Woo00<007ooOol05goo00<007ooOol00Woo00<007ooOol08Goo00<0
07ooOol00goo00<007ooOol0Cgoo0P00V7oo0015Ool00`00Oomoo`0AOol00`00Oomoo`0OOol00`00
Oomoo`0GOol00`00Oomoo`02Ool00`00Oomoo`0QOol00`00Oomoo`04Ool00`00Oomoo`1=Ool01000
Oomoo`00Ugoo0015Ool00`00Oomoo`0AOol00`00Oomoo`0OOol00`00Oomoo`0GOol00`00Oomoo`03
Ool00`00Oomoo`0OOol00`00Oomoo`05Ool00`00Oomoo`1=Ool01@00Oomoogoo0000UWoo0015Ool0
0`00Oomoo`0AOol00`00Oomoo`0POol00`00Oomoo`0EOol00`00Oomoo`04Ool00`00Oomoo`0NOol0
0`00Oomoo`06Ool00`00Oomoo`1<Ool00`00Oomoo`02Ool00`00Oomoo`2DOol004Eoo`03001oogoo
011oo`03001oogoo025oo`03001oogoo01Eoo`03001oogoo00Eoo`03001oogoo01aoo`03001oogoo
00Qoo`03001oogoo04]oo`03001oogoo00=oo`03001oogoo09=oo`00AGoo00<007ooOol047oo00<0
07ooOol08Goo00<007ooOol05Goo00<007ooOol01Goo00<007ooOol03Goo0P003Goo00<007ooOol0
27oo00<007ooOol0BWoo00<007ooOol01Goo00<007ooOol0TWoo0015Ool2000fOol00`00Oomoo`0C
Ool00`00Oomoo`07Ool00`00Oomoo`0;Ool00`00Oomoo`02000:Ool00`00Oomoo`0:Ool00`00Oomo
o`19Ool00`00Oomoo`06Ool00`00Oomoo`2AOol004Eoo`03001oogoo03Eoo`03001oogoo01=oo`03
001oogoo00Moo`03001oogoo00Yoo`03001oogoo00=oo`8000Moo`03001oogoo00]oo`03001oogoo
04Uoo`03001oogoo00Moo`03001oogoo091oo`00AGoo00<007ooOol0=Goo00<007ooOol04goo00<0
07ooOol027oo00<007ooOol02Goo00<007ooOol01Goo0P0017oo00<007ooOol03Goo00<007ooOol0
;7oo00<007ooOol067oo00<007ooOol02Goo00<007ooOol0Sgoo0015Ool00`00Oomoo`0fOol00`00
Oomoo`0AOol00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`08Ool20002Ool00`00Oomoo`0=
Ool00`00Oomoo`0[Ool00`00Ool0000IOol00`00Oomoo`09Ool00`00Oomoo`2?Ool003Yoo`@000Mo
o`03001oogoo03Ioo`03001oogoo015oo`03001oogoo00Yoo`03001oogoo00Ioo`03001oogoo00]o
o`80015oo`03001oogoo02Uoo`05001oogooOol0000GOol00`00Oomoo`0;Ool00`00Oomoo`2>Ool0
03Uoo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo03Ioo`03001oogoo015oo`03001oogoo
00Yoo`03001oogoo00Eoo`03001oogoo01moo`03001oogoo02Qoo`03001oogoo00=oo`03001oogoo
01Aoo`03001oogoo00aoo`03001oogoo08eoo`00>Goo00<007ooOol00Woo00<007ooOol017oo00<0
07ooOol0=goo00<007ooOol03goo00<007ooOol037oo00<007ooOol00goo00<007ooOol087oo00<0
07ooOol09goo00<007ooOol01Goo00<007ooOol04Woo00<007ooOol03Woo00<007ooOol0S7oo000i
Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`0gOol00`00Oomoo`0?Ool00`00Oomoo`0<
Ool00`00Oomoo`02Ool00`00Oomoo`0ROol00`00Oomoo`0TOol20009Ool2000BOol00`00Oomoo`0?
Ool00`00Oomoo`2;Ool003Uoo`03001oogoo009oo`03001oogoo00Aoool0050001aoo`00>Goo00<0
07ooOol00Woo00<007ooOol017oo00<007ooOol0>7oo00<007ooOol03Goo00<007ooOol03Woo00@0
07ooOol002Ioo`03001oogoo025oo`03001oogoo00eoo`03001oogoo00eoo`03001oogoo015oo`03
001oogoo08Yoo`00>Goo00<007ooOol00Woo00<007ooOol017oo00<007ooOol0>7oo00<007ooOol0
3Goo00<007ooOol03goo0P009goo00<007ooOol04goo0`002Woo00<007ooOol03goo00<007ooOol0
37oo00<007ooOol04Woo00<007ooOol03goo00<007ooOol0Mgoo000iOol00`00Oomoo`02Ool00`00
Oomoo`04Ool00`00Oomoo`0hOol00`00Oomoo`0=Ool00`00Oomoo`0?Ool00`00Oomoo`0WOol00`00
Oomoo`0AOol01000Oomoogoo1P000goo00<007ooOol04Goo0P002goo00<007ooOol057oo00<007oo
Ool03Goo0P00NGoo000jOol40007Ool00`00Oomoo`0iOol00`00Oomoo`0;Ool00`00Oomoo`0jOol0
0`00Oomoo`0@Ool00`00Oomoo`08Ool3000FOol20009Ool00`00Oomoo`0EOol00`00Oomoo`0;Ool0
1000Oomoo`00N7oo0015Ool00`00Oomoo`0iOol00`00Oomoo`0;Ool00`00Oomoo`0kOol2000?Ool0
0`00Oomoo`0TOol20006Ool00`00Oomoo`0FOol00`00Oomoo`0:Ool01@00Oomoogoo0000N7oo0015
Ool00`00Oomoo`0iOol00`00Oomoo`0;Ool00`00Oomoo`0mOol00`00Oomoo`0;Ool00`00Oomoo`0W
Ool20004Ool00`00Oomoo`0GOol00`00Oomoo`08Ool00`00Oomoo`02Ool00`00Oomoo`1fOol004Eo
o`8003]oo`03001oogoo00Uoo`03001oogoo03moo`03001oogoo00Uoo`03001oogoo02Yoo`800003
Ool007oo01Yoo`03001oogoo00Ioo`03001oogoo00Aoo`03001oogoo07Eoo`00AGoo00<007ooOol0
>Woo0P002Woo00<007ooOol0@7oo0P0027oo00<007ooOol0;Goo0P0077oo00<007ooOol017oo00<0
07ooOol01Goo00<007ooOol0MGoo0015Ool00`00Oomoo`0lOol40006Ool00`00Oomoo`12Ool00`00
Oomoo`04Ool00`00Oomoo`1=Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`1eOol004Eo
o`03001oogoo041oo`@00003Ool007oo04Eoo`03001oogoo009oo`03001oogoo04ioo`05001oogoo
Ool0000:Ool00`00Oomoo`1dOol004Eoo`03001oogoo04Aoo`8004Moo`800003Ool007oo055oo`03
001oo`0000]oo`03001oogoo07Aoo`00AGoo00<007ooOol0Sgoo00<007ooOol0DWoo00<007ooOol0
2Woo00<007ooOol0M7oo0015Ool00`00Oomoo`3aOol00`00Oomoo`1dOol004Eoo`03001oogoo0?9o
o`03001oogoo07=oo`00AGoo0P00lgoo00<007ooOol0Lgoo0015Ool00`00Oomoo`3bOol00`00Oomo
o`1cOol004Eoo`03001oogoo0?=oo`03001oogoo079oo`00AGoo00<007ooOol0lgoo00<007ooOol0
LWoo0015Ool00`00Oomoo`3cOol00`00Oomoo`1bOol004Eoo`03001oogoo0?Aoo`03001oogoo075o
o`00AGoo00<007ooOol0m7oo00<007ooOol0LGoo0015Ool00`00Oomoo`3dOol00`00Oomoo`1aOol0
04Eoo`800?Ioo`03001oogoo071oo`00AGoo00<007ooOol0mGoo00<007ooOol0L7oo0015Ool00`00
Oomoo`3eOol00`00Oomoo`1`Ool004Eoo`03001oogoo0?Ioo`03001oogoo06moo`00>Goo1P001Woo
00<007ooOol0mWoo00<007ooOol0Kgoo000iOol00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomo
o`3fOol00`00Oomoo`1_Ool003Yoo`03001oogoo00Qoo`03001oogoo0?Ioo`03001oogoo06moo`00
>goo00<007ooOol01goo0`00mgoo00<007ooOol0KWoo000lOol00`00Oomoo`06Ool00`00Oomoo`3g
Ool00`00Oomoo`1^Ool003eoo`03001oogoo00Eoo`03001oogoo0?Moo`03001oogoo06ioo`00>Goo
00<007ooOol00Woo00<007ooOol017oo00<007ooOol0n7oo00<007ooOol0KGoo000iOol00`00Oomo
o`02Ool00`00Oomoo`04Ool00`00Oomoo`3hOol00`00Oomoo`1]Ool003Yoo`@000Moo`03001oogoo
0?Qoo`03001oogoo06eoo`00AGoo00<007ooOol0nGoo00<007ooOol0K7oo0015Ool00`00Oomoo`3i
Ool00`00Oomoo`1/Ool004Eoo`800?Yoo`03001oogoo06aoo`00AGoo00<007ooOol0nWoo00<007oo
Ool0Jgoo0015Ool00`00Oomoo`3jOol00`00Oomoo`1[Ool0025oo`@0021oo`03001oogoo0?]oo`03
001oogoo06Yoo`0087oo00<007ooOol00Woo00<007ooOol07Goo00<007ooOol0ngoo00<007ooOol0
JWoo000OOol00`00Oomoo`04Ool00`00Oomoo`0LOol00`00Oomoo`3lOol00`00Oomoo`1YOol001mo
o`03001oogoo00Aoo`03001oogoo01aoo`03001oogoo0?aoo`03001oogoo06Uoo`007goo00<007oo
Ool017oo00<007ooOol077oo00<007ooOol0o7oo00<007ooOol0JGoo000POol00`00Oomoo`03Ool0
0`00Oomoo`0LOol2003nOol00`00Oomoo`1XOol001moo`<000=oo`03001oogoo01eoo`03001oogoo
0?eoo`03001oogoo06Qoo`00AGoo00<007ooOol0oWoo00<007ooOol0Igoo000SOol00`00Oomoo`03
Ool00`00Oomoo`0IOol00`00Oomoo`3nOol00`00Oomoo`1WOol002=oo`L001]oo`03001oogoo0?mo
o`03001oogoo06Ioo`009goo00<007ooOol06goo00<007ooOol0ogoo00<007ooOol0IWoo000UOol0
1@00Ool007oo00006goo00<007ooOol0ogoo0Goo00<007ooOol0IGoo000UOol200000goo0000000K
Ool00`00Oomoo`3oOol1Ool00`00Oomoo`1UOol002Eoo`05001oogooOol0000KOol2003oOol2Ool0
0`00Oomoo`1UOol004Eoo`03001oogoo0?moo`9oo`03001oogoo06Aoo`00AGoo00<007ooOol0ogoo
0Woo00<007ooOol0I7oo0015Ool00`00Oomoo`3oOol3Ool00`00Oomoo`1SOol003]oo`@000Ioo`03
001oogoo0?moo`=oo`03001oogoo06=oo`00?Goo00<007ooOol01Goo00<007ooOol0ogoo17oo00<0
07ooOol0HWoo000mOol00`00Oomoo`05Ool00`00Oomoo`3oOol4Ool00`00Oomoo`1ROol003Uoo`H0
00Ioo`<00?moo`Eoo`03001oogoo065oo`00>Woo00@007ooOol000Moo`03001oogoo0?moo`Ioo`03
001oogoo061oo`00>Woo00@007ooOol000Moo`03001oogoo0?moo`Moo`03001oogoo05moo`00>goo
00<007oo00001goo00<007ooOol0ogoo27oo00<007ooOol0GWoo000kOol00`00Ool00007Ool00`00
Oomoo`3oOol9Ool2001NOol003aoo`8000Moo`03001oogoo0?moo`]oo`03001oogoo05]oo`00AGoo
00<007ooOol0ogoo37oo00<007ooOol0FWoo0015Ool00`00Oomoo`3oOol=Ool00`00Oomoo`1IOol0
04Eoo`800?moo`moo`03001oogoo05Qoo`00AGoo00<007ooOol0ogoo3goo00<007ooOol0Egoo0015
Ool00`00Oomoo`3oOol@Ool00`00Oomoo`1FOol004Eoo`03001oogoo0?mooa1oo`03001oogoo05Io
o`00AGoo00<007ooOol0ogoo4Goo00<007ooOol0EGoo0015Ool00`00Oomoo`3oOolBOol00`00Oomo
o`1DOol004Eoo`03001oogoo0?mooa9oo`03001oogoo05Aoo`00AGoo00<007ooOol0ogoo4goo00<0
07ooOol0Dgoo0015Ool2003oOolEOol00`00Oomoo`1BOol004Eoo`03001oogoo0?mooaEoo`03001o
ogoo055oo`00AGoo00<007ooOol0ogoo5Goo00<007ooOol0DGoo0015Ool00`00Oomoo`3oOolFOol0
0`00Oomoo`1@Ool004Eoo`03001oogoo0?mooaMoo`03001oogoo04moo`00AGoo00<007ooOol0ogoo
5goo00<007ooOol0Cgoo0015Ool00`00Oomoo`3oOolHOol00`00Oomoo`1>Ool004Eoo`03001oogoo
0?mooaUoo`03001oogoo04eoo`00AGoo0P00ogoo6Woo00<007ooOol0CGoo0015Ool00`00Oomoo`3o
OolJOol00`00Oomoo`1<Ool004Eoo`03001oogoo0?mooa]oo`8004aoo`00AGoo00<007ooOol0ogoo
7Goo0P00BWoo000kOol40006Ool00`00Oomoo`3oOolOOol00`00Oomoo`17Ool003Yoo`03001oogoo
009oo`03001oogoo00=oo`03001oogoo0?moob1oo`8004Moo`00>Woo00<007ooOol00Woo00<007oo
Ool00goo00<007ooOol0ogoo8Woo0P00AGoo000jOol20003Ool00`00Oomoo`03Ool3003oOolTOol0
0`00Oomoo`12Ool003Yoo`03001oo`00008000Ioo`03001oogoo0?moobAoo`03001oogoo049oo`00
>Woo00<007ooOol027oo00<007ooOol0ogoo9Goo00<007ooOol0@Goo000kOol00`00Oomoo`07Ool0
0`00Oomoo`3oOolUOol00`00Oomoo`11Ool003aoo`03001oogoo00Ioo`03001oogoo0?moobIoo`03
001oogoo041oo`00?Goo0`001Goo00<007ooOol0ogoo9Woo00<007ooOol0@7oo0015Ool00`00Oomo
o`3oOolWOol00`00Oomoo`0oOol004Eoo`03001oogoo0?moobMoo`03001oogoo03moo`00AGoo0P00
ogoo:Goo00<007ooOol0?Woo0015Ool00`00Oomoo`3oOolXOol00`00Oomoo`0nOol004Eoo`03001o
ogoo0?moobQoo`03001oogoo03ioo`00AGoo00<007ooOol0ogoo:Goo00<007ooOol0?Goo0015Ool0
0`00Oomoo`3oOolYOol00`00Oomoo`0mOol004Eoo`03001oogoo0?moobYoo`03001oogoo03aoo`00
AGoo00<007ooOol0ogoo:Woo00<007ooOol0?7oo0015Ool00`00Oomoo`3oOol[Ool00`00Oomoo`0k
Ool004Eoo`800?moobaoo`03001oogoo03]oo`00AGoo00<007ooOol0ogoo:goo00<007ooOol0>goo
0015Ool00`00Oomoo`3oOol/Ool00`00Oomoo`0jOol004Eoo`03001oogoo0?moobaoo`03001oogoo
03Yoo`00AGoo00<007ooOol0ogoo;Goo00<007ooOol0>Goo0015Ool00`00Oomoo`3oOol]Ool00`00
Oomoo`0iOol004Eoo`03001oogoo0?moobioo`03001oogoo03Qoo`00AGoo0P00ogoo;goo00<007oo
Ool0>7oo0015Ool00`00Oomoo`3oOol_Ool00`00Oomoo`0gOol004Eoo`03001oogoo0?moobmoo`03
001oogoo03Moo`00AGoo00<007ooOol0ogoo;goo00<007ooOol0=goo0015Ool00`00Oomoo`3oOol`
Ool00`00Oomoo`0fOol003Yoo`@000Moo`03001oogoo0?mooc1oo`03001oogoo03Ioo`00>Goo00<0
07ooOol00Woo00<007ooOol017oo00<007ooOol0ogoo<Goo00<007ooOol0=Goo000iOol00`00Oomo
o`02Ool00`00Oomoo`04Ool00`00Oomoo`3oOolaOol00`00Oomoo`0eOol003Uoo`03001oogoo009o
o`03001oogoo00Aoo`<00?mooc9oo`03001oogoo03Aoo`00>Woo10001goo00<007ooOol0ogoo<Woo
00<007ooOol0=7oo000iOol00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`3oOolcOol00`00
Oomoo`0cOol003Uoo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo0?mooc=oo`03001oogoo
03=oo`00>Goo00<007ooOol00Woo00<007ooOol017oo00<007ooOol0ogoo=7oo00<007ooOol0<Woo
000jOol40007Ool00`00Oomoo`3oOoldOol00`00Oomoo`0bOol004Eoo`03001oogoo0?moocEoo`03
001oogoo035oo`00AGoo00<007ooOol0ogoo=Goo00<007ooOol0<Goo0015Ool2003oOolgOol00`00
Oomoo`0`Ool004Eoo`03001oogoo0?moocIoo`03001oogoo031oo`00AGoo00<007ooOol0ogoo=goo
00<007ooOol0;goo0015Ool00`00Oomoo`3oOolgOol00`00Oomoo`0_Ool004Eoo`03001oogoo0?mo
ocQoo`03001oogoo02ioo`00AGoo00<007ooOol0ogoo>7oo00<007ooOol0;Woo0015Ool00`00Oomo
o`3oOoliOol00`00Oomoo`0]Ool004Eoo`03001oogoo0?moocUoo`03001oogoo02eoo`00AGoo0P00
ogoo>goo0P00;Goo0015Ool00`00Oomoo`3oOollOol00`00Oomoo`0ZOol004Eoo`03001oogoo0?mo
oceoo`03001oogoo02Uoo`00AGoo00<007ooOol0ogoo?Woo0P00:Goo0015Ool00`00Oomoo`3oOom0
Ool00`00Oomoo`0VOol004Eoo`03001oogoo0?mood5oo`03001oogoo02Eoo`00AGoo00<007ooOol0
ogoo@Woo0P009Goo0015Ool2003oOom5Ool00`00Oomoo`0ROol004Eoo`03001oogoo0?moofUoo`00
AGoo00<007ooOol0ogooJGoo0015Ool00`00Oomoo`3oOomYOol004Eoo`03001oogoo0?moofUoo`00
ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOona
Ool00<ioo`800004Ool00000003LOol00<moo`04001oogoo003MOol00<Qoo`@000=oo`<0011oo`80
00Ioo`D0009oo`L000Aoo`<00003Ool0000000=oo`@000Aoo`D009ioo`00agoo00<007ooOol00Woo
00@007ooOol0009oo`03001oogoo00eoo`8000Eoo`05001oogooOol00006Ool00`00Oomoo`04Ool0
1000Oomoogoo0P000goo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo09]oo`00aWoo
00<007ooOol01Woo00<007oo00000P003Goo00@007ooOol000Aoo`05001oogooOol00006Ool00`00
Oomoo`04Ool00`00Oomoo`02Ool01@00Oomoogoo00003Goo00<007ooOol0Vgoo0036Ool00`00Oomo
o`06Ool00`00Oomoo`0?Ool01000Oomoo`001Goo10001Woo00<007ooOol017oo00<007ooOol00Woo
00@007ooOomoo`H000Aoo`@009ioo`00aWoo00<007ooOol01Goo0P0047oo00<007ooOol00Woo00D0
07ooOomoo`0000=oo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo009oo`05001oogooOol0
0004Ool01@00Oomoogoo000017oo00<007ooOol0Vgoo0036Ool00`00Oomoo`03Ool00`00Oomoo`0@
Ool30002Ool30003Ool30007Ool00`00Oomoo`03Ool20003Ool20004Ool40005Ool5002MOol00<Mo
o`04001oogooOol2000WOol00`00Oomoo`2iOol00<Qoo`<00003Ool007oo02Ioo`03001oogoo0;Uo
o`00lWoo0`00^goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol00001\
\>"],
  ImageRangeCache->{{{135, 422}, {467.375, 290.438}} -> {-26.4875, 22.3046, 
  0.141834, 0.0973046}},
  CellTags->"Cusum Chart"]
}, Closed]],

Cell[OutputFormData["\<\
Graphics[Line[{{1, -0.5500000000000007}, 
   {2, -2.5600000000000005}, 
   {3, -3.2700000000000014}, 
   {4, -1.6100000000000012}, 
   {5, 0.5499999999999989}, 
   {6, 0.7299999999999986}, 
   {7, -1.2300000000000022}, 
   {8, 0.22999999999999865}, 
   {9, -0.5700000000000021}, 
   {10, -0.2300000000000022}, 
   {11, -1.2000000000000028}, 
   {12, 0.2699999999999978}, 
   {13, 0.7799999999999976}, 
   {14, 0.17999999999999794}, 
   {15, 0.259999999999998}, 
   {16, -0.37000000000000277}, 
   {17, 0.24999999999999645}, 
   {18, 0.559999999999997}, 
   {19, -0.9200000000000035}, 
   {20, -0.08000000000000362}, 
   {21, 0.8199999999999967}, 
   {22, 0.1499999999999968}, 
   {23, 2.439999999999996}, 
   {24, 3.939999999999996}, 
   {25, 4.539999999999996}, 
   {26, 5.619999999999996}, 
   {27, 5.9999999999999964}, 
   {28, 7.619999999999996}, 
   {29, 8.929999999999996}, 
   {30, 9.449999999999996}}], 
 {PlotRange -> Automatic, AspectRatio -> 
   GoldenRatio^(-1), DisplayFunction :> 
   $DisplayFunction, ColorOutput -> 
   Automatic, Axes -> Automatic, 
  AxesOrigin -> Automatic, 
  PlotLabel -> \"\\!\\(C\\_k\\) values\", 
  AxesLabel -> None, Ticks -> Automatic, 
  GridLines -> None, Prolog -> {}, 
  Epilog -> {}, AxesStyle -> Automatic, 
  Background -> Automatic, 
  DefaultColor -> Automatic, 
  DefaultFont :> $DefaultFont, 
  RotateLabel -> True, Frame -> 
   {True, True, False, False}, 
  FrameStyle -> Automatic, 
  FrameTicks -> Automatic, 
  FrameLabel -> {\"subgroup\", \"\\!\\(C\\_k\\)\"}, 
  PlotRegion -> Automatic, 
  ImageSize -> Automatic, TextStyle :> 
   $TextStyle, FormatType :> $FormatType}]\
\>", "\<\
-Graphics-\
\>"], "Output",
  CellLabel->"Out[32]=",
  CellTags->"Cusum Chart"]
}, Closed]],

Cell["The exponentially weighted moving-average EWMA Chart ", "Section",
  CellTags->"The exponentially weighted moving-average EWMA Chart"],

Cell["Introduction", "Subsection",
  CellTags->"The exponentially weighted moving-average EWMA Chart"],

Cell[TextData[{
  "The EWMA control chart is useful when we are interested in detecting small \
shifts . As with the cusum, the EWMA is typically used with individual \
observations {",
  Cell[BoxData[
      \(TraditionalForm\`X\_1\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`X\_2\)]],
  ", ...., ",
  Cell[BoxData[
      \(TraditionalForm\`X\_n\)]],
  "}. The EWMA  is defined as\n",
  Cell[BoxData[
      \(TraditionalForm
      \`z\_k = \[Lambda]\ x\_k + \((1 - \[Lambda])\) z\_\(k - 1\)\)]],
  "\nwhere 0<\[Lambda]\[LessEqual]1 is a constant and the starting value (",
  StyleBox["i",
    FontSlant->"Italic"],
  "=0) is ",
  Cell[BoxData[
      \(TraditionalForm\`z\_0 = \[Mu]\_0\)]],
  ". Often ",
  Cell[BoxData[
      \(TraditionalForm\`\[Mu]\_0\)]],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`x\&_\)]],
  ", is estimated making a preliminary study taking several ",
  Cell[BoxData[
      \(TraditionalForm\`x\_i\)]],
  " values when the process is in control. \nThe EWMA control chart is \
represented by plotting ",
  Cell[BoxData[
      \(TraditionalForm\`z\_i\)]],
  " versus ",
  Cell[BoxData[
      \(TraditionalForm\`i\)]],
  ". The center  line and control limits are represented as well. They are \
evaluated as follows:\n",
  Cell[BoxData[
      \(TraditionalForm\`UCL\_i\)]],
  " = ",
  Cell[BoxData[
      \(TraditionalForm
      \`\[Mu]\_0 + 
        L\ \[Sigma] 
          \@\( \[Lambda]\/\(2 - \[Lambda]\)\)[1 - \((1 - \[Lambda])\)\^\(2  k\
\)]\)]],
  " \nCL = ",
  Cell[BoxData[
      \(TraditionalForm\`\[Mu]\_0\)]],
  "\n",
  Cell[BoxData[
      \(TraditionalForm\`LCL\_k\)]],
  " = ",
  Cell[BoxData[
      \(TraditionalForm
      \`\[Mu]\_0 - 
        L\ \[Sigma] 
          \@\( \[Lambda]\/\(2 - \[Lambda]\)\)[1 - \((1 - \[Lambda])\)\^\(2  k\
\)]\)]],
  "\n",
  StyleBox["L",
    FontSlant->"Italic"],
  " is the width of the control limits, and, like \[Lambda],  it should be \
chosen carefully (see Montgomery 1996) "
}], "Text",
  CellTags->"The exponentially weighted moving-average EWMA Chart"],

Cell["EWMA Chart", "Subsection",
  CellTags->"The exponentially weighted moving-average EWMA Chart"],

Cell[TextData[{
  "EWMAReport[",
  StyleBox["data",
    FontSlant->"Italic"],
  ", ",
  StyleBox["mu, lamb, sig, L ",
    FontSlant->"Italic"],
  "] \tgives {",
  StyleBox["k",
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`X\_k\)]],
  " ,",
  Cell[BoxData[
      \(TraditionalForm\`UCL\_k\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`LCL\_k\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`z\_k\)]],
  "}\n\nEWMAChart[",
  StyleBox["data",
    FontSlant->"Italic"],
  ", ",
  StyleBox["mu, lamb, sig, L",
    FontSlant->"Italic"],
  "]\t \tplots the EWMA control chart."
}], "DefinitionBox",
  CellTags->"The exponentially weighted moving-average EWMA Chart"],

Cell["Example ", "Subsection",
  CellTags->"The exponentially weighted moving-average EWMA Chart"],

Cell[BoxData[
    \(\(data3\  = 
        {9.45, 7.99, 9.29, 11.66, 12.16, 10.18, 8.04, 11.46, 9.2, 10.34, 
          9.03, 11.47, 10.51, 9.4, 10.08, 9.37, 10.62, 10.31, 8.52, 10.84, 
          10.9, 9.33, 12.29, 11.5, 10.6, 11.08, 10.38, 11.62, 11.31, 10.52};
      \)\)], "Input",
  CellLabel->"In[33]:=",
  CellTags->"The exponentially weighted moving-average EWMA Chart"],

Cell[TextData[{
  "Typical values  of \[Lambda] and ",
  StyleBox["L",
    FontSlant->"Italic"],
  " are \[Lambda]=0.1, L =2.7. "
}], "Text",
  CellTags->"The exponentially weighted moving-average EWMA Chart"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?EWMAReport\)\)], "Input",
  CellLabel->"In[34]:=",
  CellTags->"The exponentially weighted moving-average EWMA Chart"],

Cell["\<\
EWMAReport[list,lamb,sig,L] give k, Xk, UCL,
   LCL and zk of the entries in list.\
\>", "Print",
  CellLabel->"From In[34]:=",
  CellTags->"The exponentially weighted moving-average EWMA Chart"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(EWMAReport[data3, 10, \ 0.1, 1, \ 2.7]\)], "Input",
  CellLabel->"In[35]:=",
  CellTags->"The exponentially weighted moving-average EWMA Chart"],

Cell[OutputFormData["\<\
{{\"k\", \"UCL\", \"LCL\", \"Zk\"}, 
 {{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 
   13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 
   23, 24, 25, 26, 27, 28, 29, 30}, 
  {10.27, 10.36324784927099, 
   10.424003172157946, 10.467462018671036, 
   10.499901788863573, 10.524709878687537, 
   10.543975707179792, 10.559094582071246, 
   10.571047518931788, 10.580549022728746, 
   10.588132728141323, 10.594204582435943, 
   10.599077674002443, 10.6029960100908, 
   10.606151295000014, 10.608695086121497, 
   10.610747790314013, 10.612405437053342, 
   10.613744848988015, 10.614827633669835, 
   10.615703293389341, 10.616411665891626, 
   10.616984851431788, 10.617448741666873, 
   10.617824237428952, 10.618128221785156, 
   10.618374339570696, 10.6185736231929, 
   10.618734995875531, 10.618865676902578}, 
  {9.73, 9.63675215072901, 
   9.575996827842054, 9.532537981328964, 
   9.500098211136427, 9.475290121312463, 
   9.456024292820208, 9.440905417928754, 
   9.428952481068212, 9.419450977271254, 
   9.411867271858677, 9.405795417564057, 
   9.400922325997557, 9.3970039899092, 
   9.393848704999986, 9.391304913878503, 
   9.389252209685987, 9.387594562946658, 
   9.386255151011985, 9.385172366330165, 
   9.384296706610659, 9.383588334108374, 
   9.383015148568212, 9.382551258333127, 
   9.382175762571048, 9.381871778214844, 
   9.381625660429304, 9.3814263768071, 
   9.381265004124469, 9.381134323097422}, 
  {9.945, 9.7495, 9.70355, 9.899195, 
   10.1252755, 10.130747950000002, 
   9.921673155000002, 10.075505839500003, 
   9.987955255550004, 10.023159729995005, 
   9.923843756995504, 10.078459381295954, 
   10.121613443166359, 10.049452098849722, 
   10.05250688896475, 9.984256200068275, 
   10.047830580061447, 10.074047522055304, 
   9.918642769849773, 10.010778492864796, 
   10.099700643578316, 10.022730579220484, 
   10.249457521298435, 10.374511769168592, 
   10.397060592251734, 10.465354533026561, 
   10.456819079723905, 10.573137171751515, 
   10.646823454576364, 10.634141109118728}}}\
\>", "\<\
k    UCL       LCL       Zk

1    10.27     9.73      9.945
2    10.3632   9.63675   9.7495
3    10.424    9.576     9.70355
4    10.4675   9.53254   9.8992
5    10.4999   9.5001    10.1253
6    10.5247   9.47529   10.1307
7    10.544    9.45602   9.92167
8    10.5591   9.44091   10.0755
9    10.571    9.42895   9.98796
10   10.5805   9.41945   10.0232
11   10.5881   9.41187   9.92384
12   10.5942   9.4058    10.0785
13   10.5991   9.40092   10.1216
14   10.603    9.397     10.0495
15   10.6062   9.39385   10.0525
16   10.6087   9.3913    9.98426
17   10.6107   9.38925   10.0478
18   10.6124   9.38759   10.074
19   10.6137   9.38626   9.91864
20   10.6148   9.38517   10.0108
21   10.6157   9.3843    10.0997
22   10.6164   9.38359   10.0227
23   10.617    9.38302   10.2495
24   10.6174   9.38255   10.3745
25   10.6178   9.38218   10.3971
26   10.6181   9.38187   10.4654
27   10.6184   9.38163   10.4568
28   10.6186   9.38143   10.5731
29   10.6187   9.38127   10.6468
30   10.6189   9.38113   10.6341\
\>"], "Output",
  CellLabel->"Out[35]//TableForm=",
  LineSpacing->{1, 0},
  CellTags->"The exponentially weighted moving-average EWMA Chart"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(\[IndentingNewLine]\)\(?EWMAChart\)\)\)], "Input",
  CellLabel->"In[36]:=",
  CellTags->"The exponentially weighted moving-average EWMA Chart"],

Cell["\<\
EWMAChart[list,lamb,sig,L] plots the EWMA
   chart of the entries in list.\
\>", "Print",
  CellLabel->"From In[36]:=",
  CellTags->"The exponentially weighted moving-average EWMA Chart"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(EWMAChart[data3, 10, \ 0.1, 1, \ 2.7]\)], "Input",
  CellLabel->"In[37]:=",
  CellTags->"The exponentially weighted moving-average EWMA Chart"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.031746 -3.76582 0.406915 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.18254 -0.0125 -3 -9 ]
[.18254 -0.0125 3 0 ]
[.34127 -0.0125 -6 -9 ]
[.34127 -0.0125 6 0 ]
[.5 -0.0125 -6 -9 ]
[.5 -0.0125 6 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -26 -21.5625 ]
[.5 -0.0125 26 -9 ]
[-0.0125 .05918 -18 -4.5 ]
[-0.0125 .05918 0 4.5 ]
[-0.0125 .14056 -18 -4.5 ]
[-0.0125 .14056 0 4.5 ]
[-0.0125 .22195 -18 -4.5 ]
[-0.0125 .22195 0 4.5 ]
[-0.0125 .30333 -12 -4.5 ]
[-0.0125 .30333 0 4.5 ]
[-0.0125 .38471 -24 -4.5 ]
[-0.0125 .38471 0 4.5 ]
[-0.0125 .46609 -24 -4.5 ]
[-0.0125 .46609 0 4.5 ]
[-0.0125 .54748 -24 -4.5 ]
[-0.0125 .54748 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -36.5625 -14 ]
[-0.01875 .30902 -24 14 ]
[.5 .63053 -56 0 ]
[.5 .63053 56 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .30333 m
1 .30333 L
s
0 g
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(5)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(10)] .34127 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(15)] .5 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(20)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(25)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(30)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -87 -25.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(subgroup) show
111.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .05918 m
.00625 .05918 L
s
[(9.4)] -0.0125 .05918 1 0 Mshowa
0 .14056 m
.00625 .14056 L
s
[(9.6)] -0.0125 .14056 1 0 Mshowa
0 .22195 m
.00625 .22195 L
s
[(9.8)] -0.0125 .22195 1 0 Mshowa
0 .30333 m
.00625 .30333 L
s
[(10)] -0.0125 .30333 1 0 Mshowa
0 .38471 m
.00625 .38471 L
s
[(10.2)] -0.0125 .38471 1 0 Mshowa
0 .46609 m
.00625 .46609 L
s
[(10.4)] -0.0125 .46609 1 0 Mshowa
0 .54748 m
.00625 .54748 L
s
[(10.6)] -0.0125 .54748 1 0 Mshowa
.125 Mabswid
0 .07953 m
.00375 .07953 L
s
0 .09987 m
.00375 .09987 L
s
0 .12022 m
.00375 .12022 L
s
0 .16091 m
.00375 .16091 L
s
0 .18125 m
.00375 .18125 L
s
0 .2016 m
.00375 .2016 L
s
0 .24229 m
.00375 .24229 L
s
0 .26264 m
.00375 .26264 L
s
0 .28298 m
.00375 .28298 L
s
0 .32367 m
.00375 .32367 L
s
0 .34402 m
.00375 .34402 L
s
0 .36437 m
.00375 .36437 L
s
0 .40506 m
.00375 .40506 L
s
0 .4254 m
.00375 .4254 L
s
0 .44575 m
.00375 .44575 L
s
0 .48644 m
.00375 .48644 L
s
0 .50679 m
.00375 .50679 L
s
0 .52713 m
.00375 .52713 L
s
0 .03883 m
.00375 .03883 L
s
0 .01849 m
.00375 .01849 L
s
0 .56782 m
.00375 .56782 L
s
0 .58817 m
.00375 .58817 L
s
0 .60852 m
.00375 .60852 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -105.281 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
75 10.2813 translate
90 rotate
-75 -10.2813 translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(EWMA) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -117 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(EWMA) show
93.000 12.813 moveto
(Control) show
141.000 12.813 moveto
(chart) show
171.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.001 w
.05556 .4132 m
.0873 .45114 L
.11905 .47586 L
.15079 .49355 L
.18254 .50675 L
.21429 .51684 L
.24603 .52468 L
.27778 .53083 L
.30952 .5357 L
.34127 .53956 L
.37302 .54265 L
.40476 .54512 L
.43651 .5471 L
.46825 .5487 L
.5 .54998 L
.53175 .55102 L
.56349 .55185 L
.59524 .55253 L
.62698 .55307 L
.65873 .55351 L
.69048 .55387 L
.72222 .55416 L
.75397 .55439 L
.78571 .55458 L
.81746 .55473 L
.84921 .55485 L
.88095 .55495 L
.9127 .55504 L
.94444 .5551 L
.97619 .55515 L
s
.0001 w
.05556 .4132 m
.05556 .4132 L
.05556 .4132 L
.05556 .4132 L
.05556 .4132 L closepath F
.0873 .45114 m
.0873 .45114 L
.0873 .45114 L
.0873 .45114 L
.0873 .45114 L closepath F
.11905 .47586 m
.11905 .47586 L
.11905 .47586 L
.11905 .47586 L
.11905 .47586 L closepath F
.15079 .49355 m
.15079 .49355 L
.15079 .49355 L
.15079 .49355 L
.15079 .49355 L closepath F
.18254 .50675 m
.18254 .50675 L
.18254 .50675 L
.18254 .50675 L
.18254 .50675 L closepath F
.21429 .51684 m
.21429 .51684 L
.21429 .51684 L
.21429 .51684 L
.21429 .51684 L closepath F
.24603 .52468 m
.24603 .52468 L
.24603 .52468 L
.24603 .52468 L
.24603 .52468 L closepath F
.27778 .53083 m
.27778 .53083 L
.27778 .53083 L
.27778 .53083 L
.27778 .53083 L closepath F
.30952 .5357 m
.30952 .5357 L
.30952 .5357 L
.30952 .5357 L
.30952 .5357 L closepath F
.34127 .53956 m
.34127 .53956 L
.34127 .53956 L
.34127 .53956 L
.34127 .53956 L closepath F
.37302 .54265 m
.37302 .54265 L
.37302 .54265 L
.37302 .54265 L
.37302 .54265 L closepath F
.40476 .54512 m
.40476 .54512 L
.40476 .54512 L
.40476 .54512 L
.40476 .54512 L closepath F
.43651 .5471 m
.43651 .5471 L
.43651 .5471 L
.43651 .5471 L
.43651 .5471 L closepath F
.46825 .5487 m
.46825 .5487 L
.46825 .5487 L
.46825 .5487 L
.46825 .5487 L closepath F
.5 .54998 m
.5 .54998 L
.5 .54998 L
.5 .54998 L
.5 .54998 L closepath F
.53175 .55102 m
.53175 .55102 L
.53175 .55102 L
.53175 .55102 L
.53175 .55102 L closepath F
.56349 .55185 m
.56349 .55185 L
.56349 .55185 L
.56349 .55185 L
.56349 .55185 L closepath F
.59524 .55253 m
.59524 .55253 L
.59524 .55253 L
.59524 .55253 L
.59524 .55253 L closepath F
.62698 .55307 m
.62698 .55307 L
.62698 .55307 L
.62698 .55307 L
.62698 .55307 L closepath F
.65873 .55351 m
.65873 .55351 L
.65873 .55351 L
.65873 .55351 L
.65873 .55351 L closepath F
.69048 .55387 m
.69048 .55387 L
.69048 .55387 L
.69048 .55387 L
.69048 .55387 L closepath F
.72222 .55416 m
.72222 .55416 L
.72222 .55416 L
.72222 .55416 L
.72222 .55416 L closepath F
.75397 .55439 m
.75397 .55439 L
.75397 .55439 L
.75397 .55439 L
.75397 .55439 L closepath F
.78571 .55458 m
.78571 .55458 L
.78571 .55458 L
.78571 .55458 L
.78571 .55458 L closepath F
.81746 .55473 m
.81746 .55473 L
.81746 .55473 L
.81746 .55473 L
.81746 .55473 L closepath F
.84921 .55485 m
.84921 .55485 L
.84921 .55485 L
.84921 .55485 L
.84921 .55485 L closepath F
.88095 .55495 m
.88095 .55495 L
.88095 .55495 L
.88095 .55495 L
.88095 .55495 L closepath F
.9127 .55504 m
.9127 .55504 L
.9127 .55504 L
.9127 .55504 L
.9127 .55504 L closepath F
.94444 .5551 m
.94444 .5551 L
.94444 .5551 L
.94444 .5551 L
.94444 .5551 L closepath F
.97619 .55515 m
.97619 .55515 L
.97619 .55515 L
.97619 .55515 L
.97619 .55515 L closepath F
.001 w
.05556 .19346 m
.0873 .15552 L
.11905 .1308 L
.15079 .11311 L
.18254 .09991 L
.21429 .08982 L
.24603 .08198 L
.27778 .07582 L
.30952 .07096 L
.34127 .06709 L
.37302 .06401 L
.40476 .06154 L
.43651 .05955 L
.46825 .05796 L
.5 .05668 L
.53175 .05564 L
.56349 .05481 L
.59524 .05413 L
.62698 .05359 L
.65873 .05315 L
.69048 .05279 L
.72222 .0525 L
.75397 .05227 L
.78571 .05208 L
.81746 .05193 L
.84921 .0518 L
.88095 .0517 L
.9127 .05162 L
.94444 .05156 L
.97619 .0515 L
s
.0001 w
.05556 .19346 m
.05556 .19346 L
.05556 .19346 L
.05556 .19346 L
.05556 .19346 L closepath F
.0873 .15552 m
.0873 .15552 L
.0873 .15552 L
.0873 .15552 L
.0873 .15552 L closepath F
.11905 .1308 m
.11905 .1308 L
.11905 .1308 L
.11905 .1308 L
.11905 .1308 L closepath F
.15079 .11311 m
.15079 .11311 L
.15079 .11311 L
.15079 .11311 L
.15079 .11311 L closepath F
.18254 .09991 m
.18254 .09991 L
.18254 .09991 L
.18254 .09991 L
.18254 .09991 L closepath F
.21429 .08982 m
.21429 .08982 L
.21429 .08982 L
.21429 .08982 L
.21429 .08982 L closepath F
.24603 .08198 m
.24603 .08198 L
.24603 .08198 L
.24603 .08198 L
.24603 .08198 L closepath F
.27778 .07582 m
.27778 .07582 L
.27778 .07582 L
.27778 .07582 L
.27778 .07582 L closepath F
.30952 .07096 m
.30952 .07096 L
.30952 .07096 L
.30952 .07096 L
.30952 .07096 L closepath F
.34127 .06709 m
.34127 .06709 L
.34127 .06709 L
.34127 .06709 L
.34127 .06709 L closepath F
.37302 .06401 m
.37302 .06401 L
.37302 .06401 L
.37302 .06401 L
.37302 .06401 L closepath F
.40476 .06154 m
.40476 .06154 L
.40476 .06154 L
.40476 .06154 L
.40476 .06154 L closepath F
.43651 .05955 m
.43651 .05955 L
.43651 .05955 L
.43651 .05955 L
.43651 .05955 L closepath F
.46825 .05796 m
.46825 .05796 L
.46825 .05796 L
.46825 .05796 L
.46825 .05796 L closepath F
.5 .05668 m
.5 .05668 L
.5 .05668 L
.5 .05668 L
.5 .05668 L closepath F
.53175 .05564 m
.53175 .05564 L
.53175 .05564 L
.53175 .05564 L
.53175 .05564 L closepath F
.56349 .05481 m
.56349 .05481 L
.56349 .05481 L
.56349 .05481 L
.56349 .05481 L closepath F
.59524 .05413 m
.59524 .05413 L
.59524 .05413 L
.59524 .05413 L
.59524 .05413 L closepath F
.62698 .05359 m
.62698 .05359 L
.62698 .05359 L
.62698 .05359 L
.62698 .05359 L closepath F
.65873 .05315 m
.65873 .05315 L
.65873 .05315 L
.65873 .05315 L
.65873 .05315 L closepath F
.69048 .05279 m
.69048 .05279 L
.69048 .05279 L
.69048 .05279 L
.69048 .05279 L closepath F
.72222 .0525 m
.72222 .0525 L
.72222 .0525 L
.72222 .0525 L
.72222 .0525 L closepath F
.75397 .05227 m
.75397 .05227 L
.75397 .05227 L
.75397 .05227 L
.75397 .05227 L closepath F
.78571 .05208 m
.78571 .05208 L
.78571 .05208 L
.78571 .05208 L
.78571 .05208 L closepath F
.81746 .05193 m
.81746 .05193 L
.81746 .05193 L
.81746 .05193 L
.81746 .05193 L closepath F
.84921 .0518 m
.84921 .0518 L
.84921 .0518 L
.84921 .0518 L
.84921 .0518 L closepath F
.88095 .0517 m
.88095 .0517 L
.88095 .0517 L
.88095 .0517 L
.88095 .0517 L closepath F
.9127 .05162 m
.9127 .05162 L
.9127 .05162 L
.9127 .05162 L
.9127 .05162 L closepath F
.94444 .05156 m
.94444 .05156 L
.94444 .05156 L
.94444 .05156 L
.94444 .05156 L closepath F
.97619 .0515 m
.97619 .0515 L
.97619 .0515 L
.97619 .0515 L
.97619 .0515 L closepath F
.001 w
.05556 .28095 m
.0873 .2014 L
.11905 .1827 L
.15079 .26231 L
.18254 .35431 L
.21429 .35653 L
.24603 .27146 L
.27778 .33405 L
.30952 .29843 L
.34127 .31275 L
.37302 .27234 L
.40476 .33526 L
.43651 .35282 L
.46825 .32345 L
.5 .32469 L
.53175 .29692 L
.56349 .32279 L
.59524 .33346 L
.62698 .27022 L
.65873 .30771 L
.69048 .3439 L
.72222 .31258 L
.75397 .40484 L
.78571 .45572 L
.81746 .4649 L
.84921 .49269 L
.88095 .48922 L
.9127 .53655 L
.94444 .56653 L
.97619 .56137 L
s
.0001 w
.05556 .28095 -2.5 2.5 Mabsadd m
.05556 .28095 2.5 2.5 Mabsadd L
.05556 .28095 2.5 -2.5 Mabsadd L
.05556 .28095 -2.5 -2.5 Mabsadd L
.05556 .28095 -2.5 2.5 Mabsadd L closepath F
.0873 .2014 -2.5 2.5 Mabsadd m
.0873 .2014 2.5 2.5 Mabsadd L
.0873 .2014 2.5 -2.5 Mabsadd L
.0873 .2014 -2.5 -2.5 Mabsadd L
.0873 .2014 -2.5 2.5 Mabsadd L closepath F
.11905 .1827 -2.5 2.5 Mabsadd m
.11905 .1827 2.5 2.5 Mabsadd L
.11905 .1827 2.5 -2.5 Mabsadd L
.11905 .1827 -2.5 -2.5 Mabsadd L
.11905 .1827 -2.5 2.5 Mabsadd L closepath F
.15079 .26231 -2.5 2.5 Mabsadd m
.15079 .26231 2.5 2.5 Mabsadd L
.15079 .26231 2.5 -2.5 Mabsadd L
.15079 .26231 -2.5 -2.5 Mabsadd L
.15079 .26231 -2.5 2.5 Mabsadd L closepath F
.18254 .35431 -2.5 2.5 Mabsadd m
.18254 .35431 2.5 2.5 Mabsadd L
.18254 .35431 2.5 -2.5 Mabsadd L
.18254 .35431 -2.5 -2.5 Mabsadd L
.18254 .35431 -2.5 2.5 Mabsadd L closepath F
.21429 .35653 -2.5 2.5 Mabsadd m
.21429 .35653 2.5 2.5 Mabsadd L
.21429 .35653 2.5 -2.5 Mabsadd L
.21429 .35653 -2.5 -2.5 Mabsadd L
.21429 .35653 -2.5 2.5 Mabsadd L closepath F
.24603 .27146 -2.5 2.5 Mabsadd m
.24603 .27146 2.5 2.5 Mabsadd L
.24603 .27146 2.5 -2.5 Mabsadd L
.24603 .27146 -2.5 -2.5 Mabsadd L
.24603 .27146 -2.5 2.5 Mabsadd L closepath F
.27778 .33405 -2.5 2.5 Mabsadd m
.27778 .33405 2.5 2.5 Mabsadd L
.27778 .33405 2.5 -2.5 Mabsadd L
.27778 .33405 -2.5 -2.5 Mabsadd L
.27778 .33405 -2.5 2.5 Mabsadd L closepath F
.30952 .29843 -2.5 2.5 Mabsadd m
.30952 .29843 2.5 2.5 Mabsadd L
.30952 .29843 2.5 -2.5 Mabsadd L
.30952 .29843 -2.5 -2.5 Mabsadd L
.30952 .29843 -2.5 2.5 Mabsadd L closepath F
.34127 .31275 -2.5 2.5 Mabsadd m
.34127 .31275 2.5 2.5 Mabsadd L
.34127 .31275 2.5 -2.5 Mabsadd L
.34127 .31275 -2.5 -2.5 Mabsadd L
.34127 .31275 -2.5 2.5 Mabsadd L closepath F
.37302 .27234 -2.5 2.5 Mabsadd m
.37302 .27234 2.5 2.5 Mabsadd L
.37302 .27234 2.5 -2.5 Mabsadd L
.37302 .27234 -2.5 -2.5 Mabsadd L
.37302 .27234 -2.5 2.5 Mabsadd L closepath F
.40476 .33526 -2.5 2.5 Mabsadd m
.40476 .33526 2.5 2.5 Mabsadd L
.40476 .33526 2.5 -2.5 Mabsadd L
.40476 .33526 -2.5 -2.5 Mabsadd L
.40476 .33526 -2.5 2.5 Mabsadd L closepath F
.43651 .35282 -2.5 2.5 Mabsadd m
.43651 .35282 2.5 2.5 Mabsadd L
.43651 .35282 2.5 -2.5 Mabsadd L
.43651 .35282 -2.5 -2.5 Mabsadd L
.43651 .35282 -2.5 2.5 Mabsadd L closepath F
.46825 .32345 -2.5 2.5 Mabsadd m
.46825 .32345 2.5 2.5 Mabsadd L
.46825 .32345 2.5 -2.5 Mabsadd L
.46825 .32345 -2.5 -2.5 Mabsadd L
.46825 .32345 -2.5 2.5 Mabsadd L closepath F
.5 .32469 -2.5 2.5 Mabsadd m
.5 .32469 2.5 2.5 Mabsadd L
.5 .32469 2.5 -2.5 Mabsadd L
.5 .32469 -2.5 -2.5 Mabsadd L
.5 .32469 -2.5 2.5 Mabsadd L closepath F
.53175 .29692 -2.5 2.5 Mabsadd m
.53175 .29692 2.5 2.5 Mabsadd L
.53175 .29692 2.5 -2.5 Mabsadd L
.53175 .29692 -2.5 -2.5 Mabsadd L
.53175 .29692 -2.5 2.5 Mabsadd L closepath F
.56349 .32279 -2.5 2.5 Mabsadd m
.56349 .32279 2.5 2.5 Mabsadd L
.56349 .32279 2.5 -2.5 Mabsadd L
.56349 .32279 -2.5 -2.5 Mabsadd L
.56349 .32279 -2.5 2.5 Mabsadd L closepath F
.59524 .33346 -2.5 2.5 Mabsadd m
.59524 .33346 2.5 2.5 Mabsadd L
.59524 .33346 2.5 -2.5 Mabsadd L
.59524 .33346 -2.5 -2.5 Mabsadd L
.59524 .33346 -2.5 2.5 Mabsadd L closepath F
.62698 .27022 -2.5 2.5 Mabsadd m
.62698 .27022 2.5 2.5 Mabsadd L
.62698 .27022 2.5 -2.5 Mabsadd L
.62698 .27022 -2.5 -2.5 Mabsadd L
.62698 .27022 -2.5 2.5 Mabsadd L closepath F
.65873 .30771 -2.5 2.5 Mabsadd m
.65873 .30771 2.5 2.5 Mabsadd L
.65873 .30771 2.5 -2.5 Mabsadd L
.65873 .30771 -2.5 -2.5 Mabsadd L
.65873 .30771 -2.5 2.5 Mabsadd L closepath F
.69048 .3439 -2.5 2.5 Mabsadd m
.69048 .3439 2.5 2.5 Mabsadd L
.69048 .3439 2.5 -2.5 Mabsadd L
.69048 .3439 -2.5 -2.5 Mabsadd L
.69048 .3439 -2.5 2.5 Mabsadd L closepath F
.72222 .31258 -2.5 2.5 Mabsadd m
.72222 .31258 2.5 2.5 Mabsadd L
.72222 .31258 2.5 -2.5 Mabsadd L
.72222 .31258 -2.5 -2.5 Mabsadd L
.72222 .31258 -2.5 2.5 Mabsadd L closepath F
.75397 .40484 -2.5 2.5 Mabsadd m
.75397 .40484 2.5 2.5 Mabsadd L
.75397 .40484 2.5 -2.5 Mabsadd L
.75397 .40484 -2.5 -2.5 Mabsadd L
.75397 .40484 -2.5 2.5 Mabsadd L closepath F
.78571 .45572 -2.5 2.5 Mabsadd m
.78571 .45572 2.5 2.5 Mabsadd L
.78571 .45572 2.5 -2.5 Mabsadd L
.78571 .45572 -2.5 -2.5 Mabsadd L
.78571 .45572 -2.5 2.5 Mabsadd L closepath F
.81746 .4649 -2.5 2.5 Mabsadd m
.81746 .4649 2.5 2.5 Mabsadd L
.81746 .4649 2.5 -2.5 Mabsadd L
.81746 .4649 -2.5 -2.5 Mabsadd L
.81746 .4649 -2.5 2.5 Mabsadd L closepath F
.84921 .49269 -2.5 2.5 Mabsadd m
.84921 .49269 2.5 2.5 Mabsadd L
.84921 .49269 2.5 -2.5 Mabsadd L
.84921 .49269 -2.5 -2.5 Mabsadd L
.84921 .49269 -2.5 2.5 Mabsadd L closepath F
.88095 .48922 -2.5 2.5 Mabsadd m
.88095 .48922 2.5 2.5 Mabsadd L
.88095 .48922 2.5 -2.5 Mabsadd L
.88095 .48922 -2.5 -2.5 Mabsadd L
.88095 .48922 -2.5 2.5 Mabsadd L closepath F
.9127 .53655 -2.5 2.5 Mabsadd m
.9127 .53655 2.5 2.5 Mabsadd L
.9127 .53655 2.5 -2.5 Mabsadd L
.9127 .53655 -2.5 -2.5 Mabsadd L
.9127 .53655 -2.5 2.5 Mabsadd L closepath F
.94444 .56653 -2.5 2.5 Mabsadd m
.94444 .56653 2.5 2.5 Mabsadd L
.94444 .56653 2.5 -2.5 Mabsadd L
.94444 .56653 -2.5 -2.5 Mabsadd L
.94444 .56653 -2.5 2.5 Mabsadd L closepath F
.97619 .56137 -2.5 2.5 Mabsadd m
.97619 .56137 2.5 2.5 Mabsadd L
.97619 .56137 2.5 -2.5 Mabsadd L
.97619 .56137 -2.5 -2.5 Mabsadd L
.97619 .56137 -2.5 2.5 Mabsadd L closepath F
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[37]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012Q000`40O003h00Oogoo/Goo003oOona
Ool00?mook5oo`00kWoo10007goo0`00W7oo003bOol00`00Oomoo`0MOol00`00Oomoo`2KOol00?9o
o`03001oogoo01eoo`03001oogoo09]oo`00dgoo1@001Goo0`0000Aoo`00001oo`800004Ool00000
0004Ool300000goo001oo`03Ool50005Ool40005Ool300000goo00000002Ool00`00Ool00002002I
Ool00==oo`03001oogoo009oo`05001oogooOol00003Ool20003Ool20003Ool01000Oomoo`000goo
0P001Goo00<007ooOol01Goo00<007ooOol00Woo00D007ooOomoo`0000=oo`8000=oo`8000=oo`03
001oogoo09Ioo`00f7oo00D007ooOomoo`0000Aoo`05001oogooOol00004Ool01000Oomoo`0017oo
00<007ooOol00goo00<007ooOol01Goo00<007ooOol00Woo00D007ooOomoo`0000Aoo`05001oogoo
Ool00004Ool00`00Oomoo`2FOol00=Aoo`@000Aoo`03001oogoo009oo`05001oogooOol00004Ool0
1000Oomoo`0017oo00<007ooOol00goo00<007ooOol01Goo00<007ooOol00Woo00D007ooOomoo`00
00Aoo`05001oogooOol00004Ool00`00Oomoo`2FOol00==oo`03001oogoo009oo`05001oogooOol0
0004Ool01000Oomoogoo0P000goo00@007ooOol000=oo`8000Eoo`8000Ioo`03001oogoo009oo`05
001oogooOol00004Ool01000Oomoogoo0P000goo00<007ooOol0UWoo003DOol50002Ool20003Ool2
0003Ool00`00Ool000020004Ool300000goo00000003Ool2000017oo0000000017oo10000goo0P00
0goo0P000Woo0P0000Aoo`00000009Uoo`00iGoo00<007ooOol0b7oo003UOol00`00Oomoo`38Ool0
0>Aoo`800<Yoo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol005Aoo`@0035o
o`@002]oo`L000=oo`@002Moo`L000=oo`@002Moo`H000Aoo`@002Moo`H000Aoo`@002Qoo`@000Eo
o`@001Ioo`00Dgoo00<007ooOol00Woo00<007ooOol0;Goo00<007ooOol00Woo00<007ooOol0:goo
00<007ooOol00goo00<007ooOol00Woo00<007ooOol09goo00<007ooOol00goo00<007ooOol00Woo
00<007ooOol097oo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo02Aoo`03001oogoo
009oo`05001oogooOol00004Ool00`00Oomoo`0TOol00`00Oomoo`02Ool01@00Oomoogoo000017oo
00<007ooOol04goo001COol00`00Oomoo`02Ool00`00Oomoo`0bOol00`00Oomoo`0[Ool00`00Oomo
o`03Ool00`00Oomoo`02Ool00`00Oomoo`0WOol00`00Oomoo`08Ool00`00Oomoo`0UOol00`00Oomo
o`05Ool00`00Oomoo`02Ool00`00Oomoo`0UOol00`00Oomoo`0:Ool00`00Oomoo`0YOol01@00Oomo
ogoo000017oo00<007ooOol04goo001COol00`00Oomoo`02Ool00`00Oomoo`0bOol00`00Oomoo`0[
Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`0WOol00`00Oomoo`08Ool00`00Oomoo`0V
Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`0VOol00`00Oomoo`09Ool00`00Oomoo`0Y
Ool01@00Oomoogoo000017oo00<007ooOol04goo001COol00`00Oomoo`02Ool00`00Oomoo`0bOol0
0`00Oomoo`0[Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`0WOol00`00Oomoo`08Ool0
0`00Oomoo`0WOol00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`0WOol00`00Oomoo`08Ool0
0`00Oomoo`0WOol20004Ool00`00Oomoo`02Ool00`00Oomoo`0COol005=oo`03001oogoo009oo`03
001oogoo02ioo`@002ioo`03001oogoo00=oo`03001oogoo009oo`03001oogoo02Moo`03001oogoo
00Aoo`@002]oo`03001oogoo009oo`03001oogoo009oo`03001oogoo02Qoo`03001oogoo00=oo`@0
02aoo`05001oogooOol00004Ool00`00Oomoo`0COol005=oo`03001oogoo009oo`03001oogoo02io
o`03001oogoo02moo`03001oogoo00=oo`03001oogoo009oo`03001oogoo02Moo`03001oogoo00Ao
o`03001oogoo02Qoo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`0TOol00`00Oomo
o`02Ool00`00Oomoo`02Ool00`00Oomoo`0]Ool01@00Oomoogoo000017oo00<007ooOol04goo001C
Ool00`00Oomoo`02Ool00`00Oomoo`0^Ool00`00Oomoo`0]Ool30005Ool00`00Oomoo`02Ool00`00
Oomoo`0UOol30006Ool00`00Oomoo`0XOol00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007oo
Ool097oo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol0:7oo00<007ooOol00Woo00D007oo
Oomoo`0000Aoo`03001oogoo01=oo`00E7oo1000<Goo1@00;Goo00<007ooOol017oo1000:Woo00<0
07ooOol017oo1@009goo10001Goo1000:7oo10001Goo1@009goo10001Goo10005Woo003oOonaOol0
0?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol004ioool0050001=o
o`00CWoo00<007ooOol01Goo00<007ooOol027oo00<007ooOol01goo00<007ooOol027oo00<007oo
Ool01goo00<007ooOol027oo00<007ooOol027oo00<007ooOol01goo00<007ooOol027oo00<007oo
Ool01goo00<007ooOol027oo00<007ooOol027oo00<007ooOol01goo00<007ooOol027oo00<007oo
Ool01goo00<007ooOol027oo00<007ooOol027oo00<007ooOol01goo00<007ooOol027oo00<007oo
Ool01goo00<007ooOol027oo00<007ooOol027oo00<007ooOol01goo00<007ooOol027oo00<007oo
Ool01goo00<007ooOol027oo00<007ooOol027oo00<007ooOol01goo00<007ooOol027oo00<007oo
Ool01goo00<007ooOol027oo00<007ooOol06Goo001>Ool00`00Oomoo`05Ool00`00Oomoo`0bOol0
0`00Oomoo`0bOol00`00Oomoo`0bOol00`00Oomoo`0bOol00`00Oomoo`0bOol00`00Oomoo`0bOol0
0`00Oomoo`0IOol004ioo`03001oogoo0?moof1oo`00CWoo00<007ooOol0ogooH7oo001>Ool00`00
Oomoo`3oOomPOol004ioo`800?moof5oo`00CWoo00<007ooOol0ogooH7oo001>Ool00`00Oomoo`3o
OomPOol004ioo`03001oogoo0?moof1oo`00CWoo00<007ooOol0ogooH7oo001>Ool00`00Oomoo`3o
OomPOol004ioo`03001oogoo0?moof1oo`00CWoo0P00ogooHGoo001>Ool00`00Oomoo`3oOomPOol0
04ioo`03001oogoo0?moof1oo`00<Goo0`001goo0P001goo10001Woo00<007ooOol0ogooH7oo000d
Ool00`00Oomoo`04Ool20009Ool00`00Oomoo`05Ool00`00Oomoo`3oOol:Oolk000KOol003Eoo`03
001oogoo00ioo`03001oogoo00Eoo`03001oogoo0;AooeD005Ioo`00=Woo00<007ooOol02Goo1P00
1Woo00<007ooOol0U7oo8000Zgoo000bOol5000<Ool01000Oomoo`001goo0`00RWoo2P00bgoo000a
Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool01000Oomoo`001goo00<007ooOol0Ogoo2`00eGoo000a
Ool00`00Oomoo`02Ool00`00Oomoo`0;Ool00`00Ool00007Ool00`00Oomoo`1eOol:003POol0035o
o`03001oogoo009oo`03001oogoo00]oo`03001oo`0000Moo`03001oogoo06Yoo`/00>Yoo`00<Woo
10003goo0P001goo00<007ooOol0Ggoo2`00mGoo001>Ool00`00Oomoo`1IOol6003oOol1Ool004io
o`03001oogoo05Eoo`@00?moo`Moo`00CWoo0P00DWoo1000ogoo2goo001>Ool00`00Oomoo`1=Ool4
003oOol?Ool004ioo`03001oogoo04Qoo`D00?mooa=oo`00CWoo00<007ooOol0A7oo1000ogoo67oo
001>Ool00`00Oomoo`10Ool4003oOolLOol004ioo`03001oogoo03aoo`@00?moob1oo`00CWoo0P00
>Woo0`00ogoo97oo001>Ool00`00Oomoo`0gOol2003oOolWOol004ioo`03001oogoo03Eoo`800?mo
obUoo`00CWoo00<007ooOol0<goo0P00ogoo:goo001>Ool00`00Oomoo`0aOol2003oOol]Ool004io
o`03001oogoo02moo`800?moobmoo`00CWoo00<007ooOol0;Goo0P00ogoo<Goo001>Ool2000/Ool2
003oOolcOol004ioo`03001oogoo02Yoo`03001oogoo0?mooc=oo`00CWoo00<007ooOol0:7oo0P00
ogoo=Woo001>Ool00`00Oomoo`0VOol2003oOolhOol0035oo`<000Moo`8000Moo`@000Ioo`03001o
ogoo02Eoo`03001oogoo0?moocQoo`00=7oo00<007ooOol017oo0P001Woo00<007ooOol00Woo00<0
07ooOol00goo00<007ooOol08goo0P00ogoo>goo000eOol00`00Oomoo`0;Ool00`00Oomoo`02Ool0
0`00Oomoo`03Ool00`00Oomoo`0ROol00`00Oomoo`3oOolkOol003Ioo`03001oogoo00Yoo`8000=o
o`03001oogoo00=oo`<0025oo`03001oogoo0?moocaoo`00<Woo1@0037oo00<007oo00000P001Woo
00<007ooOol07goo0P00ogoo?goo000aOol00`00Oomoo`02Ool00`00Oomoo`0:Ool00`00Oomoo`08
Ool00`00Oomoo`0NOol00`00Oomoo`3oOoloOol0035oo`03001oogoo009oo`03001oogoo00]oo`03
001oogoo00Moo`03001oogoo01eoo`03001oogoo0?mood1oo`00<Goo00<007ooOol00Woo00<007oo
Ool037oo00<007ooOol01Woo00<007ooOol06goo0P00ogoo@goo000bOol4000@Ool30005Ool00`00
Oomoo`0JOol00`00Oomoo`3oOom3Ool004ioo`03001oogoo01Uoo`03001oogoo0?moodAoo`00CWoo
0P006Goo00<007ooOol0ogooAGoo001>Ool00`00Oomoo`0HOol00`00Oomoo`3oOom5Ool004ioo`03
001oogoo01Moo`03001oogoo0?moodIoo`00CWoo00<007ooOol05Woo00<007ooOol0ogooAgoo001>
Ool00`00Oomoo`0EOol00`00Oomoo`09Ool8003oOolgOol004ioo`03001oogoo01Eoo`03001oogoo
00Uoo`P00?moocMoo`00CWoo00<007ooOol057oo00<007ooOol02Woo2000ogoo=goo001>Ool2000D
Ool00`00Oomoo`0;Ool8003oOolgOol004ioo`03001oogoo019oo`03001oogoo00aoo`P00?moocMo
o`00CWoo00<007ooOol04Woo00<007ooOol037oo2000ogoo=goo001>Ool00`00Oomoo`0AOol00`00
Oomoo`0;Ool:003oOolgOol004ioo`03001oogoo011oo`03001oogoo00=oo`T0009oo`P00?moocMo
o`00CWoo00<007ooOol05Woo20002Goo00<007ooOol0ogoo=Woo001>Ool2000GOol80009Ool00`00
Oomoo`3oOolfOol004ioo`03001oogoo01Ioo`P000Yoo`03001oogoo0?moocEoo`00CWoo00<007oo
Ool05Woo20002Woo00<007ooOol0ogoo=Goo001>Ool00`00Oomoo`0FOol8000:Ool00`00Oomoo`3o
OoleOol0035oo`<000Moo`8000Ioo`@000Moo`03001oogoo01Ioo`P000]oo`03001oogoo0?moocAo
o`00=7oo00<007ooOol017oo0P001Goo00<007ooOol00Woo00<007ooOol017oo00<007ooOol067oo
00<007ooOol03Woo00<007ooOol0ogoo=7oo000eOol00`00Oomoo`0:Ool00`00Oomoo`02Ool00`00
Oomoo`04Ool00`00Oomoo`0HOol00`00Oomoo`0>Ool00`00Oomoo`3oOoldOol003Ioo`03001oogoo
00Uoo`03001oogoo009oo`03001oogoo00Aoo`<001Moo`03001oogoo011oo`03001oogoo0?mooc=o
o`00<Woo1@0037oo10001goo00<007ooOol05goo00<007ooOol047oo00<007ooOol0ogoo<goo000a
Ool00`00Oomoo`02Ool00`00Oomoo`09Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`0G
Ool00`00Oomoo`0AOol00`00Oomoo`3oOolbOol0035oo`03001oogoo009oo`03001oogoo00Uoo`03
001oogoo009oo`03001oogoo00Aoo`03001oogoo01Ioo`03001oogoo019oo`03001oogoo0?mooc9o
o`00<Goo00<007ooOol00Woo00<007ooOol02Goo00<007ooOol00Woo00<007ooOol017oo00<007oo
Ool05Woo00<007ooOol04Woo00<007ooOol0ogoo<Woo000bOol4000=Ool40007Ool00`00Oomoo`0F
Ool00`00Oomoo`0COol00`00Oomoo`3oOolaOol004ioo`03001oogoo01Eoo`03001oogoo01Aoo`03
001oogoo0?mooc5oo`00CWoo0P005Woo00<007ooOol057oo00<007ooOol0ogoo<Goo001>Ool00`00
Oomoo`0DOol00`00Oomoo`0FOol00`00Oomoo`3oOol`Ool004ioo`03001oogoo01Aoo`03001oogoo
01Ioo`03001oogoo0?mooc1oo`00CWoo00<007ooOol057oo00<007ooOol05goo00<007ooOol0ogoo
;goo001>Ool00`00Oomoo`0COol00`00Oomoo`0FOol7003oOol]Ool004ioo`03001oogoo01=oo`03
001oogoo01Ioo`L00?moobeoo`005Woo00<007ooOol017oo00<007ooOol0;Woo00<007ooOol04goo
00<007ooOol05Woo1`00ogoo;Goo000FOol8000`Ool2000COol00`00Oomoo`0GOol7000HOol8000S
Ool7001>Ool7002=Ool001Ioo`04001oogoo0003Ool00`00Oomoo`0^Ool00`00Oomoo`0BOol00`00
Oomoo`0GOol7000HOol8000SOol7001>Ool7002=Ool001Ioo`04001oogoo0003Ool00`00Oomoo`0^
Ool00`00Oomoo`0AOol00`00Oomoo`0HOol7000HOol8000SOol7001>Ool7002=Ool001Ioo`03001o
o`000080009oo`03001oogoo02ioo`03001oogoo00aoo`L001Uoo`L001Qoo`P002=oo`L004ioo`L0
08eoo`005Woo00<007ooOol017oo00<007ooOol0;Woo00<007ooOol037oo1`007Goo00<007ooOol0
67oo20008goo1`00CWoo1`00SGoo000FOol30002Ool3000`Ool00`00Oomoo`0<Ool7000NOol00`00
Oomoo`0GOol8000SOol7001>Ool7002=Ool004ioo`03001oogoo00aoo`L001ioo`03001oogoo01Mo
o`P002=oo`L004ioo`L008eoo`005Woo00<007ooOol0=Goo0P003Goo1`007goo00<007ooOol05Woo
20008goo1`00Cgoo00<007ooOol00goo00<007ooOol0RWoo000FOol7000aOol00`00Oomoo`0<Ool7
000OOol00`00Oomoo`0HOol00`00Oomoo`02Ool00`00Oomoo`0QOol00`00Oomoo`03Ool00`00Oomo
o`1<Ool00`00Oomoo`05Ool00`00Oomoo`29Ool001Ioo`03001oogoo00Aoo`03001oogoo02ioo`03
001oogoo00aoo`L001moo`03001oogoo01Qoo`03001oogoo009oo`03001oogoo00aoo`L000eoo`03
001oogoo00Eoo`03001oogoo02]oo`L001Uoo`03001oogoo00Ioo`03001oogoo08Qoo`006Goo1000
77oo1`000goo10001goo00<007ooOol037oo1`0087oo00<007ooOol05goo00<007ooOol00goo00<0
07ooOol02goo1`003Goo00<007ooOol01Goo00<007ooOol0:goo1`0067oo00<007ooOol027oo00<0
07ooOol0Qgoo000GOol2000SOol00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00
Oomoo`0cOol00`00Oomoo`0FOol00`00Oomoo`04Ool00`00Oomoo`0;Ool7000<Ool00`00Oomoo`07
Ool00`00Oomoo`0ZOol7000HOol00`00Oomoo`09Ool00`00Oomoo`26Ool001Uoo`@001moo`03001o
ogoo00=oo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo03=oo`03001oogoo01Ioo`03001o
ogoo00Eoo`03001oogoo00Yoo`L000]oo`03001oogoo00Qoo`03001oogoo02Yoo`L001Moo`03001o
ogoo00Uoo`P0089oo`005Woo00<007ooOol017oo00<007ooOol077oo00<007ooOol00goo00<007oo
Ool00Woo00<007ooOol017oo0`00=00?00<0000?00l0500?00<0000?00l01P0?00<0000?00l02P0?
1`002P0?00<0000?00l02P0?00<0000?00l0:@0?1`005`0?00<0000?00l02@0?2000K`0?4goo000F
Ool7000OOol00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`0dOol00`00
Oomoo`0DOol00`00Oomoo`07Ool00`00Oomoo`09Ool900000goo00000006000<Ool00`00Oomoo`0Y
Ool8000EOol00`00Oomoo`0:Ool8000=Ool8001]Ool001Ioo`03001oogoo02=oo`03001oogoo00=o
o`03001oogoo009oo`03001oogoo00Aoo`03001oogoo03Aoo`03001oogoo01Aoo`03001oogoo00Mo
o`03001oogoo00Uoo`L0009oo`T000eoo`03001oogoo02Qoo`L00003Ool007oo01=oo`03001oogoo
00Yoo`P000eoo`P006eoo`005Woo00<007ooOol017oo00<007ooOol077oo00<007ooOol00goo00<0
07ooOol00Woo00<007ooOol017oo00<007ooOol0=Goo00<007ooOol04Woo00<007ooOol02Goo00<0
07ooOol027oo1`000goo20003Goo00<007ooOol09Woo0P002Goo0P004Goo00<007ooOol02goo2000
3Goo2000KGoo000FOol8000LOol30005Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`0e
Ool00`00Oomoo`0BOol00`00Oomoo`09Ool00`00Oomoo`07Ool00`00Oomoo`08Ool8000>Ool00`00
Oomoo`0BOol7000;Ool00`00Oomoo`0:Ool8000:Ool00`00Oomoo`0;Ool8000=Ool8001]Ool001Io
o`8000Eoo`03001oogoo01aoo`03001oogoo00Aoo`@000Moo`03001oogoo03Ioo`03001oogoo015o
o`03001oogoo00Yoo`03001oogoo00Eoo`03001oogoo00Uoo`P000ioo`03001oogoo019oo`L000=o
o`P000eoo`P000Uoo`03001oogoo00aoo`P000eoo`P006eoo`0067oo0`00<goo00<007ooOol0=Woo
00<007ooOol047oo00<007ooOol02goo00<007ooOol017oo00<007ooOol02Woo20003goo00<007oo
Ool04Goo1`000goo20003Goo20002Goo00<007ooOol037oo2@0037oo2000KGoo000KOol00`00Oomo
o`0`Ool2000gOol00`00Oomoo`0@Ool00`00Oomoo`0<Ool00`00Oomoo`02Ool00`00Oomoo`0;Ool8
000?Ool00`00Oomoo`0AOol900000goo00000006000=Ool80008Ool00`00Oomoo`0FOol00`00Oomo
o`09Ool8001]Ool001Qoo`<003=oo`03001oogoo03Moo`03001oogoo00moo`03001oogoo00Yoo`P0
029oo`P000ioo`L0009oo`T000eoo`X00003Ool0000000H001Ioo`03001oogoo00Uoo`03001oogoo
009oo`03001oogoo06eoo`005Woo0P001Goo00<007ooOol0;Woo00<007ooOol0=goo00<007ooOol0
3Woo00<007ooOol02goo20008Woo20003Woo1`000goo20003Goo20000Woo2@005goo00<007ooOol0
1goo00<007ooOol017oo00<007ooOol0K7oo000FOol8000`Ool00`00Oomoo`0gOol00`00Oomoo`0>
Ool00`00Oomoo`0;Ool8000ROol8000>Ool70003Ool8000=Ool80003Ool8000HOol00`00Oomoo`05
Ool00`00Oomoo`05Ool00`00Oomoo`1/Ool001Ioo`03001oogoo00Aoo`03001oogoo02ioo`03001o
ogoo03Qoo`03001oogoo00eoo`03001oogoo00]oo`P0029oo`P000eoo`P000=oo`P000eoo`P000=o
o`P001Qoo`P000Uoo`03001oogoo06]oo`007Goo00<007ooOol0;Woo00<007ooOol0>7oo00<007oo
Ool037oo00<007ooOol037oo20008Woo200037oo00<007ooOol0:Goo200067oo1`002Woo00<007oo
Ool0Jgoo000LOol2000`Ool00`00Oomoo`0iOol00`00Oomoo`0;Ool00`00Oomoo`0<Ool8000ROol9
000:Ool00`00Oomoo`0ZOol8000HOol7000:Ool00`00Oomoo`1[Ool001Yoo`800003Ool007oo02mo
o`8003Yoo`03001oogoo00Yoo`03001oogoo00eoo`P0029oo`P00003Ool0000000P002eoo`P001Qo
o`L000]oo`03001oogoo06Yoo`005Woo00H007oo000007oo000bOol00`00Oomoo`0fOol80003Ool7
000hOol80003Ool8001=Ool7000;Ool00`00Oomoo`1ZOol001Ioo`8000=oo`03001oogoo031oo`03
001oogoo03Ioo`P000=oo`L004=oo`P004eoo`L000]oo`03001oogoo06Yoo`0067oo0P0000=oo`00
Ool0<Goo00<007ooOol0=Woo2P0000=oo`0000001@00@goo2000CGoo1`0037oo00<007ooOol0JGoo
000JOol200000goo001oo`0_Ool00`00Oomoo`0fOol80002Ool80013Ool8001=Ool7000<Ool00`00
Oomoo`1YOol001aoo`80031oo`03001oogoo03Ioo`P000=oo`L004=oo`P0061oo`03001oogoo06Uo
o`007Goo00<007ooOol0;Woo00<007ooOol0=Woo20000goo1`00@goo2000HGoo00<007ooOol0J7oo
001>Ool2000gOol80003Ool70013Ool8001QOol00`00Oomoo`1XOol004ioo`03001oogoo045oo`L0
0:eoo`03001oogoo06Moo`00CWoo00<007ooOol0mGoo00<007ooOol0Igoo000WOol70003Ool40006
Ool20005Ool60006Ool00`00Oomoo`3eOol00`00Oomoo`1WOol002Yoo`03001oogoo00=oo`03001o
ogoo009oo`03001oogoo00=oo`8000Eoo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo0?Io
o`03001oogoo06Ioo`00:Woo00<007ooOol00goo00<007ooOol00Woo00<007ooOol02goo00<007oo
Ool027oo00<007ooOol0mWoo00<007ooOol0IWoo000ZOol00`00Oomoo`03Ool00`00Oomoo`02Ool0
0`00Oomoo`0<Ool00`00Oomoo`07Ool00`00Oomoo`3fOol00`00Oomoo`1VOol002Yoo`03001oogoo
00=oo`03001oogoo009oo`03001oogoo00eoo`03001oogoo00Ioo`<00?Moo`03001oogoo06Eoo`00
:Woo00<007ooOol00goo00<007ooOol00Woo00<007ooOol03Woo00<007ooOol01Goo00<007ooOol0
mgoo00<007ooOol0IGoo000ZOol00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool00`00
Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`3hOol00`00Oomoo`1TOol002Qoo`<000Eoo`03001o
ogoo009oo`03001oogoo00Yoo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo0?Qoo`03001o
ogoo06Aoo`00:Woo00<007ooOol017oo10003Woo10001goo00<007ooOol0mGoo2000HWoo001>Ool0
0`00Oomoo`3eOol8001ROol004ioo`800?Ioo`P0069oo`00CWoo00<007ooOol0mGoo2000HWoo001>
Ool00`00Oomoo`3eOol8001ROol004ioo`03001oogoo011oo`03001oogoo0>9oo`P0069oo`00CWoo
00<007ooOol04Goo00<007ooOol0hGoo2000HWoo001>Ool00`00Oomoo`0BOol00`00Oomoo`3WOol0
0`00Oomoo`1POol004ioo`03001oogoo019oo`03001oogoo0>Qoo`03001oogoo05moo`00CWoo0P00
57oo00<007ooOol0igoo00<007ooOol0Ggoo001>Ool00`00Oomoo`0DOol00`00Oomoo`3WOol00`00
Oomoo`1NOol004ioo`03001oogoo01Eoo`03001oogoo0>Ioo`03001oogoo05ioo`00CWoo00<007oo
Ool05Goo00<007ooOol0igoo00<007ooOol0GGoo001>Ool00`00Oomoo`0FOol00`00Oomoo`3VOol0
0`00Oomoo`1MOol004ioo`03001oogoo01Moo`03001oogoo0>Ioo`03001oogoo05aoo`00CWoo00<0
07ooOol067oo00<007ooOol0iWoo00<007ooOol0Fgoo001>Ool2000IOol00`00Oomoo`3VOol00`00
Oomoo`1KOol004ioo`03001oogoo01Uoo`03001oogoo0>Aoo`L005Qoo`00CWoo00<007ooOol06Woo
00<007ooOol0hgoo1`00F7oo000WOol70003Ool40006Ool20007Ool40006Ool00`00Oomoo`0KOol2
003SOol7001HOol002Yoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00=oo`8000Uoo`03
001oogoo00Eoo`03001oogoo01eoo`03001oogoo0>1oo`T00003Ool0000000H004eoo`00:Woo00<0
07ooOol00goo00<007ooOol00Woo00<007ooOol03Woo00<007ooOol01Goo00<007ooOol07Woo00<0
07ooOol0ggoo1`000Woo2@00CGoo000ZOol00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`0:
Ool60006Ool00`00Oomoo`0OOol2003OOol70003Ool8001=Ool002Yoo`03001oogoo00=oo`03001o
ogoo009oo`03001oogoo00]oo`04001oogoo0007Ool3000QOol00`00Oomoo`3LOol70003Ool8001=
Ool002Yoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00]oo`04001oogoo0007Ool00`00
Oomoo`0ROol00`00Oomoo`3UOol8001=Ool002Yoo`03001oogoo00=oo`03001oogoo009oo`03001o
ogoo00aoo`03001oo`0000Moo`03001oogoo02=oo`800>Eoo`P004eoo`00:7oo0`001Goo00<007oo
Ool00Woo00<007ooOol037oo00<007oo00001goo00<007ooOol09Goo00<007ooOol0hWoo2@00C7oo
000ZOol00`00Oomoo`04Ool4000@Ool20007Ool00`00Oomoo`0VOol2003[Ool2001:Ool004ioo`03
001oogoo02Qoo`800>]oo`03001oogoo00Moo`P003Qoo`00CWoo00<007ooOol0:Woo00<007ooOol0
j7oo1`000goo2000>7oo001>Ool2000/Ool2003XOol70003Ool8000hOol004ioo`03001oogoo02eo
o`800>Iooa8003Qoo`00CWoo00<007ooOol0;goo0P00i7oo1`000goo2000>7oo001>Ool00`00Oomo
o`0aOol3003QOol70003Ool8000hOol004ioo`03001oogoo03Aoo`800=moo`L000=oo`P003Qoo`00
CWoo00<007ooOol0=Woo0`00g7oo1`002Woo00<007ooOol0=Woo001>Ool2000jOol3003[Ool00`00
Oomoo`0eOol004ioo`03001oogoo03aoo`<00>Uoo`03001oogoo03Aoo`00CWoo00<007ooOol0?goo
0P00j7oo00<007ooOol0<goo001>Ool00`00Oomoo`11Ool3003UOol00`00Oomoo`0cOol004ioo`03
001oogoo04Aoo`@00>9oo`03001oogoo039oo`00CWoo00<007ooOol0B7oo1@00gWoo00<007ooOol0
<Goo001>Ool00`00Oomoo`1=Ool5003IOol00`00Oomoo`0aOol004ioo`8005=oo`H00=Aoo`03001o
ogoo031oo`00CWoo00<007ooOol0F7oo1@00cGoo2000;Goo001>Ool00`00Oomoo`1MOol50038Ool8
000]Ool002Moo`L000=oo`@000Ioo`8000Moo`@000Ioo`03001oogoo069oo`P00<1oo`P002eoo`00
:Woo00<007ooOol00goo00<007ooOol00Woo00<007ooOol00goo0P001Woo00<007ooOol00Woo00<0
07ooOol00goo00<007ooOol0JWoo2`00]Goo2000;Goo000ZOol00`00Oomoo`03Ool00`00Oomoo`02
Ool00`00Oomoo`0;Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`1eOol;002ZOol8000]
Ool002Yoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00]oo`8000=oo`03001oogoo00=o
o`03001oogoo081oo`X00:1oo`P002eoo`00:Woo00<007ooOol00goo00<007ooOol00Woo00<007oo
Ool02goo00<007oo00000P001Woo0`00RWoo5@00Rgoo2@00;7oo000ZOol00`00Oomoo`03Ool00`00
Oomoo`02Ool00`00Oomoo`0;Ool00`00Oomoo`08Ool00`00Oomoo`2OOolP001dOol00`00Oomoo`0Y
Ool002Yoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00aoo`03001oogoo00Moo`03001o
ogoo0;moohP001Qoo`00:7oo0`001Goo00<007ooOol00Woo00<007ooOol03Goo00<007ooOol01Woo
00<007ooOol0ogoo=Woo00<007ooOol01goo200067oo000ZOol00`00Oomoo`04Ool4000AOol30005
Ool00`00Oomoo`3oOolfOol70003Ool8000HOol004ioo`03001oogoo0?moocIoo`L0009oo`T001Qo
o`00CWoo00<007ooOol0ogoo=Woo2@0000=oo`0000001P0067oo001>Ool2003oOolgOol70003Ool8
000HOol004ioo`03001oogoo0?moocIoo`L000=oo`P001Qoo`00CWoo00<007ooOol0ogoo=Woo1`00
8goo001>Ool00`00Oomoo`3oOolfOol7000SOol004ioo`03001oogoo0?moof1oo`00CWoo00<007oo
Ool0ogooH7oo001>Ool00`00Oomoo`3oOomPOol004ioo`800?moof5oo`00CWoo00<007ooOol0ogoo
H7oo001>Ool00`00Oomoo`3oOomPOol004ioo`03001oogoo0?moof1oo`00CWoo00<007ooOol0ogoo
H7oo001>Ool00`00Oomoo`3oOomPOol004ioo`800?moof5oo`00CWoo00<007ooOol0ogooH7oo001>
Ool00`00Oomoo`3oOomPOol004ioo`03001oogoo0?moof1oo`00ogoo/Goo003oOonaOol00?mook5o
o`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo002U
Ool70003Ool01@00Oomoogoo00000Woo0`000goo1P000goo0`0037oo10001Goo10000goo0`000Woo
0`0017oo10000goo1@001Goo10000goo1`003Goo10000goo0`000Woo0`000goo1@000goo1@001Woo
1000Jgoo002VOol00`00Oomoo`02Ool02P00Oomoo`00Ool007oo001oo`000Woo00<007ooOol00goo
00@007ooOol000Eoo`03001oogoo00Yoo`03001oogoo009oo`05001oogooOol00004Ool01@00Oomo
ogoo000017oo00<007ooOol00Woo00<007ooOol00Woo00D007ooOomoo`0000Moo`03001oogoo009o
o`03001oogoo00=oo`03001oogoo00eoo`03001oogoo009oo`05001oogooOol00004Ool01@00Oomo
ogoo00000goo00<007ooOol00goo00<007ooOol01Woo00<007ooOol00Woo00<007ooOol0J7oo002V
Ool00`00Oomoo`02Ool02P00Oomoo`00Ool007oo001oo`000Woo00@007ooOol0009oo`04001oogoo
Ool5000<Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol00Woo
00<007ooOol01Woo00<007ooOol01Goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol037oo
00<007ooOol01goo00<007ooOol00Woo00D007ooOomoo`0000=oo`03001oogoo00=oo`03001oogoo
00Ioo`03001oogoo06eoo`00YWoo00@007ooOol000Aoo`07001oo`00Ool007oo00000Woo00L007oo
001oo`00Ool00003Ool01@00Oomoogoo000037oo00<007ooOol01goo00<007ooOol00Woo00D007oo
Oomoo`0000Aoo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo00Eoo`03001oogoo009oo`03
001oogoo00=oo`03001oogoo00aoo`03001oogoo00Moo`03001oogoo009oo`03001oogoo009oo`@0
00Eoo`03001oogoo00Ioo`03001oogoo06eoo`00YWoo100017oo00L007oo001oo`00Ool00002Ool0
1`00Ool007oo001oo`0000Aoo`03001oo`0000eoo`03001oogoo00Moo`03001oogoo009oo`04001o
ogooOol20003Ool00`00Oomoo`02Ool00`00Oomoo`06Ool20006Ool00`00Oomoo`02Ool00`00Oomo
o`03Ool00`00Oomoo`0=Ool01000Oomoogoo0P000goo0P000goo00D007ooOomoo`0000=oo`03001o
ogoo00=oo`8000Moo`03001oogoo06eoo`00YWoo00H007ooOol007oo0002Ool01000Oomoo`000Woo
00X007ooOol007oo001oo`00Ool000Aoo`03001oo`0000eoo`03001oogoo00=oo`03001oogoo009o
o`@000=oo`800004Ool000000003Ool70003Ool2000017oo0000000017oo10001Woo00<007ooOol0
3Woo0`0000=oo`00Ool00Woo00<007oo00000P001Goo0`001Goo0P0000Aoo`000000009oo`L006]o
o`00YWoo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0002Ool20003Ool20005Ool00`00
Oomoo`0=Ool01000Oomoogoo0P005Woo00<007ooOol06Goo00<007ooOol05Woo00<007ooOol06Goo
00<007ooOol0KGoo002UOol7000017oo000000000goo1P000goo0`000goo0P0047oo0`0000=oo`00
Ool05Goo00<007ooOol06Goo00<007ooOol05Woo00<007ooOol06Goo00<007ooOol0KGoo003oOol:
Ool3000GOol2002;Ool00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00\
\>"],
  ImageRangeCache->{{{135, 422}, {647.813, 470.875}} -> {-27.3385, 14.1956, 
  0.141834, 0.0110654}},
  CellTags->"The exponentially weighted moving-average EWMA Chart"],

Cell[OutputFormData["\<\
Graphics[{Thickness[0.001], 
  {{{Dashing[{0}], Line[{{1, 10.27}, 
       {2, 10.36324784927099}, 
       {3, 10.424003172157946}, 
       {4, 10.467462018671036}, 
       {5, 10.499901788863573}, 
       {6, 10.524709878687537}, 
       {7, 10.543975707179792}, 
       {8, 10.559094582071246}, 
       {9, 10.571047518931788}, 
       {10, 10.580549022728746}, 
       {11, 10.588132728141323}, 
       {12, 10.594204582435943}, 
       {13, 10.599077674002443}, 
       {14, 10.6029960100908}, 
       {15, 10.606151295000014}, 
       {16, 10.608695086121497}, 
       {17, 10.610747790314013}, 
       {18, 10.612405437053342}, 
       {19, 10.613744848988015}, 
       {20, 10.614827633669835}, 
       {21, 10.615703293389341}, 
       {22, 10.616411665891626}, 
       {23, 10.616984851431788}, 
       {24, 10.617448741666873}, 
       {25, 10.617824237428952}, 
       {26, 10.618128221785156}, 
       {27, 10.618374339570696}, 
       {28, 10.6185736231929}, 
       {29, 10.618734995875531}, 
       {30, 10.618865676902578}}]}, 
    {{}, {}, {}, {}, {}, {}, {}, {}, {}, 
     {}, {}, {}, {}, {}, {}, {}, {}, {}, 
     {}, {}, {}, {}, {}, {}, {}, {}, {}, 
     {}, {}, {}}, {GrayLevel[0], 
     Dashing[{}], Thickness[0.0001], 
     PointSize[0.01], Polygon[
      {Offset[{0, 0}, {1, 10.27}], 
       Offset[{0, 0}, {1, 10.27}], 
       Offset[{0, 0}, {1, 10.27}], 
       Offset[{0, 0}, {1, 10.27}], 
       Offset[{0, 0}, {1, 10.27}]}], 
     Polygon[{Offset[{0, 0}, 
        {2, 10.36324784927099}], 
       Offset[{0, 0}, 
        {2, 10.36324784927099}], 
       Offset[{0, 0}, 
        {2, 10.36324784927099}], 
       Offset[{0, 0}, 
        {2, 10.36324784927099}], 
       Offset[{0, 0}, 
        {2, 10.36324784927099}]}], 
     Polygon[{Offset[{0, 0}, 
        {3, 10.424003172157946}], 
       Offset[{0, 0}, 
        {3, 10.424003172157946}], 
       Offset[{0, 0}, 
        {3, 10.424003172157946}], 
       Offset[{0, 0}, 
        {3, 10.424003172157946}], 
       Offset[{0, 0}, 
        {3, 10.424003172157946}]}], 
     Polygon[{Offset[{0, 0}, 
        {4, 10.467462018671036}], 
       Offset[{0, 0}, 
        {4, 10.467462018671036}], 
       Offset[{0, 0}, 
        {4, 10.467462018671036}], 
       Offset[{0, 0}, 
        {4, 10.467462018671036}], 
       Offset[{0, 0}, 
        {4, 10.467462018671036}]}], 
     Polygon[{Offset[{0, 0}, 
        {5, 10.499901788863573}], 
       Offset[{0, 0}, 
        {5, 10.499901788863573}], 
       Offset[{0, 0}, 
        {5, 10.499901788863573}], 
       Offset[{0, 0}, 
        {5, 10.499901788863573}], 
       Offset[{0, 0}, 
        {5, 10.499901788863573}]}], 
     Polygon[{Offset[{0, 0}, 
        {6, 10.524709878687537}], 
       Offset[{0, 0}, 
        {6, 10.524709878687537}], 
       Offset[{0, 0}, 
        {6, 10.524709878687537}], 
       Offset[{0, 0}, 
        {6, 10.524709878687537}], 
       Offset[{0, 0}, 
        {6, 10.524709878687537}]}], 
     Polygon[{Offset[{0, 0}, 
        {7, 10.543975707179792}], 
       Offset[{0, 0}, 
        {7, 10.543975707179792}], 
       Offset[{0, 0}, 
        {7, 10.543975707179792}], 
       Offset[{0, 0}, 
        {7, 10.543975707179792}], 
       Offset[{0, 0}, 
        {7, 10.543975707179792}]}], 
     Polygon[{Offset[{0, 0}, 
        {8, 10.559094582071246}], 
       Offset[{0, 0}, 
        {8, 10.559094582071246}], 
       Offset[{0, 0}, 
        {8, 10.559094582071246}], 
       Offset[{0, 0}, 
        {8, 10.559094582071246}], 
       Offset[{0, 0}, 
        {8, 10.559094582071246}]}], 
     Polygon[{Offset[{0, 0}, 
        {9, 10.571047518931788}], 
       Offset[{0, 0}, 
        {9, 10.571047518931788}], 
       Offset[{0, 0}, 
        {9, 10.571047518931788}], 
       Offset[{0, 0}, 
        {9, 10.571047518931788}], 
       Offset[{0, 0}, 
        {9, 10.571047518931788}]}], 
     Polygon[{Offset[{0, 0}, 
        {10, 10.580549022728746}], 
       Offset[{0, 0}, {10, 
         10.580549022728746}], 
       Offset[{0, 0}, {10, 
         10.580549022728746}], 
       Offset[{0, 0}, {10, 
         10.580549022728746}], 
       Offset[{0, 0}, {10, 
         10.580549022728746}]}], 
     Polygon[{Offset[{0, 0}, 
        {11, 10.588132728141323}], 
       Offset[{0, 0}, {11, 
         10.588132728141323}], 
       Offset[{0, 0}, {11, 
         10.588132728141323}], 
       Offset[{0, 0}, {11, 
         10.588132728141323}], 
       Offset[{0, 0}, {11, 
         10.588132728141323}]}], 
     Polygon[{Offset[{0, 0}, 
        {12, 10.594204582435943}], 
       Offset[{0, 0}, {12, 
         10.594204582435943}], 
       Offset[{0, 0}, {12, 
         10.594204582435943}], 
       Offset[{0, 0}, {12, 
         10.594204582435943}], 
       Offset[{0, 0}, {12, 
         10.594204582435943}]}], 
     Polygon[{Offset[{0, 0}, 
        {13, 10.599077674002443}], 
       Offset[{0, 0}, {13, 
         10.599077674002443}], 
       Offset[{0, 0}, {13, 
         10.599077674002443}], 
       Offset[{0, 0}, {13, 
         10.599077674002443}], 
       Offset[{0, 0}, {13, 
         10.599077674002443}]}], 
     Polygon[{Offset[{0, 0}, 
        {14, 10.6029960100908}], 
       Offset[{0, 0}, {14, 
         10.6029960100908}], Offset[{0, 0}, 
        {14, 10.6029960100908}], 
       Offset[{0, 0}, {14, 
         10.6029960100908}], Offset[{0, 0}, 
        {14, 10.6029960100908}]}], 
     Polygon[{Offset[{0, 0}, 
        {15, 10.606151295000014}], 
       Offset[{0, 0}, {15, 
         10.606151295000014}], 
       Offset[{0, 0}, {15, 
         10.606151295000014}], 
       Offset[{0, 0}, {15, 
         10.606151295000014}], 
       Offset[{0, 0}, {15, 
         10.606151295000014}]}], 
     Polygon[{Offset[{0, 0}, 
        {16, 10.608695086121497}], 
       Offset[{0, 0}, {16, 
         10.608695086121497}], 
       Offset[{0, 0}, {16, 
         10.608695086121497}], 
       Offset[{0, 0}, {16, 
         10.608695086121497}], 
       Offset[{0, 0}, {16, 
         10.608695086121497}]}], 
     Polygon[{Offset[{0, 0}, 
        {17, 10.610747790314013}], 
       Offset[{0, 0}, {17, 
         10.610747790314013}], 
       Offset[{0, 0}, {17, 
         10.610747790314013}], 
       Offset[{0, 0}, {17, 
         10.610747790314013}], 
       Offset[{0, 0}, {17, 
         10.610747790314013}]}], 
     Polygon[{Offset[{0, 0}, 
        {18, 10.612405437053342}], 
       Offset[{0, 0}, {18, 
         10.612405437053342}], 
       Offset[{0, 0}, {18, 
         10.612405437053342}], 
       Offset[{0, 0}, {18, 
         10.612405437053342}], 
       Offset[{0, 0}, {18, 
         10.612405437053342}]}], 
     Polygon[{Offset[{0, 0}, 
        {19, 10.613744848988015}], 
       Offset[{0, 0}, {19, 
         10.613744848988015}], 
       Offset[{0, 0}, {19, 
         10.613744848988015}], 
       Offset[{0, 0}, {19, 
         10.613744848988015}], 
       Offset[{0, 0}, {19, 
         10.613744848988015}]}], 
     Polygon[{Offset[{0, 0}, 
        {20, 10.614827633669835}], 
       Offset[{0, 0}, {20, 
         10.614827633669835}], 
       Offset[{0, 0}, {20, 
         10.614827633669835}], 
       Offset[{0, 0}, {20, 
         10.614827633669835}], 
       Offset[{0, 0}, {20, 
         10.614827633669835}]}], 
     Polygon[{Offset[{0, 0}, 
        {21, 10.615703293389341}], 
       Offset[{0, 0}, {21, 
         10.615703293389341}], 
       Offset[{0, 0}, {21, 
         10.615703293389341}], 
       Offset[{0, 0}, {21, 
         10.615703293389341}], 
       Offset[{0, 0}, {21, 
         10.615703293389341}]}], 
     Polygon[{Offset[{0, 0}, 
        {22, 10.616411665891626}], 
       Offset[{0, 0}, {22, 
         10.616411665891626}], 
       Offset[{0, 0}, {22, 
         10.616411665891626}], 
       Offset[{0, 0}, {22, 
         10.616411665891626}], 
       Offset[{0, 0}, {22, 
         10.616411665891626}]}], 
     Polygon[{Offset[{0, 0}, 
        {23, 10.616984851431788}], 
       Offset[{0, 0}, {23, 
         10.616984851431788}], 
       Offset[{0, 0}, {23, 
         10.616984851431788}], 
       Offset[{0, 0}, {23, 
         10.616984851431788}], 
       Offset[{0, 0}, {23, 
         10.616984851431788}]}], 
     Polygon[{Offset[{0, 0}, 
        {24, 10.617448741666873}], 
       Offset[{0, 0}, {24, 
         10.617448741666873}], 
       Offset[{0, 0}, {24, 
         10.617448741666873}], 
       Offset[{0, 0}, {24, 
         10.617448741666873}], 
       Offset[{0, 0}, {24, 
         10.617448741666873}]}], 
     Polygon[{Offset[{0, 0}, 
        {25, 10.617824237428952}], 
       Offset[{0, 0}, {25, 
         10.617824237428952}], 
       Offset[{0, 0}, {25, 
         10.617824237428952}], 
       Offset[{0, 0}, {25, 
         10.617824237428952}], 
       Offset[{0, 0}, {25, 
         10.617824237428952}]}], 
     Polygon[{Offset[{0, 0}, 
        {26, 10.618128221785156}], 
       Offset[{0, 0}, {26, 
         10.618128221785156}], 
       Offset[{0, 0}, {26, 
         10.618128221785156}], 
       Offset[{0, 0}, {26, 
         10.618128221785156}], 
       Offset[{0, 0}, {26, 
         10.618128221785156}]}], 
     Polygon[{Offset[{0, 0}, 
        {27, 10.618374339570696}], 
       Offset[{0, 0}, {27, 
         10.618374339570696}], 
       Offset[{0, 0}, {27, 
         10.618374339570696}], 
       Offset[{0, 0}, {27, 
         10.618374339570696}], 
       Offset[{0, 0}, {27, 
         10.618374339570696}]}], 
     Polygon[{Offset[{0, 0}, 
        {28, 10.6185736231929}], 
       Offset[{0, 0}, {28, 
         10.6185736231929}], Offset[{0, 0}, 
        {28, 10.6185736231929}], 
       Offset[{0, 0}, {28, 
         10.6185736231929}], Offset[{0, 0}, 
        {28, 10.6185736231929}]}], 
     Polygon[{Offset[{0, 0}, 
        {29, 10.618734995875531}], 
       Offset[{0, 0}, {29, 
         10.618734995875531}], 
       Offset[{0, 0}, {29, 
         10.618734995875531}], 
       Offset[{0, 0}, {29, 
         10.618734995875531}], 
       Offset[{0, 0}, {29, 
         10.618734995875531}]}], 
     Polygon[{Offset[{0, 0}, 
        {30, 10.618865676902578}], 
       Offset[{0, 0}, {30, 
         10.618865676902578}], 
       Offset[{0, 0}, {30, 
         10.618865676902578}], 
       Offset[{0, 0}, {30, 
         10.618865676902578}], 
       Offset[{0, 0}, {30, 
         10.618865676902578}]}]}}, 
   {{Dashing[{0}], Line[{{1, 9.73}, 
       {2, 9.63675215072901}, 
       {3, 9.575996827842054}, 
       {4, 9.532537981328964}, 
       {5, 9.500098211136427}, 
       {6, 9.475290121312463}, 
       {7, 9.456024292820208}, 
       {8, 9.440905417928754}, 
       {9, 9.428952481068212}, 
       {10, 9.419450977271254}, 
       {11, 9.411867271858677}, 
       {12, 9.405795417564057}, 
       {13, 9.400922325997557}, 
       {14, 9.3970039899092}, 
       {15, 9.393848704999986}, 
       {16, 9.391304913878503}, 
       {17, 9.389252209685987}, 
       {18, 9.387594562946658}, 
       {19, 9.386255151011985}, 
       {20, 9.385172366330165}, 
       {21, 9.384296706610659}, 
       {22, 9.383588334108374}, 
       {23, 9.383015148568212}, 
       {24, 9.382551258333127}, 
       {25, 9.382175762571048}, 
       {26, 9.381871778214844}, 
       {27, 9.381625660429304}, 
       {28, 9.3814263768071}, 
       {29, 9.381265004124469}, 
       {30, 9.381134323097422}}]}, 
    {{}, {}, {}, {}, {}, {}, {}, {}, {}, 
     {}, {}, {}, {}, {}, {}, {}, {}, {}, 
     {}, {}, {}, {}, {}, {}, {}, {}, {}, 
     {}, {}, {}}, {GrayLevel[0], 
     Dashing[{}], Thickness[0.0001], 
     PointSize[0.01], Polygon[
      {Offset[{0, 0}, {1, 9.73}], 
       Offset[{0, 0}, {1, 9.73}], 
       Offset[{0, 0}, {1, 9.73}], 
       Offset[{0, 0}, {1, 9.73}], 
       Offset[{0, 0}, {1, 9.73}]}], 
     Polygon[{Offset[{0, 0}, 
        {2, 9.63675215072901}], 
       Offset[{0, 0}, 
        {2, 9.63675215072901}], 
       Offset[{0, 0}, 
        {2, 9.63675215072901}], 
       Offset[{0, 0}, 
        {2, 9.63675215072901}], 
       Offset[{0, 0}, 
        {2, 9.63675215072901}]}], 
     Polygon[{Offset[{0, 0}, 
        {3, 9.575996827842054}], 
       Offset[{0, 0}, 
        {3, 9.575996827842054}], 
       Offset[{0, 0}, 
        {3, 9.575996827842054}], 
       Offset[{0, 0}, 
        {3, 9.575996827842054}], 
       Offset[{0, 0}, 
        {3, 9.575996827842054}]}], 
     Polygon[{Offset[{0, 0}, 
        {4, 9.532537981328964}], 
       Offset[{0, 0}, 
        {4, 9.532537981328964}], 
       Offset[{0, 0}, 
        {4, 9.532537981328964}], 
       Offset[{0, 0}, 
        {4, 9.532537981328964}], 
       Offset[{0, 0}, 
        {4, 9.532537981328964}]}], 
     Polygon[{Offset[{0, 0}, 
        {5, 9.500098211136427}], 
       Offset[{0, 0}, 
        {5, 9.500098211136427}], 
       Offset[{0, 0}, 
        {5, 9.500098211136427}], 
       Offset[{0, 0}, 
        {5, 9.500098211136427}], 
       Offset[{0, 0}, 
        {5, 9.500098211136427}]}], 
     Polygon[{Offset[{0, 0}, 
        {6, 9.475290121312463}], 
       Offset[{0, 0}, 
        {6, 9.475290121312463}], 
       Offset[{0, 0}, 
        {6, 9.475290121312463}], 
       Offset[{0, 0}, 
        {6, 9.475290121312463}], 
       Offset[{0, 0}, 
        {6, 9.475290121312463}]}], 
     Polygon[{Offset[{0, 0}, 
        {7, 9.456024292820208}], 
       Offset[{0, 0}, 
        {7, 9.456024292820208}], 
       Offset[{0, 0}, 
        {7, 9.456024292820208}], 
       Offset[{0, 0}, 
        {7, 9.456024292820208}], 
       Offset[{0, 0}, 
        {7, 9.456024292820208}]}], 
     Polygon[{Offset[{0, 0}, 
        {8, 9.440905417928754}], 
       Offset[{0, 0}, 
        {8, 9.440905417928754}], 
       Offset[{0, 0}, 
        {8, 9.440905417928754}], 
       Offset[{0, 0}, 
        {8, 9.440905417928754}], 
       Offset[{0, 0}, 
        {8, 9.440905417928754}]}], 
     Polygon[{Offset[{0, 0}, 
        {9, 9.428952481068212}], 
       Offset[{0, 0}, 
        {9, 9.428952481068212}], 
       Offset[{0, 0}, 
        {9, 9.428952481068212}], 
       Offset[{0, 0}, 
        {9, 9.428952481068212}], 
       Offset[{0, 0}, 
        {9, 9.428952481068212}]}], 
     Polygon[{Offset[{0, 0}, 
        {10, 9.419450977271254}], 
       Offset[{0, 0}, {10, 
         9.419450977271254}], 
       Offset[{0, 0}, {10, 
         9.419450977271254}], 
       Offset[{0, 0}, {10, 
         9.419450977271254}], 
       Offset[{0, 0}, {10, 
         9.419450977271254}]}], 
     Polygon[{Offset[{0, 0}, 
        {11, 9.411867271858677}], 
       Offset[{0, 0}, {11, 
         9.411867271858677}], 
       Offset[{0, 0}, {11, 
         9.411867271858677}], 
       Offset[{0, 0}, {11, 
         9.411867271858677}], 
       Offset[{0, 0}, {11, 
         9.411867271858677}]}], 
     Polygon[{Offset[{0, 0}, 
        {12, 9.405795417564057}], 
       Offset[{0, 0}, {12, 
         9.405795417564057}], 
       Offset[{0, 0}, {12, 
         9.405795417564057}], 
       Offset[{0, 0}, {12, 
         9.405795417564057}], 
       Offset[{0, 0}, {12, 
         9.405795417564057}]}], 
     Polygon[{Offset[{0, 0}, 
        {13, 9.400922325997557}], 
       Offset[{0, 0}, {13, 
         9.400922325997557}], 
       Offset[{0, 0}, {13, 
         9.400922325997557}], 
       Offset[{0, 0}, {13, 
         9.400922325997557}], 
       Offset[{0, 0}, {13, 
         9.400922325997557}]}], 
     Polygon[{Offset[{0, 0}, 
        {14, 9.3970039899092}], 
       Offset[{0, 0}, {14, 
         9.3970039899092}], Offset[{0, 0}, 
        {14, 9.3970039899092}], 
       Offset[{0, 0}, {14, 
         9.3970039899092}], Offset[{0, 0}, 
        {14, 9.3970039899092}]}], 
     Polygon[{Offset[{0, 0}, 
        {15, 9.393848704999986}], 
       Offset[{0, 0}, {15, 
         9.393848704999986}], 
       Offset[{0, 0}, {15, 
         9.393848704999986}], 
       Offset[{0, 0}, {15, 
         9.393848704999986}], 
       Offset[{0, 0}, {15, 
         9.393848704999986}]}], 
     Polygon[{Offset[{0, 0}, 
        {16, 9.391304913878503}], 
       Offset[{0, 0}, {16, 
         9.391304913878503}], 
       Offset[{0, 0}, {16, 
         9.391304913878503}], 
       Offset[{0, 0}, {16, 
         9.391304913878503}], 
       Offset[{0, 0}, {16, 
         9.391304913878503}]}], 
     Polygon[{Offset[{0, 0}, 
        {17, 9.389252209685987}], 
       Offset[{0, 0}, {17, 
         9.389252209685987}], 
       Offset[{0, 0}, {17, 
         9.389252209685987}], 
       Offset[{0, 0}, {17, 
         9.389252209685987}], 
       Offset[{0, 0}, {17, 
         9.389252209685987}]}], 
     Polygon[{Offset[{0, 0}, 
        {18, 9.387594562946658}], 
       Offset[{0, 0}, {18, 
         9.387594562946658}], 
       Offset[{0, 0}, {18, 
         9.387594562946658}], 
       Offset[{0, 0}, {18, 
         9.387594562946658}], 
       Offset[{0, 0}, {18, 
         9.387594562946658}]}], 
     Polygon[{Offset[{0, 0}, 
        {19, 9.386255151011985}], 
       Offset[{0, 0}, {19, 
         9.386255151011985}], 
       Offset[{0, 0}, {19, 
         9.386255151011985}], 
       Offset[{0, 0}, {19, 
         9.386255151011985}], 
       Offset[{0, 0}, {19, 
         9.386255151011985}]}], 
     Polygon[{Offset[{0, 0}, 
        {20, 9.385172366330165}], 
       Offset[{0, 0}, {20, 
         9.385172366330165}], 
       Offset[{0, 0}, {20, 
         9.385172366330165}], 
       Offset[{0, 0}, {20, 
         9.385172366330165}], 
       Offset[{0, 0}, {20, 
         9.385172366330165}]}], 
     Polygon[{Offset[{0, 0}, 
        {21, 9.384296706610659}], 
       Offset[{0, 0}, {21, 
         9.384296706610659}], 
       Offset[{0, 0}, {21, 
         9.384296706610659}], 
       Offset[{0, 0}, {21, 
         9.384296706610659}], 
       Offset[{0, 0}, {21, 
         9.384296706610659}]}], 
     Polygon[{Offset[{0, 0}, 
        {22, 9.383588334108374}], 
       Offset[{0, 0}, {22, 
         9.383588334108374}], 
       Offset[{0, 0}, {22, 
         9.383588334108374}], 
       Offset[{0, 0}, {22, 
         9.383588334108374}], 
       Offset[{0, 0}, {22, 
         9.383588334108374}]}], 
     Polygon[{Offset[{0, 0}, 
        {23, 9.383015148568212}], 
       Offset[{0, 0}, {23, 
         9.383015148568212}], 
       Offset[{0, 0}, {23, 
         9.383015148568212}], 
       Offset[{0, 0}, {23, 
         9.383015148568212}], 
       Offset[{0, 0}, {23, 
         9.383015148568212}]}], 
     Polygon[{Offset[{0, 0}, 
        {24, 9.382551258333127}], 
       Offset[{0, 0}, {24, 
         9.382551258333127}], 
       Offset[{0, 0}, {24, 
         9.382551258333127}], 
       Offset[{0, 0}, {24, 
         9.382551258333127}], 
       Offset[{0, 0}, {24, 
         9.382551258333127}]}], 
     Polygon[{Offset[{0, 0}, 
        {25, 9.382175762571048}], 
       Offset[{0, 0}, {25, 
         9.382175762571048}], 
       Offset[{0, 0}, {25, 
         9.382175762571048}], 
       Offset[{0, 0}, {25, 
         9.382175762571048}], 
       Offset[{0, 0}, {25, 
         9.382175762571048}]}], 
     Polygon[{Offset[{0, 0}, 
        {26, 9.381871778214844}], 
       Offset[{0, 0}, {26, 
         9.381871778214844}], 
       Offset[{0, 0}, {26, 
         9.381871778214844}], 
       Offset[{0, 0}, {26, 
         9.381871778214844}], 
       Offset[{0, 0}, {26, 
         9.381871778214844}]}], 
     Polygon[{Offset[{0, 0}, 
        {27, 9.381625660429304}], 
       Offset[{0, 0}, {27, 
         9.381625660429304}], 
       Offset[{0, 0}, {27, 
         9.381625660429304}], 
       Offset[{0, 0}, {27, 
         9.381625660429304}], 
       Offset[{0, 0}, {27, 
         9.381625660429304}]}], 
     Polygon[{Offset[{0, 0}, 
        {28, 9.3814263768071}], 
       Offset[{0, 0}, {28, 
         9.3814263768071}], Offset[{0, 0}, 
        {28, 9.3814263768071}], 
       Offset[{0, 0}, {28, 
         9.3814263768071}], Offset[{0, 0}, 
        {28, 9.3814263768071}]}], 
     Polygon[{Offset[{0, 0}, 
        {29, 9.381265004124469}], 
       Offset[{0, 0}, {29, 
         9.381265004124469}], 
       Offset[{0, 0}, {29, 
         9.381265004124469}], 
       Offset[{0, 0}, {29, 
         9.381265004124469}], 
       Offset[{0, 0}, {29, 
         9.381265004124469}]}], 
     Polygon[{Offset[{0, 0}, 
        {30, 9.381134323097422}], 
       Offset[{0, 0}, {30, 
         9.381134323097422}], 
       Offset[{0, 0}, {30, 
         9.381134323097422}], 
       Offset[{0, 0}, {30, 
         9.381134323097422}], 
       Offset[{0, 0}, {30, 
         9.381134323097422}]}]}}, 
   {{Dashing[{0}], Line[{{1, 9.945}, 
       {2, 9.7495}, {3, 9.70355}, 
       {4, 9.899195}, {5, 10.1252755}, 
       {6, 10.130747950000002}, 
       {7, 9.921673155000002}, 
       {8, 10.075505839500003}, 
       {9, 9.987955255550004}, 
       {10, 10.023159729995005}, 
       {11, 9.923843756995504}, 
       {12, 10.078459381295954}, 
       {13, 10.121613443166359}, 
       {14, 10.049452098849722}, 
       {15, 10.05250688896475}, 
       {16, 9.984256200068275}, 
       {17, 10.047830580061447}, 
       {18, 10.074047522055304}, 
       {19, 9.918642769849773}, 
       {20, 10.010778492864796}, 
       {21, 10.099700643578316}, 
       {22, 10.022730579220484}, 
       {23, 10.249457521298435}, 
       {24, 10.374511769168592}, 
       {25, 10.397060592251734}, 
       {26, 10.465354533026561}, 
       {27, 10.456819079723905}, 
       {28, 10.573137171751515}, 
       {29, 10.646823454576364}, 
       {30, 10.634141109118728}}]}, 
    {{}, {}, {}, {}, {}, {}, {}, {}, {}, 
     {}, {}, {}, {}, {}, {}, {}, {}, {}, 
     {}, {}, {}, {}, {}, {}, {}, {}, {}, 
     {}, {}, {}}, {GrayLevel[0], 
     Dashing[{}], Thickness[0.0001], 
     PointSize[0.01], Polygon[
      {Offset[{-2.5, 2.5}, {1, 9.945}], 
       Offset[{2.5, 2.5}, {1, 9.945}], 
       Offset[{2.5, -2.5}, {1, 9.945}], 
       Offset[{-2.5, -2.5}, {1, 9.945}], 
       Offset[{-2.5, 2.5}, {1, 9.945}]}], 
     Polygon[{Offset[{-2.5, 2.5}, 
        {2, 9.7495}], Offset[{2.5, 2.5}, 
        {2, 9.7495}], Offset[{2.5, -2.5}, 
        {2, 9.7495}], Offset[{-2.5, -2.5}, 
        {2, 9.7495}], Offset[{-2.5, 2.5}, 
        {2, 9.7495}]}], Polygon[
      {Offset[{-2.5, 2.5}, {3, 9.70355}], 
       Offset[{2.5, 2.5}, {3, 9.70355}], 
       Offset[{2.5, -2.5}, {3, 9.70355}], 
       Offset[{-2.5, -2.5}, {3, 9.70355}], 
       Offset[{-2.5, 2.5}, {3, 9.70355}]}], 
     Polygon[{Offset[{-2.5, 2.5}, 
        {4, 9.899195}], Offset[{2.5, 2.5}, 
        {4, 9.899195}], Offset[{2.5, -2.5}, 
        {4, 9.899195}], Offset[
        {-2.5, -2.5}, {4, 9.899195}], 
       Offset[{-2.5, 2.5}, 
        {4, 9.899195}]}], Polygon[
      {Offset[{-2.5, 2.5}, 
        {5, 10.1252755}], Offset[
        {2.5, 2.5}, {5, 10.1252755}], 
       Offset[{2.5, -2.5}, 
        {5, 10.1252755}], Offset[
        {-2.5, -2.5}, {5, 10.1252755}], 
       Offset[{-2.5, 2.5}, 
        {5, 10.1252755}]}], 
     Polygon[{Offset[{-2.5, 2.5}, 
        {6, 10.130747950000002}], 
       Offset[{2.5, 2.5}, 
        {6, 10.130747950000002}], 
       Offset[{2.5, -2.5}, 
        {6, 10.130747950000002}], 
       Offset[{-2.5, -2.5}, 
        {6, 10.130747950000002}], 
       Offset[{-2.5, 2.5}, 
        {6, 10.130747950000002}]}], 
     Polygon[{Offset[{-2.5, 2.5}, 
        {7, 9.921673155000002}], 
       Offset[{2.5, 2.5}, 
        {7, 9.921673155000002}], 
       Offset[{2.5, -2.5}, 
        {7, 9.921673155000002}], 
       Offset[{-2.5, -2.5}, 
        {7, 9.921673155000002}], 
       Offset[{-2.5, 2.5}, 
        {7, 9.921673155000002}]}], 
     Polygon[{Offset[{-2.5, 2.5}, 
        {8, 10.075505839500003}], 
       Offset[{2.5, 2.5}, 
        {8, 10.075505839500003}], 
       Offset[{2.5, -2.5}, 
        {8, 10.075505839500003}], 
       Offset[{-2.5, -2.5}, 
        {8, 10.075505839500003}], 
       Offset[{-2.5, 2.5}, 
        {8, 10.075505839500003}]}], 
     Polygon[{Offset[{-2.5, 2.5}, 
        {9, 9.987955255550004}], 
       Offset[{2.5, 2.5}, 
        {9, 9.987955255550004}], 
       Offset[{2.5, -2.5}, 
        {9, 9.987955255550004}], 
       Offset[{-2.5, -2.5}, 
        {9, 9.987955255550004}], 
       Offset[{-2.5, 2.5}, 
        {9, 9.987955255550004}]}], 
     Polygon[{Offset[{-2.5, 2.5}, 
        {10, 10.023159729995005}], 
       Offset[{2.5, 2.5}, 
        {10, 10.023159729995005}], 
       Offset[{2.5, -2.5}, 
        {10, 10.023159729995005}], 
       Offset[{-2.5, -2.5}, 
        {10, 10.023159729995005}], 
       Offset[{-2.5, 2.5}, 
        {10, 10.023159729995005}]}], 
     Polygon[{Offset[{-2.5, 2.5}, 
        {11, 9.923843756995504}], 
       Offset[{2.5, 2.5}, 
        {11, 9.923843756995504}], 
       Offset[{2.5, -2.5}, 
        {11, 9.923843756995504}], 
       Offset[{-2.5, -2.5}, 
        {11, 9.923843756995504}], 
       Offset[{-2.5, 2.5}, 
        {11, 9.923843756995504}]}], 
     Polygon[{Offset[{-2.5, 2.5}, 
        {12, 10.078459381295954}], 
       Offset[{2.5, 2.5}, 
        {12, 10.078459381295954}], 
       Offset[{2.5, -2.5}, 
        {12, 10.078459381295954}], 
       Offset[{-2.5, -2.5}, 
        {12, 10.078459381295954}], 
       Offset[{-2.5, 2.5}, 
        {12, 10.078459381295954}]}], 
     Polygon[{Offset[{-2.5, 2.5}, 
        {13, 10.121613443166359}], 
       Offset[{2.5, 2.5}, 
        {13, 10.121613443166359}], 
       Offset[{2.5, -2.5}, 
        {13, 10.121613443166359}], 
       Offset[{-2.5, -2.5}, 
        {13, 10.121613443166359}], 
       Offset[{-2.5, 2.5}, 
        {13, 10.121613443166359}]}], 
     Polygon[{Offset[{-2.5, 2.5}, 
        {14, 10.049452098849722}], 
       Offset[{2.5, 2.5}, 
        {14, 10.049452098849722}], 
       Offset[{2.5, -2.5}, 
        {14, 10.049452098849722}], 
       Offset[{-2.5, -2.5}, 
        {14, 10.049452098849722}], 
       Offset[{-2.5, 2.5}, 
        {14, 10.049452098849722}]}], 
     Polygon[{Offset[{-2.5, 2.5}, 
        {15, 10.05250688896475}], 
       Offset[{2.5, 2.5}, 
        {15, 10.05250688896475}], 
       Offset[{2.5, -2.5}, 
        {15, 10.05250688896475}], 
       Offset[{-2.5, -2.5}, 
        {15, 10.05250688896475}], 
       Offset[{-2.5, 2.5}, 
        {15, 10.05250688896475}]}], 
     Polygon[{Offset[{-2.5, 2.5}, 
        {16, 9.984256200068275}], 
       Offset[{2.5, 2.5}, 
        {16, 9.984256200068275}], 
       Offset[{2.5, -2.5}, 
        {16, 9.984256200068275}], 
       Offset[{-2.5, -2.5}, 
        {16, 9.984256200068275}], 
       Offset[{-2.5, 2.5}, 
        {16, 9.984256200068275}]}], 
     Polygon[{Offset[{-2.5, 2.5}, 
        {17, 10.047830580061447}], 
       Offset[{2.5, 2.5}, 
        {17, 10.047830580061447}], 
       Offset[{2.5, -2.5}, 
        {17, 10.047830580061447}], 
       Offset[{-2.5, -2.5}, 
        {17, 10.047830580061447}], 
       Offset[{-2.5, 2.5}, 
        {17, 10.047830580061447}]}], 
     Polygon[{Offset[{-2.5, 2.5}, 
        {18, 10.074047522055304}], 
       Offset[{2.5, 2.5}, 
        {18, 10.074047522055304}], 
       Offset[{2.5, -2.5}, 
        {18, 10.074047522055304}], 
       Offset[{-2.5, -2.5}, 
        {18, 10.074047522055304}], 
       Offset[{-2.5, 2.5}, 
        {18, 10.074047522055304}]}], 
     Polygon[{Offset[{-2.5, 2.5}, 
        {19, 9.918642769849773}], 
       Offset[{2.5, 2.5}, 
        {19, 9.918642769849773}], 
       Offset[{2.5, -2.5}, 
        {19, 9.918642769849773}], 
       Offset[{-2.5, -2.5}, 
        {19, 9.918642769849773}], 
       Offset[{-2.5, 2.5}, 
        {19, 9.918642769849773}]}], 
     Polygon[{Offset[{-2.5, 2.5}, 
        {20, 10.010778492864796}], 
       Offset[{2.5, 2.5}, 
        {20, 10.010778492864796}], 
       Offset[{2.5, -2.5}, 
        {20, 10.010778492864796}], 
       Offset[{-2.5, -2.5}, 
        {20, 10.010778492864796}], 
       Offset[{-2.5, 2.5}, 
        {20, 10.010778492864796}]}], 
     Polygon[{Offset[{-2.5, 2.5}, 
        {21, 10.099700643578316}], 
       Offset[{2.5, 2.5}, 
        {21, 10.099700643578316}], 
       Offset[{2.5, -2.5}, 
        {21, 10.099700643578316}], 
       Offset[{-2.5, -2.5}, 
        {21, 10.099700643578316}], 
       Offset[{-2.5, 2.5}, 
        {21, 10.099700643578316}]}], 
     Polygon[{Offset[{-2.5, 2.5}, 
        {22, 10.022730579220484}], 
       Offset[{2.5, 2.5}, 
        {22, 10.022730579220484}], 
       Offset[{2.5, -2.5}, 
        {22, 10.022730579220484}], 
       Offset[{-2.5, -2.5}, 
        {22, 10.022730579220484}], 
       Offset[{-2.5, 2.5}, 
        {22, 10.022730579220484}]}], 
     Polygon[{Offset[{-2.5, 2.5}, 
        {23, 10.249457521298435}], 
       Offset[{2.5, 2.5}, 
        {23, 10.249457521298435}], 
       Offset[{2.5, -2.5}, 
        {23, 10.249457521298435}], 
       Offset[{-2.5, -2.5}, 
        {23, 10.249457521298435}], 
       Offset[{-2.5, 2.5}, 
        {23, 10.249457521298435}]}], 
     Polygon[{Offset[{-2.5, 2.5}, 
        {24, 10.374511769168592}], 
       Offset[{2.5, 2.5}, 
        {24, 10.374511769168592}], 
       Offset[{2.5, -2.5}, 
        {24, 10.374511769168592}], 
       Offset[{-2.5, -2.5}, 
        {24, 10.374511769168592}], 
       Offset[{-2.5, 2.5}, 
        {24, 10.374511769168592}]}], 
     Polygon[{Offset[{-2.5, 2.5}, 
        {25, 10.397060592251734}], 
       Offset[{2.5, 2.5}, 
        {25, 10.397060592251734}], 
       Offset[{2.5, -2.5}, 
        {25, 10.397060592251734}], 
       Offset[{-2.5, -2.5}, 
        {25, 10.397060592251734}], 
       Offset[{-2.5, 2.5}, 
        {25, 10.397060592251734}]}], 
     Polygon[{Offset[{-2.5, 2.5}, 
        {26, 10.465354533026561}], 
       Offset[{2.5, 2.5}, 
        {26, 10.465354533026561}], 
       Offset[{2.5, -2.5}, 
        {26, 10.465354533026561}], 
       Offset[{-2.5, -2.5}, 
        {26, 10.465354533026561}], 
       Offset[{-2.5, 2.5}, 
        {26, 10.465354533026561}]}], 
     Polygon[{Offset[{-2.5, 2.5}, 
        {27, 10.456819079723905}], 
       Offset[{2.5, 2.5}, 
        {27, 10.456819079723905}], 
       Offset[{2.5, -2.5}, 
        {27, 10.456819079723905}], 
       Offset[{-2.5, -2.5}, 
        {27, 10.456819079723905}], 
       Offset[{-2.5, 2.5}, 
        {27, 10.456819079723905}]}], 
     Polygon[{Offset[{-2.5, 2.5}, 
        {28, 10.573137171751515}], 
       Offset[{2.5, 2.5}, 
        {28, 10.573137171751515}], 
       Offset[{2.5, -2.5}, 
        {28, 10.573137171751515}], 
       Offset[{-2.5, -2.5}, 
        {28, 10.573137171751515}], 
       Offset[{-2.5, 2.5}, 
        {28, 10.573137171751515}]}], 
     Polygon[{Offset[{-2.5, 2.5}, 
        {29, 10.646823454576364}], 
       Offset[{2.5, 2.5}, 
        {29, 10.646823454576364}], 
       Offset[{2.5, -2.5}, 
        {29, 10.646823454576364}], 
       Offset[{-2.5, -2.5}, 
        {29, 10.646823454576364}], 
       Offset[{-2.5, 2.5}, 
        {29, 10.646823454576364}]}], 
     Polygon[{Offset[{-2.5, 2.5}, 
        {30, 10.634141109118728}], 
       Offset[{2.5, 2.5}, 
        {30, 10.634141109118728}], 
       Offset[{2.5, -2.5}, 
        {30, 10.634141109118728}], 
       Offset[{-2.5, -2.5}, 
        {30, 10.634141109118728}], 
       Offset[{-2.5, 2.5}, 
        {30, 10.634141109118728}]}]}}}}, 
 {PlotRange -> {9.254565409949528, 
    10.773392367724258}, PlotLabel -> 
   \"EWMA Control chart\", 
  Frame -> {True, True, False, False}, 
  FrameLabel -> {\"subgroup\", \"EWMA\"}, 
  GridLines -> {None, {10}}, 
  AspectRatio -> GoldenRatio^(-1), 
  Axes -> Automatic, AxesLabel -> None, 
  AxesOrigin -> Automatic, 
  AxesStyle -> Automatic, Background -> 
   Automatic, ColorOutput -> Automatic, 
  DefaultColor -> Automatic, Epilog -> {}, 
  Frame -> False, FrameLabel -> None, 
  FrameStyle -> Automatic, 
  FrameTicks -> Automatic, 
  GridLines -> None, ImageSize -> 
   Automatic, PlotLabel -> None, 
  PlotRange -> Automatic, PlotRegion -> 
   Automatic, Prolog -> {}, 
  RotateLabel -> True, Ticks -> Automatic, 
  DefaultFont :> $DefaultFont, 
  DisplayFunction :> $DisplayFunction, 
  FormatType :> $FormatType, 
  TextStyle :> $TextStyle}]\
\>", "\<\
-Graphics-\
\>"], "Output",
  CellLabel->"Out[37]=",
  CellTags->"The exponentially weighted moving-average EWMA Chart"]
}, Closed]],

Cell["Multivariable Control Chart", "Section",
  CellTags->"Multivariable Control Chart"],

Cell["Introduction", "Subsection",
  CellTags->"Multivariable Control Chart"],

Cell[TextData[{
  "Many processes have multiple quality characteristics and however they \
require multivariable monitoring methods. Hotelling's ",
  Cell[BoxData[
      \(TraditionalForm\`T\^2\)]],
  " is the most popular control chart for monitoring a multivariable process. \
It is applied to the case where the ",
  StyleBox["p",
    FontSlant->"Italic"],
  " quality characteristics are controlled jointly, and the probability \
distribution of the ",
  StyleBox["p",
    FontSlant->"Italic"],
  " qualify characteristics is the ",
  StyleBox["p",
    FontSlant->"Italic"],
  "-variable normal distribution. The multinormal distribution is usually \
denoted by N",
  Cell[BoxData[
      \(TraditionalForm\`\_p\)]],
  "(",
  StyleBox["\[Mu]",
    FontWeight->"Bold"],
  ", ",
  StyleBox["\[CapitalSigma]",
    FontWeight->"Bold"],
  "), where  ",
  StyleBox["p",
    FontSlant->"Italic"],
  " is the number of control variables, \[Mu]",
  StyleBox["'",
    FontWeight->"Bold"],
  "(",
  Cell[BoxData[
      \(TraditionalForm\`\[Mu]\_1\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\[Mu]\_2\)]],
  ", ..., ",
  Cell[BoxData[
      \(TraditionalForm\`\[Mu]\_p\)]],
  ") is the vector of in-control means (' = transpose) for each quality \
characteristic and ",
  StyleBox["\[Sum]",
    FontWeight->"Bold"],
  " is the covariance matrix.\nOne statistics derived of Multinormal and used \
to make Multivariable Control Chart is\n\t",
  Cell[BoxData[
      \(TraditionalForm\`\[Chi]\_0\%2\)]],
  " = n (",
  Cell[BoxData[
      FormBox[
        OverscriptBox[
          StyleBox["x",
            FontWeight->"Bold",
            FontSlant->"Plain"], "_"], TraditionalForm]]],
  " - ",
  StyleBox["\[Mu]",
    FontWeight->"Bold"],
  ") ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          StyleBox["\[CapitalSigma]",
            FontWeight->"Bold"], \(-1\)], TraditionalForm]]],
  " (",
  Cell[BoxData[
      FormBox[
        OverscriptBox[
          StyleBox["x",
            FontWeight->"Bold",
            FontSlant->"Plain"], "_"], TraditionalForm]]],
  " - ",
  StyleBox["\[Mu]",
    FontWeight->"Bold"],
  ") \t\nIn practice, it is necessary to estimate ",
  StyleBox["\[Mu]",
    FontWeight->"Bold"],
  " and ",
  StyleBox["\[CapitalSigma] ",
    FontWeight->"Bold"],
  " making a initial evaluation of process. This evaluation consists in \
taking ",
  StyleBox["m",
    FontSlant->"Italic"],
  " samples of size ",
  StyleBox["n",
    FontSlant->"Italic"],
  "  when the process is assumed to be in control, ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(x\_ijk\),
          FontSlant->"Italic"], TraditionalForm]]],
  "  is the ",
  StyleBox["i",
    FontSlant->"Italic"],
  "-th observation on the ",
  StyleBox["j",
    FontSlant->"Italic"],
  "-th quality characteristic in  ",
  StyleBox["k",
    FontSlant->"Italic"],
  "-th sample. The sample means , ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(x\&_\_jk\),
          FontSlant->"Italic"], TraditionalForm]]],
  ", and variances  ",
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["S", 
          StyleBox["jk",
            FontSlant->"Italic"], "2"], TraditionalForm]]],
  ",are calculated from each sample. That is \n",
  StyleBox[" \t", "InlineFormula"],
  Cell[BoxData[
      \(TraditionalForm\`x\&_\_jk\)], "InlineFormula",
    FontSlant->"Italic"],
  StyleBox[" = ", "InlineFormula"],
  Cell[BoxData[
      \(TraditionalForm\`1\/n\)], "InlineFormula"],
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Sum]\+\(i = 1\)\%n\), 
          StyleBox[\(x\_ijk\),
            FontSlant->"Italic"]}], TraditionalForm]], "InlineFormula"],
  StyleBox[", and ", "InlineFormula"],
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["S", 
          StyleBox["jk",
            FontSlant->"Italic"], "2"], TraditionalForm]], "InlineFormula"],
  StyleBox["= ", "InlineFormula"],
  Cell[BoxData[
      \(TraditionalForm\`1\/\(n - 1\)\)], "InlineFormula"],
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Sum]\+\(i = 1\)\%n\), 
          RowBox[{"(", 
            RowBox[{
              StyleBox[\(x\_ijk\),
                FontSlant->"Italic"], "-", 
              SubscriptBox[\(x\&_\), 
                StyleBox["jk",
                  FontSlant->"Italic"]]}], ")"}]}], TraditionalForm]], 
    "InlineFormula"],
  ", where ",
  StyleBox["j",
    FontSlant->"Italic"],
  " = 1, 2, ..., ",
  StyleBox["p,",
    FontSlant->"Italic"],
  " ",
  StyleBox["k",
    FontSlant->"Italic"],
  " = 1, 2,..., ",
  StyleBox["m",
    FontSlant->"Italic"],
  "\nThe covariance between ",
  StyleBox["j",
    FontSlant->"Italic"],
  " and ",
  StyleBox["h",
    FontSlant->"Italic"],
  " in ",
  StyleBox["k",
    FontSlant->"Italic"],
  " sample is\n \n\t",
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["S", 
          StyleBox["jkh",
            FontSlant->"Italic"], "2"], TraditionalForm]]],
  "= ",
  Cell[BoxData[
      \(TraditionalForm\`1\/\(n - 1\)\)]],
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Sum]\+\(i = 1\)\%n\), 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                SubscriptBox["x", 
                  StyleBox["ijk",
                    FontSlant->"Italic"]], "-", 
                SubscriptBox[\(x\&_\), 
                  StyleBox["jk",
                    FontSlant->"Italic"]]}], ")"}], 
            RowBox[{"(", 
              RowBox[{
                SubscriptBox["x", 
                  StyleBox["ijh",
                    FontSlant->"Italic"]], "-", 
                SubscriptBox[\(x\&_\), 
                  StyleBox["jh",
                    FontSlant->"Italic"]]}], ")"}]}]}], TraditionalForm]]],
  ", with ",
  StyleBox["j ",
    FontSlant->"Italic"],
  "\[NotEqual] ",
  StyleBox["h",
    FontSlant->"Italic"],
  "\n\nand the averages ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(x\&_\_jk\),
          FontSlant->"Italic"], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["S", 
          StyleBox["jk",
            FontSlant->"Italic"], "2"], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(S\_jhk\),
          FontSlant->"Italic"], TraditionalForm]]],
  " over all ",
  StyleBox["m",
    FontSlant->"Italic"],
  " samples are\n\n\t",
  Cell[BoxData[
      \(TraditionalForm\`\(x\&_\)\&_\_j\)], "InlineFormula",
    FontSlant->"Italic"],
  StyleBox[" = ", "InlineFormula"],
  Cell[BoxData[
      \(TraditionalForm\`1\/m\)], "InlineFormula"],
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Sum]\+\(k = 1\)\%m\), 
          StyleBox[\(x\&_\_jk\),
            FontSlant->"Italic"]}], TraditionalForm]], "InlineFormula"],
  ", with ",
  StyleBox["j",
    FontSlant->"Italic"],
  " = 1,2 ,..., ",
  StyleBox["p\n\t",
    FontSlant->"Italic"],
  Cell[BoxData[
      FormBox[
        OverscriptBox[
          SubsuperscriptBox["S", 
            StyleBox["j",
              FontSlant->"Italic"], "2"], "_"], TraditionalForm]], 
    "InlineFormula"],
  StyleBox[" = ", "InlineFormula"],
  Cell[BoxData[
      \(TraditionalForm\`1\/m\)], "InlineFormula"],
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Sum]\+\(k = 1\)\%m\), 
          SubsuperscriptBox["S", 
            StyleBox["jk",
              FontSlant->"Italic"], "2"]}], TraditionalForm]], 
    "InlineFormula"],
  ", with ",
  StyleBox["j",
    FontSlant->"Italic"],
  " = 1,2 ,..., ",
  StyleBox["p\n\t",
    FontSlant->"Italic"],
  Cell[BoxData[
      FormBox[
        SubscriptBox[\(S\&_\), 
          StyleBox["jh",
            FontSlant->"Italic"]], TraditionalForm]], "InlineFormula"],
  StyleBox[" = ", "InlineFormula"],
  Cell[BoxData[
      \(TraditionalForm\`1\/m\)], "InlineFormula"],
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Sum]\+\(k = 1\)\%m\), 
          StyleBox[\(S\_jhk\),
            FontSlant->"Italic"]}], TraditionalForm]], "InlineFormula"],
  ", with ",
  StyleBox["j ",
    FontSlant->"Italic"],
  "\[NotEqual] ",
  StyleBox["h",
    FontSlant->"Italic"],
  "\n\nThe {",
  Cell[BoxData[
      \(TraditionalForm\`\(x\&_\)\&_\_j\)]],
  "} are the elements of the vector ",
  Cell[BoxData[
      FormBox[
        OverscriptBox[
          FormBox[
            OverscriptBox[
              StyleBox["x",
                FontWeight->"Bold",
                FontSlant->"Plain"], "_"],
            "TraditionalForm"], "_"], TraditionalForm]]],
  " and the covariance matrices ",
  StyleBox["S",
    FontWeight->"Bold"],
  " is formed as\n\n\t",
  StyleBox["S = ", "InlineFormula"],
  Cell[BoxData[
      RowBox[{"(", GridBox[{
            {
              FormBox[\(\(S\_1\%2\)\&_\),
                "TraditionalForm"], 
              StyleBox[\(S\&_\_12\),
                FontSlant->"Italic"], 
              StyleBox[\(S\&_\_13\),
                FontSlant->"Italic"], "..", 
              StyleBox[\(S\&_\_\(1  P\)\),
                FontSlant->"Italic"]},
            {"\[Placeholder]", 
              FormBox[
                OverscriptBox[
                  SubsuperscriptBox["S", 
                    StyleBox["j",
                      FontSlant->"Italic"], "2"], "_"],
                "TraditionalForm"], 
              StyleBox[\(S\&_\_23\),
                FontSlant->"Italic"], "..", 
              StyleBox[\(S\&_\_\(2  P\)\),
                FontSlant->"Italic"]},
            {"\[Placeholder]", "\[Placeholder]", 
              FormBox[
                OverscriptBox[
                  SubsuperscriptBox["S", 
                    StyleBox["j",
                      FontSlant->"Italic"], "2"], "_"],
                "TraditionalForm"], "..", ".."},
            {"\[Placeholder]", "\[Placeholder]", "\[Placeholder]", "..", 
              FormBox[
                OverscriptBox[
                  SubsuperscriptBox["S", 
                    StyleBox["j",
                      FontSlant->"Italic"], "2"], "_"],
                "TraditionalForm"]}
            }], ")"}]], "InlineFormula"],
  "\n\t\n",
  StyleBox["S",
    FontWeight->"Bold"],
  " is an estimated of ",
  StyleBox["\[CapitalSigma] ",
    FontWeight->"Bold"],
  "when the process is in control. If we replace \[Mu] for  ",
  Cell[BoxData[
      FormBox[
        OverscriptBox[
          FormBox[
            OverscriptBox[
              StyleBox["x",
                FontWeight->"Bold",
                FontSlant->"Plain"], "_"],
            "TraditionalForm"], "_"], TraditionalForm]]],
  " and ",
  StyleBox["\[CapitalSigma]",
    FontWeight->"Bold"],
  " for ",
  StyleBox["S",
    FontWeight->"Bold"],
  " in ",
  Cell[BoxData[
      \(TraditionalForm\`\[Chi]\_0\%2\)]],
  " equation we obtain \n\n\t",
  Cell[BoxData[
      \(TraditionalForm\`T\^2\)]],
  "= n (",
  Cell[BoxData[
      FormBox[
        OverscriptBox[
          StyleBox["x",
            FontWeight->"Bold",
            FontSlant->"Plain"], "_"], TraditionalForm]]],
  " - ",
  Cell[BoxData[
      FormBox[
        OverscriptBox[
          OverscriptBox[
            StyleBox["x",
              FontWeight->"Bold",
              FontSlant->"Plain"], "_"], "_"], TraditionalForm]]],
  ")' ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          StyleBox["S",
            FontWeight->"Bold",
            FontSlant->"Plain"], \(-1\)], TraditionalForm]]],
  "(",
  Cell[BoxData[
      FormBox[
        OverscriptBox[
          StyleBox["x",
            FontWeight->"Bold",
            FontSlant->"Plain"], "_"], TraditionalForm]]],
  " - ",
  Cell[BoxData[
      FormBox[
        OverscriptBox[
          OverscriptBox[
            StyleBox["x",
              FontWeight->"Bold",
              FontSlant->"Plain"], "_"], "_"], TraditionalForm]]],
  ")\n\nAlso, we need to define the limits. In the initial study of a process \
these are:  \n\n\tUCL = ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          \(\(\(p\ \((m\  - 1)\) \((n - 1)\)\)\/\(m\ n - m - p + 1\)\) 
            F\_\(\(\[Alpha], \ p, m\ n - m - p + 1\)\(\ \)\)\),
          "Text"], TraditionalForm]]],
  ", LCL = 0\n\nThis procedure is usually called the Hotelling ",
  Cell[BoxData[
      \(TraditionalForm\`T\^2\)]],
  " Control Chart."
}], "Text",
  CellTags->"Multivariable Control Chart"],

Cell["Performing a T2 Chart  ", "Subsection",
  CellTags->"Multivariable Control Chart"],

Cell[TextData[{
  "We have a list of the way:  {",
  Cell[BoxData[
      FormBox[
        StyleBox[\(x\_ijk\),
          FontSlant->"Italic"], TraditionalForm]]],
  "},  ",
  StyleBox["i =",
    FontSlant->"Italic"],
  "1, 2, ..., ",
  StyleBox["n, j",
    FontSlant->"Italic"],
  " = 1, 2, ..., ",
  StyleBox["p,",
    FontSlant->"Italic"],
  " ",
  StyleBox["k",
    FontSlant->"Italic"],
  " = 1, 2,..., ",
  StyleBox["m, ",
    FontSlant->"Italic"],
  "where the ",
  StyleBox["i",
    FontSlant->"Italic"],
  "-th observation on the ",
  StyleBox["j",
    FontSlant->"Italic"],
  "-th quality characteristic in  ",
  StyleBox["k",
    FontSlant->"Italic"],
  "-th sample.",
  StyleBox[" We will need calculate ",
    FontWeight->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`x\&_\_jk\)],
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox[" , ",
    FontWeight->"Plain"],
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["S", 
          StyleBox["jk",
            FontSlant->"Italic"], "2"], TraditionalForm]],
    FontWeight->"Plain"],
  StyleBox[", ",
    FontWeight->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`\(x\&_\)\&_\_j\)],
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontWeight->"Plain"],
  Cell[BoxData[
      FormBox[
        OverscriptBox[
          SubsuperscriptBox["S", 
            StyleBox["j",
              FontSlant->"Italic"], "2"], "_"], TraditionalForm]],
    FontWeight->"Plain"],
  StyleBox[" , ",
    FontWeight->"Plain"],
  Cell[BoxData[
      FormBox[
        SubscriptBox[\(S\&_\), 
          StyleBox["jh",
            FontSlant->"Italic"]], TraditionalForm]],
    FontWeight->"Plain"],
  StyleBox[",",
    FontWeight->"Plain"],
  " ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          StyleBox["S",
            FontSlant->"Plain"], \(-1\)], TraditionalForm]]],
  "and finally  ",
  Cell[BoxData[
      RowBox[{\(T\_k\%2\), "=", 
        RowBox[{"n", " ", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                SubscriptBox[
                  FormBox[
                    OverscriptBox[
                      StyleBox["x",
                        FontWeight->"Bold",
                        FontSlant->"Plain"], "_"],
                    "TraditionalForm"], 
                  StyleBox["k",
                    FontSlant->"Italic"]], "-", 
                FormBox[
                  OverscriptBox[
                    OverscriptBox[
                      StyleBox["x",
                        FontWeight->"Bold",
                        FontSlant->"Plain"], "_"], "_"],
                  "TraditionalForm"]}], ")"}], "'"}], 
          RowBox[{
            FormBox[
              SuperscriptBox[
                StyleBox["S",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], \(-1\)],
              "TraditionalForm"], "(", 
            RowBox[{
              FormBox[
                SubscriptBox[
                  OverscriptBox[
                    StyleBox["x",
                      FontWeight->"Bold",
                      FontSlant->"Plain"], "_"], "k"],
                "TraditionalForm"], "-", 
              FormBox[
                OverscriptBox[
                  OverscriptBox[
                    StyleBox["x",
                      FontWeight->"Bold",
                      FontSlant->"Plain"], "_"], "_"],
                "TraditionalForm"]}], ")"}]}]}]]],
  " where ",
  StyleBox["n",
    FontSlant->"Italic"],
  " is the size of sample (or subgroup), ",
  Cell[BoxData[
      SubscriptBox[
        FormBox[
          OverscriptBox[
            StyleBox["x",
              FontWeight->"Bold",
              FontSlant->"Plain"], "_"],
          "TraditionalForm"], 
        StyleBox["k",
          FontSlant->"Italic"]]]],
  " = {",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          FormBox[\(x\&_\),
            "TraditionalForm"], \(1  k\)], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          FormBox[\(x\&_\),
            "TraditionalForm"], \(2  k\)], TraditionalForm]]],
  ", ..., ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          FormBox[\(x\&_\),
            "TraditionalForm"], 
          StyleBox["jk",
            FontSlant->"Italic"]], TraditionalForm]]],
  ", ..., ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          FormBox[\(x\&_\),
            "TraditionalForm"], 
          StyleBox["pk",
            FontSlant->"Italic"]], TraditionalForm]]],
  "}, ",
  Cell[BoxData[
      FormBox[
        FormBox[
          OverscriptBox[
            OverscriptBox[
              StyleBox["x",
                FontWeight->"Bold",
                FontSlant->"Plain"], "_"], "_"],
          "TraditionalForm"], TraditionalForm]]],
  " = {",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          FormBox[\(\(x\&_\)\&_\),
            "TraditionalForm"], "1"], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          FormBox[\(\(x\&_\)\&_\),
            "TraditionalForm"], "2"], TraditionalForm]]],
  ", ..., ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          FormBox[\(\(x\&_\)\&_\),
            "TraditionalForm"], 
          StyleBox["j",
            FontSlant->"Italic"]], TraditionalForm]]],
  ", ..., ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          FormBox[\(\(x\&_\)\&_\),
            "TraditionalForm"], 
          StyleBox["p",
            FontSlant->"Italic"]], TraditionalForm]]],
  "}, (') =Transpose, and ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          StyleBox["S",
            FontWeight->"Bold",
            FontSlant->"Plain"], \(-1\)], TraditionalForm]]],
  " is the inverse matrix of covariances ",
  StyleBox["S",
    FontWeight->"Bold"],
  ". Finally we will represent these values ",
  Cell[BoxData[
      \(T\_k\%2\)]],
  " comparing then with UCL for an \[Alpha] given ."
}], "Text",
  CellTags->"Multivariable Control Chart"],

Cell[TextData[{
  "T2Report[",
  StyleBox["data, alfa ",
    FontSlant->"Italic"],
  "] \t\tgives ",
  Cell[BoxData[
      \(T\_k\%2\)]],
  "values and the UCL for the alfa chosen\n\nT2Chart[",
  StyleBox[" data, alfa",
    FontSlant->"Italic"],
  "] \t\tplots ",
  Cell[BoxData[
      \(T\_k\%2\)]],
  " and UCL Upper Control Limit versus ",
  StyleBox["k",
    FontSlant->"Italic"],
  " for an \[Alpha] given "
}], "DefinitionBox",
  CellTags->"Multivariable Control Chart"],

Cell["Example", "Subsection",
  CellTags->"Multivariable Control Chart"],

Cell["\<\
We will generate a list that represent a multinormal population , 20 samples \
of size 10, means:{7,4,5,6} and covariances \
{{1,0.5,0.5,0.5},{0.5,1,0.5,0.5},{0.5,0.5,1,0.5},{0.5,0.5,0.5,1}}.  \
\>", "Text",
  CellTags->"Multivariable Control Chart"],

Cell[BoxData[
    \(Needs["\<Statistics`MultinormalDistribution`\>"]\)], "Input",
  CellLabel->"In[38]:=",
  CellTags->"Multivariable Control Chart"],

Cell[BoxData[
    \(\(ndist = 
        MultinormalDistribution[{7, 4, 5, 6}, 
          {{1, 0.5, 0.5, 0.5}, {0.5, 1, 0.5, 0.5}, {0.5, 0.5, 1, 0.5}, 
            {0.5, 0.5, 0.5, 1}}];\)\)], "Input",
  CellLabel->"In[39]:=",
  CellTags->"Multivariable Control Chart"],

Cell[BoxData[
    \(exampleList\  := Random[ndist]\)], "Input",
  CellLabel->"In[40]:=",
  CellTags->"Multivariable Control Chart"],

Cell[BoxData[
    \(\(data4\  = Transpose[Table[Transpose[Table[exampleList, {10}]], {20}]];
      \)\)], "Input",
  CellLabel->"In[41]:=",
  CellTags->"Multivariable Control Chart"],

Cell["\<\
Check the list to verify that has the way {p=variables, m = samples or \
subgroups, n = size each sample}\
\>", "Text",
  CellTags->"Multivariable Control Chart"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Dimensions[%]\)], "Input",
  CellLabel->"In[42]:=",
  CellTags->"Multivariable Control Chart"],

Cell[OutputFormData["\<\
{4, 20, 10}\
\>", "\<\
{4, 20, 10}\
\>"], "Output",
  CellLabel->"Out[42]=",
  CellTags->"Multivariable Control Chart"]
}, Closed]],

Cell[TextData[{
  "Now We will obtain ",
  Cell[BoxData[
      \(T\_k\%2\)]],
  " values and represents T2 control chart with alfa = 0.05."
}], "Text",
  CellTags->"Multivariable Control Chart"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?T2Report\)\)], "Input",
  CellLabel->"In[43]:=",
  CellTags->"Multivariable Control Chart"],

Cell["\<\
T2Report [list, alfa] give T2k values for a
   list of p variables, m samples and n size
   of each sample. The dimension of list
   must be {p,m,n}.\
\>", "Print",
  CellLabel->"From In[43]:=",
  CellTags->"Multivariable Control Chart"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(T2Report[data4, 0.05]\)], "Input",
  CellLabel->"In[44]:=",
  CellTags->"Multivariable Control Chart"],

Cell[OutputFormData["\<\
{\"{k,\\!\\(T\\_k\\%2\\)}\" -> 
  {{1, 0.7646787413350942}, 
   {2, 4.248882146385515}, 
   {3, 6.279221813791783}, 
   {4, 1.9947297658331182}, 
   {5, 4.382287920636364}, 
   {6, 7.490718805599382}, 
   {7, 2.7897887370333048}, 
   {8, 3.967565355509267}, 
   {9, 3.269992527727799}, 
   {10, 2.329345421259525}, 
   {11, 2.2946651402433456}, 
   {12, 0.9767292512023822}, 
   {13, 7.965836251772939}, 
   {14, 3.9539885394618564}, 
   {15, 2.6734506575395107}, 
   {16, 1.3239555454664371}, 
   {17, 6.48097821678016}, 
   {18, 1.6568330628490182}, 
   {19, 0.26029366339015214}, 
   {20, 7.990499560069702}}, 
 \"UCL\" -> 8.851595834524039, \"LCL\" -> 0}\
\>", "\<\
     2
{{k,T } -> 
     k
 
   {{1, 0.764679}, {2, 4.24888}, 
 
    {3, 6.27922}, {4, 1.99473}, 
 
    {5, 4.38229}, {6, 7.49072}, 
 
    {7, 2.78979}, {8, 3.96757}, 
 
    {9, 3.26999}, {10, 2.32935}, 
 
    {11, 2.29467}, {12, 0.976729}, 
 
    {13, 7.96584}, {14, 3.95399}, 
 
    {15, 2.67345}, {16, 1.32396}, 
 
    {17, 6.48098}, {18, 1.65683}, 
 
    {19, 0.260294}, {20, 7.9905}}, 
 
  UCL -> 8.8516, LCL -> 0}\
\>"], "Output",
  CellLabel->"Out[44]=",
  CellTags->"Multivariable Control Chart"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?T2Chart\)\)], "Input",
  CellLabel->"In[45]:=",
  CellTags->"Multivariable Control Chart"],

Cell["\<\
T2Chart[list, alfa] plots T2k values and UCL
   for a list of p variables, m samples and
   n size of each sample. The dimension of
   list must be {p,m,n}.\
\>", "Print",
  CellLabel->"From In[45]:=",
  CellTags->"Multivariable Control Chart"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(T2Chart[data4, 0.05]\)], "Input",
  CellLabel->"In[46]:=",
  CellTags->"Multivariable Control Chart"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.047619 0 0.0634743 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -6 -9 ]
[.5 -0.0125 6 0 ]
[.7381 -0.0125 -6 -9 ]
[.7381 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -26 -21.5625 ]
[.5 -0.0125 26 -9 ]
[-0.0125 .12695 -6 -4.5 ]
[-0.0125 .12695 0 4.5 ]
[-0.0125 .2539 -6 -4.5 ]
[-0.0125 .2539 0 4.5 ]
[-0.0125 .38085 -6 -4.5 ]
[-0.0125 .38085 0 4.5 ]
[-0.0125 .50779 -6 -4.5 ]
[-0.0125 .50779 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -18.5625 -8 ]
[-0.01875 .30902 -6 8 ]
[.5 .63053 -80 0 ]
[.5 .63053 80 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 .56185 m
1 .56185 L
s
0 g
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(10)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(15)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(20)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -87 -25.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(subgroup) show
111.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .12695 m
.00625 .12695 L
s
[(2)] -0.0125 .12695 1 0 Mshowa
0 .2539 m
.00625 .2539 L
s
[(4)] -0.0125 .2539 1 0 Mshowa
0 .38085 m
.00625 .38085 L
s
[(6)] -0.0125 .38085 1 0 Mshowa
0 .50779 m
.00625 .50779 L
s
[(8)] -0.0125 .50779 1 0 Mshowa
.125 Mabswid
0 .03174 m
.00375 .03174 L
s
0 .06347 m
.00375 .06347 L
s
0 .09521 m
.00375 .09521 L
s
0 .15869 m
.00375 .15869 L
s
0 .19042 m
.00375 .19042 L
s
0 .22216 m
.00375 .22216 L
s
0 .28563 m
.00375 .28563 L
s
0 .31737 m
.00375 .31737 L
s
0 .34911 m
.00375 .34911 L
s
0 .41258 m
.00375 .41258 L
s
0 .44432 m
.00375 .44432 L
s
0 .47606 m
.00375 .47606 L
s
0 .53953 m
.00375 .53953 L
s
0 .57127 m
.00375 .57127 L
s
0 .60301 m
.00375 .60301 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -81.2813 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
69 10.2813 translate
90 rotate
-69 -10.2813 translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T2) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -141 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T2) show
81.000 12.813 moveto
(Hotelling) show
141.000 12.813 moveto
(Control) show
189.000 12.813 moveto
(Chart) show
219.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.07143 .04854 m
.11905 .26969 L
.16667 .39857 L
.21429 .12661 L
.2619 .27816 L
.30952 .47547 L
.35714 .17708 L
.40476 .25184 L
.45238 .20756 L
.5 .14785 L
.54762 .14565 L
.59524 .062 L
.64286 .50563 L
.69048 .25098 L
.7381 .1697 L
.78571 .08404 L
.83333 .41138 L
.88095 .10517 L
.92857 .01652 L
.97619 .50719 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[46]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012Q000`40O003h00Oogoo/Goo003oOona
Ool00?mook5oo`00hGoo10007goo0`00ZGoo003UOol00`00Oomoo`0MOol00`00Oomoo`2XOol00>Eo
o`03001oogoo01eoo`03001oogoo0:Qoo`00aWoo1@001Goo0`0000Aoo`00001oo`800004Ool00000
0004Ool300000goo001oo`03Ool50005Ool40005Ool300000goo00000002Ool00`00Ool00002002V
Ool00<Ioo`03001oogoo009oo`05001oogooOol00003Ool20003Ool20003Ool01000Oomoo`000goo
0P001Goo00<007ooOol01Goo00<007ooOol00Woo00D007ooOomoo`0000=oo`8000=oo`8000=oo`03
001oogoo0:=oo`00bgoo00D007ooOomoo`0000Aoo`05001oogooOol00004Ool01000Oomoo`0017oo
00<007ooOol00goo00<007ooOol01Goo00<007ooOol00Woo00D007ooOomoo`0000Aoo`05001oogoo
Ool00004Ool00`00Oomoo`2SOol00<Moo`@000Aoo`03001oogoo009oo`05001oogooOol00004Ool0
1000Oomoo`0017oo00<007ooOol00goo00<007ooOol01Goo00<007ooOol00Woo00D007ooOomoo`00
00Aoo`05001oogooOol00004Ool00`00Oomoo`2SOol00<Ioo`03001oogoo009oo`05001oogooOol0
0004Ool01000Oomoogoo0P000goo00@007ooOol000=oo`8000Eoo`8000Ioo`03001oogoo009oo`05
001oogooOol00004Ool01000Oomoogoo0P000goo00<007ooOol0Xgoo0037Ool50002Ool20003Ool2
0003Ool00`00Ool000020004Ool300000goo00000003Ool2000017oo0000000017oo10000goo0P00
0goo0P000Woo0P0000Aoo`0000000:Ioo`00f7oo00<007ooOol0eGoo003HOol00`00Oomoo`3EOol0
0=Moo`800=Moo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol004Ioo`@004ao
o`@004Ioo`L000=oo`@0045oo`L000=oo`@0049oo`H000Aoo`@002=oo`00AGoo00<007ooOol00Woo
00<007ooOol0B7oo00<007ooOol00Woo00<007ooOol0AWoo00<007ooOol00goo00<007ooOol00Woo
00<007ooOol0@Goo00<007ooOol00goo00<007ooOol00Woo00<007ooOol0?goo00<007ooOol00Woo
00D007ooOomoo`0000Aoo`03001oogoo021oo`00AGoo00<007ooOol00Woo00<007ooOol0CGoo00<0
07ooOol0AWoo00<007ooOol00goo00<007ooOol00Woo00<007ooOol0@Goo00<007ooOol027oo00<0
07ooOol0@7oo00<007ooOol01Goo00<007ooOol00Woo00<007ooOol087oo0015Ool00`00Oomoo`02
Ool00`00Oomoo`1=Ool00`00Oomoo`16Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`11
Ool00`00Oomoo`08Ool00`00Oomoo`11Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`0P
Ool004Eoo`03001oogoo009oo`03001oogoo04eoo`03001oogoo04Ioo`03001oogoo00=oo`03001o
ogoo009oo`03001oogoo045oo`03001oogoo00Qoo`03001oogoo049oo`03001oogoo00=oo`03001o
ogoo009oo`03001oogoo021oo`00AGoo00<007ooOol00Woo00<007ooOol0BGoo1000BGoo00<007oo
Ool00goo00<007ooOol00Woo00<007ooOol0@Goo00<007ooOol017oo1000AWoo00<007ooOol00Woo
00<007ooOol00Woo00<007ooOol087oo0015Ool00`00Oomoo`02Ool00`00Oomoo`19Ool00`00Oomo
o`1:Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`11Ool00`00Oomoo`04Ool00`00Oomo
o`13Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol087oo0015Ool00`00Oomoo`02
Ool00`00Oomoo`19Ool00`00Oomoo`18Ool30005Ool00`00Oomoo`02Ool00`00Oomoo`0oOol30006
Ool00`00Oomoo`13Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol087oo0016Ool4
001<Ool50018Ool00`00Oomoo`04Ool40014Ool00`00Oomoo`04Ool50012Ool40005Ool4000SOol0
0?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00@Goo
o`00C`008Goo0011Ool00`00Oomoo`05Ool00`00Oomoo`0<Ool00`00Oomoo`0=Ool00`00Oomoo`0=
Ool00`00Oomoo`0=Ool00`00Oomoo`0=Ool00`00Oomoo`0=Ool00`00Oomoo`0=Ool00`00Oomoo`0=
Ool00`00Oomoo`0=Ool00`00Oomoo`0=Ool00`00Oomoo`0<Ool00`00Oomoo`0=Ool00`00Oomoo`0=
Ool00`00Oomoo`0=Ool00`00Oomoo`0=Ool00`00Oomoo`0=Ool00`00Oomoo`0=Ool00`00Oomoo`0=
Ool00`00Oomoo`0=Ool00`00Oomoo`0=Ool00`00Oomoo`0VOol0045oo`03001oogoo00Eoo`03001o
ogoo04aoo`03001oogoo04eoo`03001oogoo04aoo`03001oogoo04eoo`03001oogoo02Ioo`00@Goo
00<007ooOol0ogooKGoo0011Ool00`00Oomoo`3oOom]Ool0045oo`03001oogoo0?moofeoo`00@Goo
00<007ooOol0ogoo=7oo00<007ooOol0=Woo0011Ool00`00Oomoo`3oOolcOol2000hOol0045oo`03
001oogoo0?mooc=oo`8003Qoo`00@Goo00<007ooOol0ogoo<Woo00<007oo0000>7oo0011Ool00`00
Oomoo`3oOolbOol00`00Ool0000hOol0045oo`800?mooc9oo`04001oogoo000hOol0045oo`03001o
ogoo0?mooc5oo`05001oogooOol0000gOol0045oo`03001oogoo0?mooc1oo`03001oogoo009oo`03
001oogoo03Eoo`00@Goo00<007ooOol0ogoo<7oo00<007ooOol00Woo00<007ooOol0=Goo0011Ool0
0`00Oomoo`3oOol_Ool00`00Oomoo`03Ool00`00Oomoo`0eOol0045oo`03001oogoo01Aoo`03001o
ogoo0?mooaMoo`03001oogoo00Aoo`03001oogoo03Eoo`00@Goo00<007ooOol057oo00<007ooOol0
ogoo5goo00<007ooOol017oo00<007ooOol0=Goo0011Ool00`00Oomoo`0DOol00`00Oomoo`3oOolF
Ool00`00Oomoo`05Ool00`00Oomoo`0eOol0045oo`03001oogoo01Eoo`03001oogoo0?mooaEoo`03
001oogoo00Eoo`03001oogoo03Eoo`00@Goo00<007ooOol05Goo00<007ooOol0ogoo57oo00<007oo
Ool01Woo00<007ooOol0=Goo0011Ool2000FOol00`00Oomoo`2[Ool00`00Oomoo`1UOol00`00Oomo
o`06Ool00`00Oomoo`0eOol0045oo`03001oogoo01Eoo`03001oogoo0:Yoo`8006Ioo`03001oogoo
00Qoo`03001oogoo03Aoo`00@Goo00<007ooOol05Woo00<007ooOol0ZGoo0P00IWoo00<007ooOol0
27oo00<007ooOol0=7oo0011Ool00`00Oomoo`0FOol00`00Oomoo`2XOol00`00Ool0001UOol00`00
Oomoo`09Ool00`00Oomoo`0dOol0045oo`03001oogoo01Ioo`03001oogoo0:Qoo`03001oo`0006Eo
o`03001oogoo00Uoo`03001oogoo03Aoo`00@Goo00<007ooOol05Woo00<007ooOol0Ygoo00D007oo
Oomoo`0006=oo`03001oogoo00Yoo`03001oogoo03Aoo`00@Goo00<007ooOol05Woo00<007ooOol0
Ygoo00D007ooOomoo`00069oo`03001oogoo00]oo`03001oogoo03Aoo`00@Goo00<007ooOol05goo
00<007ooOol0YGoo00<007ooOol00Woo00<007ooOol0?7oo00<007ooOol08Goo00<007ooOol02goo
00<007ooOol0=7oo0011Ool00`00Oomoo`0GOol00`00Oomoo`2TOol00`00Oomoo`03Ool00`00Oomo
o`0kOol2000ROol00`00Oomoo`0<Ool00`00Oomoo`0dOol0045oo`03001oogoo01Moo`03001oogoo
0:Aoo`03001oogoo00=oo`03001oogoo03]oo`80029oo`03001oogoo00aoo`03001oogoo03Aoo`00
@Goo00<007ooOol05goo00<007ooOol0Xgoo00<007ooOol017oo00<007ooOol0>Woo00<007oo0000
8Goo00<007ooOol03Goo00<007ooOol0=7oo0011Ool2000HOol00`00Oomoo`2SOol00`00Oomoo`04
Ool00`00Oomoo`0jOol01000Oomoo`0087oo00<007ooOol03Woo00<007ooOol0<goo0011Ool00`00
Oomoo`0HOol00`00Oomoo`2QOol00`00Oomoo`05Ool00`00Oomoo`0iOol01@00Oomoogoo00007goo
00<007ooOol03goo00<007ooOol0<goo0011Ool00`00Oomoo`0HOol00`00Oomoo`2QOol00`00Oomo
o`05Ool00`00Oomoo`0iOol01@00Oomoogoo00007goo00<007ooOol03goo00<007ooOol0<goo0011
Ool00`00Oomoo`0HOol00`00Oomoo`2POol00`00Oomoo`07Ool00`00Oomoo`0gOol00`00Oomoo`02
Ool00`00Oomoo`0LOol00`00Oomoo`0@Ool00`00Oomoo`0cOol0045oo`03001oogoo01Qoo`03001o
ogoo09moo`03001oogoo00Qoo`03001oogoo03Moo`03001oogoo009oo`03001oogoo01aoo`03001o
ogoo011oo`03001oogoo03=oo`00@Goo00<007ooOol06Goo00<007ooOol0WWoo00<007ooOol027oo
00<007ooOol0=Woo00<007ooOol00goo00<007ooOol077oo00<007ooOol047oo00<007ooOol0<goo
0011Ool00`00Oomoo`0IOol00`00Oomoo`2MOol00`00Oomoo`09Ool00`00Oomoo`0eOol00`00Oomo
o`04Ool00`00Oomoo`0LOol00`00Oomoo`0@Ool00`00Oomoo`0cOol003Aoo`H000Moo`03001oogoo
01Uoo`03001oogoo09eoo`03001oogoo00Uoo`03001oogoo03Eoo`03001oogoo00Eoo`03001oogoo
01Yoo`03001oogoo015oo`03001oogoo03=oo`00=7oo00<007ooOol00Woo00<007ooOol01Goo00<0
07ooOol06Goo00<007ooOol0W7oo00<007ooOol02Woo00<007ooOol0=7oo00<007ooOol01Woo00<0
07ooOol06Woo00<007ooOol04Goo00<007ooOol0<goo000eOol00`00Oomoo`09Ool00`00Oomoo`0I
Ool00`00Oomoo`2LOol00`00Oomoo`0:Ool00`00Oomoo`0dOol00`00Oomoo`06Ool00`00Oomoo`0J
Ool00`00Oomoo`0AOol00`00Oomoo`0cOol003Ioo`03001oogoo00Qoo`03001oogoo01Yoo`03001o
ogoo02Moo`03001oogoo071oo`03001oogoo00]oo`03001oogoo03=oo`03001oogoo00Moo`03001o
ogoo01Yoo`03001oogoo019oo`03001oogoo039oo`00=goo00<007ooOol01goo0`006Woo00<007oo
Ool09goo00<007ooOol0Kgoo00<007ooOol037oo00<007ooOol0<goo00<007ooOol01goo00<007oo
Ool06Woo00<007ooOol04Woo00<007ooOol0<Woo000hOol00`00Oomoo`06Ool00`00Oomoo`0JOol0
0`00Oomoo`0WOol2001`Ool00`00Oomoo`0<Ool00`00Oomoo`0bOol00`00Oomoo`08Ool00`00Oomo
o`0JOol00`00Oomoo`0BOol00`00Oomoo`0bOol003Aoo`03001oogoo009oo`03001oogoo00Eoo`03
001oogoo01Yoo`03001oogoo02Ioo`03001oo`0006moo`03001oogoo00ioo`03001oogoo035oo`03
001oogoo00Qoo`03001oogoo01Uoo`03001oogoo01=oo`03001oogoo039oo`00=7oo00<007ooOol0
0Woo00<007ooOol01Goo00<007ooOol06Woo00<007ooOol09Woo00<007oo0000Kgoo00<007ooOol0
3Woo00<007ooOol0<7oo00<007ooOol02Woo00<007ooOol067oo00<007ooOol04goo00<007ooOol0
<Woo000eOol40008Ool00`00Oomoo`0KOol00`00Oomoo`0UOol01000Oomoo`00KGoo00<007ooOol0
3goo00<007ooOol0<7oo00<007ooOol02Woo00<007ooOol067oo00<007ooOol04goo00<007ooOol0
<Woo0011Ool00`00Oomoo`0KOol00`00Oomoo`0UOol01000Oomoo`00KGoo00<007ooOol03goo00<0
07ooOol0;goo00<007ooOol02goo00<007ooOol067oo00<007ooOol04goo00<007ooOol0<Woo0011
Ool00`00Oomoo`0KOol00`00Oomoo`0UOol01000Oomoo`00IGoo20004Woo00<007ooOol0;Woo00<0
07ooOol037oo00<007ooOol067oo00<007ooOol04goo00<007ooOol0<Woo0011Ool00`00Oomoo`0K
Ool00`00Oomoo`0UOol01@00Oomoogoo0000G7oo20006Woo00<007ooOol0;Woo00<007ooOol037oo
00<007ooOol067oo00<007ooOol04goo00<007ooOol0<Woo0011Ool00`00Oomoo`0LOol00`00Oomo
o`0SOol00`00Oomoo`02Ool00`00Oomoo`1IOol00`00Oomoo`0POol00`00Oomoo`0]Ool00`00Oomo
o`0=Ool00`00Oomoo`0GOol00`00Oomoo`0DOol00`00Oomoo`0bOol0045oo`03001oogoo01aoo`03
001oogoo02=oo`03001oogoo009oo`03001oogoo05Qoo`03001oogoo025oo`03001oogoo02eoo`03
001oogoo00ioo`03001oogoo01Ioo`03001oogoo01Eoo`03001oogoo035oo`00@Goo0P007Goo00<0
07ooOol08goo00<007ooOol00Woo00<007ooOol0Egoo00<007ooOol08Woo00<007ooOol0;7oo00<0
07ooOol03goo00<007ooOol05Woo00<007ooOol05Goo00<007ooOol0<Goo0011Ool00`00Oomoo`0L
Ool00`00Oomoo`0SOol00`00Oomoo`03Ool00`00Oomoo`1FOol00`00Oomoo`0SOol00`00Oomoo`0[
Ool00`00Oomoo`0?Ool00`00Oomoo`0FOol00`00Oomoo`0EOol00`00Oomoo`0aOol0045oo`03001o
ogoo01aoo`03001oogoo02=oo`03001oogoo00=oo`03001oogoo05Eoo`03001oogoo02Aoo`03001o
ogoo02Yoo`03001oogoo011oo`03001oogoo01Ioo`03001oogoo01Eoo`03001oogoo035oo`00@Goo
00<007ooOol07Goo00<007ooOol08Woo00<007ooOol00goo00<007ooOol0E7oo00<007ooOol09Goo
00<007ooOol0:Woo00<007ooOol047oo00<007ooOol05Woo00<007ooOol05Goo00<007ooOol0<Goo
0011Ool00`00Oomoo`0MOol00`00Oomoo`0QOol00`00Oomoo`05Ool00`00Oomoo`1BOol00`00Oomo
o`0VOol00`00Oomoo`0YOol00`00Oomoo`0AOol00`00Oomoo`0FOol00`00Oomoo`0EOol00`00Oomo
o`0aOol0045oo`03001oogoo01eoo`03001oogoo025oo`03001oogoo00Eoo`03001oogoo055oo`03
001oogoo02Moo`03001oogoo02Qoo`03001oogoo019oo`03001oogoo01Eoo`03001oogoo01Ioo`03
001oogoo035oo`00@Goo00<007ooOol07Goo00<007ooOol08Goo00<007ooOol01Goo00<007ooOol0
:7oo00<007ooOol09Goo00<007ooOol0:7oo00<007ooOol0:7oo00<007ooOol04goo00<007ooOol0
57oo00<007ooOol05Woo00<007ooOol0<Goo0011Ool00`00Oomoo`0NOol00`00Oomoo`0POol00`00
Oomoo`06Ool00`00Oomoo`0WOol2000VOol00`00Oomoo`0XOol00`00Oomoo`0WOol00`00Oomoo`0D
Ool00`00Oomoo`0DOol00`00Oomoo`0FOol00`00Oomoo`0aOol0045oo`03001oogoo01ioo`03001o
ogoo021oo`03001oogoo00Ioo`03001oogoo02Moo`8002Eoo`03001oogoo02Uoo`03001oogoo02Mo
o`03001oogoo01Aoo`03001oogoo01Aoo`03001oogoo01Ioo`03001oogoo035oo`00@Goo00<007oo
Ool07Woo00<007ooOol07goo00<007ooOol01goo00<007ooOol09goo00<007oo00008goo00<007oo
Ool0:Woo00<007ooOol09Woo00<007ooOol05Goo00<007ooOol057oo00<007ooOol05Woo00<007oo
Ool0<Goo0011Ool00`00Oomoo`0NOol00`00Oomoo`0OOol00`00Oomoo`08Ool00`00Oomoo`0UOol0
1@00Oomoogoo00008Goo00<007ooOol0;7oo00<007ooOol097oo00<007ooOol05Woo00<007ooOol0
57oo00<007ooOol05goo00<007ooOol0<7oo0011Ool2000OOol00`00Oomoo`0OOol00`00Oomoo`08
Ool00`00Oomoo`0UOol01@00Oomoogoo000087oo00<007ooOol0;Goo00<007ooOol097oo00<007oo
Ool05Woo00<007ooOol04goo00<007ooOol067oo00<007ooOol0<7oo0011Ool00`00Oomoo`0OOol0
0`00Oomoo`0NOol00`00Oomoo`08Ool00`00Oomoo`0UOol00`00Oomoo`02Ool00`00Oomoo`0LOol0
0`00Oomoo`0^Ool00`00Oomoo`0SOol00`00Oomoo`0GOol00`00Oomoo`0COol00`00Oomoo`0HOol0
0`00Oomoo`0`Ool0045oo`03001oogoo01moo`03001oogoo01ioo`03001oogoo00Uoo`03001oogoo
02Aoo`03001oogoo009oo`03001oogoo01aoo`03001oogoo02ioo`03001oogoo02=oo`03001oogoo
01Qoo`03001oogoo019oo`03001oogoo01Qoo`03001oogoo031oo`00@Goo00<007ooOol07goo00<0
07ooOol07Woo00<007ooOol02Goo00<007ooOol097oo00<007ooOol00goo00<007ooOol06Woo00<0
07ooOol0;goo00<007ooOol08Woo00<007ooOol06Goo00<007ooOol04Woo00<007ooOol067oo00<0
07ooOol0<7oo0011Ool00`00Oomoo`0OOol00`00Oomoo`0MOol00`00Oomoo`0:Ool00`00Oomoo`0T
Ool00`00Oomoo`04Ool00`00Oomoo`0HOol00`00Oomoo`0`Ool00`00Oomoo`0QOol00`00Oomoo`0J
Ool00`00Oomoo`0BOol00`00Oomoo`0HOol00`00Oomoo`0`Ool0045oo`03001oogoo01moo`03001o
ogoo01eoo`03001oogoo00Yoo`03001oogoo02=oo`03001oogoo00Eoo`03001oogoo01Moo`03001o
ogoo035oo`03001oogoo025oo`03001oogoo01Yoo`03001oogoo019oo`03001oogoo01Qoo`03001o
ogoo031oo`00@Goo00<007ooOol087oo00<007ooOol077oo00<007ooOol02goo00<007ooOol08Woo
00<007ooOol01Woo00<007ooOol05Goo00<007ooOol0<Woo00<007ooOol087oo00<007ooOol06goo
00<007ooOol04Woo00<007ooOol067oo00<007ooOol0<7oo0011Ool00`00Oomoo`0POol00`00Oomo
o`0LOol00`00Oomoo`0;Ool00`00Oomoo`0ROol00`00Oomoo`07Ool00`00Oomoo`0COol00`00Oomo
o`0cOol00`00Oomoo`0POol00`00Oomoo`0KOol00`00Oomoo`0AOol00`00Oomoo`0IOol00`00Oomo
o`0`Ool0045oo`03001oogoo021oo`03001oogoo01aoo`03001oogoo00]oo`03001oogoo029oo`03
001oogoo00Moo`03001oogoo019oo`03001oogoo03Eoo`03001oogoo01ioo`03001oogoo01aoo`03
001oogoo015oo`03001oogoo01Uoo`03001oogoo031oo`00@Goo00<007ooOol087oo00<007ooOol0
77oo00<007ooOol037oo00<007ooOol08Goo00<007ooOol027oo00<007ooOol047oo00<007ooOol0
=Woo00<007ooOol07Woo00<007ooOol07Goo00<007ooOol047oo00<007ooOol06Woo00<007ooOol0
;goo0011Ool2000ROol00`00Oomoo`0JOol00`00Oomoo`0=Ool00`00Oomoo`0QOol00`00Oomoo`09
Ool00`00Oomoo`0>Ool00`00Oomoo`0gOol00`00Oomoo`0MOol00`00Oomoo`0NOol00`00Oomoo`0@
Ool00`00Oomoo`0JOol00`00Oomoo`0_Ool0045oo`03001oogoo025oo`03001oogoo01Yoo`03001o
ogoo00eoo`03001oogoo021oo`03001oogoo00Yoo`03001oogoo00eoo`03001oogoo03Qoo`03001o
ogoo01aoo`03001oogoo01moo`03001oogoo011oo`03001oogoo01Yoo`03001oogoo02moo`00@Goo
00<007ooOol08Goo00<007ooOol06Woo00<007ooOol03Woo00<007ooOol07goo00<007ooOol02goo
00<007ooOol02goo00<007ooOol0>Goo00<007ooOol077oo00<007ooOol07goo00<007ooOol047oo
00<007ooOol06Woo00<007ooOol0;goo0011Ool00`00Oomoo`0QOol00`00Oomoo`0JOol00`00Oomo
o`0>Ool00`00Oomoo`0OOol00`00Oomoo`0<Ool00`00Oomoo`08Ool2000lOol00`00Oomoo`0KOol0
0`00Oomoo`0POol00`00Oomoo`0?Ool00`00Oomoo`0KOol00`00Oomoo`0_Ool0045oo`03001oogoo
025oo`03001oogoo01Yoo`03001oogoo00ioo`03001oogoo01moo`03001oogoo00aoo`03001oogoo
00Moo`03001oogoo03aoo`03001oogoo01]oo`03001oogoo021oo`03001oogoo00moo`03001oogoo
01]oo`03001oogoo02moo`00@Goo00<007ooOol08Woo00<007ooOol067oo00<007ooOol047oo00<0
07ooOol07Woo00<007ooOol03Goo00<007ooOol01Goo00<007ooOol0?Goo00<007ooOol06Woo00<0
07ooOol08Goo00<007ooOol03goo00<007ooOol06goo00<007ooOol0;goo0011Ool00`00Oomoo`0R
Ool00`00Oomoo`0HOol00`00Oomoo`0@Ool00`00Oomoo`0NOol00`00Oomoo`0=Ool00`00Oomoo`04
Ool00`00Oomoo`0nOol00`00Oomoo`0IOol00`00Oomoo`0SOol00`00Oomoo`0>Ool00`00Oomoo`0K
Ool00`00Oomoo`0_Ool003Ioo`@000Moo`03001oogoo029oo`03001oogoo01Qoo`03001oogoo011o
o`03001oogoo01eoo`03001oogoo00moo`03001oogoo009oo`03001oogoo03moo`03001oogoo01Uo
o`03001oogoo02=oo`03001oogoo00ioo`03001oogoo01]oo`03001oogoo02moo`00>7oo00<007oo
Ool01Woo00<007ooOol08Woo00<007ooOol067oo00<007ooOol04Goo00<007ooOol077oo00<007oo
Ool047oo00@007ooOol004=oo`03001oogoo01Moo`03001oogoo02Aoo`03001oogoo00ioo`03001o
ogoo01]oo`03001oogoo02moo`00>7oo00<007ooOol01Woo00<007ooOol08Woo00<007ooOol067oo
00<007ooOol04Goo00<007ooOol077oo00<007ooOol047oo00<007oo0000A7oo00<007ooOol05goo
00<007ooOol097oo00<007ooOol03Goo00<007ooOol07Goo00<007ooOol0;Woo000dOol60007Ool0
0`00Oomoo`0SOol00`00Oomoo`0GOol00`00Oomoo`0AOol00`00Oomoo`0LOol00`00Oomoo`0AOol0
0`00Oomoo`13Ool00`00Oomoo`0FOol00`00Oomoo`0UOol00`00Oomoo`0=Ool00`00Oomoo`0MOol0
0`00Oomoo`0^Ool003Eoo`04001oogoo0008Ool3000SOol00`00Oomoo`0FOol00`00Oomoo`0BOol0
0`00Oomoo`0LOol00`00Oomoo`1GOol00`00Oomoo`0FOol00`00Oomoo`0UOol00`00Oomoo`0=Ool0
0`00Oomoo`0MOol00`00Oomoo`0^Ool003Eoo`04001oogoo0008Ool00`00Oomoo`0SOol00`00Oomo
o`0FOol00`00Oomoo`0COol00`00Oomoo`0KOol00`00Oomoo`1GOol00`00Oomoo`0FOol00`00Oomo
o`0VOol00`00Oomoo`0<Ool00`00Oomoo`0MOol00`00Oomoo`0^Ool003Ioo`03001oo`0000Qoo`03
001oogoo02=oo`03001oogoo01Ioo`03001oogoo01=oo`03001oogoo01]oo`03001oogoo05Moo`03
001oogoo01Eoo`03001oogoo02Moo`03001oogoo00aoo`03001oogoo01eoo`03001oogoo02ioo`00
=Woo00<007oo000027oo00<007ooOol097oo00<007ooOol05Goo00<007ooOol04goo00<007ooOol0
6Woo00<007ooOol0F7oo00<007ooOol05Goo00<007ooOol09goo00<007ooOol037oo00<007ooOol0
7Goo00<007ooOol0;Woo000gOol20008Ool00`00Oomoo`0TOol00`00Oomoo`0EOol00`00Oomoo`0D
Ool00`00Oomoo`0IOol00`00Oomoo`1HOol00`00Oomoo`0EOol00`00Oomoo`0WOol00`00Oomoo`0<
Ool00`00Oomoo`0MOol00`00Oomoo`0^Ool0045oo`03001oogoo02Aoo`03001oogoo01Eoo`03001o
ogoo01Aoo`03001oogoo01Uoo`03001oogoo05Qoo`03001oogoo01Eoo`03001oogoo02Moo`03001o
ogoo00]oo`03001oogoo01ioo`03001oogoo02ioo`00@Goo00<007ooOol097oo00<007ooOol057oo
00<007ooOol05Goo00<007ooOol06Goo00<007ooOol0FGoo00<007ooOol057oo00<007ooOol09goo
00<007ooOol02goo00<007ooOol07Woo00<007ooOol0;Woo0011Ool00`00Oomoo`0UOol00`00Oomo
o`0COol00`00Oomoo`0FOol00`00Oomoo`0HOol00`00Oomoo`1IOol00`00Oomoo`0COol00`00Oomo
o`0XOol00`00Oomoo`0;Ool00`00Oomoo`0NOol00`00Oomoo`0^Ool0045oo`03001oogoo02Eoo`03
001oogoo01=oo`03001oogoo01Ioo`03001oogoo01Qoo`03001oogoo05Uoo`03001oogoo01=oo`03
001oogoo02Uoo`03001oogoo00Yoo`03001oogoo01moo`03001oogoo02eoo`00@Goo00<007ooOol0
9Goo00<007ooOol04goo00<007ooOol05Woo00<007ooOol05goo00<007ooOol0FWoo00<007ooOol0
4goo00<007ooOol0:Goo00<007ooOol02Woo00<007ooOol07goo00<007ooOol0;Goo0011Ool00`00
Oomoo`0VOol00`00Oomoo`0BOol00`00Oomoo`0FOol00`00Oomoo`0GOol00`00Oomoo`1JOol00`00
Oomoo`0COol00`00Oomoo`0YOol00`00Oomoo`0:Ool00`00Oomoo`0OOol00`00Oomoo`0]Ool002Ao
o`@001Uoo`8002Moo`03001oogoo019oo`03001oogoo01Moo`03001oogoo01Ioo`03001oogoo05Yo
o`03001oogoo01=oo`03001oogoo02Uoo`03001oogoo00Uoo`03001oogoo021oo`03001oogoo02eo
o`0097oo00<007ooOol017oo00<007ooOol04goo00<007ooOol09goo00<007ooOol047oo00<007oo
Ool067oo00<007ooOol05Woo00<007ooOol0FWoo00<007ooOol04goo00<007ooOol0:Goo00<007oo
Ool02Goo00<007ooOol087oo00<007ooOol0;Goo000TOol00`00Oomoo`04Ool00`00Oomoo`0COol0
0`00Oomoo`0WOol00`00Oomoo`0@Ool00`00Oomoo`0HOol00`00Oomoo`0FOol00`00Oomoo`1JOol0
0`00Oomoo`0BOol00`00Oomoo`0ZOol00`00Oomoo`09Ool00`00Oomoo`0POol00`00Oomoo`0]Ool0
02Aoo`P001Eoo`03001oogoo02Moo`03001oogoo011oo`03001oogoo01Qoo`03001oogoo01Ioo`03
001oogoo05Yoo`03001oogoo019oo`03001oogoo02Yoo`03001oogoo00Uoo`03001oogoo021oo`03
001oogoo02eoo`0097oo00<007ooOol017oo00<007ooOol04goo00<007ooOol0:7oo00<007ooOol0
3goo00<007ooOol06Goo00<007ooOol057oo00<007ooOol0G7oo00<007ooOol04Goo00<007ooOol0
:goo00<007ooOol027oo00<007ooOol087oo00<007ooOol0;Goo000TOol00`00Oomoo`04Ool00`00
Oomoo`0COol00`00Oomoo`0XOol00`00Oomoo`0?Ool00`00Oomoo`0IOol00`00Oomoo`0DOol00`00
Oomoo`1LOol00`00Oomoo`0AOol00`00Oomoo`0[Ool00`00Oomoo`08Ool00`00Oomoo`0POol00`00
Oomoo`0]Ool002Aoo`@001Uoo`03001oogoo02Qoo`03001oogoo00ioo`03001oogoo01Yoo`03001o
ogoo01Aoo`03001oogoo05aoo`03001oogoo015oo`03001oogoo02]oo`03001oogoo00Moo`03001o
ogoo025oo`03001oogoo02eoo`00@Goo00<007ooOol0:Goo00<007ooOol03Goo00<007ooOol06Woo
00<007ooOol057oo00<007ooOol0G7oo00<007ooOol047oo00<007ooOol0;7oo00<007ooOol01goo
00<007ooOol08Woo00<007ooOol0;7oo0011Ool00`00Oomoo`0YOol00`00Oomoo`0=Ool00`00Oomo
o`0KOol00`00Oomoo`0COol00`00Oomoo`1LOol00`00Oomoo`0@Ool00`00Oomoo`0/Ool00`00Oomo
o`07Ool00`00Oomoo`0ROol00`00Oomoo`0/Ool002Aoo`8000Aoo`8001Eoo`03001oogoo02Yoo`03
001oogoo00aoo`03001oogoo01]oo`03001oogoo01=oo`03001oogoo05aoo`03001oogoo011oo`03
001oogoo02aoo`03001oogoo00Moo`03001oogoo029oo`03001oogoo02aoo`008goo00<007ooOol0
0goo00<007oo00005Goo0P00:goo00<007ooOol037oo00<007ooOol06goo00<007ooOol04Woo00<0
07ooOol0GGoo00<007ooOol047oo00<007ooOol0;7oo00<007ooOol01goo00<007ooOol08Woo00<0
07ooOol0;7oo000SOol00`00Oomoo`02Ool01000Oomoo`005Goo00<007ooOol0:Woo00<007ooOol0
37oo00<007ooOol06goo00<007ooOol04Woo00<007ooOol0GGoo00<007ooOol047oo00<007ooOol0
;Goo00<007ooOol01Woo00<007ooOol08Woo00<007ooOol0;7oo000SOol01@00Oomoogoo00000goo
00<007ooOol04goo00<007ooOol0:goo00<007ooOol02Woo00<007ooOol07Goo00<007ooOol04Goo
00<007ooOol0GGoo00<007ooOol03goo00<007ooOol0;Woo00<007ooOol01Woo00<007ooOol08Woo
00<007ooOol0;7oo000SOol01000Oomoo`0017oo00<007ooOol04goo00<007ooOol0:goo00<007oo
Ool02Woo00<007ooOol07Goo00<007ooOol04Goo00<007ooOol0GWoo00<007ooOol03Woo00<007oo
Ool0;Woo00<007ooOol01Goo00<007ooOol08goo00<007ooOol0;7oo000TOol20004Ool2000EOol0
0`00Oomoo`0[Ool00`00Oomoo`0:Ool00`00Oomoo`0MOol00`00Oomoo`0AOol00`00Oomoo`1NOol0
0`00Oomoo`0>Ool00`00Oomoo`0^Ool00`00Oomoo`05Ool00`00Oomoo`0SOol00`00Oomoo`0/Ool0
045oo`03001oogoo02aoo`03001oogoo00Uoo`03001oogoo01eoo`03001oogoo015oo`03001oogoo
05ioo`03001oogoo00ioo`03001oogoo02ioo`03001oogoo00Eoo`03001oogoo02=oo`03001oogoo
02aoo`00@Goo00<007ooOol0;7oo00<007ooOol02Goo00<007ooOol07Woo00<007ooOol047oo00<0
07ooOol0GWoo00<007ooOol03Woo00<007ooOol0;Woo00<007ooOol01Goo00<007ooOol08goo00<0
07ooOol0;7oo0011Ool00`00Oomoo`0]Ool00`00Oomoo`08Ool00`00Oomoo`0NOol00`00Oomoo`0?
Ool00`00Oomoo`1OOol00`00Oomoo`0>Ool00`00Oomoo`0^Ool00`00Oomoo`05Ool00`00Oomoo`0T
Ool00`00Oomoo`0[Ool0045oo`03001oogoo02eoo`03001oogoo00Moo`03001oogoo01moo`03001o
ogoo00moo`03001oogoo05moo`03001oogoo00eoo`03001oogoo031oo`03001oogoo00Aoo`03001o
ogoo02Aoo`03001oogoo02]oo`00@Goo00<007ooOol0;Goo00<007ooOol01goo00<007ooOol07goo
00<007ooOol03goo00<007ooOol0Ggoo00<007ooOol03Goo00<007ooOol0<7oo00<007ooOol00goo
00<007ooOol09Goo00<007ooOol0:goo0011Ool00`00Oomoo`0^Ool00`00Oomoo`06Ool00`00Oomo
o`0POol00`00Oomoo`0>Ool00`00Oomoo`1OOol00`00Oomoo`0=Ool00`00Oomoo`0`Ool00`00Oomo
o`03Ool00`00Oomoo`0UOol00`00Oomoo`0[Ool0045oo`8002moo`03001oogoo00Ioo`03001oogoo
021oo`03001oogoo00ioo`03001oogoo05moo`03001oogoo00eoo`03001oogoo031oo`03001oogoo
00=oo`03001oogoo02Eoo`03001oogoo02]oo`00@Goo00<007ooOol0;Woo00<007ooOol01Woo00<0
07ooOol087oo00<007ooOol03Woo00<007ooOol0Ggoo00<007ooOol03Goo00<007ooOol0<7oo00<0
07ooOol00goo00<007ooOol09Goo00<007ooOol0:goo0011Ool00`00Oomoo`0_Ool00`00Oomoo`04
Ool00`00Oomoo`0QOol00`00Oomoo`0=Ool00`00Oomoo`1QOol00`00Oomoo`0;Ool00`00Oomoo`0a
Ool00`00Oomoo`03Ool00`00Oomoo`0UOol00`00Oomoo`0[Ool0045oo`03001oogoo02moo`03001o
ogoo00Aoo`03001oogoo029oo`03001oogoo00aoo`03001oogoo065oo`03001oogoo00]oo`03001o
ogoo039oo`03001oogoo009oo`03001oogoo02Eoo`03001oogoo02]oo`00@Goo00<007ooOol0<7oo
00<007ooOol00goo00<007ooOol08Woo00<007ooOol037oo00<007ooOol0HGoo00<007ooOol02goo
00<007ooOol0<Woo00<007ooOol00Woo00<007ooOol09Goo00<007ooOol0:goo0011Ool00`00Oomo
o`0`Ool00`00Oomoo`03Ool00`00Oomoo`0ROol00`00Oomoo`0<Ool00`00Oomoo`1QOol00`00Oomo
o`0;Ool00`00Oomoo`0bOol01@00Oomoogoo0000:7oo00<007ooOol0:goo0011Ool00`00Oomoo`0`
Ool00`00Oomoo`03Ool00`00Oomoo`0ROol00`00Oomoo`0<Ool00`00Oomoo`1QOol00`00Oomoo`0;
Ool00`00Oomoo`0bOol01@00Oomoogoo0000:7oo00<007ooOol0:goo000fOol40007Ool00`00Oomo
o`0aOol00`00Oomoo`02Ool00`00Oomoo`0SOol00`00Oomoo`0;Ool00`00Oomoo`1QOol00`00Oomo
o`0:Ool00`00Oomoo`0cOol01@00Oomoogoo0000:Goo00<007ooOol0:Woo000eOol00`00Oomoo`02
Ool00`00Oomoo`04Ool00`00Oomoo`0aOol01@00Oomoogoo00009Woo00<007ooOol02Woo00<007oo
Ool0HWoo00<007ooOol02Woo00<007ooOol0<goo00D007ooOomoo`0002Uoo`03001oogoo02Yoo`00
=Goo00<007ooOol00Woo00<007ooOol017oo00<007ooOol0<Goo00D007ooOomoo`0002Ioo`03001o
ogoo00Yoo`03001oogoo069oo`03001oogoo00Yoo`03001oogoo03=oo`05001oogooOol0000YOol0
0`00Oomoo`0ZOol003Eoo`8000=oo`03001oogoo00Aoo`<0039oo`04001oogoo000VOol00`00Oomo
o`0:Ool00`00Oomoo`1ROol00`00Oomoo`0:Ool00`00Oomoo`0dOol01000Oomoo`00:Goo00<007oo
Ool0:Woo000eOol00`00Ool000020007Ool00`00Oomoo`0bOol01000Oomoo`009Woo00<007ooOol0
2Woo00<007ooOol0Hgoo00<007ooOol02Goo00<007ooOol0=7oo00<007oo0000:Woo00<007ooOol0
:Woo000eOol00`00Oomoo`09Ool00`00Oomoo`0cOol00`00Ool0000WOol00`00Oomoo`09Ool00`00
Oomoo`1SOol00`00Oomoo`09Ool00`00Oomoo`0dOol00`00Ool0000ZOol00`00Oomoo`0ZOol003Io
o`03001oogoo00Qoo`03001oogoo03=oo`03001oo`0002Moo`03001oogoo00Uoo`03001oogoo06=o
o`03001oogoo00Qoo`03001oogoo03Eoo`03001oo`0002Yoo`03001oogoo02Yoo`00=goo00<007oo
Ool01goo00<007ooOol0<goo0P00:7oo00<007ooOol027oo00<007ooOol0I7oo00<007ooOol027oo
00<007ooOol0=Goo00<007oo0000:Woo00<007ooOol0:Woo000hOol30006Ool00`00Oomoo`0dOol0
0`00Oomoo`0VOol00`00Oomoo`08Ool00`00Oomoo`1TOol00`00Oomoo`08Ool00`00Oomoo`0eOol0
0`00Ool0000ZOol00`00Oomoo`0ZOol0045oo`03001oogoo03Aoo`03001oogoo02Moo`03001oogoo
00Moo`03001oogoo06Aoo`03001oogoo00Qoo`03001oogoo03Eoo`03001oo`0002Yoo`03001oogoo
02Yoo`00@Goo00<007ooOol0GWoo00<007ooOol01goo00<007ooOol0I7oo00<007ooOol027oo00<0
07ooOol0=Woo00<007ooOol0:Woo00<007ooOol0:Goo0011Ool00`00Oomoo`1NOol00`00Oomoo`07
Ool00`00Oomoo`1TOol00`00Oomoo`07Ool00`00Oomoo`0gOol00`00Oomoo`0ZOol00`00Oomoo`0Y
Ool0045oo`03001oogoo05ioo`03001oogoo00Moo`03001oogoo06Aoo`03001oogoo00Moo`03001o
ogoo03Moo`03001oogoo02Yoo`03001oogoo02Uoo`00@Goo00<007ooOol0Ggoo00<007ooOol01Woo
00<007ooOol0IGoo00<007ooOol01Woo00<007ooOol0=goo00<007ooOol0:Woo00<007ooOol0:Goo
0011Ool2001POol00`00Oomoo`05Ool00`00Oomoo`1VOol00`00Oomoo`06Ool00`00Oomoo`1TOol0
0`00Oomoo`0YOol0045oo`03001oogoo05moo`03001oogoo00Eoo`03001oogoo06Ioo`03001oogoo
00Ioo`03001oogoo06Aoo`03001oogoo02Uoo`00@Goo00<007ooOol0Ggoo00<007ooOol01Goo00<0
07ooOol0IWoo00<007ooOol01Goo00<007ooOol0IGoo00<007ooOol0:Goo0011Ool00`00Oomoo`1P
Ool00`00Oomoo`04Ool00`00Oomoo`1VOol00`00Oomoo`05Ool00`00Oomoo`1UOol00`00Oomoo`0Y
Ool0045oo`03001oogoo061oo`03001oogoo00Aoo`03001oogoo06Ioo`03001oogoo00Eoo`03001o
ogoo06Eoo`03001oogoo02Uoo`00@Goo00<007ooOol0H7oo00<007ooOol017oo00<007ooOol0IWoo
00<007ooOol01Goo00<007ooOol0IGoo00<007ooOol0:Goo0011Ool00`00Oomoo`1POol00`00Oomo
o`03Ool00`00Oomoo`1WOol00`00Oomoo`05Ool00`00Oomoo`1VOol00`00Oomoo`0XOol0045oo`03
001oogoo065oo`03001oogoo009oo`03001oogoo06Moo`03001oogoo00Eoo`03001oogoo06Ioo`03
001oogoo02Qoo`00@Goo00<007ooOol0HGoo00<007ooOol00Woo00<007ooOol0J7oo00<007ooOol0
0goo00<007ooOol0Igoo00<007ooOol0:7oo0011Ool00`00Oomoo`1QOol00`00Oomoo`02Ool00`00
Oomoo`1XOol00`00Oomoo`03Ool00`00Oomoo`1WOol00`00Oomoo`0XOol0045oo`80069oo`03001o
ogoo009oo`03001oogoo06Qoo`03001oogoo00=oo`03001oogoo06Moo`03001oogoo02Qoo`00@Goo
00<007ooOol0HWoo00D007ooOomoo`0006Yoo`03001oogoo00=oo`03001oogoo06Moo`03001oogoo
02Qoo`00@Goo00<007ooOol0HWoo00@007ooOol006]oo`03001oogoo00=oo`03001oogoo06Moo`03
001oogoo02Qoo`00@Goo00<007ooOol0HWoo00@007ooOol006]oo`03001oogoo009oo`03001oogoo
06Qoo`03001oogoo02Qoo`00@Goo00<007ooOol0HWoo00@007ooOol006]oo`03001oogoo009oo`03
001oogoo06Qoo`03001oogoo02Qoo`00@Goo00<007ooOol0Hgoo00<007oo0000Jgoo00<007ooOol0
0Woo00<007ooOol0J7oo00<007ooOol0:7oo0011Ool00`00Oomoo`1SOol00`00Ool0001[Ool00`00
Oomoo`02Ool00`00Oomoo`1YOol00`00Oomoo`0WOol0045oo`03001oogoo06=oo`03001oo`0006]o
o`03001oogoo009oo`03001oogoo06Uoo`03001oogoo02Moo`00@Goo00<007ooOol0Hgoo0P00KGoo
00@007ooOol006aoo`03001oogoo02Moo`00@Goo00<007ooOol0I7oo00<007ooOol0Jgoo00@007oo
Ool006aoo`03001oogoo02Moo`00@Goo00<007ooOol0I7oo00<007ooOol0Jgoo00@007ooOol006ao
o`03001oogoo02Moo`00@Goo0P00IGoo00<007ooOol0Jgoo00@007ooOol006aoo`03001oogoo02Mo
o`00@Goo00<007ooOol0dWoo00@007ooOol006aoo`03001oogoo02Moo`00@Goo00<007ooOol0dWoo
00@007ooOol006aoo`03001oogoo02Moo`00@Goo00<007ooOol0dWoo00<007oo0000KGoo00<007oo
Ool09goo0011Ool00`00Oomoo`3BOol00`00Ool0001]Ool00`00Oomoo`0WOol0045oo`03001oogoo
0=9oo`03001oo`0006ioo`03001oogoo02Ioo`00@Goo00<007ooOol0dgoo0P00KWoo00<007ooOol0
9Woo000eOol40008Ool00`00Oomoo`3COol2001^Ool00`00Oomoo`0VOol003Aoo`03001oogoo009o
o`03001oogoo00Eoo`03001oogoo0==oo`03001oogoo06eoo`03001oogoo02Ioo`00=7oo00<007oo
Ool00Woo00<007ooOol01Goo00<007ooOol0dgoo00<007ooOol0KGoo00<007ooOol09Woo000dOol0
0`00Oomoo`02Ool00`00Oomoo`05Ool00`00Oomoo`3COol00`00Oomoo`1]Ool00`00Oomoo`0VOol0
03Eoo`@000Qoo`<00?moofeoo`00=7oo00<007ooOol00Woo00<007ooOol01Goo00<007ooOol0ogoo
KGoo000dOol00`00Oomoo`02Ool00`00Oomoo`05Ool00`00Oomoo`3oOom]Ool003Aoo`03001oogoo
009oo`03001oogoo00Eoo`03001oogoo0?moofeoo`00=Goo100027oo00<007ooOol0ogooKGoo0011
Ool00`00Oomoo`3oOom]Ool0045oo`03001oogoo0?moofeoo`00@Goo00<007ooOol0ogooKGoo0011
Ool00`00Oomoo`3oOom]Ool0045oo`03001oogoo0?moofeoo`00@Goo0P00ogooKWoo0011Ool00`00
Oomoo`3oOom]Ool0045oo`03001oogoo0?moofeoo`00@Goo00<007ooOol0ogooKGoo0011Ool00`00
Oomoo`3oOom]Ool0045oo`03001oogoo0?moofeoo`00@Goo00<007ooOol0ogooKGoo0011Ool00`00
Oomoo`3oOom]Ool0045oo`0300003`0?0?l03d`03b5oo`00@Goo00<007ooOol0ogooKGoo0011Ool0
0`00Oomoo`3oOom]Ool0045oo`800?moofioo`00@Goo00<007ooOol0ogooKGoo0011Ool00`00Oomo
o`3oOom]Ool0045oo`03001oogoo0?moofeoo`00@Goo00<007ooOol0ogooKGoo0011Ool00`00Oomo
o`3oOom]Ool0045oo`03001oogoo0?moofeoo`00@Goo00<007ooOol0ogooKGoo0011Ool00`00Oomo
o`3oOom]Ool0045oo`03001oogoo0?moofeoo`00@Goo0P00ogooKWoo0011Ool00`00Oomoo`3oOom]
Ool0045oo`03001oogoo0?moofeoo`00@Goo00<007ooOol0ogooKGoo0011Ool00`00Oomoo`3oOom]
Ool0045oo`03001oogoo0?moofeoo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOona
Ool00?mook5oo`00ogoo/Goo003HOol4003DOol00=aoo`03001oogoo0=5oo`00g7oo00<007ooOol0
dGoo001eOol50003Ool6000<Ool30002Ool30003Ool40006Ool40004Ool40003Ool70002Ool70002
Ool70002Ool30002Ool30002Ool300000goo001oo`0=Ool40005Ool40003Ool30002Ool30004Ool4
0003Ool50005Ool40003Ool7000=Ool40003Ool30002Ool30003Ool50003Ool50006Ool4001DOol0
07Moo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00]oo`03001oogoo009oo`05001oogoo
Ool00004Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomoo`0017oo00<007ooOol00goo00<0
07ooOol01Woo00<007ooOol01Woo00<007ooOol017oo00<007ooOol00Woo00@007ooOol000=oo`80
00eoo`03001oogoo009oo`05001oogooOol00004Ool01@00Oomoogoo000017oo00<007ooOol00Woo
00<007ooOol00Woo00D007ooOomoo`0000Moo`03001oogoo009oo`03001oogoo00=oo`03001oogoo
00eoo`03001oogoo009oo`05001oogooOol00004Ool01@00Oomoogoo00000goo00<007ooOol00goo
00<007ooOol01Woo00<007ooOol00Woo00<007ooOol0DGoo001gOol00`00Oomoo`04Ool00`00Oomo
o`0?Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol00Woo00<007ooOol01Goo00<0
07ooOol027oo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol017oo00<007ooOol00Woo00@0
07ooOol000Aoo`03001oogoo00Yoo`03001oogoo00Moo`03001oogoo009oo`05001oogooOol00004
Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`02Ool00`00Oomoo`03
Ool00`00Oomoo`0<Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00<007oo
Ool00goo00<007ooOol01Woo00<007ooOol0EWoo001gOol00`00Oomoo`05Ool00`00Oomoo`0>Ool0
0`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol00Woo00<007ooOol01Goo1P001Goo00<0
07ooOol01Woo00<007ooOol01Woo00<007ooOol017oo00<007ooOol00Woo00@007ooOol000Aoo`03
001oogoo00Yoo`03001oogoo00Moo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`02
Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`0<
Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`02Ool40005Ool00`00Oomoo`06Ool00`00
Oomoo`1FOol007Aoo`04001oogoo0002Ool00`00Oomoo`03Ool00`00Oomoo`0=Ool60003Ool00`00
Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`05Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00
Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`04Ool20003Ool01000Oomoo`000goo0P0037oo00<0
07ooOol01goo00<007ooOol00Woo00@007ooOomoo`8000=oo`03001oogoo009oo`03001oogoo00Io
o`8000Ioo`03001oogoo009oo`03001oogoo00=oo`03001oogoo00aoo`03001oogoo00Moo`8000=o
o`05001oogooOol00003Ool00`00Oomoo`03Ool20007Ool00`00Oomoo`1FOol007Aoo`04001oogoo
0002Ool00`00Oomoo`04Ool00`00Oomoo`0<Ool00`00Oomoo`02Ool00`00Oomoo`02Ool40003Ool7
0004Ool40006Ool00`00Oomoo`06Ool00`00Oomoo`04Ool30005Ool2000017oo0000000017oo0`00
00=oo`0000002goo00<007ooOol00goo00<007ooOol00Woo10000goo0P0000Aoo`00000000=oo`L0
00=oo`800004Ool000000004Ool40006Ool00`00Oomoo`0<Ool00`00Oomoo`03Ool01P00Oomoogoo
001oo`<000Eoo`<000Eoo`800004Ool000000002Ool7001DOol007Aoo`04001oogoo0002Ool01000
Oomoo`0017oo00<007ooOol02goo00<007ooOol00Woo00<007ooOol02goo00<007ooOol047oo00<0
07ooOol01Woo00<007ooOol0:7oo00@007ooOomoo`8001Ioo`03001oogoo01Uoo`03001oogoo00eo
o`04001oogooOol20003Ool00`00Oomoo`0IOol00`00Oomoo`1FOol007Aoo`L0009oo`03001oogoo
009oo`03001oogoo00Yoo`<0009oo`<000aoo`03001oogoo011oo`03001oogoo00Ioo`03001oogoo
02Uoo`<00003Ool007oo01Eoo`03001oogoo01Uoo`03001oogoo00ioo`<00003Ool007oo009oo`03
001oogoo01Uoo`03001oogoo05Ioo`00OWoo1000<Woo0`001Woo0`0027oo00<007ooOol0EGoo0`00
5goo0P00M7oo0038Ool00`00Oomoo`3UOol00?mook5oo`00ogoo/Goo003oOonaOol00001\
\>"],
  ImageRangeCache->{{{135, 422}, {510.688, 333.75}} -> {-17.3746, 21.9486, 
  0.094556, 0.0709368}},
  CellTags->"Multivariable Control Chart"],

Cell[OutputFormData["\<\
{\"UCL\" -> 8.851595834524039}\
\>", "\<\
{UCL -> 8.8516}\
\>"], "Output",
  CellLabel->"Out[46]=",
  CellTags->"Multivariable Control Chart"]
}, Closed]],

Cell["References and Author", "Section",
  CellTags->"References"],

Cell[TextData[{
  "Douglas C. Montgomery (1996) Introduction to Statistical Quality Control, \
3rd ed., John Wiley&Sons.\nInternational Standards: ISO 7870:1993(E), ISO \
8258:1991(E)\nRoman E. Maeder. (1996), Programming in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ", 3rd ed., Addison-Wesley.\nWolfram,S.(1998),The Mathematica Book,4rd \
ed.,Wolfram Media/Cambridge University Press,Champaign,IL.\n\n",
  StyleBox[
  "Control Chart for Variables by Guillermo Sanchez, guillerm@gugu.usal.es\n\
August 1999",
    FontSize->18,
    FontWeight->"Plain"]
}], "Text",
  CellTags->"References"]
}, Open  ]]
},
FrontEndVersion->"4.0 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 695}},
ScreenStyleEnvironment->"Working",
WindowToolbars->{},
WindowSize->{874, 640},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
Magnification->1,
StyleDefinitions -> "HelpBrowser.nb"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Introduction (Loading the package)"->{
    Cell[1917, 59, 103, 1, 56, "Section",
      CellTags->"Introduction (Loading the package)"],
    Cell[2023, 62, 1669, 31, 177, "Text",
      CellTags->"Introduction (Loading the package)"],
    Cell[3695, 95, 92, 1, 39, "Subsection",
      CellTags->"Introduction (Loading the package)"],
    Cell[3790, 98, 264, 5, 42, "Text",
      CellTags->"Introduction (Loading the package)"],
    Cell[4057, 105, 149, 3, 29, "Input",
      CellTags->"Introduction (Loading the package)"],
    Cell[4209, 110, 358, 11, 25, "Text",
      CellTags->"Introduction (Loading the package)"]},
  "Mean and standard deviation chart"->{
    Cell[4570, 123, 151, 3, 56, "Section",
      PageBreakBelow->False,
      CellTags->"Mean and standard deviation chart"],
    Cell[4724, 128, 108, 2, 39, "Subsection",
      PageBreakBelow->False,
      CellTags->"Mean and standard deviation chart"],
    Cell[4835, 132, 517, 19, 25, "Text",
      PageBreakBelow->False,
      CellTags->"Mean and standard deviation chart"],
    Cell[5355, 153, 394, 10, 42, "Text",
      PageBreakBelow->False,
      CellTags->"Mean and standard deviation chart"],
    Cell[5752, 165, 332, 14, 25, "Text",
      PageBreakBelow->False,
      CellTags->"Mean and standard deviation chart"],
    Cell[6087, 181, 3422, 105, 71, "Text",
      PageBreakBelow->False,
      CellTags->"Mean and standard deviation chart"],
    Cell[9512, 288, 2074, 84, 63, "Text",
      PageBreakBelow->False,
      CellTags->"Mean and standard deviation chart"],
    Cell[11589, 374, 1116, 47, 25, "Text",
      PageBreakBelow->False,
      CellTags->"Mean and standard deviation chart"],
    Cell[12708, 423, 604, 23, 45, "Text",
      PageBreakBelow->False,
      CellTags->"Mean and standard deviation chart"],
    Cell[13315, 448, 923, 39, 36, "Text",
      PageBreakBelow->False,
      CellTags->"Mean and standard deviation chart"],
    Cell[14241, 489, 238, 7, 25, "Text",
      CellTags->"Mean and standard deviation chart"],
    Cell[14482, 498, 1477, 60, 42, "Text",
      CellTags->"Mean and standard deviation chart"],
    Cell[15962, 560, 132, 2, 39, "Subsection",
      CellTags->"Mean and standard deviation chart"],
    Cell[16097, 564, 190, 6, 25, "Text",
      CellTags->"Mean and standard deviation chart"],
    Cell[16290, 572, 571, 20, 110, "DefinitionBox",
      CellTags->"Mean and standard deviation chart"],
    Cell[16864, 594, 111, 1, 39, "Subsection",
      CellTags->"Mean and standard deviation chart"],
    Cell[16978, 597, 246, 9, 25, "Text",
      CellTags->"Mean and standard deviation chart"],
    Cell[17227, 608, 756, 29, 110, "DefinitionBox",
      CellTags->"Mean and standard deviation chart"],
    Cell[17986, 639, 105, 2, 39, "Subsection",
      PageBreakBelow->False,
      CellTags->"Mean and standard deviation chart"],
    Cell[18094, 643, 896, 15, 149, "Input",
      PageBreakBelow->False,
      CellTags->"Mean and standard deviation chart"],
    Cell[18993, 660, 98, 1, 35, "Subsubsection",
      CellTags->"Mean and standard deviation chart"],
    Cell[19116, 665, 122, 3, 29, "Input",
      CellTags->"Mean and standard deviation chart"],
    Cell[19241, 670, 182, 5, 35, "Print",
      CellTags->"Mean and standard deviation chart"],
    Cell[19460, 680, 124, 3, 25, "Input",
      CellTags->"Mean and standard deviation chart"],
    Cell[19587, 685, 1772, 80, 446, "Output",
      CellTags->"Mean and standard deviation chart"],
    Cell[21396, 770, 124, 3, 25, "Input",
      CellTags->"Mean and standard deviation chart"],
    Cell[21523, 775, 185, 5, 35, "Print",
      CellTags->"Mean and standard deviation chart"],
    Cell[21745, 785, 126, 3, 25, "Input",
      CellTags->"Mean and standard deviation chart"],
    Cell[21874, 790, 377, 16, 86, "Output",
      CellTags->"Mean and standard deviation chart"],
    Cell[22288, 811, 148, 3, 45, "Input",
      CellTags->"Mean and standard deviation chart"],
    Cell[22439, 816, 184, 5, 35, "Print",
      CellTags->"Mean and standard deviation chart"],
    Cell[22660, 826, 123, 3, 25, "Input",
      CellTags->"Mean and standard deviation chart"],
    Cell[22808, 833, 27606, 672, 184, 7327, 416, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"Mean and standard deviation chart"],
    Cell[50417, 1507, 28541, 704, 184, 7272, 436, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"Mean and standard deviation chart"],
    Cell[78973, 2214, 377, 16, 86, "Output",
      CellTags->"Mean and standard deviation chart"],
    Cell[79365, 2233, 120, 2, 35, "Subsubsection",
      PageBreakBelow->False,
      CellTags->"Mean and standard deviation chart"],
    Cell[79488, 2237, 123, 3, 25, "Text",
      CellTags->"Mean and standard deviation chart"],
    Cell[79636, 2244, 126, 3, 29, "Input",
      CellTags->"Mean and standard deviation chart"],
    Cell[79765, 2249, 191, 5, 35, "Print",
      CellTags->"Mean and standard deviation chart"],
    Cell[79993, 2259, 135, 3, 25, "Input",
      CellTags->"Mean and standard deviation chart"],
    Cell[80131, 2264, 377, 16, 86, "Output",
      CellTags->"Mean and standard deviation chart"],
    Cell[80545, 2285, 125, 3, 25, "Input",
      CellTags->"Mean and standard deviation chart"],
    Cell[80673, 2290, 189, 5, 35, "Print",
      CellTags->"Mean and standard deviation chart"],
    Cell[80899, 2300, 133, 3, 25, "Input",
      CellTags->"Mean and standard deviation chart"],
    Cell[81035, 2305, 1772, 80, 446, "Output",
      CellTags->"Mean and standard deviation chart"],
    Cell[82844, 2390, 124, 3, 25, "Input",
      CellTags->"Mean and standard deviation chart"],
    Cell[82971, 2395, 191, 5, 35, "Print",
      CellTags->"Mean and standard deviation chart"],
    Cell[83199, 2405, 132, 3, 25, "Input",
      CellTags->"Mean and standard deviation chart"],
    Cell[83356, 2412, 32506, 735, 184, 7365, 419, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"Mean and standard deviation chart"],
    Cell[115865, 3149, 36847, 790, 184, 7165, 418, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"Mean and standard deviation chart"],
    Cell[152727, 3942, 377, 16, 86, "Output",
      CellTags->"Mean and standard deviation chart"]},
  "Control Charts for Individual Measurements"->{
    Cell[153119, 3961, 169, 3, 42, "Section",
      PageBreakBelow->False,
      CellTags->"Control Charts for Individual Measurements"],
    Cell[153291, 3966, 117, 2, 39, "Subsection",
      PageBreakBelow->False,
      CellTags->"Control Charts for Individual Measurements"],
    Cell[153411, 3970, 572, 16, 42, "Text",
      PageBreakBelow->False,
      CellTags->"Control Charts for Individual Measurements"],
    Cell[153986, 3988, 348, 15, 25, "Text",
      PageBreakBelow->False,
      CellTags->"Control Charts for Individual Measurements"],
    Cell[154337, 4005, 710, 25, 25, "Text",
      PageBreakBelow->False,
      CellTags->"Control Charts for Individual Measurements"],
    Cell[155050, 4032, 259, 9, 25, "Text",
      PageBreakBelow->False,
      CellTags->"Control Charts for Individual Measurements"],
    Cell[155312, 4043, 3759, 110, 100, "Text",
      PageBreakBelow->False,
      CellTags->"Control Charts for Individual Measurements"],
    Cell[159074, 4155, 1357, 57, 56, "Text",
      PageBreakBelow->False,
      CellTags->"Control Charts for Individual Measurements"],
    Cell[160434, 4214, 149, 2, 38, "Subsection",
      PageBreakBelow->False,
      CellTags->"Control Charts for Individual Measurements"],
    Cell[160586, 4218, 199, 6, 22, "Text",
      CellTags->"Control Charts for Individual Measurements"],
    Cell[160788, 4226, 584, 20, 98, "DefinitionBox",
      CellTags->"Control Charts for Individual Measurements"],
    Cell[161375, 4248, 130, 2, 38, "Subsection",
      PageBreakBelow->False,
      CellTags->"Control Charts for Individual Measurements"],
    Cell[161508, 4252, 269, 9, 22, "Text",
      CellTags->"Control Charts for Individual Measurements"],
    Cell[161780, 4263, 886, 33, 98, "DefinitionBox",
      CellTags->"Control Charts for Individual Measurements"],
    Cell[162669, 4298, 87, 1, 38, "Subsection",
      CellTags->"Control Charts for Individual Measurements"],
    Cell[162759, 4301, 297, 6, 44, "Input",
      CellTags->"Control Charts for Individual Measurements"],
    Cell[163059, 4309, 100, 1, 33, "Subsubsection",
      CellTags->"Control Charts for Individual Measurements"],
    Cell[163184, 4314, 161, 3, 44, "Input",
      CellTags->"Control Charts for Individual Measurements"],
    Cell[163348, 4319, 195, 5, 35, "Print",
      CellTags->"Control Charts for Individual Measurements"],
    Cell[163580, 4329, 136, 3, 21, "Input",
      CellTags->"Control Charts for Individual Measurements"],
    Cell[163719, 4334, 401, 16, 86, "Output",
      CellTags->"Control Charts for Individual Measurements"],
    Cell[164157, 4355, 132, 3, 21, "Input",
      CellTags->"Control Charts for Individual Measurements"],
    Cell[164292, 4360, 192, 5, 35, "Print",
      CellTags->"Control Charts for Individual Measurements"],
    Cell[164521, 4370, 134, 3, 21, "Input",
      CellTags->"Control Charts for Individual Measurements"],
    Cell[164658, 4375, 1326, 61, 356, "Output",
      CellTags->"Control Charts for Individual Measurements"],
    Cell[166021, 4441, 158, 3, 39, "Input",
      CellTags->"Control Charts for Individual Measurements"],
    Cell[166182, 4446, 199, 5, 35, "Print",
      CellTags->"Control Charts for Individual Measurements"],
    Cell[166418, 4456, 133, 3, 21, "Input",
      CellTags->"Control Charts for Individual Measurements"],
    Cell[166576, 4463, 30737, 774, 184, 7991, 488, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"Control Charts for Individual Measurements"],
    Cell[197316, 5239, 27484, 688, 184, 7281, 433, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"Control Charts for Individual Measurements"],
    Cell[224815, 5930, 424, 17, 112, "Output",
      CellTags->"Control Charts for Individual Measurements"],
    Cell[225254, 5950, 97, 1, 27, "Subsubsection",
      CellTags->"Control Charts for Individual Measurements"],
    Cell[225354, 5953, 138, 3, 22, "Text",
      CellTags->"Control Charts for Individual Measurements"],
    Cell[225517, 5960, 163, 3, 44, "Input",
      CellTags->"Control Charts for Individual Measurements"],
    Cell[225683, 5965, 196, 5, 35, "Print",
      CellTags->"Control Charts for Individual Measurements"],
    Cell[225916, 5975, 142, 3, 21, "Input",
      CellTags->"Control Charts for Individual Measurements"],
    Cell[226061, 5980, 330, 14, 86, "Output",
      CellTags->"Control Charts for Individual Measurements"],
    Cell[226428, 5999, 134, 3, 21, "Input",
      CellTags->"Control Charts for Individual Measurements"],
    Cell[226565, 6004, 199, 5, 35, "Print",
      CellTags->"Control Charts for Individual Measurements"],
    Cell[226801, 6014, 149, 3, 21, "Input",
      CellTags->"Control Charts for Individual Measurements"],
    Cell[226953, 6019, 1226, 58, 356, "Output",
      CellTags->"Control Charts for Individual Measurements"],
    Cell[228216, 6082, 133, 3, 21, "Input",
      CellTags->"Control Charts for Individual Measurements"],
    Cell[228352, 6087, 209, 6, 50, "Print",
      CellTags->"Control Charts for Individual Measurements"],
    Cell[228598, 6098, 148, 3, 21, "Input",
      CellTags->"Control Charts for Individual Measurements"],
    Cell[228771, 6105, 30994, 770, 184, 7899, 479, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"Control Charts for Individual Measurements"],
    Cell[259768, 6877, 27723, 686, 184, 7214, 427, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"Control Charts for Individual Measurements"],
    Cell[287506, 7566, 330, 14, 86, "Output",
      CellTags->"Control Charts for Individual Measurements"]},
  "Cusum Chart"->{
    Cell[287851, 7583, 58, 1, 39, "Section",
      CellTags->"Cusum Chart"],
    Cell[287912, 7586, 86, 2, 38, "Subsection",
      PageBreakBelow->False,
      CellTags->"Cusum Chart"],
    Cell[288001, 7590, 4513, 154, 297, "Text",
      PageBreakBelow->False,
      CellTags->"Cusum Chart"],
    Cell[292517, 7746, 60, 1, 39, "Subsection",
      CellTags->"Cusum Chart"],
    Cell[292580, 7749, 886, 41, 76, "DefinitionBox",
      CellTags->"Cusum Chart"],
    Cell[293469, 7792, 56, 1, 39, "Subsection",
      CellTags->"Cusum Chart"],
    Cell[293528, 7795, 333, 7, 49, "Input",
      CellTags->"Cusum Chart"],
    Cell[293864, 7804, 169, 6, 25, "Text",
      CellTags->"Cusum Chart"],
    Cell[294058, 7814, 128, 3, 49, "Input",
      CellTags->"Cusum Chart"],
    Cell[294189, 7819, 156, 5, 35, "Print",
      CellTags->"Cusum Chart"],
    Cell[294382, 7829, 136, 4, 25, "Input",
      CellTags->"Cusum Chart"],
    Cell[294521, 7835, 3478, 124, 832, "Output",
      CellTags->"Cusum Chart"],
    Cell[298036, 7964, 100, 3, 25, "Input",
      CellTags->"Cusum Chart"],
    Cell[298139, 7969, 162, 5, 35, "Print",
      CellTags->"Cusum Chart"],
    Cell[298316, 7977, 184, 6, 21, "Text",
      CellTags->"Cusum Chart"],
    Cell[298525, 7987, 114, 3, 29, "Input",
      CellTags->"Cusum Chart"],
    Cell[298664, 7994, 28819, 737, 184, 8176, 476, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"Cusum Chart"],
    Cell[327486, 8733, 26397, 694, 184, 7721, 458, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"Cusum Chart"],
    Cell[353898, 9430, 1746, 55, 19, "Output",
      CellTags->"Cusum Chart"]},
  "The exponentially weighted moving-average EWMA Chart"->{
    Cell[355659, 9488, 140, 1, 42, "Section",
      CellTags->"The exponentially weighted moving-average EWMA Chart"],
    Cell[355802, 9491, 102, 1, 39, "Subsection",
      CellTags->"The exponentially weighted moving-average EWMA Chart"],
    Cell[355907, 9494, 2045, 68, 239, "Text",
      CellTags->"The exponentially weighted moving-average EWMA Chart"],
    Cell[357955, 9564, 100, 1, 39, "Subsection",
      CellTags->"The exponentially weighted moving-average EWMA Chart"],
    Cell[358058, 9567, 706, 30, 76, "DefinitionBox",
      CellTags->"The exponentially weighted moving-average EWMA Chart"],
    Cell[358767, 9599, 98, 1, 39, "Subsection",
      CellTags->"The exponentially weighted moving-average EWMA Chart"],
    Cell[358868, 9602, 374, 7, 49, "Input",
      CellTags->"The exponentially weighted moving-average EWMA Chart"],
    Cell[359245, 9611, 209, 6, 25, "Text",
      CellTags->"The exponentially weighted moving-average EWMA Chart"],
    Cell[359479, 9621, 141, 3, 29, "Input",
      CellTags->"The exponentially weighted moving-average EWMA Chart"],
    Cell[359623, 9626, 205, 5, 35, "Print",
      CellTags->"The exponentially weighted moving-average EWMA Chart"],
    Cell[359865, 9636, 164, 3, 25, "Input",
      CellTags->"The exponentially weighted moving-average EWMA Chart"],
    Cell[360032, 9641, 3207, 85, 445, "Output",
      CellTags->"The exponentially weighted moving-average EWMA Chart"],
    Cell[363276, 9731, 167, 3, 45, "Input",
      CellTags->"The exponentially weighted moving-average EWMA Chart"],
    Cell[363446, 9736, 197, 5, 35, "Print",
      CellTags->"The exponentially weighted moving-average EWMA Chart"],
    Cell[363680, 9746, 163, 3, 25, "Input",
      CellTags->"The exponentially weighted moving-average EWMA Chart"],
    Cell[363846, 9751, 40609, 1242, 184, 19057, 971, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"The exponentially weighted moving-average EWMA Chart"],
    Cell[404458, 10995, 31859, 999, 19, "Output",
      CellTags->"The exponentially weighted moving-average EWMA Chart"]},
  "Multivariable Control Chart"->{
    Cell[436332, 11997, 89, 1, 42, "Section",
      CellTags->"Multivariable Control Chart"],
    Cell[436424, 12000, 77, 1, 39, "Subsection",
      CellTags->"Multivariable Control Chart"],
    Cell[436504, 12003, 12163, 414, 868, "Text",
      CellTags->"Multivariable Control Chart"],
    Cell[448670, 12419, 88, 1, 39, "Subsection",
      CellTags->"Multivariable Control Chart"],
    Cell[448761, 12422, 6012, 216, 65, "Text",
      CellTags->"Multivariable Control Chart"],
    Cell[454776, 12640, 476, 18, 76, "DefinitionBox",
      CellTags->"Multivariable Control Chart"],
    Cell[455255, 12660, 72, 1, 39, "Subsection",
      CellTags->"Multivariable Control Chart"],
    Cell[455330, 12663, 260, 5, 42, "Text",
      CellTags->"Multivariable Control Chart"],
    Cell[455593, 12670, 149, 3, 29, "Input",
      CellTags->"Multivariable Control Chart"],
    Cell[455745, 12675, 266, 6, 49, "Input",
      CellTags->"Multivariable Control Chart"],
    Cell[456014, 12683, 131, 3, 29, "Input",
      CellTags->"Multivariable Control Chart"],
    Cell[456148, 12688, 182, 4, 29, "Input",
      CellTags->"Multivariable Control Chart"],
    Cell[456333, 12694, 172, 4, 25, "Text",
      CellTags->"Multivariable Control Chart"],
    Cell[456530, 12702, 114, 3, 29, "Input",
      CellTags->"Multivariable Control Chart"],
    Cell[456647, 12707, 144, 6, 19, "Output",
      CellTags->"Multivariable Control Chart"],
    Cell[456806, 12716, 194, 6, 21, "Text",
      CellTags->"Multivariable Control Chart"],
    Cell[457025, 12726, 114, 3, 29, "Input",
      CellTags->"Multivariable Control Chart"],
    Cell[457142, 12731, 247, 7, 64, "Print",
      CellTags->"Multivariable Control Chart"],
    Cell[457426, 12743, 122, 3, 25, "Input",
      CellTags->"Multivariable Control Chart"],
    Cell[457551, 12748, 1198, 51, 235, "Output",
      CellTags->"Multivariable Control Chart"],
    Cell[458786, 12804, 113, 3, 25, "Input",
      CellTags->"Multivariable Control Chart"],
    Cell[458902, 12809, 254, 7, 64, "Print",
      CellTags->"Multivariable Control Chart"],
    Cell[459193, 12821, 121, 3, 25, "Input",
      CellTags->"Multivariable Control Chart"],
    Cell[459317, 12826, 37165, 755, 184, 6235, 368, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"Multivariable Control Chart"],
    Cell[496485, 13583, 167, 6, 19, "Output",
      CellTags->"Multivariable Control Chart"]},
  "References"->{
    Cell[496667, 13592, 66, 1, 42, "Section",
      CellTags->"References"],
    Cell[496736, 13595, 604, 14, 185, "Text",
      CellTags->"References"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Introduction (Loading the package)", 498157, 13634},
  {"Mean and standard deviation chart", 498778, 13647},
  {"Control Charts for Individual Measurements", 504407, 13767},
  {"Cusum Chart", 510033, 13876},
  {"The exponentially weighted moving-average EWMA Chart", 511735, 13919},
  {"Multivariable Control Chart", 513852, 13955},
  {"References", 516281, 14007}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 175, 6, 150, "Title"],
Cell[1917, 59, 103, 1, 56, "Section",
  CellTags->"Introduction (Loading the package)"],
Cell[2023, 62, 1669, 31, 177, "Text",
  CellTags->"Introduction (Loading the package)"],
Cell[3695, 95, 92, 1, 39, "Subsection",
  CellTags->"Introduction (Loading the package)"],
Cell[3790, 98, 264, 5, 42, "Text",
  CellTags->"Introduction (Loading the package)"],
Cell[4057, 105, 149, 3, 29, "Input",
  CellTags->"Introduction (Loading the package)"],
Cell[4209, 110, 358, 11, 25, "Text",
  CellTags->"Introduction (Loading the package)"],
Cell[4570, 123, 151, 3, 56, "Section",
  PageBreakBelow->False,
  CellTags->"Mean and standard deviation chart"],
Cell[4724, 128, 108, 2, 39, "Subsection",
  PageBreakBelow->False,
  CellTags->"Mean and standard deviation chart"],
Cell[4835, 132, 517, 19, 25, "Text",
  PageBreakBelow->False,
  CellTags->"Mean and standard deviation chart"],
Cell[5355, 153, 394, 10, 42, "Text",
  PageBreakBelow->False,
  CellTags->"Mean and standard deviation chart"],
Cell[5752, 165, 332, 14, 25, "Text",
  PageBreakBelow->False,
  CellTags->"Mean and standard deviation chart"],
Cell[6087, 181, 3422, 105, 71, "Text",
  PageBreakBelow->False,
  CellTags->"Mean and standard deviation chart"],
Cell[9512, 288, 2074, 84, 63, "Text",
  PageBreakBelow->False,
  CellTags->"Mean and standard deviation chart"],
Cell[11589, 374, 1116, 47, 25, "Text",
  PageBreakBelow->False,
  CellTags->"Mean and standard deviation chart"],
Cell[12708, 423, 604, 23, 45, "Text",
  PageBreakBelow->False,
  CellTags->"Mean and standard deviation chart"],
Cell[13315, 448, 923, 39, 36, "Text",
  PageBreakBelow->False,
  CellTags->"Mean and standard deviation chart"],
Cell[14241, 489, 238, 7, 25, "Text",
  CellTags->"Mean and standard deviation chart"],
Cell[14482, 498, 1477, 60, 42, "Text",
  CellTags->"Mean and standard deviation chart"],
Cell[15962, 560, 132, 2, 39, "Subsection",
  CellTags->"Mean and standard deviation chart"],
Cell[16097, 564, 190, 6, 25, "Text",
  CellTags->"Mean and standard deviation chart"],
Cell[16290, 572, 571, 20, 110, "DefinitionBox",
  CellTags->"Mean and standard deviation chart"],
Cell[16864, 594, 111, 1, 39, "Subsection",
  CellTags->"Mean and standard deviation chart"],
Cell[16978, 597, 246, 9, 25, "Text",
  CellTags->"Mean and standard deviation chart"],
Cell[17227, 608, 756, 29, 110, "DefinitionBox",
  CellTags->"Mean and standard deviation chart"],
Cell[17986, 639, 105, 2, 39, "Subsection",
  PageBreakBelow->False,
  CellTags->"Mean and standard deviation chart"],
Cell[18094, 643, 896, 15, 149, "Input",
  PageBreakBelow->False,
  CellTags->"Mean and standard deviation chart"],
Cell[18993, 660, 98, 1, 35, "Subsubsection",
  CellTags->"Mean and standard deviation chart"],

Cell[CellGroupData[{
Cell[19116, 665, 122, 3, 29, "Input",
  CellTags->"Mean and standard deviation chart"],
Cell[19241, 670, 182, 5, 35, "Print",
  CellTags->"Mean and standard deviation chart"]
}, Closed]],

Cell[CellGroupData[{
Cell[19460, 680, 124, 3, 25, "Input",
  CellTags->"Mean and standard deviation chart"],
Cell[19587, 685, 1772, 80, 446, "Output",
  CellTags->"Mean and standard deviation chart"]
}, Closed]],

Cell[CellGroupData[{
Cell[21396, 770, 124, 3, 25, "Input",
  CellTags->"Mean and standard deviation chart"],
Cell[21523, 775, 185, 5, 35, "Print",
  CellTags->"Mean and standard deviation chart"]
}, Closed]],

Cell[CellGroupData[{
Cell[21745, 785, 126, 3, 25, "Input",
  CellTags->"Mean and standard deviation chart"],
Cell[21874, 790, 377, 16, 86, "Output",
  CellTags->"Mean and standard deviation chart"]
}, Closed]],

Cell[CellGroupData[{
Cell[22288, 811, 148, 3, 45, "Input",
  CellTags->"Mean and standard deviation chart"],
Cell[22439, 816, 184, 5, 35, "Print",
  CellTags->"Mean and standard deviation chart"]
}, Closed]],

Cell[CellGroupData[{
Cell[22660, 826, 123, 3, 25, "Input",
  CellTags->"Mean and standard deviation chart"],

Cell[CellGroupData[{
Cell[22808, 833, 27606, 672, 184, 7327, 416, "GraphicsData", 
"PostScript", "Graphics",
  CellTags->"Mean and standard deviation chart"],
Cell[50417, 1507, 28541, 704, 184, 7272, 436, "GraphicsData", 
"PostScript", "Graphics",
  CellTags->"Mean and standard deviation chart"]
}, Closed]],
Cell[78973, 2214, 377, 16, 86, "Output",
  CellTags->"Mean and standard deviation chart"]
}, Closed]],
Cell[79365, 2233, 120, 2, 35, "Subsubsection",
  PageBreakBelow->False,
  CellTags->"Mean and standard deviation chart"],
Cell[79488, 2237, 123, 3, 25, "Text",
  CellTags->"Mean and standard deviation chart"],

Cell[CellGroupData[{
Cell[79636, 2244, 126, 3, 29, "Input",
  CellTags->"Mean and standard deviation chart"],
Cell[79765, 2249, 191, 5, 35, "Print",
  CellTags->"Mean and standard deviation chart"]
}, Closed]],

Cell[CellGroupData[{
Cell[79993, 2259, 135, 3, 25, "Input",
  CellTags->"Mean and standard deviation chart"],
Cell[80131, 2264, 377, 16, 86, "Output",
  CellTags->"Mean and standard deviation chart"]
}, Closed]],

Cell[CellGroupData[{
Cell[80545, 2285, 125, 3, 25, "Input",
  CellTags->"Mean and standard deviation chart"],
Cell[80673, 2290, 189, 5, 35, "Print",
  CellTags->"Mean and standard deviation chart"]
}, Closed]],

Cell[CellGroupData[{
Cell[80899, 2300, 133, 3, 25, "Input",
  CellTags->"Mean and standard deviation chart"],
Cell[81035, 2305, 1772, 80, 446, "Output",
  CellTags->"Mean and standard deviation chart"]
}, Closed]],

Cell[CellGroupData[{
Cell[82844, 2390, 124, 3, 25, "Input",
  CellTags->"Mean and standard deviation chart"],
Cell[82971, 2395, 191, 5, 35, "Print",
  CellTags->"Mean and standard deviation chart"]
}, Closed]],

Cell[CellGroupData[{
Cell[83199, 2405, 132, 3, 25, "Input",
  CellTags->"Mean and standard deviation chart"],

Cell[CellGroupData[{
Cell[83356, 2412, 32506, 735, 184, 7365, 419, "GraphicsData", 
"PostScript", "Graphics",
  CellTags->"Mean and standard deviation chart"],
Cell[115865, 3149, 36847, 790, 184, 7165, 418, "GraphicsData", 
"PostScript", "Graphics",
  CellTags->"Mean and standard deviation chart"]
}, Closed]],
Cell[152727, 3942, 377, 16, 86, "Output",
  CellTags->"Mean and standard deviation chart"]
}, Closed]],
Cell[153119, 3961, 169, 3, 42, "Section",
  PageBreakBelow->False,
  CellTags->"Control Charts for Individual Measurements"],
Cell[153291, 3966, 117, 2, 39, "Subsection",
  PageBreakBelow->False,
  CellTags->"Control Charts for Individual Measurements"],
Cell[153411, 3970, 572, 16, 42, "Text",
  PageBreakBelow->False,
  CellTags->"Control Charts for Individual Measurements"],
Cell[153986, 3988, 348, 15, 25, "Text",
  PageBreakBelow->False,
  CellTags->"Control Charts for Individual Measurements"],
Cell[154337, 4005, 710, 25, 25, "Text",
  PageBreakBelow->False,
  CellTags->"Control Charts for Individual Measurements"],
Cell[155050, 4032, 259, 9, 25, "Text",
  PageBreakBelow->False,
  CellTags->"Control Charts for Individual Measurements"],
Cell[155312, 4043, 3759, 110, 100, "Text",
  PageBreakBelow->False,
  CellTags->"Control Charts for Individual Measurements"],
Cell[159074, 4155, 1357, 57, 56, "Text",
  PageBreakBelow->False,
  CellTags->"Control Charts for Individual Measurements"],
Cell[160434, 4214, 149, 2, 38, "Subsection",
  PageBreakBelow->False,
  CellTags->"Control Charts for Individual Measurements"],
Cell[160586, 4218, 199, 6, 22, "Text",
  CellTags->"Control Charts for Individual Measurements"],
Cell[160788, 4226, 584, 20, 98, "DefinitionBox",
  CellTags->"Control Charts for Individual Measurements"],
Cell[161375, 4248, 130, 2, 38, "Subsection",
  PageBreakBelow->False,
  CellTags->"Control Charts for Individual Measurements"],
Cell[161508, 4252, 269, 9, 22, "Text",
  CellTags->"Control Charts for Individual Measurements"],
Cell[161780, 4263, 886, 33, 98, "DefinitionBox",
  CellTags->"Control Charts for Individual Measurements"],
Cell[162669, 4298, 87, 1, 38, "Subsection",
  CellTags->"Control Charts for Individual Measurements"],
Cell[162759, 4301, 297, 6, 44, "Input",
  CellTags->"Control Charts for Individual Measurements"],
Cell[163059, 4309, 100, 1, 33, "Subsubsection",
  CellTags->"Control Charts for Individual Measurements"],

Cell[CellGroupData[{
Cell[163184, 4314, 161, 3, 44, "Input",
  CellTags->"Control Charts for Individual Measurements"],
Cell[163348, 4319, 195, 5, 35, "Print",
  CellTags->"Control Charts for Individual Measurements"]
}, Closed]],

Cell[CellGroupData[{
Cell[163580, 4329, 136, 3, 21, "Input",
  CellTags->"Control Charts for Individual Measurements"],
Cell[163719, 4334, 401, 16, 86, "Output",
  CellTags->"Control Charts for Individual Measurements"]
}, Closed]],

Cell[CellGroupData[{
Cell[164157, 4355, 132, 3, 21, "Input",
  CellTags->"Control Charts for Individual Measurements"],
Cell[164292, 4360, 192, 5, 35, "Print",
  CellTags->"Control Charts for Individual Measurements"]
}, Closed]],

Cell[CellGroupData[{
Cell[164521, 4370, 134, 3, 21, "Input",
  CellTags->"Control Charts for Individual Measurements"],
Cell[164658, 4375, 1326, 61, 356, "Output",
  CellTags->"Control Charts for Individual Measurements"]
}, Closed]],

Cell[CellGroupData[{
Cell[166021, 4441, 158, 3, 39, "Input",
  CellTags->"Control Charts for Individual Measurements"],
Cell[166182, 4446, 199, 5, 35, "Print",
  CellTags->"Control Charts for Individual Measurements"]
}, Closed]],

Cell[CellGroupData[{
Cell[166418, 4456, 133, 3, 21, "Input",
  CellTags->"Control Charts for Individual Measurements"],

Cell[CellGroupData[{
Cell[166576, 4463, 30737, 774, 184, 7991, 488, "GraphicsData", 
"PostScript", "Graphics",
  CellTags->"Control Charts for Individual Measurements"],
Cell[197316, 5239, 27484, 688, 184, 7281, 433, "GraphicsData", 
"PostScript", "Graphics",
  CellTags->"Control Charts for Individual Measurements"]
}, Closed]],
Cell[224815, 5930, 424, 17, 112, "Output",
  CellTags->"Control Charts for Individual Measurements"]
}, Closed]],
Cell[225254, 5950, 97, 1, 27, "Subsubsection",
  CellTags->"Control Charts for Individual Measurements"],
Cell[225354, 5953, 138, 3, 22, "Text",
  CellTags->"Control Charts for Individual Measurements"],

Cell[CellGroupData[{
Cell[225517, 5960, 163, 3, 44, "Input",
  CellTags->"Control Charts for Individual Measurements"],
Cell[225683, 5965, 196, 5, 35, "Print",
  CellTags->"Control Charts for Individual Measurements"]
}, Closed]],

Cell[CellGroupData[{
Cell[225916, 5975, 142, 3, 21, "Input",
  CellTags->"Control Charts for Individual Measurements"],
Cell[226061, 5980, 330, 14, 86, "Output",
  CellTags->"Control Charts for Individual Measurements"]
}, Closed]],

Cell[CellGroupData[{
Cell[226428, 5999, 134, 3, 21, "Input",
  CellTags->"Control Charts for Individual Measurements"],
Cell[226565, 6004, 199, 5, 35, "Print",
  CellTags->"Control Charts for Individual Measurements"]
}, Closed]],

Cell[CellGroupData[{
Cell[226801, 6014, 149, 3, 21, "Input",
  CellTags->"Control Charts for Individual Measurements"],
Cell[226953, 6019, 1226, 58, 356, "Output",
  CellTags->"Control Charts for Individual Measurements"]
}, Closed]],

Cell[CellGroupData[{
Cell[228216, 6082, 133, 3, 21, "Input",
  CellTags->"Control Charts for Individual Measurements"],
Cell[228352, 6087, 209, 6, 50, "Print",
  CellTags->"Control Charts for Individual Measurements"]
}, Closed]],

Cell[CellGroupData[{
Cell[228598, 6098, 148, 3, 21, "Input",
  CellTags->"Control Charts for Individual Measurements"],

Cell[CellGroupData[{
Cell[228771, 6105, 30994, 770, 184, 7899, 479, "GraphicsData", 
"PostScript", "Graphics",
  CellTags->"Control Charts for Individual Measurements"],
Cell[259768, 6877, 27723, 686, 184, 7214, 427, "GraphicsData", 
"PostScript", "Graphics",
  CellTags->"Control Charts for Individual Measurements"]
}, Closed]],
Cell[287506, 7566, 330, 14, 86, "Output",
  CellTags->"Control Charts for Individual Measurements"]
}, Closed]],
Cell[287851, 7583, 58, 1, 39, "Section",
  CellTags->"Cusum Chart"],
Cell[287912, 7586, 86, 2, 38, "Subsection",
  PageBreakBelow->False,
  CellTags->"Cusum Chart"],
Cell[288001, 7590, 4513, 154, 297, "Text",
  PageBreakBelow->False,
  CellTags->"Cusum Chart"],
Cell[292517, 7746, 60, 1, 39, "Subsection",
  CellTags->"Cusum Chart"],
Cell[292580, 7749, 886, 41, 76, "DefinitionBox",
  CellTags->"Cusum Chart"],
Cell[293469, 7792, 56, 1, 39, "Subsection",
  CellTags->"Cusum Chart"],
Cell[293528, 7795, 333, 7, 49, "Input",
  CellTags->"Cusum Chart"],
Cell[293864, 7804, 169, 6, 25, "Text",
  CellTags->"Cusum Chart"],

Cell[CellGroupData[{
Cell[294058, 7814, 128, 3, 49, "Input",
  CellTags->"Cusum Chart"],
Cell[294189, 7819, 156, 5, 35, "Print",
  CellTags->"Cusum Chart"]
}, Closed]],

Cell[CellGroupData[{
Cell[294382, 7829, 136, 4, 25, "Input",
  CellTags->"Cusum Chart"],
Cell[294521, 7835, 3478, 124, 832, "Output",
  CellTags->"Cusum Chart"]
}, Closed]],

Cell[CellGroupData[{
Cell[298036, 7964, 100, 3, 25, "Input",
  CellTags->"Cusum Chart"],
Cell[298139, 7969, 162, 5, 35, "Print",
  CellTags->"Cusum Chart"]
}, Closed]],
Cell[298316, 7977, 184, 6, 21, "Text",
  CellTags->"Cusum Chart"],

Cell[CellGroupData[{
Cell[298525, 7987, 114, 3, 29, "Input",
  CellTags->"Cusum Chart"],

Cell[CellGroupData[{
Cell[298664, 7994, 28819, 737, 184, 8176, 476, "GraphicsData", 
"PostScript", "Graphics",
  CellTags->"Cusum Chart"],
Cell[327486, 8733, 26397, 694, 184, 7721, 458, "GraphicsData", 
"PostScript", "Graphics",
  CellTags->"Cusum Chart"]
}, Closed]],
Cell[353898, 9430, 1746, 55, 19, "Output",
  CellTags->"Cusum Chart"]
}, Closed]],
Cell[355659, 9488, 140, 1, 42, "Section",
  CellTags->"The exponentially weighted moving-average EWMA Chart"],
Cell[355802, 9491, 102, 1, 39, "Subsection",
  CellTags->"The exponentially weighted moving-average EWMA Chart"],
Cell[355907, 9494, 2045, 68, 239, "Text",
  CellTags->"The exponentially weighted moving-average EWMA Chart"],
Cell[357955, 9564, 100, 1, 39, "Subsection",
  CellTags->"The exponentially weighted moving-average EWMA Chart"],
Cell[358058, 9567, 706, 30, 76, "DefinitionBox",
  CellTags->"The exponentially weighted moving-average EWMA Chart"],
Cell[358767, 9599, 98, 1, 39, "Subsection",
  CellTags->"The exponentially weighted moving-average EWMA Chart"],
Cell[358868, 9602, 374, 7, 49, "Input",
  CellTags->"The exponentially weighted moving-average EWMA Chart"],
Cell[359245, 9611, 209, 6, 25, "Text",
  CellTags->"The exponentially weighted moving-average EWMA Chart"],

Cell[CellGroupData[{
Cell[359479, 9621, 141, 3, 29, "Input",
  CellTags->"The exponentially weighted moving-average EWMA Chart"],
Cell[359623, 9626, 205, 5, 35, "Print",
  CellTags->"The exponentially weighted moving-average EWMA Chart"]
}, Closed]],

Cell[CellGroupData[{
Cell[359865, 9636, 164, 3, 25, "Input",
  CellTags->"The exponentially weighted moving-average EWMA Chart"],
Cell[360032, 9641, 3207, 85, 445, "Output",
  CellTags->"The exponentially weighted moving-average EWMA Chart"]
}, Closed]],

Cell[CellGroupData[{
Cell[363276, 9731, 167, 3, 45, "Input",
  CellTags->"The exponentially weighted moving-average EWMA Chart"],
Cell[363446, 9736, 197, 5, 35, "Print",
  CellTags->"The exponentially weighted moving-average EWMA Chart"]
}, Closed]],

Cell[CellGroupData[{
Cell[363680, 9746, 163, 3, 25, "Input",
  CellTags->"The exponentially weighted moving-average EWMA Chart"],
Cell[363846, 9751, 40609, 1242, 184, 19057, 971, "GraphicsData", 
"PostScript", "Graphics",
  CellTags->"The exponentially weighted moving-average EWMA Chart"],
Cell[404458, 10995, 31859, 999, 19, "Output",
  CellTags->"The exponentially weighted moving-average EWMA Chart"]
}, Closed]],
Cell[436332, 11997, 89, 1, 42, "Section",
  CellTags->"Multivariable Control Chart"],
Cell[436424, 12000, 77, 1, 39, "Subsection",
  CellTags->"Multivariable Control Chart"],
Cell[436504, 12003, 12163, 414, 868, "Text",
  CellTags->"Multivariable Control Chart"],
Cell[448670, 12419, 88, 1, 39, "Subsection",
  CellTags->"Multivariable Control Chart"],
Cell[448761, 12422, 6012, 216, 65, "Text",
  CellTags->"Multivariable Control Chart"],
Cell[454776, 12640, 476, 18, 76, "DefinitionBox",
  CellTags->"Multivariable Control Chart"],
Cell[455255, 12660, 72, 1, 39, "Subsection",
  CellTags->"Multivariable Control Chart"],
Cell[455330, 12663, 260, 5, 42, "Text",
  CellTags->"Multivariable Control Chart"],
Cell[455593, 12670, 149, 3, 29, "Input",
  CellTags->"Multivariable Control Chart"],
Cell[455745, 12675, 266, 6, 49, "Input",
  CellTags->"Multivariable Control Chart"],
Cell[456014, 12683, 131, 3, 29, "Input",
  CellTags->"Multivariable Control Chart"],
Cell[456148, 12688, 182, 4, 29, "Input",
  CellTags->"Multivariable Control Chart"],
Cell[456333, 12694, 172, 4, 25, "Text",
  CellTags->"Multivariable Control Chart"],

Cell[CellGroupData[{
Cell[456530, 12702, 114, 3, 29, "Input",
  CellTags->"Multivariable Control Chart"],
Cell[456647, 12707, 144, 6, 19, "Output",
  CellTags->"Multivariable Control Chart"]
}, Closed]],
Cell[456806, 12716, 194, 6, 21, "Text",
  CellTags->"Multivariable Control Chart"],

Cell[CellGroupData[{
Cell[457025, 12726, 114, 3, 29, "Input",
  CellTags->"Multivariable Control Chart"],
Cell[457142, 12731, 247, 7, 64, "Print",
  CellTags->"Multivariable Control Chart"]
}, Closed]],

Cell[CellGroupData[{
Cell[457426, 12743, 122, 3, 25, "Input",
  CellTags->"Multivariable Control Chart"],
Cell[457551, 12748, 1198, 51, 235, "Output",
  CellTags->"Multivariable Control Chart"]
}, Closed]],

Cell[CellGroupData[{
Cell[458786, 12804, 113, 3, 25, "Input",
  CellTags->"Multivariable Control Chart"],
Cell[458902, 12809, 254, 7, 64, "Print",
  CellTags->"Multivariable Control Chart"]
}, Closed]],

Cell[CellGroupData[{
Cell[459193, 12821, 121, 3, 25, "Input",
  CellTags->"Multivariable Control Chart"],
Cell[459317, 12826, 37165, 755, 184, 6235, 368, "GraphicsData", 
"PostScript", "Graphics",
  CellTags->"Multivariable Control Chart"],
Cell[496485, 13583, 167, 6, 19, "Output",
  CellTags->"Multivariable Control Chart"]
}, Closed]],
Cell[496667, 13592, 66, 1, 42, "Section",
  CellTags->"References"],
Cell[496736, 13595, 604, 14, 185, "Text",
  CellTags->"References"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

